/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qgenericargument_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGenericArgument_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGenericArgument >()))
        return -1;

    QGenericArgument* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QGenericArgument(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QGenericArgument", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QGenericArgument(QGenericArgument)
    // 1: QGenericArgument(const char*,const void*)
    if (numArgs == 0) {
        overloadId = 1; // QGenericArgument(const char*,const void*)
    } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QGenericArgument(const char*,const void*)
        } else if (Shiboken::Converter< void * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QGenericArgument(const char*,const void*)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[0])) {
        overloadId = 0; // QGenericArgument(QGenericArgument)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGenericArgument_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGenericArgument(QGenericArgument)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QGenericArgument cppArg0 = Shiboken::Converter<QGenericArgument >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QGenericArgument(QGenericArgument)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGenericArgument(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QGenericArgument(const char*,const void*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aName");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "aName";
                        else if (Shiboken::Converter< const char * >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QGenericArgument_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "aData");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "aData";
                        else if (Shiboken::Converter< void * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGenericArgument_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QGenericArgument(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                const char * cppArg0 = pyargs[0] ? Shiboken::Converter<const char * >::toCpp(pyargs[0]) : 0;
                void * cppArg1 = pyargs[1] ? Shiboken::Converter<void * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QGenericArgument(const char*,const void*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGenericArgument(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGenericArgument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGenericArgument_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGenericArgument_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QGenericArgument", "str = None, void = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QGenericArgument", overloads);
        return -1;
}

static PyObject* Sbk_QGenericArgumentFunc_data(PyObject* self)
{
    QGenericArgument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGenericArgument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // data()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                void * cppResult = const_cast<const QGenericArgument*>(cppSelf)->data();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< void * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGenericArgumentFunc_name(PyObject* self)
{
    QGenericArgument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGenericArgument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const char * cppResult = const_cast<const QGenericArgument*>(cppSelf)->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< const char * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QGenericArgument___copy__(PyObject *self)
{
        QGenericArgument* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QGenericArgument*>::toCpp(self);
        PyObject* pyResult = 0;
        QGenericArgument* copy = new QGenericArgument(*cppSelf);
        pyResult = Shiboken::Converter<QGenericArgument*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QGenericArgument_methods[] = {
    {"data", (PyCFunction)Sbk_QGenericArgumentFunc_data, METH_NOARGS},
    {"name", (PyCFunction)Sbk_QGenericArgumentFunc_name, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QGenericArgument___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGenericArgument_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QGenericArgument",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGenericArgument_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGenericArgument_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QGenericArgument(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QGENERICARGUMENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGenericArgument_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGenericArgument_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGenericArgument_Type, &Shiboken::callCppDestructor<QGenericArgument >);
    Py_INCREF((PyObject*)&Sbk_QGenericArgument_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QGenericArgument_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QGenericArgument_Type, "QGenericArgument");
    PyModule_AddObject(module, "QGenericArgument",
        ((PyObject*)&Sbk_QGenericArgument_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QGenericArgument >("QGenericArgument");
    Shiboken::TypeResolver::createObjectTypeResolver<QGenericArgument >("QGenericArgument*");
    Shiboken::TypeResolver::createValueTypeResolver<QGenericArgument >(typeid(QGenericArgument).name());
    qRegisterMetaType< ::QGenericArgument* >("QGenericArgument*");
}

