/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtcore_python.h"

#include "qprocess_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qprocess.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QProcessWrapper::QProcessWrapper(QObject * parent) : QProcess(parent) {
    // ... middle
}

bool QProcessWrapper::atEnd() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "atEnd"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QProcess::atEnd();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.atEnd", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::bytesAvailable() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "bytesAvailable"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QProcess::bytesAvailable();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.bytesAvailable", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::bytesToWrite() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "bytesToWrite"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QProcess::bytesToWrite();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.bytesToWrite", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

bool QProcessWrapper::canReadLine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "canReadLine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QProcess::canReadLine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.canReadLine", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QProcessWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QProcessWrapper::close()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "close"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QProcess::close();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QProcessWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QProcessWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QProcessWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QProcessWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QProcessWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QProcessWrapper::isSequential() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isSequential"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QProcess::isSequential();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.isSequential", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QProcessWrapper::open(QFlags<QIODevice::OpenModeFlag> mode)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "open"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIODevice::open(mode);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::toPython(mode)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.open", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::pos() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "pos"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIODevice::pos();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.pos", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::readData(char * data, qint64 maxlen)
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "readData"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QProcess::readData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        maxlen
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Begin code injection

    qint64 cppResult;
    if (!PyString_Check(pyResult)) {
        cppResult = -1;
    } else {
        cppResult = PyString_GET_SIZE((PyObject*)pyResult);
        qstrncpy(data, PyString_AS_STRING((PyObject*)pyResult), cppResult + 1);
    }

    // End of code injection

    return cppResult;
}

qint64 QProcessWrapper::readLineData(char * data, qint64 maxlen)
{

    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "readLineData"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QIODevice::readLineData(data, maxlen);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        maxlen
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Begin code injection

    qint64 cppResult;
    if (!PyString_Check(pyResult)) {
        cppResult = -1;
    } else {
        cppResult = PyString_GET_SIZE((PyObject*)pyResult);
        qstrncpy(data, PyString_AS_STRING((PyObject*)pyResult), cppResult + 1);
    }

    // End of code injection

    return cppResult;
}

bool QProcessWrapper::reset()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIODevice::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.reset", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QProcessWrapper::seek(qint64 pos)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "seek"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIODevice::seek(pos);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        pos
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.seek", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QProcessWrapper::setupChildProcess()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setupChildProcess"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QProcess::setupChildProcess();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

qint64 QProcessWrapper::size() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "size"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIODevice::size();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.size", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

void QProcessWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QProcessWrapper::waitForBytesWritten(int msecs)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "waitForBytesWritten"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QProcess::waitForBytesWritten(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.waitForBytesWritten", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QProcessWrapper::waitForReadyRead(int msecs)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "waitForReadyRead"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QProcess::waitForReadyRead(msecs);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        msecs
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.waitForReadyRead", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

qint64 QProcessWrapper::writeData(const char * data, qint64 len)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return qint64(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "writeData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QProcess::writeData(data, len);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NL)",
        Shiboken::Converter< const char * >::toPython(data),
        len
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QProcess.writeData", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QProcessWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QProcessWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QProcess::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QProcessWrapper::~QProcessWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QProcess_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QProcess >()))
        return -1;

    QProcessWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QProcess", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QProcess(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QProcess(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QProcess(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcess_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QProcess_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QProcess(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QProcessWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QProcess >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QProcess_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QProcess_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess", overloads);
        return -1;
}

static PyObject* Sbk_QProcessFunc_atEnd(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // atEnd()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QProcess*>(cppSelf)->::QProcess::atEnd() : const_cast<const QProcess*>(cppSelf)->atEnd());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_bytesAvailable(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bytesAvailable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QProcess*>(cppSelf)->::QProcess::bytesAvailable() : const_cast<const QProcess*>(cppSelf)->bytesAvailable());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_bytesToWrite(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bytesToWrite()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QProcess*>(cppSelf)->::QProcess::bytesToWrite() : const_cast<const QProcess*>(cppSelf)->bytesToWrite());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_canReadLine(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // canReadLine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QProcess*>(cppSelf)->::QProcess::canReadLine() : const_cast<const QProcess*>(cppSelf)->canReadLine());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_close(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // close()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QProcess::close() : cppSelf->close());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QProcessFunc_closeReadChannel(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: closeReadChannel(QProcess::ProcessChannel)
    if (Shiboken::Converter< ::QProcess::ProcessChannel >::isConvertible(arg)) {
        overloadId = 0; // closeReadChannel(QProcess::ProcessChannel)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_closeReadChannel_TypeError;

    // Call function/method
    {
        {
            QProcess::ProcessChannel cppArg0 = Shiboken::Converter<QProcess::ProcessChannel >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // closeReadChannel(QProcess::ProcessChannel)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->closeReadChannel(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_closeReadChannel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcess.ProcessChannel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.closeReadChannel", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_closeWriteChannel(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // closeWriteChannel()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->closeWriteChannel();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QProcessFunc_environment(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // environment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QProcess*>(cppSelf)->environment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_error(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // error()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QProcess::ProcessError cppResult = const_cast<const QProcess*>(cppSelf)->error();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QProcess::ProcessError >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_execute(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "execute", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: execute(QString)
    // 1: execute(QString,QStringList)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // execute(QString)
        } else if (numArgs == 2 && Shiboken::Converter< ::QStringList >::isConvertible(pyargs[1])) {
            overloadId = 1; // execute(QString,QStringList)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_execute_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // execute(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // execute(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = QProcess::execute(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // execute(QString,QStringList)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QStringList cppArg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // execute(QString,QStringList)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = QProcess::execute(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QProcessFunc_execute_TypeError:
        const char* overloads[] = {"QString", "QString, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.execute", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_exitCode(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // exitCode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QProcess*>(cppSelf)->exitCode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_exitStatus(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // exitStatus()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QProcess::ExitStatus cppResult = const_cast<const QProcess*>(cppSelf)->exitStatus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QProcess::ExitStatus >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_isSequential(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSequential()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QProcess*>(cppSelf)->::QProcess::isSequential() : const_cast<const QProcess*>(cppSelf)->isSequential());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_kill(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // kill()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->kill();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QProcessFunc_processChannelMode(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // processChannelMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QProcess::ProcessChannelMode cppResult = const_cast<const QProcess*>(cppSelf)->processChannelMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QProcess::ProcessChannelMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_processEnvironment(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // processEnvironment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QProcessEnvironment cppResult = const_cast<const QProcess*>(cppSelf)->processEnvironment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QProcessEnvironment >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_readAllStandardError(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readAllStandardError()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->readAllStandardError();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_readAllStandardOutput(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readAllStandardOutput()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->readAllStandardOutput();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_readChannel(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readChannel()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QProcess::ProcessChannel cppResult = const_cast<const QProcess*>(cppSelf)->readChannel();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QProcess::ProcessChannel >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_readData(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: readData(char*,qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_readData_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // readData(char*,qint64)
                // Begin code injection

                QByteArray ba;
                ba.resize(cppArg0);
                cppSelf->readData(ba.data(), ba.size());
                pyResult = Shiboken::Converter<QByteArray >::toPython(ba);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QProcessFunc_readData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.readData", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setEnvironment(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnvironment(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setEnvironment(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_setEnvironment_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEnvironment(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEnvironment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_setEnvironment_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setEnvironment", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setProcessChannelMode(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProcessChannelMode(QProcess::ProcessChannelMode)
    if (Shiboken::Converter< ::QProcess::ProcessChannelMode >::isConvertible(arg)) {
        overloadId = 0; // setProcessChannelMode(QProcess::ProcessChannelMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_setProcessChannelMode_TypeError;

    // Call function/method
    {
        {
            QProcess::ProcessChannelMode cppArg0 = Shiboken::Converter<QProcess::ProcessChannelMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setProcessChannelMode(QProcess::ProcessChannelMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProcessChannelMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_setProcessChannelMode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcess.ProcessChannelMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setProcessChannelMode", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setProcessEnvironment(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProcessEnvironment(QProcessEnvironment)
    if (Shiboken::Converter< ::QProcessEnvironment >::isConvertible(arg)) {
        overloadId = 0; // setProcessEnvironment(QProcessEnvironment)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_setProcessEnvironment_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QProcessEnvironment cppArg0 = Shiboken::Converter<QProcessEnvironment >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setProcessEnvironment(QProcessEnvironment)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProcessEnvironment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_setProcessEnvironment_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcessEnvironment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setProcessEnvironment", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setProcessState(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setProcessState(QProcess::ProcessState)
    if (Shiboken::Converter< ::QProcess::ProcessState >::isConvertible(arg)) {
        overloadId = 0; // setProcessState(QProcess::ProcessState)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_setProcessState_TypeError;

    // Call function/method
    {
        {
            QProcess::ProcessState cppArg0 = Shiboken::Converter<QProcess::ProcessState >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setProcessState(QProcess::ProcessState)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProcessState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_setProcessState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcess.ProcessState", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setProcessState", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setReadChannel(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setReadChannel(QProcess::ProcessChannel)
    if (Shiboken::Converter< ::QProcess::ProcessChannel >::isConvertible(arg)) {
        overloadId = 0; // setReadChannel(QProcess::ProcessChannel)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_setReadChannel_TypeError;

    // Call function/method
    {
        {
            QProcess::ProcessChannel cppArg0 = Shiboken::Converter<QProcess::ProcessChannel >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setReadChannel(QProcess::ProcessChannel)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setReadChannel(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_setReadChannel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcess.ProcessChannel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setReadChannel", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setStandardErrorFile(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardErrorFile(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardErrorFile(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setStandardErrorFile", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setStandardErrorFile(QString,QFlags<QIODevice::OpenModeFlag>)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setStandardErrorFile(QString,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // setStandardErrorFile(QString,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_setStandardErrorFile_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QProcessFunc_setStandardErrorFile_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardErrorFile(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QFlags<QIODevice::OpenModeFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]) : QIODevice::Truncate;

            if(!PyErr_Occurred()) {
                // setStandardErrorFile(QString,QFlags<QIODevice::OpenModeFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStandardErrorFile(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_setStandardErrorFile_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice.OpenMode = QIODevice.Truncate", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.setStandardErrorFile", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setStandardInputFile(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStandardInputFile(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setStandardInputFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_setStandardInputFile_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStandardInputFile(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStandardInputFile(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_setStandardInputFile_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setStandardInputFile", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setStandardOutputFile(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardOutputFile(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardOutputFile(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setStandardOutputFile", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setStandardOutputFile(QString,QFlags<QIODevice::OpenModeFlag>)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setStandardOutputFile(QString,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // setStandardOutputFile(QString,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_setStandardOutputFile_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QProcessFunc_setStandardOutputFile_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.setStandardOutputFile(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QFlags<QIODevice::OpenModeFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]) : QIODevice::Truncate;

            if(!PyErr_Occurred()) {
                // setStandardOutputFile(QString,QFlags<QIODevice::OpenModeFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStandardOutputFile(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_setStandardOutputFile_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice.OpenMode = QIODevice.Truncate", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.setStandardOutputFile", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setStandardOutputProcess(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStandardOutputProcess(QProcess*)
    if (Shiboken::Converter< ::QProcess * >::isConvertible(arg)) {
        overloadId = 0; // setStandardOutputProcess(QProcess*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_setStandardOutputProcess_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QProcess * cppArg0 = Shiboken::Converter<QProcess * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStandardOutputProcess(QProcess*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStandardOutputProcess(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_setStandardOutputProcess_TypeError:
        const char* overloads[] = {"PySide.QtCore.QProcess", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setStandardOutputProcess", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setWorkingDirectory(PyObject* self, PyObject* arg)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWorkingDirectory(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setWorkingDirectory(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_setWorkingDirectory_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWorkingDirectory(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWorkingDirectory(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_setWorkingDirectory_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QProcess.setWorkingDirectory", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_setupChildProcess(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // setupChildProcess()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QProcess::setupChildProcess() : cppSelf->setupChildProcess());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QProcessFunc_start(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.start(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.start(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:start", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: start(QString,QFlags<QIODevice::OpenModeFlag>)
    // 1: start(QString,QStringList,QFlags<QIODevice::OpenModeFlag>)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // start(QString,QFlags<QIODevice::OpenModeFlag>)
        } else if (Shiboken::Converter< ::QStringList >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // start(QString,QStringList,QFlags<QIODevice::OpenModeFlag>)
            } else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[2])) {
                overloadId = 1; // start(QString,QStringList,QFlags<QIODevice::OpenModeFlag>)
            }
        } else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // start(QString,QFlags<QIODevice::OpenModeFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_start_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // start(QString,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QProcessFunc_start_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.start(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QFlags<QIODevice::OpenModeFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[1]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                    // start(QString,QFlags<QIODevice::OpenModeFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->start(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // start(QString,QStringList,QFlags<QIODevice::OpenModeFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QFlags<QIODevice::OpenModeFlag> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QProcessFunc_start_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.start(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QStringList cppArg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);
                QFlags<QIODevice::OpenModeFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<QIODevice::OpenModeFlag> >::toCpp(pyargs[2]) : QIODevice::ReadWrite;

                if(!PyErr_Occurred()) {
                    // start(QString,QStringList,QFlags<QIODevice::OpenModeFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->start(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QProcessFunc_start_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", "QString, list, PySide.QtCore.QIODevice.OpenMode = QIODevice.ReadWrite", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.start", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_startDetached(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "startDetached", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: startDetached(QString)
    // 1: startDetached(QString,QStringList)
    // 2: startDetached(QString,QStringList,QString,qint64*)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // startDetached(QString)
        } else if (Shiboken::Converter< ::QStringList >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // startDetached(QString,QStringList)
            } else if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
                overloadId = 2; // startDetached(QString,QStringList,QString,qint64*)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_startDetached_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // startDetached(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // startDetached(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QProcess::startDetached(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // startDetached(QString,QStringList)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QStringList cppArg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // startDetached(QString,QStringList)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QProcess::startDetached(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // startDetached(QString,QStringList,QString,qint64*)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QStringList cppArg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);
                QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // startDetached(QString,QStringList,QString,qint64*)
                    // Begin code injection

                    qint64 pid;
                    bool retval = QProcess::startDetached(cppArg0, cppArg1, cppArg2, &pid);
                    pyResult = Shiboken::makeTuple(retval, pid);

                    // End of code injection


                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QProcessFunc_startDetached_TypeError:
        const char* overloads[] = {"QString", "QString, list", "QString, list, QString, qint64 = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.startDetached", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_state(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // state()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QProcess::ProcessState cppResult = const_cast<const QProcess*>(cppSelf)->state();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QProcess::ProcessState >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_systemEnvironment(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // systemEnvironment()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QProcess::systemEnvironment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_terminate(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // terminate()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->terminate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QProcessFunc_waitForBytesWritten(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.waitForBytesWritten(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForBytesWritten", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: waitForBytesWritten(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForBytesWritten(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // waitForBytesWritten(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_waitForBytesWritten_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "msecs";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QProcessFunc_waitForBytesWritten_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForBytesWritten(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 30000;

            if(!PyErr_Occurred()) {
                // waitForBytesWritten(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QProcess::waitForBytesWritten(cppArg0) : cppSelf->waitForBytesWritten(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QProcessFunc_waitForBytesWritten_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.waitForBytesWritten", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_waitForFinished(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.waitForFinished(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForFinished", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: waitForFinished(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForFinished(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // waitForFinished(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_waitForFinished_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "msecs";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QProcessFunc_waitForFinished_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForFinished(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 30000;

            if(!PyErr_Occurred()) {
                // waitForFinished(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->waitForFinished(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QProcessFunc_waitForFinished_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.waitForFinished", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_waitForReadyRead(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.waitForReadyRead(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForReadyRead", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: waitForReadyRead(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForReadyRead(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // waitForReadyRead(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_waitForReadyRead_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "msecs";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QProcessFunc_waitForReadyRead_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForReadyRead(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 30000;

            if(!PyErr_Occurred()) {
                // waitForReadyRead(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QProcess::waitForReadyRead(cppArg0) : cppSelf->waitForReadyRead(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QProcessFunc_waitForReadyRead_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.waitForReadyRead", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_waitForStarted(PyObject* self, PyObject* args, PyObject* kwds)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QProcess.waitForStarted(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:waitForStarted", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: waitForStarted(int)
    if (numArgs == 0) {
        overloadId = 0; // waitForStarted(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // waitForStarted(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_waitForStarted_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "msecs");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "msecs";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QProcessFunc_waitForStarted_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QProcess.waitForStarted(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 30000;

            if(!PyErr_Occurred()) {
                // waitForStarted(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->waitForStarted(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QProcessFunc_waitForStarted_TypeError:
        const char* overloads[] = {"int = 30000", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.waitForStarted", overloads);
        return 0;
}

static PyObject* Sbk_QProcessFunc_workingDirectory(PyObject* self)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // workingDirectory()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QProcess*>(cppSelf)->workingDirectory();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QProcessFunc_writeData(PyObject* self, PyObject* args)
{
    QProcess* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QProcess* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: writeData(const char*,qint64)
    if (numArgs == 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QProcessFunc_writeData_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            qint64 cppArg1 = Shiboken::Converter<qint64 >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // writeData(const char*,qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QProcess::writeData(cppArg0, cppArg1) : cppSelf->writeData(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QProcessFunc_writeData_TypeError:
        const char* overloads[] = {"str, long long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QProcess.writeData", overloads);
        return 0;
}

static PyMethodDef Sbk_QProcess_methods[] = {
    {"atEnd", (PyCFunction)Sbk_QProcessFunc_atEnd, METH_NOARGS},
    {"bytesAvailable", (PyCFunction)Sbk_QProcessFunc_bytesAvailable, METH_NOARGS},
    {"bytesToWrite", (PyCFunction)Sbk_QProcessFunc_bytesToWrite, METH_NOARGS},
    {"canReadLine", (PyCFunction)Sbk_QProcessFunc_canReadLine, METH_NOARGS},
    {"close", (PyCFunction)Sbk_QProcessFunc_close, METH_NOARGS},
    {"closeReadChannel", (PyCFunction)Sbk_QProcessFunc_closeReadChannel, METH_O},
    {"closeWriteChannel", (PyCFunction)Sbk_QProcessFunc_closeWriteChannel, METH_NOARGS},
    {"environment", (PyCFunction)Sbk_QProcessFunc_environment, METH_NOARGS},
    {"error", (PyCFunction)Sbk_QProcessFunc_error, METH_NOARGS},
    {"execute", (PyCFunction)Sbk_QProcessFunc_execute, METH_VARARGS|METH_STATIC},
    {"exitCode", (PyCFunction)Sbk_QProcessFunc_exitCode, METH_NOARGS},
    {"exitStatus", (PyCFunction)Sbk_QProcessFunc_exitStatus, METH_NOARGS},
    {"isSequential", (PyCFunction)Sbk_QProcessFunc_isSequential, METH_NOARGS},
    {"kill", (PyCFunction)Sbk_QProcessFunc_kill, METH_NOARGS},
    {"processChannelMode", (PyCFunction)Sbk_QProcessFunc_processChannelMode, METH_NOARGS},
    {"processEnvironment", (PyCFunction)Sbk_QProcessFunc_processEnvironment, METH_NOARGS},
    {"readAllStandardError", (PyCFunction)Sbk_QProcessFunc_readAllStandardError, METH_NOARGS},
    {"readAllStandardOutput", (PyCFunction)Sbk_QProcessFunc_readAllStandardOutput, METH_NOARGS},
    {"readChannel", (PyCFunction)Sbk_QProcessFunc_readChannel, METH_NOARGS},
    {"readData", (PyCFunction)Sbk_QProcessFunc_readData, METH_O},
    {"setEnvironment", (PyCFunction)Sbk_QProcessFunc_setEnvironment, METH_O},
    {"setProcessChannelMode", (PyCFunction)Sbk_QProcessFunc_setProcessChannelMode, METH_O},
    {"setProcessEnvironment", (PyCFunction)Sbk_QProcessFunc_setProcessEnvironment, METH_O},
    {"setProcessState", (PyCFunction)Sbk_QProcessFunc_setProcessState, METH_O},
    {"setReadChannel", (PyCFunction)Sbk_QProcessFunc_setReadChannel, METH_O},
    {"setStandardErrorFile", (PyCFunction)Sbk_QProcessFunc_setStandardErrorFile, METH_VARARGS|METH_KEYWORDS},
    {"setStandardInputFile", (PyCFunction)Sbk_QProcessFunc_setStandardInputFile, METH_O},
    {"setStandardOutputFile", (PyCFunction)Sbk_QProcessFunc_setStandardOutputFile, METH_VARARGS|METH_KEYWORDS},
    {"setStandardOutputProcess", (PyCFunction)Sbk_QProcessFunc_setStandardOutputProcess, METH_O},
    {"setWorkingDirectory", (PyCFunction)Sbk_QProcessFunc_setWorkingDirectory, METH_O},
    {"setupChildProcess", (PyCFunction)Sbk_QProcessFunc_setupChildProcess, METH_NOARGS},
    {"start", (PyCFunction)Sbk_QProcessFunc_start, METH_VARARGS|METH_KEYWORDS},
    {"startDetached", (PyCFunction)Sbk_QProcessFunc_startDetached, METH_VARARGS|METH_STATIC},
    {"state", (PyCFunction)Sbk_QProcessFunc_state, METH_NOARGS},
    {"systemEnvironment", (PyCFunction)Sbk_QProcessFunc_systemEnvironment, METH_NOARGS|METH_STATIC},
    {"terminate", (PyCFunction)Sbk_QProcessFunc_terminate, METH_NOARGS},
    {"waitForBytesWritten", (PyCFunction)Sbk_QProcessFunc_waitForBytesWritten, METH_VARARGS|METH_KEYWORDS},
    {"waitForFinished", (PyCFunction)Sbk_QProcessFunc_waitForFinished, METH_VARARGS|METH_KEYWORDS},
    {"waitForReadyRead", (PyCFunction)Sbk_QProcessFunc_waitForReadyRead, METH_VARARGS|METH_KEYWORDS},
    {"waitForStarted", (PyCFunction)Sbk_QProcessFunc_waitForStarted, METH_VARARGS|METH_KEYWORDS},
    {"workingDirectory", (PyCFunction)Sbk_QProcessFunc_workingDirectory, METH_NOARGS},
    {"writeData", (PyCFunction)Sbk_QProcessFunc_writeData, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QProcess_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QProcess",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QProcess_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QProcess_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QProcess_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QProcess*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QProcess_Type;
    return 0;
}


void init_QProcess(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QPROCESS_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QProcess_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QProcess_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QProcess_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QProcess_Type, &QProcess::staticMetaObject);    Sbk_QProcess_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QProcess_Type, &Shiboken::callCppDestructor<QProcess >);
    Py_INCREF((PyObject*)&Sbk_QProcess_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QProcess_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QProcess_Type, &Sbk_QProcess_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QIODEVICE_IDX]), &Sbk_QProcess_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QProcess_Type, "QProcess*");
    PyModule_AddObject(module, "QProcess",
        ((PyObject*)&Sbk_QProcess_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ProcessError
    PyTypeObject* SbkPySide_QtCore_QProcess_ProcessError = Shiboken::Enum::newType("PySide.QtCore.QProcess.ProcessError");
    SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSERROR_IDX] = SbkPySide_QtCore_QProcess_ProcessError;
    if (PyType_Ready(SbkPySide_QtCore_QProcess_ProcessError) < 0)
        return;
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,
            "ProcessError",((PyObject*)SbkPySide_QtCore_QProcess_ProcessError));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessError,(long) QProcess::FailedToStart, "FailedToStart");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"FailedToStart", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError->tp_dict,"FailedToStart", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessError,(long) QProcess::Crashed, "Crashed");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"Crashed", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError->tp_dict,"Crashed", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessError,(long) QProcess::Timedout, "Timedout");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"Timedout", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError->tp_dict,"Timedout", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessError,(long) QProcess::ReadError, "ReadError");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"ReadError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError->tp_dict,"ReadError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessError,(long) QProcess::WriteError, "WriteError");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"WriteError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError->tp_dict,"WriteError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessError,(long) QProcess::UnknownError, "UnknownError");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessError->tp_dict,"UnknownError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QProcess::ProcessError");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ProcessError");
    // end of enum ProcessError

    // init enum: ProcessChannelMode
    PyTypeObject* SbkPySide_QtCore_QProcess_ProcessChannelMode = Shiboken::Enum::newType("PySide.QtCore.QProcess.ProcessChannelMode");
    SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSCHANNELMODE_IDX] = SbkPySide_QtCore_QProcess_ProcessChannelMode;
    if (PyType_Ready(SbkPySide_QtCore_QProcess_ProcessChannelMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,
            "ProcessChannelMode",((PyObject*)SbkPySide_QtCore_QProcess_ProcessChannelMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessChannelMode,(long) QProcess::SeparateChannels, "SeparateChannels");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"SeparateChannels", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessChannelMode->tp_dict,"SeparateChannels", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessChannelMode,(long) QProcess::MergedChannels, "MergedChannels");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"MergedChannels", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessChannelMode->tp_dict,"MergedChannels", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessChannelMode,(long) QProcess::ForwardedChannels, "ForwardedChannels");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"ForwardedChannels", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessChannelMode->tp_dict,"ForwardedChannels", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QProcess::ProcessChannelMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ProcessChannelMode");
    // end of enum ProcessChannelMode

    // init enum: ProcessChannel
    PyTypeObject* SbkPySide_QtCore_QProcess_ProcessChannel = Shiboken::Enum::newType("PySide.QtCore.QProcess.ProcessChannel");
    SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSCHANNEL_IDX] = SbkPySide_QtCore_QProcess_ProcessChannel;
    if (PyType_Ready(SbkPySide_QtCore_QProcess_ProcessChannel) < 0)
        return;
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,
            "ProcessChannel",((PyObject*)SbkPySide_QtCore_QProcess_ProcessChannel));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessChannel,(long) QProcess::StandardOutput, "StandardOutput");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"StandardOutput", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessChannel->tp_dict,"StandardOutput", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessChannel,(long) QProcess::StandardError, "StandardError");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"StandardError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessChannel->tp_dict,"StandardError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QProcess::ProcessChannel");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ProcessChannel");
    // end of enum ProcessChannel

    // init enum: ProcessState
    PyTypeObject* SbkPySide_QtCore_QProcess_ProcessState = Shiboken::Enum::newType("PySide.QtCore.QProcess.ProcessState");
    SbkPySide_QtCoreTypes[SBK_QPROCESS_PROCESSSTATE_IDX] = SbkPySide_QtCore_QProcess_ProcessState;
    if (PyType_Ready(SbkPySide_QtCore_QProcess_ProcessState) < 0)
        return;
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,
            "ProcessState",((PyObject*)SbkPySide_QtCore_QProcess_ProcessState));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessState,(long) QProcess::NotRunning, "NotRunning");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"NotRunning", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessState->tp_dict,"NotRunning", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessState,(long) QProcess::Starting, "Starting");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"Starting", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessState->tp_dict,"Starting", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ProcessState,(long) QProcess::Running, "Running");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"Running", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ProcessState->tp_dict,"Running", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QProcess::ProcessState");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ProcessState");
    // end of enum ProcessState

    // init enum: ExitStatus
    PyTypeObject* SbkPySide_QtCore_QProcess_ExitStatus = Shiboken::Enum::newType("PySide.QtCore.QProcess.ExitStatus");
    SbkPySide_QtCoreTypes[SBK_QPROCESS_EXITSTATUS_IDX] = SbkPySide_QtCore_QProcess_ExitStatus;
    if (PyType_Ready(SbkPySide_QtCore_QProcess_ExitStatus) < 0)
        return;
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,
            "ExitStatus",((PyObject*)SbkPySide_QtCore_QProcess_ExitStatus));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ExitStatus,(long) QProcess::NormalExit, "NormalExit");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"NormalExit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ExitStatus->tp_dict,"NormalExit", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QProcess_ExitStatus,(long) QProcess::CrashExit, "CrashExit");
    PyDict_SetItemString(Sbk_QProcess_Type.super.ht_type.tp_dict,"CrashExit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QProcess_ExitStatus->tp_dict,"CrashExit", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QProcess::ExitStatus");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ExitStatus");
    // end of enum ExitStatus

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("error", "QProcess::ProcessError", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QProcess_Type, "error", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("started", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QProcess_Type, "started", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("finished", "int", "int,QProcess::ExitStatus", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QProcess_Type, "finished", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("readyReadStandardError", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QProcess_Type, "readyReadStandardError", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("readyReadStandardOutput", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QProcess_Type, "readyReadStandardOutput", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("stateChanged", "QProcess::ProcessState", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QProcess_Type, "stateChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QProcess >("QProcess*");
    Shiboken::TypeResolver::createObjectTypeResolver<QProcess >(typeid(QProcess).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QProcess >(typeid(QProcessWrapper).name());
    qRegisterMetaType< ::QProcess* >("QProcess*");
    qRegisterMetaType< ::QProcess::ProcessError >("QProcess::ProcessError");
    qRegisterMetaType< ::QProcess::ProcessChannelMode >("QProcess::ProcessChannelMode");
    qRegisterMetaType< ::QProcess::ProcessChannel >("QProcess::ProcessChannel");
    qRegisterMetaType< ::QProcess::ProcessState >("QProcess::ProcessState");
    qRegisterMetaType< ::QProcess::ExitStatus >("QProcess::ExitStatus");
}

