/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qrect_wrapper.h"

// Extra includes
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>


// Begin code injection

namespace PySide {
    template<> inline uint hash(const QRect& v) {
        return qHash(qMakePair(qMakePair(v.x(), v.y()), qMakePair(v.width(), v.height())));
    }
};

// End of code injection


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRect_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QRect >()))
        return -1;

    QRect* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto Sbk_QRect_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QRect", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QRect()
    // 1: QRect(QPoint,QPoint)
    // 2: QRect(QPoint,QSize)
    // 3: QRect(QRect)
    // 4: QRect(int,int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // QRect()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 4; // QRect(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 3; // QRect(QRect)
    } else if (Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[1])) {
            overloadId = 2; // QRect(QPoint,QSize)
        } else if (numArgs == 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[1])) {
            overloadId = 1; // QRect(QPoint,QPoint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRect_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QRect()
            {

                if(!PyErr_Occurred()) {
                    // QRect()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QRect();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QRect(QPoint,QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QRect(QPoint,QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QRect(QPoint,QSize)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QSize cppArg1 = Shiboken::Converter<QSize >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QRect(QPoint,QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QRect(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QRect(QRect)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QRect(QRect)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QRect(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // QRect(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QRect(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QRect >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QRect_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QRect_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPoint, PySide.QtCore.QPoint", "PySide.QtCore.QPoint, PySide.QtCore.QSize", "PySide.QtCore.QRect", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect", overloads);
        return -1;
}

static PyObject* Sbk_QRectFunc___reduce__(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection

                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(iiii))", PyObject_Type(self), cppSelf->x(), cppSelf->y(), cppSelf->width(), cppSelf->height());
                // TEMPLATE - reduce_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc___repr__(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __repr__()
                // Begin code injection

                // TEMPLATE - repr_code - START
                QString format = QString().sprintf("%s(%i, %i, %i, %i)", ((PyObject*)self)->ob_type->tp_name, cppSelf->x(), cppSelf->y(), cppSelf->width(), cppSelf->height());
                pyResult = PyString_FromString(qPrintable(format));
                // TEMPLATE - repr_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_adjust(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "adjust", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: adjust(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // adjust(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_adjust_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // adjust(int,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->adjust(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_adjust_TypeError:
        const char* overloads[] = {"int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.adjust", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_adjusted(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "adjusted", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: adjusted(int,int,int,int)const
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // adjusted(int,int,int,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_adjusted_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // adjusted(int,int,int,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QRect*>(cppSelf)->adjusted(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFunc_adjusted_TypeError:
        const char* overloads[] = {"int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.adjusted", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_bottom(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bottom()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QRect*>(cppSelf)->bottom();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_bottomLeft(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bottomLeft()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QRect*>(cppSelf)->bottomLeft();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_bottomRight(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bottomRight()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QRect*>(cppSelf)->bottomRight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_center(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // center()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QRect*>(cppSelf)->center();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_contains(PyObject* self, PyObject* args, PyObject* kwds)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRect.contains(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRect.contains(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:contains", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: contains(QPoint,bool)const
    // 1: contains(QRect,bool)const
    // 2: contains(int,int)const
    // 3: contains(int,int,bool)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // contains(int,int)const
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[2])) {
            overloadId = 3; // contains(int,int,bool)const
        }
    } else if (Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // contains(QRect,bool)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // contains(QRect,bool)const
        }
    } else if (Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // contains(QPoint,bool)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // contains(QPoint,bool)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_contains_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // contains(QPoint,bool)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "proper");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "proper";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QRectFunc_contains_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRect.contains(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

                if(!PyErr_Occurred()) {
                    // contains(QPoint,bool)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QRect*>(cppSelf)->contains(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // contains(QRect,bool)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "proper");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "proper";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QRectFunc_contains_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRect.contains(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
                bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

                if(!PyErr_Occurred()) {
                    // contains(QRect,bool)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QRect*>(cppSelf)->contains(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // contains(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // contains(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QRect*>(cppSelf)->contains(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // contains(int,int,bool)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                bool cppArg2 = Shiboken::Converter<bool >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // contains(int,int,bool)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QRect*>(cppSelf)->contains(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, bool = false", "PySide.QtCore.QRect, bool = false", "int, int", "int, int, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.contains", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_getCoords(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getCoords(int*,int*,int*,int*)const
                // Begin code injection

                int a, b, c, d;
                cppSelf->getCoords(&a, &b, &c, &d);
                pyResult = Shiboken::makeTuple(a, b, c, d);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_getRect(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getRect(int*,int*,int*,int*)const
                // Begin code injection

                int a, b, c, d;
                cppSelf->getRect(&a, &b, &c, &d);
                pyResult = Shiboken::makeTuple(a, b, c, d);

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_height(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // height()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QRect*>(cppSelf)->height();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_intersect(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersect(QRect)const
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // intersect(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_intersect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // intersect(QRect)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QRect*>(cppSelf)->intersect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFunc_intersect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.intersect", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_intersected(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QRect)const
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // intersected(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_intersected_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // intersected(QRect)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QRect*>(cppSelf)->intersected(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.intersected", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_intersects(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersects(QRect)const
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // intersects(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_intersects_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // intersects(QRect)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QRect*>(cppSelf)->intersects(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFunc_intersects_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.intersects", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_isEmpty(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QRect*>(cppSelf)->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_isNull(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QRect*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_isValid(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QRect*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_left(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // left()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QRect*>(cppSelf)->left();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_moveBottom(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottom(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveBottom(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_moveBottom_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // moveBottom(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveBottom(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_moveBottom_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveBottom", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_moveBottomLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottomLeft(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // moveBottomLeft(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_moveBottomLeft_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // moveBottomLeft(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveBottomLeft(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_moveBottomLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveBottomLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_moveBottomRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveBottomRight(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // moveBottomRight(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_moveBottomRight_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // moveBottomRight(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveBottomRight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_moveBottomRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveBottomRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_moveCenter(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveCenter(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // moveCenter(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_moveCenter_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // moveCenter(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveCenter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_moveCenter_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveCenter", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_moveLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveLeft(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveLeft(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_moveLeft_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // moveLeft(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveLeft(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_moveLeft_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_moveRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveRight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveRight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_moveRight_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // moveRight(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveRight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_moveRight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_moveTo(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "moveTo", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: moveTo(QPoint)
    // 1: moveTo(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // moveTo(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // moveTo(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_moveTo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // moveTo(QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // moveTo(QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->moveTo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // moveTo(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // moveTo(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->moveTo(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_moveTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.moveTo", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_moveTop(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTop(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // moveTop(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_moveTop_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // moveTop(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveTop(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_moveTop_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveTop", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_moveTopLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTopLeft(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // moveTopLeft(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_moveTopLeft_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // moveTopLeft(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveTopLeft(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_moveTopLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveTopLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_moveTopRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: moveTopRight(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // moveTopRight(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_moveTopRight_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // moveTopRight(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveTopRight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_moveTopRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.moveTopRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_normalized(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // normalized()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QRect*>(cppSelf)->normalized();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_right(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // right()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QRect*>(cppSelf)->right();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_setBottom(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottom(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBottom(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setBottom_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBottom(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBottom(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setBottom_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setBottom", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setBottomLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomLeft(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // setBottomLeft(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setBottomLeft_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBottomLeft(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBottomLeft(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setBottomLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setBottomLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setBottomRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomRight(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // setBottomRight(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setBottomRight_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBottomRight(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBottomRight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setBottomRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setBottomRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setCoords(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCoords", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setCoords(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // setCoords(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setCoords_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // setCoords(int,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCoords(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setCoords_TypeError:
        const char* overloads[] = {"int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.setCoords", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setHeight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHeight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setHeight_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHeight(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHeight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setHeight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setHeight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeft(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLeft(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setLeft_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLeft(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLeft(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setLeft_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setRect(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRect", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setRect(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // setRect(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setRect_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // setRect(int,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRect(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setRect_TypeError:
        const char* overloads[] = {"int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.setRect", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRight(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRight(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setRight_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRight(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setRight_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setSize(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSize(QSize)
    if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // setSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSize(QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setSize", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setTop(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTop(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTop(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setTop_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTop(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTop(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setTop_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setTop", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setTopLeft(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopLeft(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // setTopLeft(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setTopLeft_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTopLeft(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTopLeft(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setTopLeft_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setTopLeft", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setTopRight(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopRight(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // setTopRight(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setTopRight_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTopRight(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTopRight(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setTopRight_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setTopRight", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setWidth(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWidth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setWidth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWidth(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setWidth", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setX(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setX(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setX_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setX(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setX(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setX_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setX", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_setY(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setY(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_setY_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setY(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setY(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_setY_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.setY", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_size(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QRect*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_top(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // top()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QRect*>(cppSelf)->top();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_topLeft(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // topLeft()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QRect*>(cppSelf)->topLeft();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_topRight(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // topRight()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QRect*>(cppSelf)->topRight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_translate(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPoint)
    // 1: translate(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translate(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // translate(QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->translate(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // translate(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // translate(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->translate(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRectFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.translate", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_translated(PyObject* self, PyObject* args)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPoint)const
    // 1: translated(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translated(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // translated(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_translated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translated(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // translated(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRect cppResult = const_cast<const QRect*>(cppSelf)->translated(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // translated(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // translated(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRect cppResult = const_cast<const QRect*>(cppSelf)->translated(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRect.translated", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_unite(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unite(QRect)const
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // unite(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_unite_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // unite(QRect)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QRect*>(cppSelf)->unite(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFunc_unite_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.unite", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_united(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QRect)const
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // united(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc_united_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // united(QRect)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QRect*>(cppSelf)->united(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.united", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc_width(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // width()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QRect*>(cppSelf)->width();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_x(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // x()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QRect*>(cppSelf)->x();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRectFunc_y(PyObject* self)
{
    QRect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // y()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QRect*>(cppSelf)->y();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QRect___copy__(PyObject *self)
{
        QRect* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QRect*>::toCpp(self);
        PyObject* pyResult = 0;
        QRect* copy = new QRect(*cppSelf);
        pyResult = Shiboken::Converter<QRect*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QRect_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QRectFunc___reduce__, METH_NOARGS},
    {"adjust", (PyCFunction)Sbk_QRectFunc_adjust, METH_VARARGS},
    {"adjusted", (PyCFunction)Sbk_QRectFunc_adjusted, METH_VARARGS},
    {"bottom", (PyCFunction)Sbk_QRectFunc_bottom, METH_NOARGS},
    {"bottomLeft", (PyCFunction)Sbk_QRectFunc_bottomLeft, METH_NOARGS},
    {"bottomRight", (PyCFunction)Sbk_QRectFunc_bottomRight, METH_NOARGS},
    {"center", (PyCFunction)Sbk_QRectFunc_center, METH_NOARGS},
    {"contains", (PyCFunction)Sbk_QRectFunc_contains, METH_VARARGS|METH_KEYWORDS},
    {"getCoords", (PyCFunction)Sbk_QRectFunc_getCoords, METH_NOARGS},
    {"getRect", (PyCFunction)Sbk_QRectFunc_getRect, METH_NOARGS},
    {"height", (PyCFunction)Sbk_QRectFunc_height, METH_NOARGS},
    {"intersect", (PyCFunction)Sbk_QRectFunc_intersect, METH_O},
    {"intersected", (PyCFunction)Sbk_QRectFunc_intersected, METH_O},
    {"intersects", (PyCFunction)Sbk_QRectFunc_intersects, METH_O},
    {"isEmpty", (PyCFunction)Sbk_QRectFunc_isEmpty, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QRectFunc_isNull, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QRectFunc_isValid, METH_NOARGS},
    {"left", (PyCFunction)Sbk_QRectFunc_left, METH_NOARGS},
    {"moveBottom", (PyCFunction)Sbk_QRectFunc_moveBottom, METH_O},
    {"moveBottomLeft", (PyCFunction)Sbk_QRectFunc_moveBottomLeft, METH_O},
    {"moveBottomRight", (PyCFunction)Sbk_QRectFunc_moveBottomRight, METH_O},
    {"moveCenter", (PyCFunction)Sbk_QRectFunc_moveCenter, METH_O},
    {"moveLeft", (PyCFunction)Sbk_QRectFunc_moveLeft, METH_O},
    {"moveRight", (PyCFunction)Sbk_QRectFunc_moveRight, METH_O},
    {"moveTo", (PyCFunction)Sbk_QRectFunc_moveTo, METH_VARARGS},
    {"moveTop", (PyCFunction)Sbk_QRectFunc_moveTop, METH_O},
    {"moveTopLeft", (PyCFunction)Sbk_QRectFunc_moveTopLeft, METH_O},
    {"moveTopRight", (PyCFunction)Sbk_QRectFunc_moveTopRight, METH_O},
    {"normalized", (PyCFunction)Sbk_QRectFunc_normalized, METH_NOARGS},
    {"right", (PyCFunction)Sbk_QRectFunc_right, METH_NOARGS},
    {"setBottom", (PyCFunction)Sbk_QRectFunc_setBottom, METH_O},
    {"setBottomLeft", (PyCFunction)Sbk_QRectFunc_setBottomLeft, METH_O},
    {"setBottomRight", (PyCFunction)Sbk_QRectFunc_setBottomRight, METH_O},
    {"setCoords", (PyCFunction)Sbk_QRectFunc_setCoords, METH_VARARGS},
    {"setHeight", (PyCFunction)Sbk_QRectFunc_setHeight, METH_O},
    {"setLeft", (PyCFunction)Sbk_QRectFunc_setLeft, METH_O},
    {"setRect", (PyCFunction)Sbk_QRectFunc_setRect, METH_VARARGS},
    {"setRight", (PyCFunction)Sbk_QRectFunc_setRight, METH_O},
    {"setSize", (PyCFunction)Sbk_QRectFunc_setSize, METH_O},
    {"setTop", (PyCFunction)Sbk_QRectFunc_setTop, METH_O},
    {"setTopLeft", (PyCFunction)Sbk_QRectFunc_setTopLeft, METH_O},
    {"setTopRight", (PyCFunction)Sbk_QRectFunc_setTopRight, METH_O},
    {"setWidth", (PyCFunction)Sbk_QRectFunc_setWidth, METH_O},
    {"setX", (PyCFunction)Sbk_QRectFunc_setX, METH_O},
    {"setY", (PyCFunction)Sbk_QRectFunc_setY, METH_O},
    {"size", (PyCFunction)Sbk_QRectFunc_size, METH_NOARGS},
    {"top", (PyCFunction)Sbk_QRectFunc_top, METH_NOARGS},
    {"topLeft", (PyCFunction)Sbk_QRectFunc_topLeft, METH_NOARGS},
    {"topRight", (PyCFunction)Sbk_QRectFunc_topRight, METH_NOARGS},
    {"translate", (PyCFunction)Sbk_QRectFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)Sbk_QRectFunc_translated, METH_VARARGS},
    {"unite", (PyCFunction)Sbk_QRectFunc_unite, METH_O},
    {"united", (PyCFunction)Sbk_QRectFunc_united, METH_O},
    {"width", (PyCFunction)Sbk_QRectFunc_width, METH_NOARGS},
    {"x", (PyCFunction)Sbk_QRectFunc_x, METH_NOARGS},
    {"y", (PyCFunction)Sbk_QRectFunc_y, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QRect___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QRect___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QRect* cppSelf = Shiboken::Converter< ::QRect*>::toCpp(pyObj);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QRectFunc___and__(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QRect >::checkType(arg) && !Shiboken::Converter< ::QRect >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rand__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rand__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator&(QRect)const
    if (!isReverse && Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // operator&(QRect)const
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc___and___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator&(QRect)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = (*cppSelf) & (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFunc___and___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.__and__", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc___iand__(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QRect >::checkType(arg) && !Shiboken::Converter< ::QRect >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator&=(QRect)
    if (!isReverse && Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // operator&=(QRect)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc___iand___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator&=(QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) &= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QRectFunc___iand___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.__iand__", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc___or__(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QRect >::checkType(arg) && !Shiboken::Converter< ::QRect >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__ror__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__ror__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator|(QRect)const
    if (!isReverse && Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // operator|(QRect)const
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc___or___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator|(QRect)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = (*cppSelf) | (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRectFunc___or___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.__or__", overloads);
        return 0;
}

static PyObject* Sbk_QRectFunc___ior__(PyObject* self, PyObject* arg)
{
    QRect* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QRect >::checkType(arg) && !Shiboken::Converter< ::QRect >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator|=(QRect)
    if (!isReverse && Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // operator|=(QRect)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRectFunc___ior___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator|=(QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) |= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QRectFunc___ior___TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRect.__ior__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QRect_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QRect___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)Sbk_QRectFunc___and__,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)Sbk_QRectFunc___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)Sbk_QRectFunc___iand__,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)Sbk_QRectFunc___ior__,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QRect_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QRect& cppSelf = *Shiboken::Converter< QRect* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
                // operator!=(const QRect & arg__2)
                QRect cppArg0 = Shiboken::Converter< ::QRect >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
                // operator==(const QRect & arg__2)
                QRect cppArg0 = Shiboken::Converter< ::QRect >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QRect_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QRect_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static long Sbk_QRect_HashFunc(PyObject* obj){
    return PySide::hash(Shiboken::Converter< ::QRect >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QRect_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QRect",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QRectFunc___repr__,
    /*tp_as_number*/        &Sbk_QRect_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &Sbk_QRect_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QRect_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QRect_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QRect_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QRect(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QRECT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QRect_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QRect_Type);

    Shiboken::ObjectType::setDestructorFunction(&Sbk_QRect_Type, &Shiboken::callCppDestructor<QRect >);
    Py_INCREF((PyObject*)&Sbk_QRect_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QRect_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QRect_Type, "QRect");
    PyModule_AddObject(module, "QRect",
        ((PyObject*)&Sbk_QRect_Type));



    Shiboken::TypeResolver::createValueTypeResolver<QRect >("QRect");
    Shiboken::TypeResolver::createObjectTypeResolver<QRect >("QRect*");
    Shiboken::TypeResolver::createValueTypeResolver<QRect >(typeid(QRect).name());
    qRegisterMetaType< ::QRect >("QRect");
}


