/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qxmlstreamreader_wrapper.h"

// Extra includes
#include <QVector>
#include <qbytearray.h>
#include <qiodevice.h>
#include <qxmlstream.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamReader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlStreamReader >()))
        return -1;

    QXmlStreamReader* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlStreamReader", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlStreamReader()
    // 1: QXmlStreamReader(QIODevice*)
    // 2: QXmlStreamReader(QByteArray)
    // 3: QXmlStreamReader(QString)
    // 4: QXmlStreamReader(const char*)
    if (numArgs == 0) {
        overloadId = 0; // QXmlStreamReader()
    } else if (numArgs == 1 && Shiboken::Converter< const char * >::isConvertible(pyargs[0])) {
        overloadId = 4; // QXmlStreamReader(const char*)
    } else if (numArgs == 1 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QXmlStreamReader(QIODevice*)
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 3; // QXmlStreamReader(QString)
    } else if (numArgs == 1 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        overloadId = 2; // QXmlStreamReader(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamReader_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlStreamReader()
            {

                if(!PyErr_Occurred()) {
                    // QXmlStreamReader()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlStreamReader();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QXmlStreamReader(QIODevice*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlStreamReader(QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlStreamReader(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QXmlStreamReader(QByteArray)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlStreamReader(QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlStreamReader(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QXmlStreamReader(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlStreamReader(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlStreamReader(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QXmlStreamReader(const char*)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlStreamReader(const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlStreamReader(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlStreamReader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlStreamReader_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlStreamReader_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice", "PySide.QtCore.QByteArray", "QString", "str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamReader", overloads);
        return -1;
}

static PyObject* Sbk_QXmlStreamReaderFunc_addData(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addData(QByteArray)
    // 1: addData(QString)
    // 2: addData(const char*)
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 2; // addData(const char*)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 1; // addData(QString)
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // addData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamReaderFunc_addData_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addData(QByteArray)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // addData(QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addData(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // addData(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // addData(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addData(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // addData(const char*)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // addData(const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addData(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamReaderFunc_addData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", "str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.addData", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclaration(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
    if (Shiboken::Converter< ::QXmlStreamNamespaceDeclaration >::isConvertible(arg)) {
        overloadId = 0; // addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclaration_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlStreamNamespaceDeclaration cppArg0 = Shiboken::Converter<QXmlStreamNamespaceDeclaration >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addExtraNamespaceDeclaration(QXmlStreamNamespaceDeclaration)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addExtraNamespaceDeclaration(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclaration_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamNamespaceDeclaration", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.addExtraNamespaceDeclaration", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclarations(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addExtraNamespaceDeclarations(QVector<QXmlStreamNamespaceDeclaration>)
    if (Shiboken::Converter< ::QVector<QXmlStreamNamespaceDeclaration > >::isConvertible(arg)) {
        overloadId = 0; // addExtraNamespaceDeclarations(QVector<QXmlStreamNamespaceDeclaration>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclarations_TypeError;

    // Call function/method
    {
        {
            QVector<QXmlStreamNamespaceDeclaration > cppArg0 = Shiboken::Converter<QVector<QXmlStreamNamespaceDeclaration > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addExtraNamespaceDeclarations(QVector<QXmlStreamNamespaceDeclaration>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addExtraNamespaceDeclarations(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclarations_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.addExtraNamespaceDeclarations", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamReaderFunc_atEnd(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // atEnd()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->atEnd();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_attributes(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // attributes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlStreamAttributes cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->attributes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamAttributes >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_characterOffset(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // characterOffset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->characterOffset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_clear(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlStreamReaderFunc_columnNumber(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // columnNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->columnNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_device(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // device()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->device();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_documentEncoding(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // documentEncoding()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->documentEncoding();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_documentVersion(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // documentVersion()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->documentVersion();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_dtdName(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dtdName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->dtdName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_dtdPublicId(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dtdPublicId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->dtdPublicId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_dtdSystemId(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dtdSystemId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->dtdSystemId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_entityDeclarations(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // entityDeclarations()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QXmlStreamEntityDeclaration > cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->entityDeclarations();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QXmlStreamEntityDeclaration > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_entityResolver(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // entityResolver()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlStreamEntityResolver * cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->entityResolver();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamEntityResolver * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_error(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // error()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlStreamReader::Error cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->error();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamReader::Error >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_errorString(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_hasError(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasError()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->hasError();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isCDATA(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCDATA()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isCDATA();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isCharacters(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCharacters()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isCharacters();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isComment(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isComment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isComment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isDTD(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isDTD()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isDTD();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isEndDocument(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEndDocument()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isEndDocument();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isEndElement(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEndElement()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isEndElement();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isEntityReference(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEntityReference()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isEntityReference();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isProcessingInstruction(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isProcessingInstruction()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isProcessingInstruction();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isStandaloneDocument(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isStandaloneDocument()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isStandaloneDocument();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isStartDocument(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isStartDocument()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isStartDocument();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isStartElement(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isStartElement()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isStartElement();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_isWhitespace(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isWhitespace()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->isWhitespace();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_lineNumber(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lineNumber()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->lineNumber();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_name(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_namespaceDeclarations(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // namespaceDeclarations()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QXmlStreamNamespaceDeclaration > cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->namespaceDeclarations();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QXmlStreamNamespaceDeclaration > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_namespaceProcessing(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // namespaceProcessing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->namespaceProcessing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_namespaceUri(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // namespaceUri()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->namespaceUri();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_notationDeclarations(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // notationDeclarations()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QXmlStreamNotationDeclaration > cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->notationDeclarations();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QXmlStreamNotationDeclaration > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_prefix(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // prefix()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->prefix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_processingInstructionData(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // processingInstructionData()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->processingInstructionData();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_processingInstructionTarget(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // processingInstructionTarget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->processingInstructionTarget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_qualifiedName(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // qualifiedName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->qualifiedName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_raiseError(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QXmlStreamReader.raiseError(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:raiseError", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: raiseError(QString)
    if (numArgs == 0) {
        overloadId = 0; // raiseError(QString)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // raiseError(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamReaderFunc_raiseError_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "message");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "message";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QXmlStreamReaderFunc_raiseError_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QXmlStreamReader.raiseError(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();

            if(!PyErr_Occurred()) {
                // raiseError(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->raiseError(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamReaderFunc_raiseError_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamReader.raiseError", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamReaderFunc_readElementText(PyObject* self, PyObject* args)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "readElementText", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: readElementText()
    // 1: readElementText(QXmlStreamReader::ReadElementTextBehaviour)
    if (numArgs == 0) {
        overloadId = 0; // readElementText()
    } else if (numArgs == 1 && Shiboken::Converter< ::QXmlStreamReader::ReadElementTextBehaviour >::isConvertible(pyargs[0])) {
        overloadId = 1; // readElementText(QXmlStreamReader::ReadElementTextBehaviour)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamReaderFunc_readElementText_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // readElementText()
            {

                if(!PyErr_Occurred()) {
                    // readElementText()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = cppSelf->readElementText();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // readElementText(QXmlStreamReader::ReadElementTextBehaviour)
            {
                QXmlStreamReader::ReadElementTextBehaviour cppArg0 = Shiboken::Converter<QXmlStreamReader::ReadElementTextBehaviour >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // readElementText(QXmlStreamReader::ReadElementTextBehaviour)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = cppSelf->readElementText(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamReaderFunc_readElementText_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QXmlStreamReader.ReadElementTextBehaviour", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamReader.readElementText", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamReaderFunc_readNext(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readNext()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlStreamReader::TokenType cppResult = cppSelf->readNext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamReader::TokenType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_readNextStartElement(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // readNextStartElement()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->readNextStartElement();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_setDevice(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QIODevice*)
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamReaderFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDevice(QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDevice(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamReaderFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.setDevice", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamReaderFunc_setEntityResolver(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEntityResolver(QXmlStreamEntityResolver*)
    if (Shiboken::Converter< ::QXmlStreamEntityResolver * >::isConvertible(arg)) {
        overloadId = 0; // setEntityResolver(QXmlStreamEntityResolver*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamReaderFunc_setEntityResolver_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlStreamEntityResolver * cppArg0 = Shiboken::Converter<QXmlStreamEntityResolver * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEntityResolver(QXmlStreamEntityResolver*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEntityResolver(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamReaderFunc_setEntityResolver_TypeError:
        const char* overloads[] = {"PySide.QtCore.QXmlStreamEntityResolver", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.setEntityResolver", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamReaderFunc_setNamespaceProcessing(PyObject* self, PyObject* arg)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNamespaceProcessing(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setNamespaceProcessing(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamReaderFunc_setNamespaceProcessing_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNamespaceProcessing(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNamespaceProcessing(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlStreamReaderFunc_setNamespaceProcessing_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamReader.setNamespaceProcessing", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamReaderFunc_skipCurrentElement(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // skipCurrentElement()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->skipCurrentElement();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlStreamReaderFunc_text(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // text()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringRef cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->text();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QStringRef >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_tokenString(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // tokenString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->tokenString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlStreamReaderFunc_tokenType(PyObject* self)
{
    QXmlStreamReader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamReader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // tokenType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QXmlStreamReader::TokenType cppResult = const_cast<const QXmlStreamReader*>(cppSelf)->tokenType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QXmlStreamReader::TokenType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QXmlStreamReader_methods[] = {
    {"addData", (PyCFunction)Sbk_QXmlStreamReaderFunc_addData, METH_O},
    {"addExtraNamespaceDeclaration", (PyCFunction)Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclaration, METH_O},
    {"addExtraNamespaceDeclarations", (PyCFunction)Sbk_QXmlStreamReaderFunc_addExtraNamespaceDeclarations, METH_O},
    {"atEnd", (PyCFunction)Sbk_QXmlStreamReaderFunc_atEnd, METH_NOARGS},
    {"attributes", (PyCFunction)Sbk_QXmlStreamReaderFunc_attributes, METH_NOARGS},
    {"characterOffset", (PyCFunction)Sbk_QXmlStreamReaderFunc_characterOffset, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QXmlStreamReaderFunc_clear, METH_NOARGS},
    {"columnNumber", (PyCFunction)Sbk_QXmlStreamReaderFunc_columnNumber, METH_NOARGS},
    {"device", (PyCFunction)Sbk_QXmlStreamReaderFunc_device, METH_NOARGS},
    {"documentEncoding", (PyCFunction)Sbk_QXmlStreamReaderFunc_documentEncoding, METH_NOARGS},
    {"documentVersion", (PyCFunction)Sbk_QXmlStreamReaderFunc_documentVersion, METH_NOARGS},
    {"dtdName", (PyCFunction)Sbk_QXmlStreamReaderFunc_dtdName, METH_NOARGS},
    {"dtdPublicId", (PyCFunction)Sbk_QXmlStreamReaderFunc_dtdPublicId, METH_NOARGS},
    {"dtdSystemId", (PyCFunction)Sbk_QXmlStreamReaderFunc_dtdSystemId, METH_NOARGS},
    {"entityDeclarations", (PyCFunction)Sbk_QXmlStreamReaderFunc_entityDeclarations, METH_NOARGS},
    {"entityResolver", (PyCFunction)Sbk_QXmlStreamReaderFunc_entityResolver, METH_NOARGS},
    {"error", (PyCFunction)Sbk_QXmlStreamReaderFunc_error, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QXmlStreamReaderFunc_errorString, METH_NOARGS},
    {"hasError", (PyCFunction)Sbk_QXmlStreamReaderFunc_hasError, METH_NOARGS},
    {"isCDATA", (PyCFunction)Sbk_QXmlStreamReaderFunc_isCDATA, METH_NOARGS},
    {"isCharacters", (PyCFunction)Sbk_QXmlStreamReaderFunc_isCharacters, METH_NOARGS},
    {"isComment", (PyCFunction)Sbk_QXmlStreamReaderFunc_isComment, METH_NOARGS},
    {"isDTD", (PyCFunction)Sbk_QXmlStreamReaderFunc_isDTD, METH_NOARGS},
    {"isEndDocument", (PyCFunction)Sbk_QXmlStreamReaderFunc_isEndDocument, METH_NOARGS},
    {"isEndElement", (PyCFunction)Sbk_QXmlStreamReaderFunc_isEndElement, METH_NOARGS},
    {"isEntityReference", (PyCFunction)Sbk_QXmlStreamReaderFunc_isEntityReference, METH_NOARGS},
    {"isProcessingInstruction", (PyCFunction)Sbk_QXmlStreamReaderFunc_isProcessingInstruction, METH_NOARGS},
    {"isStandaloneDocument", (PyCFunction)Sbk_QXmlStreamReaderFunc_isStandaloneDocument, METH_NOARGS},
    {"isStartDocument", (PyCFunction)Sbk_QXmlStreamReaderFunc_isStartDocument, METH_NOARGS},
    {"isStartElement", (PyCFunction)Sbk_QXmlStreamReaderFunc_isStartElement, METH_NOARGS},
    {"isWhitespace", (PyCFunction)Sbk_QXmlStreamReaderFunc_isWhitespace, METH_NOARGS},
    {"lineNumber", (PyCFunction)Sbk_QXmlStreamReaderFunc_lineNumber, METH_NOARGS},
    {"name", (PyCFunction)Sbk_QXmlStreamReaderFunc_name, METH_NOARGS},
    {"namespaceDeclarations", (PyCFunction)Sbk_QXmlStreamReaderFunc_namespaceDeclarations, METH_NOARGS},
    {"namespaceProcessing", (PyCFunction)Sbk_QXmlStreamReaderFunc_namespaceProcessing, METH_NOARGS},
    {"namespaceUri", (PyCFunction)Sbk_QXmlStreamReaderFunc_namespaceUri, METH_NOARGS},
    {"notationDeclarations", (PyCFunction)Sbk_QXmlStreamReaderFunc_notationDeclarations, METH_NOARGS},
    {"prefix", (PyCFunction)Sbk_QXmlStreamReaderFunc_prefix, METH_NOARGS},
    {"processingInstructionData", (PyCFunction)Sbk_QXmlStreamReaderFunc_processingInstructionData, METH_NOARGS},
    {"processingInstructionTarget", (PyCFunction)Sbk_QXmlStreamReaderFunc_processingInstructionTarget, METH_NOARGS},
    {"qualifiedName", (PyCFunction)Sbk_QXmlStreamReaderFunc_qualifiedName, METH_NOARGS},
    {"raiseError", (PyCFunction)Sbk_QXmlStreamReaderFunc_raiseError, METH_VARARGS|METH_KEYWORDS},
    {"readElementText", (PyCFunction)Sbk_QXmlStreamReaderFunc_readElementText, METH_VARARGS},
    {"readNext", (PyCFunction)Sbk_QXmlStreamReaderFunc_readNext, METH_NOARGS},
    {"readNextStartElement", (PyCFunction)Sbk_QXmlStreamReaderFunc_readNextStartElement, METH_NOARGS},
    {"setDevice", (PyCFunction)Sbk_QXmlStreamReaderFunc_setDevice, METH_O},
    {"setEntityResolver", (PyCFunction)Sbk_QXmlStreamReaderFunc_setEntityResolver, METH_O},
    {"setNamespaceProcessing", (PyCFunction)Sbk_QXmlStreamReaderFunc_setNamespaceProcessing, METH_O},
    {"skipCurrentElement", (PyCFunction)Sbk_QXmlStreamReaderFunc_skipCurrentElement, METH_NOARGS},
    {"text", (PyCFunction)Sbk_QXmlStreamReaderFunc_text, METH_NOARGS},
    {"tokenString", (PyCFunction)Sbk_QXmlStreamReaderFunc_tokenString, METH_NOARGS},
    {"tokenType", (PyCFunction)Sbk_QXmlStreamReaderFunc_tokenType, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlStreamReader_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QXmlStreamReader",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlStreamReader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlStreamReader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlStreamReader(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlStreamReader_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlStreamReader_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlStreamReader_Type, &Shiboken::callCppDestructor<QXmlStreamReader >);
    Py_INCREF((PyObject*)&Sbk_QXmlStreamReader_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlStreamReader_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlStreamReader_Type, "QXmlStreamReader*");
    PyModule_AddObject(module, "QXmlStreamReader",
        ((PyObject*)&Sbk_QXmlStreamReader_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Error
    PyTypeObject* SbkPySide_QtCore_QXmlStreamReader_Error = Shiboken::Enum::newType("PySide.QtCore.QXmlStreamReader.Error");
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_ERROR_IDX] = SbkPySide_QtCore_QXmlStreamReader_Error;
    if (PyType_Ready(SbkPySide_QtCore_QXmlStreamReader_Error) < 0)
        return;
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,
            "Error",((PyObject*)SbkPySide_QtCore_QXmlStreamReader_Error));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_Error,(long) QXmlStreamReader::NoError, "NoError");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_Error->tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_Error,(long) QXmlStreamReader::UnexpectedElementError, "UnexpectedElementError");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"UnexpectedElementError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_Error->tp_dict,"UnexpectedElementError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_Error,(long) QXmlStreamReader::CustomError, "CustomError");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"CustomError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_Error->tp_dict,"CustomError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_Error,(long) QXmlStreamReader::NotWellFormedError, "NotWellFormedError");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"NotWellFormedError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_Error->tp_dict,"NotWellFormedError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_Error,(long) QXmlStreamReader::PrematureEndOfDocumentError, "PrematureEndOfDocumentError");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"PrematureEndOfDocumentError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_Error->tp_dict,"PrematureEndOfDocumentError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlStreamReader::Error");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Error");
    // end of enum Error

    // init enum: TokenType
    PyTypeObject* SbkPySide_QtCore_QXmlStreamReader_TokenType = Shiboken::Enum::newType("PySide.QtCore.QXmlStreamReader.TokenType");
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_TOKENTYPE_IDX] = SbkPySide_QtCore_QXmlStreamReader_TokenType;
    if (PyType_Ready(SbkPySide_QtCore_QXmlStreamReader_TokenType) < 0)
        return;
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,
            "TokenType",((PyObject*)SbkPySide_QtCore_QXmlStreamReader_TokenType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::NoToken, "NoToken");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"NoToken", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"NoToken", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::Invalid, "Invalid");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"Invalid", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"Invalid", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::StartDocument, "StartDocument");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"StartDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"StartDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::EndDocument, "EndDocument");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"EndDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"EndDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::StartElement, "StartElement");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"StartElement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"StartElement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::EndElement, "EndElement");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"EndElement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"EndElement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::Characters, "Characters");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"Characters", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"Characters", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::Comment, "Comment");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"Comment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"Comment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::DTD, "DTD");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"DTD", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"DTD", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::EntityReference, "EntityReference");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"EntityReference", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"EntityReference", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_TokenType,(long) QXmlStreamReader::ProcessingInstruction, "ProcessingInstruction");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"ProcessingInstruction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_TokenType->tp_dict,"ProcessingInstruction", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlStreamReader::TokenType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::TokenType");
    // end of enum TokenType

    // init enum: ReadElementTextBehaviour
    PyTypeObject* SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour = Shiboken::Enum::newType("PySide.QtCore.QXmlStreamReader.ReadElementTextBehaviour");
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMREADER_READELEMENTTEXTBEHAVIOUR_IDX] = SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour;
    if (PyType_Ready(SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour) < 0)
        return;
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,
            "ReadElementTextBehaviour",((PyObject*)SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour,(long) QXmlStreamReader::ErrorOnUnexpectedElement, "ErrorOnUnexpectedElement");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"ErrorOnUnexpectedElement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour->tp_dict,"ErrorOnUnexpectedElement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour,(long) QXmlStreamReader::IncludeChildElements, "IncludeChildElements");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"IncludeChildElements", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour->tp_dict,"IncludeChildElements", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour,(long) QXmlStreamReader::SkipChildElements, "SkipChildElements");
    PyDict_SetItemString(Sbk_QXmlStreamReader_Type.super.ht_type.tp_dict,"SkipChildElements", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QXmlStreamReader_ReadElementTextBehaviour->tp_dict,"SkipChildElements", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlStreamReader::ReadElementTextBehaviour");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ReadElementTextBehaviour");
    // end of enum ReadElementTextBehaviour


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamReader >("QXmlStreamReader*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamReader >(typeid(QXmlStreamReader).name());
    qRegisterMetaType< ::QXmlStreamReader* >("QXmlStreamReader*");
    qRegisterMetaType< ::QXmlStreamReader::Error >("QXmlStreamReader::Error");
    qRegisterMetaType< ::QXmlStreamReader::TokenType >("QXmlStreamReader::TokenType");
    qRegisterMetaType< ::QXmlStreamReader::ReadElementTextBehaviour >("QXmlStreamReader::ReadElementTextBehaviour");
}

