/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativeproperty_wrapper.h"

// Extra includes
#include <qdeclarativecontext.h>
#include <qdeclarativeengine.h>
#include <qdeclarativeproperty.h>
#include <qmetaobject.h>
#include <qobject.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDeclarativeProperty_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeProperty >()))
        return -1;

    QDeclarativeProperty* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDeclarativeProperty", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeProperty()
    // 1: QDeclarativeProperty(QObject*)
    // 2: QDeclarativeProperty(QObject*,QDeclarativeContext*)
    // 3: QDeclarativeProperty(QObject*,QDeclarativeEngine*)
    // 4: QDeclarativeProperty(QObject*,QString)
    // 5: QDeclarativeProperty(QObject*,QString,QDeclarativeContext*)
    // 6: QDeclarativeProperty(QObject*,QString,QDeclarativeEngine*)
    // 7: QDeclarativeProperty(QDeclarativeProperty)
    if (numArgs == 0) {
        overloadId = 0; // QDeclarativeProperty()
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QDeclarativeProperty(QObject*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QDeclarativeEngine * >::isConvertible(pyargs[1])) {
            overloadId = 3; // QDeclarativeProperty(QObject*,QDeclarativeEngine*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QDeclarativeContext * >::isConvertible(pyargs[1])) {
            overloadId = 2; // QDeclarativeProperty(QObject*,QDeclarativeContext*)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 4; // QDeclarativeProperty(QObject*,QString)
            } else if (numArgs == 3 && Shiboken::Converter< ::QDeclarativeEngine * >::isConvertible(pyargs[2])) {
                overloadId = 6; // QDeclarativeProperty(QObject*,QString,QDeclarativeEngine*)
            } else if (numArgs == 3 && Shiboken::Converter< ::QDeclarativeContext * >::isConvertible(pyargs[2])) {
                overloadId = 5; // QDeclarativeProperty(QObject*,QString,QDeclarativeContext*)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QDeclarativeProperty >::isConvertible(pyargs[0])) {
        overloadId = 7; // QDeclarativeProperty(QDeclarativeProperty)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeProperty_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDeclarativeProperty()
            {

                if(!PyErr_Occurred()) {
                    // QDeclarativeProperty()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeProperty();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDeclarativeProperty(QObject*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDeclarativeProperty(QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeProperty(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QDeclarativeProperty(QObject*,QDeclarativeContext*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QDeclarativeContext * cppArg1 = Shiboken::Converter<QDeclarativeContext * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QDeclarativeProperty(QObject*,QDeclarativeContext*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeProperty(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QDeclarativeProperty(QObject*,QDeclarativeEngine*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QDeclarativeEngine * cppArg1 = Shiboken::Converter<QDeclarativeEngine * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QDeclarativeProperty(QObject*,QDeclarativeEngine*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeProperty(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QDeclarativeProperty(QObject*,QString)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QDeclarativeProperty(QObject*,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeProperty(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QDeclarativeProperty(QObject*,QString,QDeclarativeContext*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QDeclarativeContext * cppArg2 = Shiboken::Converter<QDeclarativeContext * >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // QDeclarativeProperty(QObject*,QString,QDeclarativeContext*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeProperty(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // QDeclarativeProperty(QObject*,QString,QDeclarativeEngine*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QDeclarativeEngine * cppArg2 = Shiboken::Converter<QDeclarativeEngine * >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // QDeclarativeProperty(QObject*,QString,QDeclarativeEngine*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeProperty(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // QDeclarativeProperty(QDeclarativeProperty)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDeclarativeProperty cppArg0 = Shiboken::Converter<QDeclarativeProperty >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDeclarativeProperty(QDeclarativeProperty)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDeclarativeProperty(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeProperty >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDeclarativeProperty_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDeclarativeProperty_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject", "PySide.QtCore.QObject, PySide.QtDeclarative.QDeclarativeContext", "PySide.QtCore.QObject, PySide.QtDeclarative.QDeclarativeEngine", "PySide.QtCore.QObject, QString", "PySide.QtCore.QObject, QString, PySide.QtDeclarative.QDeclarativeContext", "PySide.QtCore.QObject, QString, PySide.QtDeclarative.QDeclarativeEngine", "PySide.QtDeclarative.QDeclarativeProperty", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeProperty", overloads);
        return -1;
}

static PyObject* Sbk_QDeclarativePropertyFunc_connectNotifySignal(PyObject* self, PyObject* args)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "connectNotifySignal", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: connectNotifySignal(QObject*,const char*)const
    // 1: connectNotifySignal(QObject*,int)const
    if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // connectNotifySignal(QObject*,int)const
        } else if (numArgs == 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
            overloadId = 0; // connectNotifySignal(QObject*,const char*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativePropertyFunc_connectNotifySignal_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // connectNotifySignal(QObject*,const char*)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // connectNotifySignal(QObject*,const char*)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->connectNotifySignal(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // connectNotifySignal(QObject*,int)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // connectNotifySignal(QObject*,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->connectNotifySignal(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativePropertyFunc_connectNotifySignal_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, str", "PySide.QtCore.QObject, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeProperty.connectNotifySignal", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativePropertyFunc_hasNotifySignal(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasNotifySignal()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->hasNotifySignal();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_index(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // index()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->index();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_isDesignable(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isDesignable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->isDesignable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_isProperty(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isProperty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->isProperty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_isResettable(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isResettable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->isResettable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_isSignalProperty(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSignalProperty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->isSignalProperty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_isValid(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_isWritable(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isWritable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->isWritable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_method(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // method()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMetaMethod cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->method();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMetaMethod >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_name(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_needsNotifySignal(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // needsNotifySignal()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->needsNotifySignal();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_object(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // object()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QObject * cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->object();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_property(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // property()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMetaProperty cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->property();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMetaProperty >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_propertyType(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // propertyType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->propertyType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_propertyTypeCategory(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // propertyTypeCategory()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeProperty::PropertyTypeCategory cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->propertyTypeCategory();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDeclarativeProperty::PropertyTypeCategory >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_propertyTypeName(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // propertyTypeName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const char * cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->propertyTypeName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< const char * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_read(PyObject* self, PyObject* args)
{
    QDeclarativeProperty* cppSelf = 0;
    if (self) {
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto Sbk_QDeclarativePropertyFunc_read_TypeError;

    if (!PyArg_UnpackTuple(args, "read", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: read()const
    // 1: read(QObject*,QString)
    // 2: read(QObject*,QString,QDeclarativeContext*)
    // 3: read(QObject*,QString,QDeclarativeEngine*)
    if (numArgs == 0) {
        overloadId = 0; // read()const
    } else if (numArgs >= 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // read(QObject*,QString)
        } else if (numArgs == 3 && Shiboken::Converter< ::QDeclarativeEngine * >::isConvertible(pyargs[2])) {
            overloadId = 3; // read(QObject*,QString,QDeclarativeEngine*)
        } else if (numArgs == 3 && Shiboken::Converter< ::QDeclarativeContext * >::isConvertible(pyargs[2])) {
            overloadId = 2; // read(QObject*,QString,QDeclarativeContext*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativePropertyFunc_read_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // read()const
            {

                if(!PyErr_Occurred()) {
                    // read()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVariant cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->read();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
                }
                break;
            }
            case 1: // read(QObject*,QString)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // read(QObject*,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVariant cppResult = QDeclarativeProperty::read(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
                }
                break;
            }
            case 2: // read(QObject*,QString,QDeclarativeContext*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QDeclarativeContext * cppArg2 = Shiboken::Converter<QDeclarativeContext * >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // read(QObject*,QString,QDeclarativeContext*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVariant cppResult = QDeclarativeProperty::read(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
                }
                break;
            }
            case 3: // read(QObject*,QString,QDeclarativeEngine*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QDeclarativeEngine * cppArg2 = Shiboken::Converter<QDeclarativeEngine * >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // read(QObject*,QString,QDeclarativeEngine*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVariant cppResult = QDeclarativeProperty::read(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativePropertyFunc_read_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject, QString", "PySide.QtCore.QObject, QString, PySide.QtDeclarative.QDeclarativeContext", "PySide.QtCore.QObject, QString, PySide.QtDeclarative.QDeclarativeEngine", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeProperty.read", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativePropertyFunc_reset(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // reset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->reset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_type(PyObject* self)
{
    QDeclarativeProperty* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeProperty::Type cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDeclarativeProperty::Type >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativePropertyFunc_write(PyObject* self, PyObject* args)
{
    QDeclarativeProperty* cppSelf = 0;
    if (self) {
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto Sbk_QDeclarativePropertyFunc_write_TypeError;

    if (!PyArg_UnpackTuple(args, "write", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: write(QObject*,QString,QVariant)
    // 1: write(QObject*,QString,QVariant,QDeclarativeContext*)
    // 2: write(QObject*,QString,QVariant,QDeclarativeEngine*)
    // 3: write(QVariant)const
    if (numArgs >= 3 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // write(QObject*,QString,QVariant)
        } else if (numArgs == 4 && Shiboken::Converter< ::QDeclarativeEngine * >::isConvertible(pyargs[3])) {
            overloadId = 2; // write(QObject*,QString,QVariant,QDeclarativeEngine*)
        } else if (numArgs == 4 && Shiboken::Converter< ::QDeclarativeContext * >::isConvertible(pyargs[3])) {
            overloadId = 1; // write(QObject*,QString,QVariant,QDeclarativeContext*)
        }
    } else if (numArgs == 1 && Shiboken::Converter< QVariant >::isConvertible(pyargs[0])) {
        overloadId = 3; // write(QVariant)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativePropertyFunc_write_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // write(QObject*,QString,QVariant)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QVariant cppArg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // write(QObject*,QString,QVariant)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QDeclarativeProperty::write(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // write(QObject*,QString,QVariant,QDeclarativeContext*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QVariant cppArg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return 0;
                QDeclarativeContext * cppArg3 = Shiboken::Converter<QDeclarativeContext * >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // write(QObject*,QString,QVariant,QDeclarativeContext*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QDeclarativeProperty::write(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // write(QObject*,QString,QVariant,QDeclarativeEngine*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                QVariant cppArg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return 0;
                QDeclarativeEngine * cppArg3 = Shiboken::Converter<QDeclarativeEngine * >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // write(QObject*,QString,QVariant,QDeclarativeEngine*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QDeclarativeProperty::write(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // write(QVariant)const
            {
                QVariant cppArg0 = Shiboken::Converter<QVariant >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // write(QVariant)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QDeclarativeProperty*>(cppSelf)->write(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativePropertyFunc_write_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, QString, QVariant", "PySide.QtCore.QObject, QString, QVariant, PySide.QtDeclarative.QDeclarativeContext", "PySide.QtCore.QObject, QString, QVariant, PySide.QtDeclarative.QDeclarativeEngine", "QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeProperty.write", overloads);
        return 0;
}

static PyObject *Sbk_QDeclarativeProperty___copy__(PyObject *self)
{
        QDeclarativeProperty* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDeclarativeProperty*>::toCpp(self);
        PyObject* pyResult = 0;
        QDeclarativeProperty* copy = new QDeclarativeProperty(*cppSelf);
        pyResult = Shiboken::Converter<QDeclarativeProperty*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QDeclarativePropertyMethod_read = {
    "read", (PyCFunction)Sbk_QDeclarativePropertyFunc_read, METH_VARARGS|METH_STATIC
};

static PyMethodDef Sbk_QDeclarativePropertyMethod_write = {
    "write", (PyCFunction)Sbk_QDeclarativePropertyFunc_write, METH_VARARGS|METH_STATIC
};

static PyMethodDef Sbk_QDeclarativeProperty_methods[] = {
    {"connectNotifySignal", (PyCFunction)Sbk_QDeclarativePropertyFunc_connectNotifySignal, METH_VARARGS},
    {"hasNotifySignal", (PyCFunction)Sbk_QDeclarativePropertyFunc_hasNotifySignal, METH_NOARGS},
    {"index", (PyCFunction)Sbk_QDeclarativePropertyFunc_index, METH_NOARGS},
    {"isDesignable", (PyCFunction)Sbk_QDeclarativePropertyFunc_isDesignable, METH_NOARGS},
    {"isProperty", (PyCFunction)Sbk_QDeclarativePropertyFunc_isProperty, METH_NOARGS},
    {"isResettable", (PyCFunction)Sbk_QDeclarativePropertyFunc_isResettable, METH_NOARGS},
    {"isSignalProperty", (PyCFunction)Sbk_QDeclarativePropertyFunc_isSignalProperty, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QDeclarativePropertyFunc_isValid, METH_NOARGS},
    {"isWritable", (PyCFunction)Sbk_QDeclarativePropertyFunc_isWritable, METH_NOARGS},
    {"method", (PyCFunction)Sbk_QDeclarativePropertyFunc_method, METH_NOARGS},
    {"name", (PyCFunction)Sbk_QDeclarativePropertyFunc_name, METH_NOARGS},
    {"needsNotifySignal", (PyCFunction)Sbk_QDeclarativePropertyFunc_needsNotifySignal, METH_NOARGS},
    {"object", (PyCFunction)Sbk_QDeclarativePropertyFunc_object, METH_NOARGS},
    {"property", (PyCFunction)Sbk_QDeclarativePropertyFunc_property, METH_NOARGS},
    {"propertyType", (PyCFunction)Sbk_QDeclarativePropertyFunc_propertyType, METH_NOARGS},
    {"propertyTypeCategory", (PyCFunction)Sbk_QDeclarativePropertyFunc_propertyTypeCategory, METH_NOARGS},
    {"propertyTypeName", (PyCFunction)Sbk_QDeclarativePropertyFunc_propertyTypeName, METH_NOARGS},
    Sbk_QDeclarativePropertyMethod_read,
    {"reset", (PyCFunction)Sbk_QDeclarativePropertyFunc_reset, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QDeclarativePropertyFunc_type, METH_NOARGS},
    Sbk_QDeclarativePropertyMethod_write,

    {"__copy__", (PyCFunction)Sbk_QDeclarativeProperty___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QDeclarativeProperty_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (reinterpret_cast<SbkObject*>(self)->ob_dict) {
            PyObject* meth = PyDict_GetItem(reinterpret_cast<SbkObject*>(self)->ob_dict, name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "read") == 0)
            return PyCFunction_NewEx(&Sbk_QDeclarativePropertyMethod_read, self, 0);
        if (strcmp(cname, "write") == 0)
            return PyCFunction_NewEx(&Sbk_QDeclarativePropertyMethod_write, self, 0);
    }
    return PyObject_GenericGetAttr(self, name);
}

// Rich comparison
static PyObject* Sbk_QDeclarativeProperty_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QDeclarativeProperty& cppSelf = *Shiboken::Converter< QDeclarativeProperty* >::toCpp(self);

    switch (op) {
        case Py_EQ:
            if (Shiboken::Converter< ::QDeclarativeProperty >::isConvertible(arg)) {
                // operator==(const QDeclarativeProperty & arg__1) const
                QDeclarativeProperty cppArg0 = Shiboken::Converter< ::QDeclarativeProperty >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QDeclarativeProperty_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QDeclarativeProperty_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDeclarativeProperty_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeProperty",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         Sbk_QDeclarativeProperty_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QDeclarativeProperty_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDeclarativeProperty_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDeclarativeProperty_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDeclarativeProperty(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPROPERTY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDeclarativeProperty_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDeclarativeProperty_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDeclarativeProperty_Type, &Shiboken::callCppDestructor<QDeclarativeProperty >);
    Py_INCREF((PyObject*)&Sbk_QDeclarativeProperty_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QDeclarativeProperty_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QDeclarativeProperty_Type, "QDeclarativeProperty");
    PyModule_AddObject(module, "QDeclarativeProperty",
        ((PyObject*)&Sbk_QDeclarativeProperty_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Type
    PyTypeObject* SbkPySide_QtDeclarative_QDeclarativeProperty_Type = Shiboken::Enum::newType("PySide.QtDeclarative.QDeclarativeProperty.Type");
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPROPERTY_TYPE_IDX] = SbkPySide_QtDeclarative_QDeclarativeProperty_Type;
    if (PyType_Ready(SbkPySide_QtDeclarative_QDeclarativeProperty_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QDeclarativeProperty_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)SbkPySide_QtDeclarative_QDeclarativeProperty_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeProperty_Type,(long) QDeclarativeProperty::Invalid, "Invalid");
    PyDict_SetItemString(Sbk_QDeclarativeProperty_Type.super.ht_type.tp_dict,"Invalid", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_Type->tp_dict,"Invalid", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeProperty_Type,(long) QDeclarativeProperty::Property, "Property");
    PyDict_SetItemString(Sbk_QDeclarativeProperty_Type.super.ht_type.tp_dict,"Property", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_Type->tp_dict,"Property", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeProperty_Type,(long) QDeclarativeProperty::SignalProperty, "SignalProperty");
    PyDict_SetItemString(Sbk_QDeclarativeProperty_Type.super.ht_type.tp_dict,"SignalProperty", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_Type->tp_dict,"SignalProperty", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDeclarativeProperty::Type");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Type");
    // end of enum Type

    // init enum: PropertyTypeCategory
    PyTypeObject* SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory = Shiboken::Enum::newType("PySide.QtDeclarative.QDeclarativeProperty.PropertyTypeCategory");
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPROPERTY_PROPERTYTYPECATEGORY_IDX] = SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory;
    if (PyType_Ready(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory) < 0)
        return;
    PyDict_SetItemString(Sbk_QDeclarativeProperty_Type.super.ht_type.tp_dict,
            "PropertyTypeCategory",((PyObject*)SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory,(long) QDeclarativeProperty::InvalidCategory, "InvalidCategory");
    PyDict_SetItemString(Sbk_QDeclarativeProperty_Type.super.ht_type.tp_dict,"InvalidCategory", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory->tp_dict,"InvalidCategory", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory,(long) QDeclarativeProperty::List, "List");
    PyDict_SetItemString(Sbk_QDeclarativeProperty_Type.super.ht_type.tp_dict,"List", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory->tp_dict,"List", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory,(long) QDeclarativeProperty::Object, "Object");
    PyDict_SetItemString(Sbk_QDeclarativeProperty_Type.super.ht_type.tp_dict,"Object", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory->tp_dict,"Object", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory,(long) QDeclarativeProperty::Normal, "Normal");
    PyDict_SetItemString(Sbk_QDeclarativeProperty_Type.super.ht_type.tp_dict,"Normal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeProperty_PropertyTypeCategory->tp_dict,"Normal", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDeclarativeProperty::PropertyTypeCategory");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PropertyTypeCategory");
    // end of enum PropertyTypeCategory


    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeProperty >("QDeclarativeProperty");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeProperty >("QDeclarativeProperty*");
    Shiboken::TypeResolver::createValueTypeResolver<QDeclarativeProperty >(typeid(QDeclarativeProperty).name());
    qRegisterMetaType< ::QDeclarativeProperty >("QDeclarativeProperty");
    qRegisterMetaType< ::QDeclarativeProperty::Type >("QDeclarativeProperty::Type");
    qRegisterMetaType< ::QDeclarativeProperty::PropertyTypeCategory >("QDeclarativeProperty::PropertyTypeCategory");
}

