/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qclipboard_wrapper.h"

// Extra includes
#include <QImage>
#include <QList>
#include <QPixmap>
#include <qbytearray.h>
#include <qclipboard.h>
#include <qcoreevent.h>
#include <qimage.h>
#include <qmimedata.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpixmap.h>
#include <qthread.h>



// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QClipboardFunc_clear(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.clear(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:clear", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: clear(QClipboard::Mode)
    if (numArgs == 0) {
        overloadId = 0; // clear(QClipboard::Mode)
    } else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(pyargs[0])) {
        overloadId = 0; // clear(QClipboard::Mode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_clear_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QClipboardFunc_clear_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.clear(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QClipboard::Mode cppArg0 = pyargs[0] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[0]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
                // clear(QClipboard::Mode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QClipboardFunc_clear_TypeError:
        const char* overloads[] = {"PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.clear", overloads);
        return 0;
}

static PyObject* Sbk_QClipboardFunc_connectNotify(PyObject* self, PyObject* arg)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: connectNotify(const char*)
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // connectNotify(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_connectNotify_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // connectNotify(const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QClipboard::connectNotify(cppArg0) : cppSelf->connectNotify(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QClipboardFunc_connectNotify_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QClipboard.connectNotify", overloads);
        return 0;
}

static PyObject* Sbk_QClipboardFunc_event(PyObject* self, PyObject* arg)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QClipboard::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QClipboardFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QClipboard.event", overloads);
        return 0;
}

static PyObject* Sbk_QClipboardFunc_image(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.image(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:image", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: image(QClipboard::Mode)const
    if (numArgs == 0) {
        overloadId = 0; // image(QClipboard::Mode)const
    } else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(pyargs[0])) {
        overloadId = 0; // image(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_image_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QClipboardFunc_image_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.image(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QClipboard::Mode cppArg0 = pyargs[0] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[0]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
                // image(QClipboard::Mode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QClipboard*>(cppSelf)->image(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QClipboardFunc_image_TypeError:
        const char* overloads[] = {"PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.image", overloads);
        return 0;
}

static PyObject* Sbk_QClipboardFunc_mimeData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.mimeData(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:mimeData", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: mimeData(QClipboard::Mode)const
    if (numArgs == 0) {
        overloadId = 0; // mimeData(QClipboard::Mode)const
    } else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(pyargs[0])) {
        overloadId = 0; // mimeData(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_mimeData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QClipboardFunc_mimeData_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.mimeData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QClipboard::Mode cppArg0 = pyargs[0] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[0]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
                // mimeData(QClipboard::Mode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QMimeData * cppResult = const_cast<const QClipboard*>(cppSelf)->mimeData(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMimeData * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QClipboardFunc_mimeData_TypeError:
        const char* overloads[] = {"PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.mimeData", overloads);
        return 0;
}

static PyObject* Sbk_QClipboardFunc_ownsClipboard(PyObject* self)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ownsClipboard()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QClipboard*>(cppSelf)->ownsClipboard();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QClipboardFunc_ownsFindBuffer(PyObject* self)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ownsFindBuffer()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QClipboard*>(cppSelf)->ownsFindBuffer();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QClipboardFunc_ownsSelection(PyObject* self)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // ownsSelection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QClipboard*>(cppSelf)->ownsSelection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QClipboardFunc_pixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.pixmap(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:pixmap", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: pixmap(QClipboard::Mode)const
    if (numArgs == 0) {
        overloadId = 0; // pixmap(QClipboard::Mode)const
    } else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(pyargs[0])) {
        overloadId = 0; // pixmap(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_pixmap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QClipboardFunc_pixmap_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.pixmap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QClipboard::Mode cppArg0 = pyargs[0] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[0]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
                // pixmap(QClipboard::Mode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmap cppResult = const_cast<const QClipboard*>(cppSelf)->pixmap(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QClipboardFunc_pixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.pixmap", overloads);
        return 0;
}

static PyObject* Sbk_QClipboardFunc_setImage(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setImage(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setImage(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setImage", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setImage(QImage,QClipboard::Mode)
    if (Shiboken::Converter< ::QImage >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setImage(QImage,QClipboard::Mode)
        } else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(pyargs[1])) {
            overloadId = 0; // setImage(QImage,QClipboard::Mode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_setImage_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QClipboardFunc_setImage_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setImage(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(pyargs[0]);
            QClipboard::Mode cppArg1 = pyargs[1] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[1]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
                // setImage(QImage,QClipboard::Mode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setImage(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QClipboardFunc_setImage_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage, PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.setImage", overloads);
        return 0;
}

static PyObject* Sbk_QClipboardFunc_setMimeData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setMimeData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setMimeData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setMimeData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMimeData(QMimeData*,QClipboard::Mode)
    if (Shiboken::Converter< ::QMimeData * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setMimeData(QMimeData*,QClipboard::Mode)
        } else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(pyargs[1])) {
            overloadId = 0; // setMimeData(QMimeData*,QClipboard::Mode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_setMimeData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QClipboardFunc_setMimeData_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setMimeData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QMimeData * cppArg0 = Shiboken::Converter<QMimeData * >::toCpp(pyargs[0]);
            QClipboard::Mode cppArg1 = pyargs[1] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[1]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
                // setMimeData(QMimeData*,QClipboard::Mode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMimeData(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[0]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QClipboardFunc_setMimeData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMimeData, PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.setMimeData", overloads);
        return 0;
}

static PyObject* Sbk_QClipboardFunc_setPixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setPixmap(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setPixmap(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setPixmap", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPixmap(QPixmap,QClipboard::Mode)
    if (Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setPixmap(QPixmap,QClipboard::Mode)
        } else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(pyargs[1])) {
            overloadId = 0; // setPixmap(QPixmap,QClipboard::Mode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_setPixmap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QClipboardFunc_setPixmap_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPixmap cppArg0 = Shiboken::Converter<QPixmap >::toCpp(pyargs[0]);
            QClipboard::Mode cppArg1 = pyargs[1] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[1]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
                // setPixmap(QPixmap,QClipboard::Mode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPixmap(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QClipboardFunc_setPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap, PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.setPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QClipboardFunc_setText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setText(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.setText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setText", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setText(QString,QClipboard::Mode)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setText(QString,QClipboard::Mode)
        } else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(pyargs[1])) {
            overloadId = 0; // setText(QString,QClipboard::Mode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_setText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QClipboardFunc_setText_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.setText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QClipboard::Mode cppArg1 = pyargs[1] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[1]) : QClipboard::Clipboard;

            if(!PyErr_Occurred()) {
                // setText(QString,QClipboard::Mode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setText(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QClipboardFunc_setText_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QClipboard.Mode = Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.setText", overloads);
        return 0;
}

static PyObject* Sbk_QClipboardFunc_supportsFindBuffer(PyObject* self)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportsFindBuffer()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QClipboard*>(cppSelf)->supportsFindBuffer();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QClipboardFunc_supportsSelection(PyObject* self)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportsSelection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QClipboard*>(cppSelf)->supportsSelection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QClipboardFunc_text(PyObject* self, PyObject* args, PyObject* kwds)
{
    QClipboard* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QClipboard* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QClipboard.text(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:text", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: text(QClipboard::Mode)const
    // 1: text(QString&,QClipboard::Mode)const
    if (numArgs == 0) {
        overloadId = 0; // text(QClipboard::Mode)const
    } else if (Shiboken::Converter< ::QString & >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // text(QString&,QClipboard::Mode)const
        } else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(pyargs[1])) {
            overloadId = 1; // text(QString&,QClipboard::Mode)const
        }
    } else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(pyargs[0])) {
        overloadId = 0; // text(QClipboard::Mode)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QClipboardFunc_text_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // text(QClipboard::Mode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QClipboardFunc_text_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.text(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QClipboard::Mode cppArg0 = pyargs[0] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[0]) : QClipboard::Clipboard;

                if(!PyErr_Occurred()) {
                    // text(QClipboard::Mode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QClipboard*>(cppSelf)->text(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // text(QString&,QClipboard::Mode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QClipboard::Mode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QClipboardFunc_text_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QClipboard.text(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QClipboard::Mode cppArg1 = pyargs[1] ? Shiboken::Converter<QClipboard::Mode >::toCpp(pyargs[1]) : QClipboard::Clipboard;

                if(!PyErr_Occurred()) {
                    // text(QString&,QClipboard::Mode)const


                    // Begin code injection

                    QString retval_ = cppSelf->text(cppArg0, cppArg1);
                    pyResult = Shiboken::makeTuple(retval_, cppArg0);

                    // End of code injection
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QClipboardFunc_text_TypeError:
        const char* overloads[] = {"PySide.QtGui.QClipboard.Mode = Clipboard", "QString, PySide.QtGui.QClipboard.Mode = QClipboard.Clipboard", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QClipboard.text", overloads);
        return 0;
}

static PyMethodDef Sbk_QClipboard_methods[] = {
    {"clear", (PyCFunction)Sbk_QClipboardFunc_clear, METH_VARARGS|METH_KEYWORDS},
    {"connectNotify", (PyCFunction)Sbk_QClipboardFunc_connectNotify, METH_O},
    {"event", (PyCFunction)Sbk_QClipboardFunc_event, METH_O},
    {"image", (PyCFunction)Sbk_QClipboardFunc_image, METH_VARARGS|METH_KEYWORDS},
    {"mimeData", (PyCFunction)Sbk_QClipboardFunc_mimeData, METH_VARARGS|METH_KEYWORDS},
    {"ownsClipboard", (PyCFunction)Sbk_QClipboardFunc_ownsClipboard, METH_NOARGS},
    {"ownsFindBuffer", (PyCFunction)Sbk_QClipboardFunc_ownsFindBuffer, METH_NOARGS},
    {"ownsSelection", (PyCFunction)Sbk_QClipboardFunc_ownsSelection, METH_NOARGS},
    {"pixmap", (PyCFunction)Sbk_QClipboardFunc_pixmap, METH_VARARGS|METH_KEYWORDS},
    {"setImage", (PyCFunction)Sbk_QClipboardFunc_setImage, METH_VARARGS|METH_KEYWORDS},
    {"setMimeData", (PyCFunction)Sbk_QClipboardFunc_setMimeData, METH_VARARGS|METH_KEYWORDS},
    {"setPixmap", (PyCFunction)Sbk_QClipboardFunc_setPixmap, METH_VARARGS|METH_KEYWORDS},
    {"setText", (PyCFunction)Sbk_QClipboardFunc_setText, METH_VARARGS|METH_KEYWORDS},
    {"supportsFindBuffer", (PyCFunction)Sbk_QClipboardFunc_supportsFindBuffer, METH_NOARGS},
    {"supportsSelection", (PyCFunction)Sbk_QClipboardFunc_supportsSelection, METH_NOARGS},
    {"text", (PyCFunction)Sbk_QClipboardFunc_text, METH_VARARGS|METH_KEYWORDS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QClipboard_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QClipboard",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          SbkDeallocWrapperWithPrivateDtor,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QClipboard_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QClipboard_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QClipboard*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QClipboard_Type;
    return 0;
}


void init_QClipboard(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QCLIPBOARD_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QClipboard_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QClipboard_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QClipboard_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QClipboard_Type, &QClipboard::staticMetaObject);    Sbk_QClipboard_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Py_INCREF((PyObject*)&Sbk_QClipboard_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QClipboard_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QClipboard_Type, &Sbk_QClipboard_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QClipboard_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QClipboard_Type, "QClipboard*");
    PyModule_AddObject(module, "QClipboard",
        ((PyObject*)&Sbk_QClipboard_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Mode
    PyTypeObject* SbkPySide_QtGui_QClipboard_Mode = Shiboken::Enum::newType("PySide.QtGui.QClipboard.Mode");
    SbkPySide_QtGuiTypes[SBK_QCLIPBOARD_MODE_IDX] = SbkPySide_QtGui_QClipboard_Mode;
    if (PyType_Ready(SbkPySide_QtGui_QClipboard_Mode) < 0)
        return;
    PyDict_SetItemString(Sbk_QClipboard_Type.super.ht_type.tp_dict,
            "Mode",((PyObject*)SbkPySide_QtGui_QClipboard_Mode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QClipboard_Mode,(long) QClipboard::Clipboard, "Clipboard");
    PyDict_SetItemString(Sbk_QClipboard_Type.super.ht_type.tp_dict,"Clipboard", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QClipboard_Mode->tp_dict,"Clipboard", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QClipboard_Mode,(long) QClipboard::Selection, "Selection");
    PyDict_SetItemString(Sbk_QClipboard_Type.super.ht_type.tp_dict,"Selection", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QClipboard_Mode->tp_dict,"Selection", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QClipboard_Mode,(long) QClipboard::FindBuffer, "FindBuffer");
    PyDict_SetItemString(Sbk_QClipboard_Type.super.ht_type.tp_dict,"FindBuffer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QClipboard_Mode->tp_dict,"FindBuffer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QClipboard_Mode,(long) QClipboard::LastMode, "LastMode");
    PyDict_SetItemString(Sbk_QClipboard_Type.super.ht_type.tp_dict,"LastMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QClipboard_Mode->tp_dict,"LastMode", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QClipboard::Mode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QClipboard$ConcreteWrapper::Mode");
    // end of enum Mode

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("dataChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QClipboard_Type, "dataChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("selectionChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QClipboard_Type, "selectionChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("changed", "QClipboard::Mode", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QClipboard_Type, "changed", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("findBufferChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QClipboard_Type, "findBufferChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QClipboard >("QClipboard*");
    Shiboken::TypeResolver::createObjectTypeResolver<QClipboard >("QClipboard$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QClipboard >(typeid(QClipboard).name());
    qRegisterMetaType< ::QClipboard::Mode >("QClipboard::Mode");
}

