/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qcontextmenuevent_wrapper.h"

// Extra includes
#include <qpoint.h>


// Native ---------------------------------------------------------

QContextMenuEventWrapper::QContextMenuEventWrapper(QContextMenuEvent::Reason reason, const QPoint & pos) : QContextMenuEvent(reason, pos) {
    // ... middle
}

QContextMenuEventWrapper::QContextMenuEventWrapper(QContextMenuEvent::Reason reason, const QPoint & pos, const QPoint & globalPos) : QContextMenuEvent(reason, pos, globalPos) {
    // ... middle
}

QContextMenuEventWrapper::QContextMenuEventWrapper(QContextMenuEvent::Reason reason, const QPoint & pos, const QPoint & globalPos, QFlags<Qt::KeyboardModifier> modifiers) : QContextMenuEvent(reason, pos, globalPos, modifiers) {
    // ... middle
}

QContextMenuEventWrapper::~QContextMenuEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QContextMenuEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QContextMenuEvent >()))
        return -1;

    QContextMenuEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QContextMenuEvent", 2, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QContextMenuEvent(QContextMenuEvent::Reason,QPoint)
    // 1: QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint)
    // 2: QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint,QFlags<Qt::KeyboardModifier>)
    if (numArgs >= 2 && Shiboken::Converter< ::QContextMenuEvent::Reason >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // QContextMenuEvent(QContextMenuEvent::Reason,QPoint)
        } else if (Shiboken::Converter< ::QPoint >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint)
            } else if (numArgs == 4 && Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[3])) {
                overloadId = 2; // QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint,QFlags<Qt::KeyboardModifier>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QContextMenuEvent_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QContextMenuEvent(QContextMenuEvent::Reason,QPoint)
            {
                QContextMenuEvent::Reason cppArg0 = Shiboken::Converter<QContextMenuEvent::Reason >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QContextMenuEvent(QContextMenuEvent::Reason,QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QContextMenuEventWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint)
            {
                QContextMenuEvent::Reason cppArg0 = Shiboken::Converter<QContextMenuEvent::Reason >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QPoint cppArg2 = Shiboken::Converter<QPoint >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QContextMenuEventWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint,QFlags<Qt::KeyboardModifier>)
            {
                QContextMenuEvent::Reason cppArg0 = Shiboken::Converter<QContextMenuEvent::Reason >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QPoint cppArg2 = Shiboken::Converter<QPoint >::toCpp(pyargs[2]);
                QFlags<Qt::KeyboardModifier> cppArg3 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // QContextMenuEvent(QContextMenuEvent::Reason,QPoint,QPoint,QFlags<Qt::KeyboardModifier>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QContextMenuEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QContextMenuEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QContextMenuEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QContextMenuEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QContextMenuEvent.Reason, PySide.QtCore.QPoint", "PySide.QtGui.QContextMenuEvent.Reason, PySide.QtCore.QPoint, PySide.QtCore.QPoint", "PySide.QtGui.QContextMenuEvent.Reason, PySide.QtCore.QPoint, PySide.QtCore.QPoint, PySide.QtCore.Qt.KeyboardModifiers", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QContextMenuEvent", overloads);
        return -1;
}

static PyObject* Sbk_QContextMenuEventFunc_globalPos(PyObject* self)
{
    QContextMenuEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // globalPos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QPoint & cppResult = const_cast<const QContextMenuEvent*>(cppSelf)->globalPos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QContextMenuEventFunc_globalX(PyObject* self)
{
    QContextMenuEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // globalX()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QContextMenuEvent*>(cppSelf)->globalX();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QContextMenuEventFunc_globalY(PyObject* self)
{
    QContextMenuEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // globalY()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QContextMenuEvent*>(cppSelf)->globalY();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QContextMenuEventFunc_pos(PyObject* self)
{
    QContextMenuEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QPoint & cppResult = const_cast<const QContextMenuEvent*>(cppSelf)->pos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QContextMenuEventFunc_reason(PyObject* self)
{
    QContextMenuEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // reason()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QContextMenuEvent::Reason cppResult = const_cast<const QContextMenuEvent*>(cppSelf)->reason();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QContextMenuEvent::Reason >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QContextMenuEventFunc_x(PyObject* self)
{
    QContextMenuEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // x()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QContextMenuEvent*>(cppSelf)->x();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QContextMenuEventFunc_y(PyObject* self)
{
    QContextMenuEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QContextMenuEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // y()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QContextMenuEvent*>(cppSelf)->y();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QContextMenuEvent_methods[] = {
    {"globalPos", (PyCFunction)Sbk_QContextMenuEventFunc_globalPos, METH_NOARGS},
    {"globalX", (PyCFunction)Sbk_QContextMenuEventFunc_globalX, METH_NOARGS},
    {"globalY", (PyCFunction)Sbk_QContextMenuEventFunc_globalY, METH_NOARGS},
    {"pos", (PyCFunction)Sbk_QContextMenuEventFunc_pos, METH_NOARGS},
    {"reason", (PyCFunction)Sbk_QContextMenuEventFunc_reason, METH_NOARGS},
    {"x", (PyCFunction)Sbk_QContextMenuEventFunc_x, METH_NOARGS},
    {"y", (PyCFunction)Sbk_QContextMenuEventFunc_y, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QContextMenuEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QContextMenuEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QContextMenuEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QContextMenuEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QContextMenuEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QContextMenuEvent*>(cptr)->type() == QEvent::ContextMenu)
        return &Sbk_QContextMenuEvent_Type;
    return 0;
}


void init_QContextMenuEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QCONTEXTMENUEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QContextMenuEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QContextMenuEvent_Type);
    Sbk_QContextMenuEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QContextMenuEvent_Type, &Shiboken::callCppDestructor<QContextMenuEvent >);
    Py_INCREF((PyObject*)&Sbk_QContextMenuEvent_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QContextMenuEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QContextMenuEvent_Type, &Sbk_QContextMenuEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX]), &Sbk_QContextMenuEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QContextMenuEvent_Type, "QContextMenuEvent*");
    PyModule_AddObject(module, "QContextMenuEvent",
        ((PyObject*)&Sbk_QContextMenuEvent_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Reason
    PyTypeObject* SbkPySide_QtGui_QContextMenuEvent_Reason = Shiboken::Enum::newType("PySide.QtGui.QContextMenuEvent.Reason");
    SbkPySide_QtGuiTypes[SBK_QCONTEXTMENUEVENT_REASON_IDX] = SbkPySide_QtGui_QContextMenuEvent_Reason;
    if (PyType_Ready(SbkPySide_QtGui_QContextMenuEvent_Reason) < 0)
        return;
    PyDict_SetItemString(Sbk_QContextMenuEvent_Type.super.ht_type.tp_dict,
            "Reason",((PyObject*)SbkPySide_QtGui_QContextMenuEvent_Reason));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QContextMenuEvent_Reason,(long) QContextMenuEvent::Mouse, "Mouse");
    PyDict_SetItemString(Sbk_QContextMenuEvent_Type.super.ht_type.tp_dict,"Mouse", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QContextMenuEvent_Reason->tp_dict,"Mouse", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QContextMenuEvent_Reason,(long) QContextMenuEvent::Keyboard, "Keyboard");
    PyDict_SetItemString(Sbk_QContextMenuEvent_Type.super.ht_type.tp_dict,"Keyboard", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QContextMenuEvent_Reason->tp_dict,"Keyboard", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QContextMenuEvent_Reason,(long) QContextMenuEvent::Other, "Other");
    PyDict_SetItemString(Sbk_QContextMenuEvent_Type.super.ht_type.tp_dict,"Other", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QContextMenuEvent_Reason->tp_dict,"Other", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QContextMenuEvent::Reason");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Reason");
    // end of enum Reason


    Shiboken::TypeResolver::createObjectTypeResolver<QContextMenuEvent >("QContextMenuEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QContextMenuEvent >(typeid(QContextMenuEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QContextMenuEvent >(typeid(QContextMenuEventWrapper).name());
    qRegisterMetaType< ::QContextMenuEvent* >("QContextMenuEvent*");
    qRegisterMetaType< ::QContextMenuEvent::Reason >("QContextMenuEvent::Reason");
}

