/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgraphicsscenewheelevent_wrapper.h"

// Extra includes
#include <qgraphicssceneevent.h>
#include <qpoint.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QGraphicsSceneWheelEventWrapper::QGraphicsSceneWheelEventWrapper(QEvent::Type type) : QGraphicsSceneWheelEvent(type) {
    // ... middle
}

QGraphicsSceneWheelEventWrapper::~QGraphicsSceneWheelEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsSceneWheelEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsSceneWheelEvent >()))
        return -1;

    QGraphicsSceneWheelEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsSceneWheelEvent(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QGraphicsSceneWheelEvent", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsSceneWheelEvent(QEvent::Type)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsSceneWheelEvent(QEvent::Type)
    } else if (Shiboken::Converter< ::QEvent::Type >::isConvertible(pyargs[0])) {
        overloadId = 0; // QGraphicsSceneWheelEvent(QEvent::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneWheelEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "type");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "type";
                    else if (Shiboken::Converter< ::QEvent::Type >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QGraphicsSceneWheelEvent_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsSceneWheelEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QEvent::Type cppArg0 = pyargs[0] ? Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]) : QEvent::None;

            if(!PyErr_Occurred()) {
                // QGraphicsSceneWheelEvent(QEvent::Type)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QGraphicsSceneWheelEventWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsSceneWheelEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGraphicsSceneWheelEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGraphicsSceneWheelEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsSceneWheelEvent", overloads);
        return -1;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_buttons(PyObject* self)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // buttons()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::MouseButton> cppResult = const_cast<const QGraphicsSceneWheelEvent*>(cppSelf)->buttons();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::MouseButton> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_delta(PyObject* self)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // delta()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QGraphicsSceneWheelEvent*>(cppSelf)->delta();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_modifiers(PyObject* self)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // modifiers()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::KeyboardModifier> cppResult = const_cast<const QGraphicsSceneWheelEvent*>(cppSelf)->modifiers();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_orientation(PyObject* self)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // orientation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::Orientation cppResult = const_cast<const QGraphicsSceneWheelEvent*>(cppSelf)->orientation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::Orientation >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_pos(PyObject* self)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QGraphicsSceneWheelEvent*>(cppSelf)->pos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_scenePos(PyObject* self)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scenePos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QGraphicsSceneWheelEvent*>(cppSelf)->scenePos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_screenPos(PyObject* self)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // screenPos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QGraphicsSceneWheelEvent*>(cppSelf)->screenPos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_setButtons(PyObject* self, PyObject* arg)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setButtons(QFlags<Qt::MouseButton>)
    if (Shiboken::Converter< ::QFlags<Qt::MouseButton> >::isConvertible(arg)) {
        overloadId = 0; // setButtons(QFlags<Qt::MouseButton>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneWheelEventFunc_setButtons_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::MouseButton> cppArg0 = Shiboken::Converter<QFlags<Qt::MouseButton> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setButtons(QFlags<Qt::MouseButton>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setButtons(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneWheelEventFunc_setButtons_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.MouseButtons", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneWheelEvent.setButtons", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_setDelta(PyObject* self, PyObject* arg)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDelta(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDelta(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneWheelEventFunc_setDelta_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDelta(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDelta(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneWheelEventFunc_setDelta_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneWheelEvent.setDelta", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_setModifiers(PyObject* self, PyObject* arg)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModifiers(QFlags<Qt::KeyboardModifier>)
    if (Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::isConvertible(arg)) {
        overloadId = 0; // setModifiers(QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneWheelEventFunc_setModifiers_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::KeyboardModifier> cppArg0 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setModifiers(QFlags<Qt::KeyboardModifier>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setModifiers(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneWheelEventFunc_setModifiers_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.KeyboardModifiers", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneWheelEvent.setModifiers", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_setOrientation(PyObject* self, PyObject* arg)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOrientation(Qt::Orientation)
    if (Shiboken::Converter< ::Qt::Orientation >::isConvertible(arg)) {
        overloadId = 0; // setOrientation(Qt::Orientation)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneWheelEventFunc_setOrientation_TypeError;

    // Call function/method
    {
        {
            Qt::Orientation cppArg0 = Shiboken::Converter<Qt::Orientation >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOrientation(Qt::Orientation)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOrientation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneWheelEventFunc_setOrientation_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneWheelEvent.setOrientation", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_setPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPos(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneWheelEventFunc_setPos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPos(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneWheelEventFunc_setPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneWheelEvent.setPos", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_setScenePos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScenePos(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setScenePos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneWheelEventFunc_setScenePos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScenePos(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScenePos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneWheelEventFunc_setScenePos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneWheelEvent.setScenePos", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneWheelEventFunc_setScreenPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneWheelEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneWheelEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScreenPos(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // setScreenPos(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneWheelEventFunc_setScreenPos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScreenPos(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScreenPos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneWheelEventFunc_setScreenPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneWheelEvent.setScreenPos", overloads);
        return 0;
}

static PyMethodDef Sbk_QGraphicsSceneWheelEvent_methods[] = {
    {"buttons", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_buttons, METH_NOARGS},
    {"delta", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_delta, METH_NOARGS},
    {"modifiers", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_modifiers, METH_NOARGS},
    {"orientation", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_orientation, METH_NOARGS},
    {"pos", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_pos, METH_NOARGS},
    {"scenePos", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_scenePos, METH_NOARGS},
    {"screenPos", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_screenPos, METH_NOARGS},
    {"setButtons", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_setButtons, METH_O},
    {"setDelta", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_setDelta, METH_O},
    {"setModifiers", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_setModifiers, METH_O},
    {"setOrientation", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_setOrientation, METH_O},
    {"setPos", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_setPos, METH_O},
    {"setScenePos", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_setScenePos, METH_O},
    {"setScreenPos", (PyCFunction)Sbk_QGraphicsSceneWheelEventFunc_setScreenPos, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGraphicsSceneWheelEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsSceneWheelEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGraphicsSceneWheelEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGraphicsSceneWheelEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGraphicsSceneWheelEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QGraphicsSceneWheelEvent*>(cptr)->type() == QEvent::GraphicsSceneWheel)
        return &Sbk_QGraphicsSceneWheelEvent_Type;
    return 0;
}


void init_QGraphicsSceneWheelEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEWHEELEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGraphicsSceneWheelEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGraphicsSceneWheelEvent_Type);
    Sbk_QGraphicsSceneWheelEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGraphicsSceneWheelEvent_Type, &Shiboken::callCppDestructor<QGraphicsSceneWheelEvent >);
    Py_INCREF((PyObject*)&Sbk_QGraphicsSceneWheelEvent_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QGraphicsSceneWheelEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGraphicsSceneWheelEvent_Type, &Sbk_QGraphicsSceneWheelEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX]), &Sbk_QGraphicsSceneWheelEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGraphicsSceneWheelEvent_Type, "QGraphicsSceneWheelEvent*");
    PyModule_AddObject(module, "QGraphicsSceneWheelEvent",
        ((PyObject*)&Sbk_QGraphicsSceneWheelEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneWheelEvent >("QGraphicsSceneWheelEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneWheelEvent >(typeid(QGraphicsSceneWheelEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneWheelEvent >(typeid(QGraphicsSceneWheelEventWrapper).name());
    qRegisterMetaType< ::QGraphicsSceneWheelEvent* >("QGraphicsSceneWheelEvent*");
}

