/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qicon_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qdatastream.h>
#include <qicon.h>
#include <qiconengine.h>
#include <qpainter.h>
#include <qpixmap.h>
#include <qrect.h>
#include <qsize.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QIcon_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QIcon >()))
        return -1;

    QIcon* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QIcon", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QIcon()
    // 1: QIcon(QIconEngine*)
    // 2: QIcon(QIconEngineV2*)
    // 3: QIcon(QIcon)
    // 4: QIcon(QPixmap)
    // 5: QIcon(QString)
    if (numArgs == 0) {
        overloadId = 0; // QIcon()
    } else if (numArgs == 1 && Shiboken::Converter< ::QIconEngineV2 * >::isConvertible(pyargs[0])) {
        overloadId = 2; // QIcon(QIconEngineV2*)
    } else if (numArgs == 1 && Shiboken::Converter< ::QIconEngine * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QIcon(QIconEngine*)
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 5; // QIcon(QString)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[0])) {
        overloadId = 4; // QIcon(QPixmap)
    } else if (numArgs == 1 && Shiboken::Converter< ::QIcon >::isConvertible(pyargs[0])) {
        overloadId = 3; // QIcon(QIcon)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIcon_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QIcon()
            {

                if(!PyErr_Occurred()) {
                    // QIcon()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QIcon();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QIcon(QIconEngine*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIconEngine * cppArg0 = Shiboken::Converter<QIconEngine * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QIcon(QIconEngine*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QIcon(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[0]);
                }
                break;
            }
            case 2: // QIcon(QIconEngineV2*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIconEngineV2 * cppArg0 = Shiboken::Converter<QIconEngineV2 * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QIcon(QIconEngineV2*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QIcon(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[0]);
                }
                break;
            }
            case 3: // QIcon(QIcon)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIcon cppArg0 = Shiboken::Converter<QIcon >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QIcon(QIcon)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QIcon(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QIcon(QPixmap)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPixmap cppArg0 = Shiboken::Converter<QPixmap >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QIcon(QPixmap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QIcon(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QIcon(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QIcon(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QIcon(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QIcon >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QIcon_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QIcon_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QIconEngine", "PySide.QtGui.QIconEngineV2", "PySide.QtGui.QIcon", "PySide.QtGui.QPixmap", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon", overloads);
        return -1;
}

static PyObject* Sbk_QIconFunc_actualSize(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.actualSize(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.actualSize(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:actualSize", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: actualSize(QSize,QIcon::Mode,QIcon::State)const
    if (Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // actualSize(QSize,QIcon::Mode,QIcon::State)const
        } else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // actualSize(QSize,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[2])) {
                overloadId = 0; // actualSize(QSize,QIcon::Mode,QIcon::State)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc_actualSize_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QIconFunc_actualSize_TypeError;
                }
                value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "state";
                    else if (Shiboken::Converter< ::QIcon::State >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QIconFunc_actualSize_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.actualSize(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
            QIcon::Mode cppArg1 = pyargs[1] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]) : QIcon::Normal;
            QIcon::State cppArg2 = pyargs[2] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]) : QIcon::Off;

            if(!PyErr_Occurred()) {
                // actualSize(QSize,QIcon::Mode,QIcon::State)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QIcon*>(cppSelf)->actualSize(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconFunc_actualSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.actualSize", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc_addFile(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.addFile(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.addFile(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:addFile", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: addFile(QString,QSize,QIcon::Mode,QIcon::State)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addFile(QString,QSize,QIcon::Mode,QIcon::State)
        } else if (Shiboken::Converter< ::QSize >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addFile(QString,QSize,QIcon::Mode,QIcon::State)
            } else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // addFile(QString,QSize,QIcon::Mode,QIcon::State)
                } else if (Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[3])) {
                    overloadId = 0; // addFile(QString,QSize,QIcon::Mode,QIcon::State)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc_addFile_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "size");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "size";
                    else if (Shiboken::Converter< ::QSize >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QIconFunc_addFile_TypeError;
                }
                value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QIconFunc_addFile_TypeError;
                }
                value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "state";
                    else if (Shiboken::Converter< ::QIcon::State >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QIconFunc_addFile_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.addFile(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QSize cppArg1_tmp = QSize();
            QSize cppArg1 = pyargs[1] ? Shiboken::Converter<QSize >::toCpp(pyargs[1]) : cppArg1_tmp;
            QIcon::Mode cppArg2 = pyargs[2] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[2]) : QIcon::Normal;
            QIcon::State cppArg3 = pyargs[3] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[3]) : QIcon::Off;

            if(!PyErr_Occurred()) {
                // addFile(QString,QSize,QIcon::Mode,QIcon::State)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addFile(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QIconFunc_addFile_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QSize = QSize(), PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.addFile", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc_addPixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.addPixmap(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.addPixmap(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:addPixmap", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addPixmap(QPixmap,QIcon::Mode,QIcon::State)
    if (Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // addPixmap(QPixmap,QIcon::Mode,QIcon::State)
        } else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // addPixmap(QPixmap,QIcon::Mode,QIcon::State)
            } else if (Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[2])) {
                overloadId = 0; // addPixmap(QPixmap,QIcon::Mode,QIcon::State)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc_addPixmap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QIconFunc_addPixmap_TypeError;
                }
                value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "state";
                    else if (Shiboken::Converter< ::QIcon::State >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QIconFunc_addPixmap_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.addPixmap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPixmap cppArg0 = Shiboken::Converter<QPixmap >::toCpp(pyargs[0]);
            QIcon::Mode cppArg1 = pyargs[1] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]) : QIcon::Normal;
            QIcon::State cppArg2 = pyargs[2] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]) : QIcon::Off;

            if(!PyErr_Occurred()) {
                // addPixmap(QPixmap,QIcon::Mode,QIcon::State)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addPixmap(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QIconFunc_addPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPixmap, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.addPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc_availableSizes(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.availableSizes(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:availableSizes", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: availableSizes(QIcon::Mode,QIcon::State)const
    if (numArgs == 0) {
        overloadId = 0; // availableSizes(QIcon::Mode,QIcon::State)const
    } else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // availableSizes(QIcon::Mode,QIcon::State)const
        } else if (Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[1])) {
            overloadId = 0; // availableSizes(QIcon::Mode,QIcon::State)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc_availableSizes_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QIconFunc_availableSizes_TypeError;
                }
                value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "state";
                    else if (Shiboken::Converter< ::QIcon::State >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QIconFunc_availableSizes_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.availableSizes(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QIcon::Mode cppArg0 = pyargs[0] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[0]) : QIcon::Normal;
            QIcon::State cppArg1 = pyargs[1] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[1]) : QIcon::Off;

            if(!PyErr_Occurred()) {
                // availableSizes(QIcon::Mode,QIcon::State)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QSize > cppResult = const_cast<const QIcon*>(cppSelf)->availableSizes(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QSize > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconFunc_availableSizes_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.availableSizes", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc_cacheKey(PyObject* self)
{
    QIcon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cacheKey()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QIcon*>(cppSelf)->cacheKey();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QIconFunc_fromTheme(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.fromTheme(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.fromTheme(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromTheme", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromTheme(QString,QIcon)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromTheme(QString,QIcon)
        } else if (Shiboken::Converter< ::QIcon >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromTheme(QString,QIcon)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc_fromTheme_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "fallback");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "fallback";
                    else if (Shiboken::Converter< ::QIcon >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QIconFunc_fromTheme_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.fromTheme(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QIcon cppArg1_tmp = QIcon();
            QIcon cppArg1 = pyargs[1] ? Shiboken::Converter<QIcon >::toCpp(pyargs[1]) : cppArg1_tmp;

            if(!PyErr_Occurred()) {
                // fromTheme(QString,QIcon)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = QIcon::fromTheme(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconFunc_fromTheme_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QIcon = QIcon()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.fromTheme", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc_hasThemeIcon(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasThemeIcon(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // hasThemeIcon(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc_hasThemeIcon_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasThemeIcon(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QIcon::hasThemeIcon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconFunc_hasThemeIcon_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIcon.hasThemeIcon", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc_isNull(PyObject* self)
{
    QIcon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QIcon*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QIconFunc_name(PyObject* self)
{
    QIcon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QIcon*>(cppSelf)->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QIconFunc_paint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 8) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.paint(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.paint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOO:paint", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7])))
        return 0;


    // Overloaded function decisor
    // 0: paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
    // 1: paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
    if (Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0])) {
        if (numArgs >= 5 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 1; // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[5])) {
                if (numArgs == 6) {
                    overloadId = 1; // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                } else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[6])) {
                    if (numArgs == 7) {
                        overloadId = 1; // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                    } else if (Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[7])) {
                        overloadId = 1; // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                    }
                }
            }
        } else if (Shiboken::Converter< ::QRect >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                } else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                    } else if (Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[4])) {
                        overloadId = 0; // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc_paint_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "alignment");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "alignment";
                        else if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QIconFunc_paint_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QIconFunc_paint_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "state";
                        else if (Shiboken::Converter< ::QIcon::State >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QIconFunc_paint_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.paint(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QRect cppArg1 = Shiboken::Converter<QRect >::toCpp(pyargs[1]);
                QFlags<Qt::AlignmentFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[2]) : Qt::AlignCenter;
                QIcon::Mode cppArg3 = pyargs[3] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[3]) : QIcon::Normal;
                QIcon::State cppArg4 = pyargs[4] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[4]) : QIcon::Off;

                if(!PyErr_Occurred()) {
                    // paint(QPainter*,QRect,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const_cast<const QIcon*>(cppSelf)->paint(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "alignment");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "alignment";
                        else if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(value))
                            pyargs[5] = value;
                        else
                            goto Sbk_QIconFunc_paint_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(value))
                            pyargs[6] = value;
                        else
                            goto Sbk_QIconFunc_paint_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "state";
                        else if (Shiboken::Converter< ::QIcon::State >::isConvertible(value))
                            pyargs[7] = value;
                        else
                            goto Sbk_QIconFunc_paint_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.paint(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                int cppArg4 = Shiboken::Converter<int >::toCpp(pyargs[4]);
                QFlags<Qt::AlignmentFlag> cppArg5 = pyargs[5] ? Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[5]) : Qt::AlignCenter;
                QIcon::Mode cppArg6 = pyargs[6] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[6]) : QIcon::Normal;
                QIcon::State cppArg7 = pyargs[7] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[7]) : QIcon::Off;

                if(!PyErr_Occurred()) {
                    // paint(QPainter*,int,int,int,int,QFlags<Qt::AlignmentFlag>,QIcon::Mode,QIcon::State)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const_cast<const QIcon*>(cppSelf)->paint(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QIconFunc_paint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRect, PySide.QtCore.Qt.Alignment = Qt.AlignCenter, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", "PySide.QtGui.QPainter, int, int, int, int, PySide.QtCore.Qt.Alignment = Qt.AlignCenter, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.paint", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc_pixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIcon* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:pixmap", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: pixmap(QSize,QIcon::Mode,QIcon::State)const
    // 1: pixmap(int,QIcon::Mode,QIcon::State)const
    // 2: pixmap(int,int,QIcon::Mode,QIcon::State)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // pixmap(int,QIcon::Mode,QIcon::State)const
        } else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // pixmap(int,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[2])) {
                overloadId = 1; // pixmap(int,QIcon::Mode,QIcon::State)const
            }
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // pixmap(int,int,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 2; // pixmap(int,int,QIcon::Mode,QIcon::State)const
                } else if (Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[3])) {
                    overloadId = 2; // pixmap(int,int,QIcon::Mode,QIcon::State)const
                }
            }
        }
    } else if (Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // pixmap(QSize,QIcon::Mode,QIcon::State)const
        } else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // pixmap(QSize,QIcon::Mode,QIcon::State)const
            } else if (Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[2])) {
                overloadId = 0; // pixmap(QSize,QIcon::Mode,QIcon::State)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc_pixmap_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // pixmap(QSize,QIcon::Mode,QIcon::State)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QIconFunc_pixmap_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "state";
                        else if (Shiboken::Converter< ::QIcon::State >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QIconFunc_pixmap_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
                QIcon::Mode cppArg1 = pyargs[1] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]) : QIcon::Normal;
                QIcon::State cppArg2 = pyargs[2] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]) : QIcon::Off;

                if(!PyErr_Occurred()) {
                    // pixmap(QSize,QIcon::Mode,QIcon::State)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPixmap cppResult = const_cast<const QIcon*>(cppSelf)->pixmap(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
                }
                break;
            }
            case 1: // pixmap(int,QIcon::Mode,QIcon::State)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QIconFunc_pixmap_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "state";
                        else if (Shiboken::Converter< ::QIcon::State >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QIconFunc_pixmap_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QIcon::Mode cppArg1 = pyargs[1] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[1]) : QIcon::Normal;
                QIcon::State cppArg2 = pyargs[2] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[2]) : QIcon::Off;

                if(!PyErr_Occurred()) {
                    // pixmap(int,QIcon::Mode,QIcon::State)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPixmap cppResult = const_cast<const QIcon*>(cppSelf)->pixmap(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
                }
                break;
            }
            case 2: // pixmap(int,int,QIcon::Mode,QIcon::State)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QIconFunc_pixmap_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "state");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "state";
                        else if (Shiboken::Converter< ::QIcon::State >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QIconFunc_pixmap_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIcon.pixmap(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QIcon::Mode cppArg2 = pyargs[2] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[2]) : QIcon::Normal;
                QIcon::State cppArg3 = pyargs[3] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[3]) : QIcon::Off;

                if(!PyErr_Occurred()) {
                    // pixmap(int,int,QIcon::Mode,QIcon::State)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPixmap cppResult = const_cast<const QIcon*>(cppSelf)->pixmap(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconFunc_pixmap_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", "int, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", "int, int, PySide.QtGui.QIcon.Mode = Normal, PySide.QtGui.QIcon.State = Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIcon.pixmap", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc_setThemeName(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setThemeName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setThemeName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc_setThemeName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setThemeName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon::setThemeName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QIconFunc_setThemeName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIcon.setThemeName", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc_setThemeSearchPaths(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setThemeSearchPaths(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setThemeSearchPaths(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc_setThemeSearchPaths_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setThemeSearchPaths(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon::setThemeSearchPaths(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QIconFunc_setThemeSearchPaths_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIcon.setThemeSearchPaths", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc_themeName(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // themeName()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QIcon::themeName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QIconFunc_themeSearchPaths(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // themeSearchPaths()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QIcon::themeSearchPaths();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QIcon___copy__(PyObject *self)
{
        QIcon* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QIcon*>::toCpp(self);
        PyObject* pyResult = 0;
        QIcon* copy = new QIcon(*cppSelf);
        pyResult = Shiboken::Converter<QIcon*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QIcon_methods[] = {
    {"actualSize", (PyCFunction)Sbk_QIconFunc_actualSize, METH_VARARGS|METH_KEYWORDS},
    {"addFile", (PyCFunction)Sbk_QIconFunc_addFile, METH_VARARGS|METH_KEYWORDS},
    {"addPixmap", (PyCFunction)Sbk_QIconFunc_addPixmap, METH_VARARGS|METH_KEYWORDS},
    {"availableSizes", (PyCFunction)Sbk_QIconFunc_availableSizes, METH_VARARGS|METH_KEYWORDS},
    {"cacheKey", (PyCFunction)Sbk_QIconFunc_cacheKey, METH_NOARGS},
    {"fromTheme", (PyCFunction)Sbk_QIconFunc_fromTheme, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"hasThemeIcon", (PyCFunction)Sbk_QIconFunc_hasThemeIcon, METH_O|METH_STATIC},
    {"isNull", (PyCFunction)Sbk_QIconFunc_isNull, METH_NOARGS},
    {"name", (PyCFunction)Sbk_QIconFunc_name, METH_NOARGS},
    {"paint", (PyCFunction)Sbk_QIconFunc_paint, METH_VARARGS|METH_KEYWORDS},
    {"pixmap", (PyCFunction)Sbk_QIconFunc_pixmap, METH_VARARGS|METH_KEYWORDS},
    {"setThemeName", (PyCFunction)Sbk_QIconFunc_setThemeName, METH_O|METH_STATIC},
    {"setThemeSearchPaths", (PyCFunction)Sbk_QIconFunc_setThemeSearchPaths, METH_O|METH_STATIC},
    {"themeName", (PyCFunction)Sbk_QIconFunc_themeName, METH_NOARGS|METH_STATIC},
    {"themeSearchPaths", (PyCFunction)Sbk_QIconFunc_themeSearchPaths, METH_NOARGS|METH_STATIC},

    {"__copy__", (PyCFunction)Sbk_QIcon___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QIcon___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QIcon* cppSelf = Shiboken::Converter< ::QIcon*>::toCpp(pyObj);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QIconFunc___lshift__(PyObject* self, PyObject* arg)
{
    QIcon* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QIcon >::checkType(arg) && !Shiboken::Converter< ::QIcon >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QIcon)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QIcon)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QIcon) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIcon.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QIconFunc___rshift__(PyObject* self, PyObject* arg)
{
    QIcon* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QIcon >::checkType(arg) && !Shiboken::Converter< ::QIcon >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIcon* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QIcon&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QIcon&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QIcon&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIcon.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QIcon_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QIcon___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QIconFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QIconFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QIcon_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QIcon",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QIcon_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QIcon_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QIcon_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QIcon(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QICON_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QIcon_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QIcon_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QIcon_Type, &Shiboken::callCppDestructor<QIcon >);
    Py_INCREF((PyObject*)&Sbk_QIcon_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QIcon_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QIcon_Type, "QIcon");
    PyModule_AddObject(module, "QIcon",
        ((PyObject*)&Sbk_QIcon_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Mode
    PyTypeObject* SbkPySide_QtGui_QIcon_Mode = Shiboken::Enum::newType("PySide.QtGui.QIcon.Mode");
    SbkPySide_QtGuiTypes[SBK_QICON_MODE_IDX] = SbkPySide_QtGui_QIcon_Mode;
    if (PyType_Ready(SbkPySide_QtGui_QIcon_Mode) < 0)
        return;
    PyDict_SetItemString(Sbk_QIcon_Type.super.ht_type.tp_dict,
            "Mode",((PyObject*)SbkPySide_QtGui_QIcon_Mode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QIcon_Mode,(long) QIcon::Normal, "Normal");
    PyDict_SetItemString(Sbk_QIcon_Type.super.ht_type.tp_dict,"Normal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_Mode->tp_dict,"Normal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QIcon_Mode,(long) QIcon::Disabled, "Disabled");
    PyDict_SetItemString(Sbk_QIcon_Type.super.ht_type.tp_dict,"Disabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_Mode->tp_dict,"Disabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QIcon_Mode,(long) QIcon::Active, "Active");
    PyDict_SetItemString(Sbk_QIcon_Type.super.ht_type.tp_dict,"Active", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_Mode->tp_dict,"Active", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QIcon_Mode,(long) QIcon::Selected, "Selected");
    PyDict_SetItemString(Sbk_QIcon_Type.super.ht_type.tp_dict,"Selected", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_Mode->tp_dict,"Selected", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QIcon::Mode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Mode");
    // end of enum Mode

    // init enum: State
    PyTypeObject* SbkPySide_QtGui_QIcon_State = Shiboken::Enum::newType("PySide.QtGui.QIcon.State");
    SbkPySide_QtGuiTypes[SBK_QICON_STATE_IDX] = SbkPySide_QtGui_QIcon_State;
    if (PyType_Ready(SbkPySide_QtGui_QIcon_State) < 0)
        return;
    PyDict_SetItemString(Sbk_QIcon_Type.super.ht_type.tp_dict,
            "State",((PyObject*)SbkPySide_QtGui_QIcon_State));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QIcon_State,(long) QIcon::On, "On");
    PyDict_SetItemString(Sbk_QIcon_Type.super.ht_type.tp_dict,"On", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_State->tp_dict,"On", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QIcon_State,(long) QIcon::Off, "Off");
    PyDict_SetItemString(Sbk_QIcon_Type.super.ht_type.tp_dict,"Off", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QIcon_State->tp_dict,"Off", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QIcon::State");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::State");
    // end of enum State


    Shiboken::TypeResolver::createValueTypeResolver<QIcon >("QIcon");
    Shiboken::TypeResolver::createObjectTypeResolver<QIcon >("QIcon*");
    Shiboken::TypeResolver::createValueTypeResolver<QIcon >(typeid(QIcon).name());
    qRegisterMetaType< ::QIcon >("QIcon");
    qRegisterMetaType< ::QIcon::Mode >("QIcon::Mode");
    qRegisterMetaType< ::QIcon::State >("QIcon::State");
}

