/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qiconenginev2_wrapper.h"

// Extra includes
#include <QList>
#include <qdatastream.h>
#include <qiconengine.h>
#include <qpainter.h>
#include <qpixmap.h>
#include <qrect.h>
#include <qsize.h>


// Native ---------------------------------------------------------

QIconEngineV2Wrapper::QIconEngineV2Wrapper() : QIconEngineV2() {
    // ... middle
}

QSize QIconEngineV2Wrapper::actualSize(const QSize & size, QIcon::Mode mode, QIcon::State state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actualSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngine::actualSize(size, mode, state);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QSize >::toPython(size),
        Shiboken::Converter< ::QIcon::Mode >::toPython(mode),
        Shiboken::Converter< ::QIcon::State >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIconEngineV2.actualSize", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QIconEngineV2Wrapper::addFile(const QString & fileName, const QSize & size, QIcon::Mode mode, QIcon::State state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "addFile"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngine::addFile(fileName, size, mode, state);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< QString >::toPython(fileName),
        Shiboken::Converter< ::QSize >::toPython(size),
        Shiboken::Converter< ::QIcon::Mode >::toPython(mode),
        Shiboken::Converter< ::QIcon::State >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QIconEngineV2Wrapper::addPixmap(const QPixmap & pixmap, QIcon::Mode mode, QIcon::State state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "addPixmap"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngine::addPixmap(pixmap, mode, state);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QPixmap >::toPython(pixmap),
        Shiboken::Converter< ::QIcon::Mode >::toPython(mode),
        Shiboken::Converter< ::QIcon::State >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QIconEngineV2 * QIconEngineV2Wrapper::clone() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "clone"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngineV2::clone();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QIconEngineV2 * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIconEngineV2.clone", Shiboken::SbkType<QIconEngineV2 >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QIconEngineV2 * cppResult(Shiboken::Converter< ::QIconEngineV2 * >::toCpp(pyResult));
    return cppResult;
}

QString QIconEngineV2Wrapper::key() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QString();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "key"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngineV2::key();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIconEngineV2.key", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

void QIconEngineV2Wrapper::paint(QPainter * painter, const QRect & rect, QIcon::Mode mode, QIcon::State state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paint"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QIconEngineV2.paint()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRect >::toPython(rect),
        Shiboken::Converter< ::QIcon::Mode >::toPython(mode),
        Shiboken::Converter< ::QIcon::State >::toPython(state)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPixmap QIconEngineV2Wrapper::pixmap(const QSize & size, QIcon::Mode mode, QIcon::State state)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QPixmap();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "pixmap"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngine::pixmap(size, mode, state);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QSize >::toPython(size),
        Shiboken::Converter< ::QIcon::Mode >::toPython(mode),
        Shiboken::Converter< ::QIcon::State >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPixmap();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPixmap >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIconEngineV2.pixmap", Shiboken::SbkType<QPixmap >()->tp_name, pyResult->ob_type->tp_name);
        return QPixmap();
    }
    QPixmap cppResult(Shiboken::Converter< ::QPixmap >::toCpp(pyResult));
    return cppResult;
}

bool QIconEngineV2Wrapper::read(QDataStream & in)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "read"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngineV2::read(in);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDataStream & >::toPython(in)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIconEngineV2.read", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QIconEngineV2Wrapper::write(QDataStream & out) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "write"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QIconEngineV2::write(out);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDataStream & >::toPython(out)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QIconEngineV2.write", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

QIconEngineV2Wrapper::~QIconEngineV2Wrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QIconEngineV2_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QIconEngineV2 >()))
        return -1;

    QIconEngineV2Wrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QICONENGINEV2_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QIconEngineV2' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QIconEngineV2()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QIconEngineV2Wrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QIconEngineV2 >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QIconEngineV2Func_availableSizes(PyObject* self, PyObject* args, PyObject* kwds)
{
    QIconEngineV2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngineV2* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QIconEngineV2.availableSizes(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:availableSizes", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: availableSizes(QIcon::Mode,QIcon::State)
    if (numArgs == 0) {
        overloadId = 0; // availableSizes(QIcon::Mode,QIcon::State)
    } else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // availableSizes(QIcon::Mode,QIcon::State)
        } else if (Shiboken::Converter< ::QIcon::State >::isConvertible(pyargs[1])) {
            overloadId = 0; // availableSizes(QIcon::Mode,QIcon::State)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconEngineV2Func_availableSizes_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QIcon::Mode >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QIconEngineV2Func_availableSizes_TypeError;
                }
                value = PyDict_GetItemString(kwds, "state");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "state";
                    else if (Shiboken::Converter< ::QIcon::State >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QIconEngineV2Func_availableSizes_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QIconEngineV2.availableSizes(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QIcon::Mode cppArg0 = pyargs[0] ? Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[0]) : QIcon::Normal;
            QIcon::State cppArg1 = pyargs[1] ? Shiboken::Converter<QIcon::State >::toCpp(pyargs[1]) : QIcon::Off;

            if(!PyErr_Occurred()) {
                // availableSizes(QIcon::Mode,QIcon::State)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QSize > cppResult = cppSelf->availableSizes(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QSize > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconEngineV2Func_availableSizes_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon.Mode = QIcon.Normal, PySide.QtGui.QIcon.State = QIcon.Off", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QIconEngineV2.availableSizes", overloads);
        return 0;
}

static PyObject* Sbk_QIconEngineV2Func_clone(PyObject* self)
{
    QIconEngineV2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngineV2* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clone()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIconEngineV2 * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QIconEngineV2*>(cppSelf)->::QIconEngineV2::clone() : const_cast<const QIconEngineV2*>(cppSelf)->clone());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIconEngineV2 * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QIconEngineV2Func_iconName(PyObject* self)
{
    QIconEngineV2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngineV2* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // iconName()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->iconName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QIconEngineV2Func_key(PyObject* self)
{
    QIconEngineV2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngineV2* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // key()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QIconEngineV2*>(cppSelf)->::QIconEngineV2::key() : const_cast<const QIconEngineV2*>(cppSelf)->key());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QIconEngineV2Func_read(PyObject* self, PyObject* arg)
{
    QIconEngineV2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngineV2* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: read(QDataStream&)
    if (Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // read(QDataStream&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconEngineV2Func_read_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // read(QDataStream&)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QIconEngineV2::read(cppArg0) : cppSelf->read(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconEngineV2Func_read_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIconEngineV2.read", overloads);
        return 0;
}

static PyObject* Sbk_QIconEngineV2Func_write(PyObject* self, PyObject* arg)
{
    QIconEngineV2* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QIconEngineV2* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: write(QDataStream&)const
    if (Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // write(QDataStream&)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QIconEngineV2Func_write_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // write(QDataStream&)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QIconEngineV2*>(cppSelf)->::QIconEngineV2::write(cppArg0) : const_cast<const QIconEngineV2*>(cppSelf)->write(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QIconEngineV2Func_write_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QIconEngineV2.write", overloads);
        return 0;
}

static PyMethodDef Sbk_QIconEngineV2_methods[] = {
    {"availableSizes", (PyCFunction)Sbk_QIconEngineV2Func_availableSizes, METH_VARARGS|METH_KEYWORDS},
    {"clone", (PyCFunction)Sbk_QIconEngineV2Func_clone, METH_NOARGS},
    {"iconName", (PyCFunction)Sbk_QIconEngineV2Func_iconName, METH_NOARGS},
    {"key", (PyCFunction)Sbk_QIconEngineV2Func_key, METH_NOARGS},
    {"read", (PyCFunction)Sbk_QIconEngineV2Func_read, METH_O},
    {"write", (PyCFunction)Sbk_QIconEngineV2Func_write, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QIconEngineV2_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QIconEngineV2",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QIconEngineV2_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QIconEngineV2_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QIconEngineV2_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QIconEngine >()) && dynamic_cast<QIconEngineV2*>(reinterpret_cast<QIconEngine*>(cptr)))
        return &Sbk_QIconEngineV2_Type;
    return 0;
}


void init_QIconEngineV2(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QICONENGINEV2_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QIconEngineV2_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QIconEngineV2_Type);
    Sbk_QIconEngineV2_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QICONENGINE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QIconEngineV2_Type, &Shiboken::callCppDestructor<QIconEngineV2 >);
    Py_INCREF((PyObject*)&Sbk_QIconEngineV2_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QIconEngineV2_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QIconEngineV2_Type, &Sbk_QIconEngineV2_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QICONENGINE_IDX]), &Sbk_QIconEngineV2_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QIconEngineV2_Type, "QIconEngineV2*");
    PyModule_AddObject(module, "QIconEngineV2",
        ((PyObject*)&Sbk_QIconEngineV2_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: IconEngineHook
    PyTypeObject* SbkPySide_QtGui_QIconEngineV2_IconEngineHook = Shiboken::Enum::newType("PySide.QtGui.QIconEngineV2.IconEngineHook");
    SbkPySide_QtGuiTypes[SBK_QICONENGINEV2_ICONENGINEHOOK_IDX] = SbkPySide_QtGui_QIconEngineV2_IconEngineHook;
    if (PyType_Ready(SbkPySide_QtGui_QIconEngineV2_IconEngineHook) < 0)
        return;
    PyDict_SetItemString(Sbk_QIconEngineV2_Type.super.ht_type.tp_dict,
            "IconEngineHook",((PyObject*)SbkPySide_QtGui_QIconEngineV2_IconEngineHook));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QIconEngineV2_IconEngineHook,(long) QIconEngineV2::AvailableSizesHook, "AvailableSizesHook");
    PyDict_SetItemString(Sbk_QIconEngineV2_Type.super.ht_type.tp_dict,"AvailableSizesHook", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QIconEngineV2_IconEngineHook->tp_dict,"AvailableSizesHook", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QIconEngineV2_IconEngineHook,(long) QIconEngineV2::IconNameHook, "IconNameHook");
    PyDict_SetItemString(Sbk_QIconEngineV2_Type.super.ht_type.tp_dict,"IconNameHook", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QIconEngineV2_IconEngineHook->tp_dict,"IconNameHook", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QIconEngineV2::IconEngineHook");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QIconEngineV2$ConcreteWrapper::IconEngineHook");
    // end of enum IconEngineHook


    Shiboken::TypeResolver::createObjectTypeResolver<QIconEngineV2 >("QIconEngineV2*");
    Shiboken::TypeResolver::createObjectTypeResolver<QIconEngineV2 >("QIconEngineV2$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QIconEngineV2 >(typeid(QIconEngineV2).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QIconEngineV2 >(typeid(QIconEngineV2Wrapper).name());
    qRegisterMetaType< ::QIconEngineV2::IconEngineHook >("QIconEngineV2::IconEngineHook");
}

