/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qimage_wrapper.h"

// Extra includes
#include <QMatrix>
#include <QStringList>
#include <QVector>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qimage.h>
#include <qiodevice.h>
#include <qmatrix.h>
#include <qpaintengine.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qtransform.h>


// Native ---------------------------------------------------------

QImageWrapper::QImageWrapper() : QImage() {
    // ... middle
}

QImageWrapper::QImageWrapper(const QSize & size, QImage::Format format) : QImage(size, format) {
    // ... middle
}

QImageWrapper::QImageWrapper(const QString & fileName, const char * format) : QImage(fileName, format) {
    // ... middle
}

QImageWrapper::QImageWrapper(const char ** xpm) : QImage(xpm) {
    // ... middle
}

QImageWrapper::QImageWrapper(int width, int height, QImage::Format format) : QImage(width, height, format) {
    // ... middle
}

QImageWrapper::QImageWrapper(uchar * data, int width, int height, QImage::Format format) : QImage(data, width, height, format) {
    // ... middle
}

QImageWrapper::QImageWrapper(uchar * data, int width, int height, int bytesPerLine, QImage::Format format) : QImage(data, width, height, bytesPerLine, format) {
    // ... middle
}

int QImageWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QImage::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QImage.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QImageWrapper::metric(QPaintDevice::PaintDeviceMetric metric) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QImage::metric(metric);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(metric)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QImage.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QPaintEngine * QImageWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QImage::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QImage.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

QImageWrapper::~QImageWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QImage_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QImage >()))
        return -1;

    QImageWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QImage", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QImage()
    // 1: QImage(QString,int,int,QImage::Format)
    // 2: QImage(QString,int,int,int,QImage::Format)
    // 3: QImage(QImage)
    // 4: QImage(QSize,QImage::Format)
    // 5: QImage(QString,const char*)
    // 6: QImage(const char**)
    // 7: QImage(int,int,QImage::Format)
    // 8: QImage(uchar*,int,int,QImage::Format)
    // 9: QImage(uchar*,int,int,int,QImage::Format)
    if (numArgs == 0) {
        overloadId = 0; // QImage()
    } else if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QImage::Format >::isConvertible(pyargs[2])) {
        overloadId = 7; // QImage(int,int,QImage::Format)
    } else if (numArgs == 2 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QImage::Format >::isConvertible(pyargs[1])) {
        overloadId = 4; // QImage(QSize,QImage::Format)
    } else if (numArgs == 1 && Shiboken::Converter< ::QImage >::isConvertible(pyargs[0])) {
        overloadId = 3; // QImage(QImage)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 5; // QImage(QString,const char*)
        } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
            overloadId = 5; // QImage(QString,const char*)
        } else if (numArgs >= 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            if (numArgs == 4 && Shiboken::Converter< ::QImage::Format >::isConvertible(pyargs[3])) {
                overloadId = 1; // QImage(QString,int,int,QImage::Format)
            } else if (numArgs == 5 && SbkNumber_Check(pyargs[3]) && Shiboken::Converter< ::QImage::Format >::isConvertible(pyargs[4])) {
                overloadId = 2; // QImage(QString,int,int,int,QImage::Format)
            }
        }
    } else if (numArgs == 1 && PySequence_Check(pyargs[0])) {
        overloadId = 6; // QImage(const char**)
    } else if (numArgs >= 3 && PyObject_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 4 && Shiboken::Converter< ::QImage::Format >::isConvertible(pyargs[3])) {
            overloadId = 8; // QImage(uchar*,int,int,QImage::Format)
        } else if (numArgs == 5 && SbkNumber_Check(pyargs[3]) && Shiboken::Converter< ::QImage::Format >::isConvertible(pyargs[4])) {
            overloadId = 9; // QImage(uchar*,int,int,int,QImage::Format)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImage_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QImage()
            {

                if(!PyErr_Occurred()) {
                    // QImage()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageWrapper();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QImage(QString,int,int,QImage::Format)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                QImage::Format cppArg3 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // QImage(QString,int,int,QImage::Format)
                    // Begin code injection

                    // TEMPLATE - qimage_buffer_constructor - START
                    PyTypeObject* pyType = reinterpret_cast<PyTypeObject*>(pyargs[1-1]->ob_type);
                    if (pyType->tp_as_buffer
                    && pyType->tp_as_buffer->bf_getreadbuffer
                    && pyType->tp_as_buffer->bf_getsegcount(pyargs[1-1], 0) == 1) {
                    void* ptr;
                    pyType->tp_as_buffer->bf_getreadbuffer(pyargs[1-1], 0, &ptr);
                    cptr = new QImageWrapper((uchar*)ptr, cppArg1, cppArg2, cppArg3);
                    } else {
                    PyErr_SetString(PyExc_TypeError, "The object must support buffer protocol with just one segment.");
                    }
                    // TEMPLATE - qimage_buffer_constructor - END

                    // End of code injection

                }
                break;
            }
            case 2: // QImage(QString,int,int,int,QImage::Format)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                QImage::Format cppArg4 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // QImage(QString,int,int,int,QImage::Format)
                    // Begin code injection

                    // TEMPLATE - qimage_buffer_constructor - START
                    PyTypeObject* pyType = reinterpret_cast<PyTypeObject*>(pyargs[1-1]->ob_type);
                    if (pyType->tp_as_buffer
                    && pyType->tp_as_buffer->bf_getreadbuffer
                    && pyType->tp_as_buffer->bf_getsegcount(pyargs[1-1], 0) == 1) {
                    void* ptr;
                    pyType->tp_as_buffer->bf_getreadbuffer(pyargs[1-1], 0, &ptr);
                    cptr = new QImageWrapper((uchar*)ptr, cppArg1, cppArg2, cppArg3, cppArg4);
                    } else {
                    PyErr_SetString(PyExc_TypeError, "The object must support buffer protocol with just one segment.");
                    }
                    // TEMPLATE - qimage_buffer_constructor - END

                    // End of code injection

                }
                break;
            }
            case 3: // QImage(QImage)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QImage(QImage)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QImage(QSize,QImage::Format)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
                QImage::Format cppArg1 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QImage(QSize,QImage::Format)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QImage(QString,const char*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< const char * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImage_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                const char * cppArg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QImage(QString,const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // QImage(const char**)
            {

                if(!PyErr_Occurred()) {
                    // QImage(const char**)
                    // Begin code injection

                    // TEMPLATE - load_xpm - START
                    Shiboken::AutoDecRef strList(PySequence_Fast(pyargs[1-1], "Invalid sequence."));
                    int lineCount = PySequence_Fast_GET_SIZE(strList.object());
                    for (int line = 0; line < lineCount; ++line) {
                    if (!PyString_Check(PySequence_Fast_GET_ITEM(strList.object(), line))) {
                        PyErr_SetString(PyExc_TypeError, "The argument must be a sequence of strings.");
                        break;
                    }
                    }

                    const char** xpm = (const char**) malloc (lineCount * sizeof(const char**));
                    for (int line = 0; line < lineCount; ++line)
                    xpm[line] = PyString_AS_STRING(PySequence_Fast_GET_ITEM(strList.object(), line));

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageWrapper(xpm);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                    free(xpm);
                    // TEMPLATE - load_xpm - END

                    // End of code injection

                }
                break;
            }
            case 7: // QImage(int,int,QImage::Format)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QImage::Format cppArg2 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // QImage(int,int,QImage::Format)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QImageWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 8: // QImage(uchar*,int,int,QImage::Format)
            {
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                QImage::Format cppArg3 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // QImage(uchar*,int,int,QImage::Format)
                    // Begin code injection

                    // TEMPLATE - qimage_buffer_constructor - START
                    PyTypeObject* pyType = reinterpret_cast<PyTypeObject*>(pyargs[1-1]->ob_type);
                    if (pyType->tp_as_buffer
                    && pyType->tp_as_buffer->bf_getreadbuffer
                    && pyType->tp_as_buffer->bf_getsegcount(pyargs[1-1], 0) == 1) {
                    void* ptr;
                    pyType->tp_as_buffer->bf_getreadbuffer(pyargs[1-1], 0, &ptr);
                    cptr = new QImageWrapper((uchar*)ptr, cppArg1, cppArg2, cppArg3);
                    } else {
                    PyErr_SetString(PyExc_TypeError, "The object must support buffer protocol with just one segment.");
                    }
                    // TEMPLATE - qimage_buffer_constructor - END

                    // End of code injection

                }
                break;
            }
            case 9: // QImage(uchar*,int,int,int,QImage::Format)
            {
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
                QImage::Format cppArg4 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // QImage(uchar*,int,int,int,QImage::Format)
                    // Begin code injection

                    // TEMPLATE - qimage_buffer_constructor - START
                    PyTypeObject* pyType = reinterpret_cast<PyTypeObject*>(pyargs[1-1]->ob_type);
                    if (pyType->tp_as_buffer
                    && pyType->tp_as_buffer->bf_getreadbuffer
                    && pyType->tp_as_buffer->bf_getsegcount(pyargs[1-1], 0) == 1) {
                    void* ptr;
                    pyType->tp_as_buffer->bf_getreadbuffer(pyargs[1-1], 0, &ptr);
                    cptr = new QImageWrapper((uchar*)ptr, cppArg1, cppArg2, cppArg3, cppArg4);
                    } else {
                    PyErr_SetString(PyExc_TypeError, "The object must support buffer protocol with just one segment.");
                    }
                    // TEMPLATE - qimage_buffer_constructor - END

                    // End of code injection

                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QImage >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QImage_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QImage_Init_TypeError:
        const char* overloads[] = {"", "QString, int, int, PySide.QtGui.QImage.Format", "QString, int, int, int, PySide.QtGui.QImage.Format", "PySide.QtGui.QImage", "PySide.QtCore.QSize, PySide.QtGui.QImage.Format", "QString, str = None", "str", "int, int, PySide.QtGui.QImage.Format", "buffer, int, int, PySide.QtGui.QImage.Format", "buffer, int, int, int, PySide.QtGui.QImage.Format", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage", overloads);
        return -1;
}

static PyObject* Sbk_QImageFunc_allGray(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // allGray()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImage*>(cppSelf)->allGray();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_alphaChannel(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // alphaChannel()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QImage*>(cppSelf)->alphaChannel();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_bitPlaneCount(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bitPlaneCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->bitPlaneCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_bits(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bits()
                // Begin code injection

                // byteCount() is only available on Qt4.7, so we use bytesPerLine * height
                pyResult = PyBuffer_FromReadWriteMemory(cppSelf->bits(), cppSelf->bytesPerLine() * cppSelf->height());

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_byteCount(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // byteCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->byteCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_bytesPerLine(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bytesPerLine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->bytesPerLine();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_cacheKey(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cacheKey()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = const_cast<const QImage*>(cppSelf)->cacheKey();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_color(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: color(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // color(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_color_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // color(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = const_cast<const QImage*>(cppSelf)->color(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_color_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.color", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_colorCount(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // colorCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->colorCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_colorTable(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // colorTable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<unsigned int > cppResult = const_cast<const QImage*>(cppSelf)->colorTable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<unsigned int > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_constBits(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // constBits()const
                // Begin code injection

                pyResult = PyBuffer_FromMemory(const_cast<uchar*>(cppSelf->constBits()), cppSelf->byteCount());

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_constScanLine(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: constScanLine(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // constScanLine(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_constScanLine_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // constScanLine(int)const
                // Begin code injection

                pyResult = PyBuffer_FromMemory(const_cast<uchar*>(cppSelf->constScanLine(cppArg0)), cppSelf->bytesPerLine());

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_constScanLine_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.constScanLine", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_convertToFormat(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.convertToFormat(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.convertToFormat(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:convertToFormat", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: convertToFormat(QImage::Format,QFlags<Qt::ImageConversionFlag>)const
    // 1: convertToFormat(QImage::Format,QVector<uint>,QFlags<Qt::ImageConversionFlag>)const
    if (Shiboken::Converter< ::QImage::Format >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // convertToFormat(QImage::Format,QFlags<Qt::ImageConversionFlag>)const
        } else if (Shiboken::Converter< ::QVector<unsigned int > >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // convertToFormat(QImage::Format,QVector<uint>,QFlags<Qt::ImageConversionFlag>)const
            } else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[2])) {
                overloadId = 1; // convertToFormat(QImage::Format,QVector<uint>,QFlags<Qt::ImageConversionFlag>)const
            }
        } else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // convertToFormat(QImage::Format,QFlags<Qt::ImageConversionFlag>)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_convertToFormat_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // convertToFormat(QImage::Format,QFlags<Qt::ImageConversionFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImageFunc_convertToFormat_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.convertToFormat(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QImage::Format cppArg0 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[0]);
                QFlags<Qt::ImageConversionFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[1]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                    // convertToFormat(QImage::Format,QFlags<Qt::ImageConversionFlag>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QImage cppResult = const_cast<const QImage*>(cppSelf)->convertToFormat(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
                }
                break;
            }
            case 1: // convertToFormat(QImage::Format,QVector<uint>,QFlags<Qt::ImageConversionFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QImageFunc_convertToFormat_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.convertToFormat(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QImage::Format cppArg0 = Shiboken::Converter<QImage::Format >::toCpp(pyargs[0]);
                QVector<unsigned int > cppArg1 = Shiboken::Converter<QVector<unsigned int > >::toCpp(pyargs[1]);
                QFlags<Qt::ImageConversionFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[2]) : Qt::AutoColor;

                if(!PyErr_Occurred()) {
                    // convertToFormat(QImage::Format,QVector<uint>,QFlags<Qt::ImageConversionFlag>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QImage cppResult = const_cast<const QImage*>(cppSelf)->convertToFormat(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_convertToFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage.Format, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", "PySide.QtGui.QImage.Format, list, PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.convertToFormat", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_copy(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.copy(): too many arguments");
        return 0;
    } else if (numArgs == 2 || numArgs == 3)
        goto Sbk_QImageFunc_copy_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:copy", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: copy(QRect)const
    // 1: copy(int,int,int,int)const
    if (numArgs == 0) {
        overloadId = 0; // copy(QRect)const
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // copy(int,int,int,int)const
    } else if (Shiboken::Converter< ::QRect >::isConvertible(pyargs[0])) {
        overloadId = 0; // copy(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_copy_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // copy(QRect)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "rect");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "rect";
                        else if (Shiboken::Converter< ::QRect >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QImageFunc_copy_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.copy(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRect cppArg0_tmp = QRect();
                QRect cppArg0 = pyargs[0] ? Shiboken::Converter<QRect >::toCpp(pyargs[0]) : cppArg0_tmp;

                if(!PyErr_Occurred()) {
                    // copy(QRect)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QImage cppResult = const_cast<const QImage*>(cppSelf)->copy(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
                }
                break;
            }
            case 1: // copy(int,int,int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // copy(int,int,int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QImage cppResult = const_cast<const QImage*>(cppSelf)->copy(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_copy_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect = QRect()", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.copy", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_createAlphaMask(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.createAlphaMask(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:createAlphaMask", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: createAlphaMask(QFlags<Qt::ImageConversionFlag>)const
    if (numArgs == 0) {
        overloadId = 0; // createAlphaMask(QFlags<Qt::ImageConversionFlag>)const
    } else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(pyargs[0])) {
        overloadId = 0; // createAlphaMask(QFlags<Qt::ImageConversionFlag>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_createAlphaMask_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<Qt::ImageConversionFlag> >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QImageFunc_createAlphaMask_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.createAlphaMask(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<Qt::ImageConversionFlag> cppArg0 = pyargs[0] ? Shiboken::Converter<QFlags<Qt::ImageConversionFlag> >::toCpp(pyargs[0]) : Qt::AutoColor;

            if(!PyErr_Occurred()) {
                // createAlphaMask(QFlags<Qt::ImageConversionFlag>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QImage*>(cppSelf)->createAlphaMask(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_createAlphaMask_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ImageConversionFlags = Qt.AutoColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.createAlphaMask", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_createHeuristicMask(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.createHeuristicMask(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:createHeuristicMask", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: createHeuristicMask(bool)const
    if (numArgs == 0) {
        overloadId = 0; // createHeuristicMask(bool)const
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // createHeuristicMask(bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_createHeuristicMask_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "clipTight");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "clipTight";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QImageFunc_createHeuristicMask_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.createHeuristicMask(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cppArg0 = pyargs[0] ? Shiboken::Converter<bool >::toCpp(pyargs[0]) : true;

            if(!PyErr_Occurred()) {
                // createHeuristicMask(bool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QImage*>(cppSelf)->createHeuristicMask(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_createHeuristicMask_TypeError:
        const char* overloads[] = {"bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.createHeuristicMask", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_createMaskFromColor(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.createMaskFromColor(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.createMaskFromColor(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createMaskFromColor", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createMaskFromColor(uint,Qt::MaskMode)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createMaskFromColor(uint,Qt::MaskMode)const
        } else if (Shiboken::Converter< ::Qt::MaskMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // createMaskFromColor(uint,Qt::MaskMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_createMaskFromColor_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::Qt::MaskMode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QImageFunc_createMaskFromColor_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.createMaskFromColor(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(pyargs[0]);
            Qt::MaskMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::MaskMode >::toCpp(pyargs[1]) : Qt::MaskInColor;

            if(!PyErr_Occurred()) {
                // createMaskFromColor(uint,Qt::MaskMode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QImage*>(cppSelf)->createMaskFromColor(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_createMaskFromColor_TypeError:
        const char* overloads[] = {"unsigned int, PySide.QtCore.Qt.MaskMode = Qt.MaskInColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.createMaskFromColor", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_depth(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // depth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->depth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_devType(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // devType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QImage*>(cppSelf)->::QImage::devType() : const_cast<const QImage*>(cppSelf)->devType());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_dotsPerMeterX(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dotsPerMeterX()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->dotsPerMeterX();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_dotsPerMeterY(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dotsPerMeterY()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->dotsPerMeterY();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_fill(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: fill(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fill(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_fill_TypeError;

    // Call function/method
    {
        {
            uint cppArg0 = Shiboken::Converter<uint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fill(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->fill(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_fill_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.fill", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_format(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // format()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage::Format cppResult = const_cast<const QImage*>(cppSelf)->format();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage::Format >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_fromData(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.fromData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.fromData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromData(QByteArray,const char*)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromData(QByteArray,const char*)
        } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromData(QByteArray,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_fromData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "format");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "format";
                    else if (Shiboken::Converter< const char * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QImageFunc_fromData_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.fromData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
            const char * cppArg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // fromData(QByteArray,const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = QImage::fromData(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_fromData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, str = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.fromData", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_hasAlphaChannel(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasAlphaChannel()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImage*>(cppSelf)->hasAlphaChannel();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_height(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // height()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->height();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_invertPixels(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.invertPixels(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:invertPixels", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: invertPixels(QImage::InvertMode)
    if (numArgs == 0) {
        overloadId = 0; // invertPixels(QImage::InvertMode)
    } else if (Shiboken::Converter< ::QImage::InvertMode >::isConvertible(pyargs[0])) {
        overloadId = 0; // invertPixels(QImage::InvertMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_invertPixels_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QImage::InvertMode >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QImageFunc_invertPixels_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.invertPixels(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QImage::InvertMode cppArg0 = pyargs[0] ? Shiboken::Converter<QImage::InvertMode >::toCpp(pyargs[0]) : QImage::InvertRgb;

            if(!PyErr_Occurred()) {
                // invertPixels(QImage::InvertMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->invertPixels(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_invertPixels_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage.InvertMode = InvertRgb", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.invertPixels", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_isGrayscale(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isGrayscale()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImage*>(cppSelf)->isGrayscale();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_isNull(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QImage*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_load(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.load(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.load(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:load", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: load(QIODevice*,const char*)
    // 1: load(QString,const char*)
    if (numArgs == 2 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
        overloadId = 0; // load(QIODevice*,const char*)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // load(QString,const char*)
        } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
            overloadId = 1; // load(QString,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_load_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // load(QIODevice*,const char*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // load(QIODevice*,const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->load(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // load(QString,const char*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< const char * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImageFunc_load_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.load(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                const char * cppArg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // load(QString,const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->load(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_load_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, str", "QString, str = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.load", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_loadFromData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.loadFromData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.loadFromData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:loadFromData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: loadFromData(QByteArray,const char*)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // loadFromData(QByteArray,const char*)
        } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
            overloadId = 0; // loadFromData(QByteArray,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_loadFromData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "aformat");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "aformat";
                    else if (Shiboken::Converter< const char * >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QImageFunc_loadFromData_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.loadFromData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
            const char * cppArg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // loadFromData(QByteArray,const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->loadFromData(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_loadFromData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, str = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.loadFromData", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_metric(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metric(QPaintDevice::PaintDeviceMetric)const
    if (Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::isConvertible(arg)) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_metric_TypeError;

    // Call function/method
    {
        {
            QPaintDevice::PaintDeviceMetric cppArg0 = Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // metric(QPaintDevice::PaintDeviceMetric)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QImage*>(cppSelf)->::QImage::metric(cppArg0) : const_cast<const QImage*>(cppSelf)->metric(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_metric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice.PaintDeviceMetric", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.metric", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_mirrored(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.mirrored(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:mirrored", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mirrored(bool,bool)const
    if (numArgs == 0) {
        overloadId = 0; // mirrored(bool,bool)const
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // mirrored(bool,bool)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // mirrored(bool,bool)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_mirrored_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "horizontally");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "horizontally";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QImageFunc_mirrored_TypeError;
                }
                value = PyDict_GetItemString(kwds, "vertically");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "vertically";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QImageFunc_mirrored_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.mirrored(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cppArg0 = pyargs[0] ? Shiboken::Converter<bool >::toCpp(pyargs[0]) : false;
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // mirrored(bool,bool)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QImage*>(cppSelf)->mirrored(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_mirrored_TypeError:
        const char* overloads[] = {"bool = false, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.mirrored", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_numBytes(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // numBytes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->numBytes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_numColors(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // numColors()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->numColors();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_offset(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // offset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QImage*>(cppSelf)->offset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_paintEngine(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // paintEngine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPaintEngine * cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QImage*>(cppSelf)->::QImage::paintEngine() : const_cast<const QImage*>(cppSelf)->paintEngine());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPaintEngine * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_pixel(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "pixel", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: pixel(QPoint)const
    // 1: pixel(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // pixel(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // pixel(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_pixel_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // pixel(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // pixel(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    unsigned int cppResult = const_cast<const QImage*>(cppSelf)->pixel(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 1: // pixel(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // pixel(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    unsigned int cppResult = const_cast<const QImage*>(cppSelf)->pixel(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_pixel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.pixel", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_pixelIndex(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "pixelIndex", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: pixelIndex(QPoint)const
    // 1: pixelIndex(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // pixelIndex(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // pixelIndex(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_pixelIndex_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // pixelIndex(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // pixelIndex(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QImage*>(cppSelf)->pixelIndex(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // pixelIndex(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // pixelIndex(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = const_cast<const QImage*>(cppSelf)->pixelIndex(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_pixelIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.pixelIndex", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_rect(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QImage*>(cppSelf)->rect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_rgbSwapped(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rgbSwapped()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QImage*>(cppSelf)->rgbSwapped();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_save(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.save(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.save(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:save", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: save(QIODevice*,const char*,int)const
    // 1: save(QString,const char*,int)const
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // save(QIODevice*,const char*,int)const
        } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // save(QIODevice*,const char*,int)const
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 0; // save(QIODevice*,const char*,int)const
            }
        }
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // save(QString,const char*,int)const
        } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // save(QString,const char*,int)const
            } else if (SbkNumber_Check(pyargs[2])) {
                overloadId = 1; // save(QString,const char*,int)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_save_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // save(QIODevice*,const char*,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< const char * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImageFunc_save_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "quality");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "quality";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QImageFunc_save_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.save(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);
                const char * cppArg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

                if(!PyErr_Occurred()) {
                    // save(QIODevice*,const char*,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QImage*>(cppSelf)->save(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // save(QString,const char*,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "format";
                        else if (Shiboken::Converter< const char * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImageFunc_save_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "quality");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "quality";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QImageFunc_save_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.save(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                const char * cppArg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : -1;

                if(!PyErr_Occurred()) {
                    // save(QString,const char*,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QImage*>(cppSelf)->save(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_save_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice, str = None, int = -1", "QString, str = None, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.save", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_scaled(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaled(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaled(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:scaled", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
    // 1: scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
        } else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
            } else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(pyargs[3])) {
                overloadId = 1; // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
            }
        }
    } else if (Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
        } else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
            } else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(pyargs[2])) {
                overloadId = 0; // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_scaled_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectMode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "aspectMode";
                        else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImageFunc_scaled_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QImageFunc_scaled_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaled(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
                Qt::AspectRatioMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[1]) : Qt::IgnoreAspectRatio;
                Qt::TransformationMode cppArg2 = pyargs[2] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[2]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                    // scaled(QSize,Qt::AspectRatioMode,Qt::TransformationMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QImage cppResult = const_cast<const QImage*>(cppSelf)->scaled(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
                }
                break;
            }
            case 1: // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "aspectMode");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "aspectMode";
                        else if (Shiboken::Converter< ::Qt::AspectRatioMode >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QImageFunc_scaled_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QImageFunc_scaled_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaled(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                Qt::AspectRatioMode cppArg2 = pyargs[2] ? Shiboken::Converter<Qt::AspectRatioMode >::toCpp(pyargs[2]) : Qt::IgnoreAspectRatio;
                Qt::TransformationMode cppArg3 = pyargs[3] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[3]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                    // scaled(int,int,Qt::AspectRatioMode,Qt::TransformationMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QImage cppResult = const_cast<const QImage*>(cppSelf)->scaled(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_scaled_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", "int, int, PySide.QtCore.Qt.AspectRatioMode = Qt.IgnoreAspectRatio, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.scaled", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_scaledToHeight(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaledToHeight(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaledToHeight(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:scaledToHeight", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scaledToHeight(int,Qt::TransformationMode)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scaledToHeight(int,Qt::TransformationMode)const
        } else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // scaledToHeight(int,Qt::TransformationMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_scaledToHeight_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QImageFunc_scaledToHeight_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaledToHeight(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::TransformationMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

            if(!PyErr_Occurred()) {
                // scaledToHeight(int,Qt::TransformationMode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QImage*>(cppSelf)->scaledToHeight(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_scaledToHeight_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.scaledToHeight", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_scaledToWidth(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaledToWidth(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.scaledToWidth(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:scaledToWidth", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scaledToWidth(int,Qt::TransformationMode)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scaledToWidth(int,Qt::TransformationMode)const
        } else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // scaledToWidth(int,Qt::TransformationMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_scaledToWidth_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QImageFunc_scaledToWidth_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.scaledToWidth(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::TransformationMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

            if(!PyErr_Occurred()) {
                // scaledToWidth(int,Qt::TransformationMode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QImage cppResult = const_cast<const QImage*>(cppSelf)->scaledToWidth(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_scaledToWidth_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.scaledToWidth", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_scanLine(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: scanLine(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // scanLine(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_scanLine_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // scanLine(int)
                // Begin code injection

                pyResult = PyBuffer_FromReadWriteMemory(cppSelf->scanLine(cppArg0), cppSelf->bytesPerLine());

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_scanLine_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.scanLine", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_setAlphaChannel(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlphaChannel(QImage)
    if (Shiboken::Converter< ::QImage >::isConvertible(arg)) {
        overloadId = 0; // setAlphaChannel(QImage)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_setAlphaChannel_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAlphaChannel(QImage)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAlphaChannel(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_setAlphaChannel_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setAlphaChannel", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_setColor(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColor", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setColor(int,uint)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setColor(int,uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_setColor_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setColor(int,uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColor(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_setColor_TypeError:
        const char* overloads[] = {"int, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.setColor", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_setColorCount(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColorCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setColorCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_setColorCount_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setColorCount(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColorCount(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_setColorCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setColorCount", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_setColorTable(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColorTable(QVector<uint>)
    if (Shiboken::Converter< ::QVector<unsigned int > >::isConvertible(arg)) {
        overloadId = 0; // setColorTable(QVector<uint>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_setColorTable_TypeError;

    // Call function/method
    {
        {
            QVector<unsigned int > cppArg0 = Shiboken::Converter<QVector<unsigned int > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setColorTable(QVector<uint>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColorTable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_setColorTable_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setColorTable", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_setDotsPerMeterX(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDotsPerMeterX(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDotsPerMeterX(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_setDotsPerMeterX_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDotsPerMeterX(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDotsPerMeterX(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_setDotsPerMeterX_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setDotsPerMeterX", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_setDotsPerMeterY(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDotsPerMeterY(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDotsPerMeterY(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_setDotsPerMeterY_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDotsPerMeterY(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDotsPerMeterY(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_setDotsPerMeterY_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setDotsPerMeterY", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_setNumColors(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNumColors(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setNumColors(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_setNumColors_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNumColors(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNumColors(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_setNumColors_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setNumColors", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_setOffset(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOffset(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // setOffset(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_setOffset_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOffset(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOffset(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_setOffset_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.setOffset", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_setPixel(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPixel", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setPixel(QPoint,uint)
    // 1: setPixel(int,int,uint)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // setPixel(int,int,uint)
    } else if (numArgs == 2 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setPixel(QPoint,uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_setPixel_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setPixel(QPoint,uint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
                uint cppArg1 = Shiboken::Converter<uint >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setPixel(QPoint,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setPixel(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setPixel(int,int,uint)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                uint cppArg2 = Shiboken::Converter<uint >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setPixel(int,int,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setPixel(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_setPixel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, unsigned int", "int, int, unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.setPixel", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_setText(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setText", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setText(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setText(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_setText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setText(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setText(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QImageFunc_setText_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.setText", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_size(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QImage*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_text(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.text(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:text", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: text(QString)const
    if (numArgs == 0) {
        overloadId = 0; // text(QString)const
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // text(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_text_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "key");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "key";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QImageFunc_text_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.text(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();

            if(!PyErr_Occurred()) {
                // text(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QImage*>(cppSelf)->text(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_text_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.text", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_textKeys(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textKeys()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QImage*>(cppSelf)->textKeys();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QImageFunc_transformed(PyObject* self, PyObject* args, PyObject* kwds)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.transformed(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QImage.transformed(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:transformed", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: transformed(QMatrix,Qt::TransformationMode)const
    // 1: transformed(QTransform,Qt::TransformationMode)const
    if (Shiboken::Converter< ::QTransform >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // transformed(QTransform,Qt::TransformationMode)const
        } else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // transformed(QTransform,Qt::TransformationMode)const
        }
    } else if (Shiboken::Converter< ::QMatrix >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // transformed(QMatrix,Qt::TransformationMode)const
        } else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(pyargs[1])) {
            overloadId = 0; // transformed(QMatrix,Qt::TransformationMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_transformed_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // transformed(QMatrix,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImageFunc_transformed_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.transformed(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QMatrix cppArg0 = Shiboken::Converter<QMatrix >::toCpp(pyargs[0]);
                Qt::TransformationMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                    // transformed(QMatrix,Qt::TransformationMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QImage cppResult = const_cast<const QImage*>(cppSelf)->transformed(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
                }
                break;
            }
            case 1: // transformed(QTransform,Qt::TransformationMode)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "mode");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "mode";
                        else if (Shiboken::Converter< ::Qt::TransformationMode >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QImageFunc_transformed_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QImage.transformed(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(pyargs[0]);
                Qt::TransformationMode cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::TransformationMode >::toCpp(pyargs[1]) : Qt::FastTransformation;

                if(!PyErr_Occurred()) {
                    // transformed(QTransform,Qt::TransformationMode)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QImage cppResult = const_cast<const QImage*>(cppSelf)->transformed(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QImage >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_transformed_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", "PySide.QtGui.QTransform, PySide.QtCore.Qt.TransformationMode = Qt.FastTransformation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.transformed", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_trueMatrix(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "trueMatrix", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: trueMatrix(QMatrix,int,int)
    // 1: trueMatrix(QTransform,int,int)
    if (numArgs == 3 && Shiboken::Converter< ::QTransform >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // trueMatrix(QTransform,int,int)
    } else if (numArgs == 3 && Shiboken::Converter< ::QMatrix >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // trueMatrix(QMatrix,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_trueMatrix_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // trueMatrix(QMatrix,int,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QMatrix cppArg0 = Shiboken::Converter<QMatrix >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // trueMatrix(QMatrix,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QMatrix cppResult = QImage::trueMatrix(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QMatrix >::toPython(cppResult);
                }
                break;
            }
            case 1: // trueMatrix(QTransform,int,int)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // trueMatrix(QTransform,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTransform cppResult = QImage::trueMatrix(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTransform >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_trueMatrix_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix, int, int", "PySide.QtGui.QTransform, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.trueMatrix", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_valid(PyObject* self, PyObject* args)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "valid", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: valid(QPoint)const
    // 1: valid(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // valid(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // valid(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc_valid_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // valid(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // valid(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QImage*>(cppSelf)->valid(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // valid(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // valid(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = const_cast<const QImage*>(cppSelf)->valid(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc_valid_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QImage.valid", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc_width(PyObject* self)
{
    QImage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // width()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QImage*>(cppSelf)->width();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QImage___copy__(PyObject *self)
{
        QImage* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QImage*>::toCpp(self);
        PyObject* pyResult = 0;
        QImage* copy = new QImage(*cppSelf);
        pyResult = Shiboken::Converter<QImage*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QImage_methods[] = {
    {"allGray", (PyCFunction)Sbk_QImageFunc_allGray, METH_NOARGS},
    {"alphaChannel", (PyCFunction)Sbk_QImageFunc_alphaChannel, METH_NOARGS},
    {"bitPlaneCount", (PyCFunction)Sbk_QImageFunc_bitPlaneCount, METH_NOARGS},
    {"bits", (PyCFunction)Sbk_QImageFunc_bits, METH_NOARGS},
    {"byteCount", (PyCFunction)Sbk_QImageFunc_byteCount, METH_NOARGS},
    {"bytesPerLine", (PyCFunction)Sbk_QImageFunc_bytesPerLine, METH_NOARGS},
    {"cacheKey", (PyCFunction)Sbk_QImageFunc_cacheKey, METH_NOARGS},
    {"color", (PyCFunction)Sbk_QImageFunc_color, METH_O},
    {"colorCount", (PyCFunction)Sbk_QImageFunc_colorCount, METH_NOARGS},
    {"colorTable", (PyCFunction)Sbk_QImageFunc_colorTable, METH_NOARGS},
    {"constBits", (PyCFunction)Sbk_QImageFunc_constBits, METH_NOARGS},
    {"constScanLine", (PyCFunction)Sbk_QImageFunc_constScanLine, METH_O},
    {"convertToFormat", (PyCFunction)Sbk_QImageFunc_convertToFormat, METH_VARARGS|METH_KEYWORDS},
    {"copy", (PyCFunction)Sbk_QImageFunc_copy, METH_VARARGS|METH_KEYWORDS},
    {"createAlphaMask", (PyCFunction)Sbk_QImageFunc_createAlphaMask, METH_VARARGS|METH_KEYWORDS},
    {"createHeuristicMask", (PyCFunction)Sbk_QImageFunc_createHeuristicMask, METH_VARARGS|METH_KEYWORDS},
    {"createMaskFromColor", (PyCFunction)Sbk_QImageFunc_createMaskFromColor, METH_VARARGS|METH_KEYWORDS},
    {"depth", (PyCFunction)Sbk_QImageFunc_depth, METH_NOARGS},
    {"devType", (PyCFunction)Sbk_QImageFunc_devType, METH_NOARGS},
    {"dotsPerMeterX", (PyCFunction)Sbk_QImageFunc_dotsPerMeterX, METH_NOARGS},
    {"dotsPerMeterY", (PyCFunction)Sbk_QImageFunc_dotsPerMeterY, METH_NOARGS},
    {"fill", (PyCFunction)Sbk_QImageFunc_fill, METH_O},
    {"format", (PyCFunction)Sbk_QImageFunc_format, METH_NOARGS},
    {"fromData", (PyCFunction)Sbk_QImageFunc_fromData, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"hasAlphaChannel", (PyCFunction)Sbk_QImageFunc_hasAlphaChannel, METH_NOARGS},
    {"height", (PyCFunction)Sbk_QImageFunc_height, METH_NOARGS},
    {"invertPixels", (PyCFunction)Sbk_QImageFunc_invertPixels, METH_VARARGS|METH_KEYWORDS},
    {"isGrayscale", (PyCFunction)Sbk_QImageFunc_isGrayscale, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QImageFunc_isNull, METH_NOARGS},
    {"load", (PyCFunction)Sbk_QImageFunc_load, METH_VARARGS|METH_KEYWORDS},
    {"loadFromData", (PyCFunction)Sbk_QImageFunc_loadFromData, METH_VARARGS|METH_KEYWORDS},
    {"metric", (PyCFunction)Sbk_QImageFunc_metric, METH_O},
    {"mirrored", (PyCFunction)Sbk_QImageFunc_mirrored, METH_VARARGS|METH_KEYWORDS},
    {"numBytes", (PyCFunction)Sbk_QImageFunc_numBytes, METH_NOARGS},
    {"numColors", (PyCFunction)Sbk_QImageFunc_numColors, METH_NOARGS},
    {"offset", (PyCFunction)Sbk_QImageFunc_offset, METH_NOARGS},
    {"paintEngine", (PyCFunction)Sbk_QImageFunc_paintEngine, METH_NOARGS},
    {"pixel", (PyCFunction)Sbk_QImageFunc_pixel, METH_VARARGS},
    {"pixelIndex", (PyCFunction)Sbk_QImageFunc_pixelIndex, METH_VARARGS},
    {"rect", (PyCFunction)Sbk_QImageFunc_rect, METH_NOARGS},
    {"rgbSwapped", (PyCFunction)Sbk_QImageFunc_rgbSwapped, METH_NOARGS},
    {"save", (PyCFunction)Sbk_QImageFunc_save, METH_VARARGS|METH_KEYWORDS},
    {"scaled", (PyCFunction)Sbk_QImageFunc_scaled, METH_VARARGS|METH_KEYWORDS},
    {"scaledToHeight", (PyCFunction)Sbk_QImageFunc_scaledToHeight, METH_VARARGS|METH_KEYWORDS},
    {"scaledToWidth", (PyCFunction)Sbk_QImageFunc_scaledToWidth, METH_VARARGS|METH_KEYWORDS},
    {"scanLine", (PyCFunction)Sbk_QImageFunc_scanLine, METH_O},
    {"setAlphaChannel", (PyCFunction)Sbk_QImageFunc_setAlphaChannel, METH_O},
    {"setColor", (PyCFunction)Sbk_QImageFunc_setColor, METH_VARARGS},
    {"setColorCount", (PyCFunction)Sbk_QImageFunc_setColorCount, METH_O},
    {"setColorTable", (PyCFunction)Sbk_QImageFunc_setColorTable, METH_O},
    {"setDotsPerMeterX", (PyCFunction)Sbk_QImageFunc_setDotsPerMeterX, METH_O},
    {"setDotsPerMeterY", (PyCFunction)Sbk_QImageFunc_setDotsPerMeterY, METH_O},
    {"setNumColors", (PyCFunction)Sbk_QImageFunc_setNumColors, METH_O},
    {"setOffset", (PyCFunction)Sbk_QImageFunc_setOffset, METH_O},
    {"setPixel", (PyCFunction)Sbk_QImageFunc_setPixel, METH_VARARGS},
    {"setText", (PyCFunction)Sbk_QImageFunc_setText, METH_VARARGS},
    {"size", (PyCFunction)Sbk_QImageFunc_size, METH_NOARGS},
    {"text", (PyCFunction)Sbk_QImageFunc_text, METH_VARARGS|METH_KEYWORDS},
    {"textKeys", (PyCFunction)Sbk_QImageFunc_textKeys, METH_NOARGS},
    {"transformed", (PyCFunction)Sbk_QImageFunc_transformed, METH_VARARGS|METH_KEYWORDS},
    {"trueMatrix", (PyCFunction)Sbk_QImageFunc_trueMatrix, METH_VARARGS|METH_STATIC},
    {"valid", (PyCFunction)Sbk_QImageFunc_valid, METH_VARARGS},
    {"width", (PyCFunction)Sbk_QImageFunc_width, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QImage___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QImage___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QImage* cppSelf = Shiboken::Converter< ::QImage*>::toCpp(pyObj);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QImageFunc___lshift__(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QImage >::checkType(arg) && !Shiboken::Converter< ::QImage >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QImage)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QImage)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QImage) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QImageFunc___rshift__(PyObject* self, PyObject* arg)
{
    QImage* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QImage >::checkType(arg) && !Shiboken::Converter< ::QImage >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QImage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QImage&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QImage&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QImageFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QImage&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QImageFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QImage.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QImage_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QImage___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QImageFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QImageFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QImage_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QImage& cppSelf = *Shiboken::Converter< QImage* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QImage >::isConvertible(arg)) {
                // operator!=(const QImage & arg__1) const
                QImage cppArg0 = Shiboken::Converter< ::QImage >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QImage >::isConvertible(arg)) {
                // operator==(const QImage & arg__1) const
                QImage cppArg0 = Shiboken::Converter< ::QImage >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QImage_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QImage_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QImage_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QImage",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QImage_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QImage_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QImage_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QImage_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QImage_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QImage*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QImage_Type;
    return 0;
}


void init_QImage(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QIMAGE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QImage_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QImage_Type);
    Sbk_QImage_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QImage_Type, &Shiboken::callCppDestructor<QImageWrapper >);
    Py_INCREF((PyObject*)&Sbk_QImage_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QImage_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QImage_Type, &Sbk_QImage_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]), &Sbk_QImage_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QImage_Type, "QImage");
    PyModule_AddObject(module, "QImage",
        ((PyObject*)&Sbk_QImage_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: InvertMode
    PyTypeObject* SbkPySide_QtGui_QImage_InvertMode = Shiboken::Enum::newType("PySide.QtGui.QImage.InvertMode");
    SbkPySide_QtGuiTypes[SBK_QIMAGE_INVERTMODE_IDX] = SbkPySide_QtGui_QImage_InvertMode;
    if (PyType_Ready(SbkPySide_QtGui_QImage_InvertMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,
            "InvertMode",((PyObject*)SbkPySide_QtGui_QImage_InvertMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_InvertMode,(long) QImage::InvertRgb, "InvertRgb");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"InvertRgb", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_InvertMode->tp_dict,"InvertRgb", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_InvertMode,(long) QImage::InvertRgba, "InvertRgba");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"InvertRgba", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_InvertMode->tp_dict,"InvertRgba", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QImage::InvertMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::InvertMode");
    // end of enum InvertMode

    // init enum: Format
    PyTypeObject* SbkPySide_QtGui_QImage_Format = Shiboken::Enum::newType("PySide.QtGui.QImage.Format");
    SbkPySide_QtGuiTypes[SBK_QIMAGE_FORMAT_IDX] = SbkPySide_QtGui_QImage_Format;
    if (PyType_Ready(SbkPySide_QtGui_QImage_Format) < 0)
        return;
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,
            "Format",((PyObject*)SbkPySide_QtGui_QImage_Format));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_Invalid, "Format_Invalid");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_Invalid", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_Invalid", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_Mono, "Format_Mono");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_Mono", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_Mono", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_MonoLSB, "Format_MonoLSB");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_MonoLSB", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_MonoLSB", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_Indexed8, "Format_Indexed8");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_Indexed8", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_Indexed8", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_RGB32, "Format_RGB32");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_RGB32", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_RGB32", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_ARGB32, "Format_ARGB32");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_ARGB32", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_ARGB32", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_ARGB32_Premultiplied, "Format_ARGB32_Premultiplied");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_ARGB32_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_ARGB32_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_RGB16, "Format_RGB16");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_RGB16", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_RGB16", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_ARGB8565_Premultiplied, "Format_ARGB8565_Premultiplied");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_ARGB8565_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_ARGB8565_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_RGB666, "Format_RGB666");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_RGB666", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_RGB666", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_ARGB6666_Premultiplied, "Format_ARGB6666_Premultiplied");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_ARGB6666_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_ARGB6666_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_RGB555, "Format_RGB555");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_RGB555", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_RGB555", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_ARGB8555_Premultiplied, "Format_ARGB8555_Premultiplied");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_ARGB8555_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_ARGB8555_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_RGB888, "Format_RGB888");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_RGB888", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_RGB888", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_RGB444, "Format_RGB444");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_RGB444", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_RGB444", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QImage_Format,(long) QImage::Format_ARGB4444_Premultiplied, "Format_ARGB4444_Premultiplied");
    PyDict_SetItemString(Sbk_QImage_Type.super.ht_type.tp_dict,"Format_ARGB4444_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QImage_Format->tp_dict,"Format_ARGB4444_Premultiplied", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QImage::Format");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Format");
    // end of enum Format


    Shiboken::TypeResolver::createValueTypeResolver<QImage >("QImage");
    Shiboken::TypeResolver::createObjectTypeResolver<QImage >("QImage*");
    Shiboken::TypeResolver::createValueTypeResolver<QImage >(typeid(QImage).name());
    Shiboken::TypeResolver::createValueTypeResolver<QImage >(typeid(QImageWrapper).name());
    qRegisterMetaType< ::QImage >("QImage");
    qRegisterMetaType< ::QImage::InvertMode >("QImage::InvertMode");
    qRegisterMetaType< ::QImage::Format >("QImage::Format");
}

