/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qinputdialog_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qinputdialog.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qwidget.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QInputDialogWrapper::QInputDialogWrapper(QWidget * parent, QFlags<Qt::WindowType> flags) : QInputDialog(parent, flags) {
    // ... middle
}

void QInputDialogWrapper::accept()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "accept"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::accept();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QInputDialogWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::changeEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::changeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QInputDialogWrapper::closeEvent(QCloseEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::closeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QInputDialogWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QInputDialogWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QInputDialog.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QInputDialogWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QInputDialogWrapper::done(int result)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "done"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QInputDialog::done(result);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        result
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QInputDialogWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QInputDialogWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QInputDialog.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QInputDialogWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QInputDialog.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QInputDialogWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QInputDialogWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QInputDialog.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QInputDialogWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QInputDialogWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QInputDialog.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QInputDialogWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QInputDialogWrapper::inputMethodQuery(Qt::InputMethodQuery arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::inputMethodQuery(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QInputDialog.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QInputDialogWrapper::keyPressEvent(QKeyEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::keyPressEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::languageChange()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QInputDialogWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QInputDialogWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QInputDialog.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QInputDialogWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QInputDialog::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QInputDialog.minimumSizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QInputDialogWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::mouseMoveEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::mouseReleaseEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QInputDialogWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QInputDialog.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

void QInputDialogWrapper::paintEvent(QPaintEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::reject()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reject"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::reject();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QInputDialogWrapper::resizeEvent(QResizeEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::resizeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QInputDialog::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QInputDialogWrapper::showEvent(QShowEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QDialog::showEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QInputDialogWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QInputDialog::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QInputDialog.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QInputDialogWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QInputDialogWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QInputDialogWrapper::wheelEvent(QWheelEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QInputDialogWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QInputDialogWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QInputDialog::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QInputDialogWrapper::~QInputDialogWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QInputDialog_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QInputDialog >()))
        return -1;

    QInputDialogWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"flags", "parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QInputDialog", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QInputDialog(QWidget*,QFlags<Qt::WindowType>)
    if (numArgs == 0) {
        overloadId = 0; // QInputDialog(QWidget*,QFlags<Qt::WindowType>)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QInputDialog(QWidget*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QInputDialog(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialog_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QInputDialog_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QInputDialog_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QInputDialog(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;
            QFlags<Qt::WindowType> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
                // QInputDialog(QWidget*,QFlags<Qt::WindowType>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QInputDialogWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QInputDialog >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QInputDialog_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 2))
        return -1;


    return 1;

    Sbk_QInputDialog_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputDialog", overloads);
        return -1;
}

static PyObject* Sbk_QInputDialogFunc_cancelButtonText(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cancelButtonText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QInputDialog*>(cppSelf)->cancelButtonText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_comboBoxItems(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // comboBoxItems()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QInputDialog*>(cppSelf)->comboBoxItems();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_done(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: done(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // done(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_done_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // done(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QInputDialog::done(cppArg0) : cppSelf->done(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_done_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.done", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_doubleDecimals(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doubleDecimals()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QInputDialog*>(cppSelf)->doubleDecimals();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_doubleMaximum(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doubleMaximum()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                double cppResult = const_cast<const QInputDialog*>(cppSelf)->doubleMaximum();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_doubleMinimum(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doubleMinimum()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                double cppResult = const_cast<const QInputDialog*>(cppSelf)->doubleMinimum();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_doubleValue(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doubleValue()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                double cppResult = const_cast<const QInputDialog*>(cppSelf)->doubleValue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_getDouble(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 8) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.getDouble(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.getDouble(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOO:getDouble", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7])))
        return 0;


    // Overloaded function decisor
    // 0: getDouble(QWidget*,QString,QString,double,double,double,int,bool*,QFlags<Qt::WindowType>)
    if (numArgs >= 3 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // getDouble(QWidget*,QString,QString,double,double,double,int,bool*,QFlags<Qt::WindowType>)
        } else if (SbkNumber_Check(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // getDouble(QWidget*,QString,QString,double,double,double,int,bool*,QFlags<Qt::WindowType>)
            } else if (SbkNumber_Check(pyargs[4])) {
                if (numArgs == 5) {
                    overloadId = 0; // getDouble(QWidget*,QString,QString,double,double,double,int,bool*,QFlags<Qt::WindowType>)
                } else if (SbkNumber_Check(pyargs[5])) {
                    if (numArgs == 6) {
                        overloadId = 0; // getDouble(QWidget*,QString,QString,double,double,double,int,bool*,QFlags<Qt::WindowType>)
                    } else if (SbkNumber_Check(pyargs[6])) {
                        if (numArgs == 7) {
                            overloadId = 0; // getDouble(QWidget*,QString,QString,double,double,double,int,bool*,QFlags<Qt::WindowType>)
                        } else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[7])) {
                            overloadId = 0; // getDouble(QWidget*,QString,QString,double,double,double,int,bool*,QFlags<Qt::WindowType>)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_getDouble_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "value");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "value";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QInputDialogFunc_getDouble_TypeError;
                }
                value = PyDict_GetItemString(kwds, "minValue");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "minValue";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QInputDialogFunc_getDouble_TypeError;
                }
                value = PyDict_GetItemString(kwds, "maxValue");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "maxValue";
                    else if (SbkNumber_Check(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QInputDialogFunc_getDouble_TypeError;
                }
                value = PyDict_GetItemString(kwds, "decimals");
                if (value) {
                    if (pyargs[6])
                        errorArgName = "decimals";
                    else if (SbkNumber_Check(value))
                        pyargs[6] = value;
                    else
                        goto Sbk_QInputDialogFunc_getDouble_TypeError;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[7])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value))
                        pyargs[7] = value;
                    else
                        goto Sbk_QInputDialogFunc_getDouble_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QInputDialog.getDouble(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            double cppArg3 = pyargs[3] ? Shiboken::Converter<double >::toCpp(pyargs[3]) : 0;
            double cppArg4 = pyargs[4] ? Shiboken::Converter<double >::toCpp(pyargs[4]) : -2147483647;
            double cppArg5 = pyargs[5] ? Shiboken::Converter<double >::toCpp(pyargs[5]) : 2147483647;
            int cppArg6 = pyargs[6] ? Shiboken::Converter<int >::toCpp(pyargs[6]) : 1;
            QFlags<Qt::WindowType> cppArg7 = pyargs[7] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[7]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
                // getDouble(QWidget*,QString,QString,double,double,double,int,bool*,QFlags<Qt::WindowType>)
                // Begin code injection

                // TEMPLATE - fix_arg,arg,arg,arg,arg,arg,arg,bool*,arg - START
                bool ok_;
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                double retval_ = QInputDialog::getDouble(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, &ok_, cppArg7);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,arg,arg,arg,arg,arg,arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QInputDialogFunc_getDouble_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString, QString, float = 0, float = -2147483647, float = 2147483647, int = 1, bool, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputDialog.getDouble", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_getInt(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 8) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.getInt(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.getInt(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOO:getInt", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7])))
        return 0;


    // Overloaded function decisor
    // 0: getInt(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
    if (numArgs >= 3 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // getInt(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
        } else if (SbkNumber_Check(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // getInt(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
            } else if (SbkNumber_Check(pyargs[4])) {
                if (numArgs == 5) {
                    overloadId = 0; // getInt(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
                } else if (SbkNumber_Check(pyargs[5])) {
                    if (numArgs == 6) {
                        overloadId = 0; // getInt(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
                    } else if (SbkNumber_Check(pyargs[6])) {
                        if (numArgs == 7) {
                            overloadId = 0; // getInt(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
                        } else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[7])) {
                            overloadId = 0; // getInt(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_getInt_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "value");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "value";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QInputDialogFunc_getInt_TypeError;
                }
                value = PyDict_GetItemString(kwds, "minValue");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "minValue";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QInputDialogFunc_getInt_TypeError;
                }
                value = PyDict_GetItemString(kwds, "maxValue");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "maxValue";
                    else if (SbkNumber_Check(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QInputDialogFunc_getInt_TypeError;
                }
                value = PyDict_GetItemString(kwds, "step");
                if (value) {
                    if (pyargs[6])
                        errorArgName = "step";
                    else if (SbkNumber_Check(value))
                        pyargs[6] = value;
                    else
                        goto Sbk_QInputDialogFunc_getInt_TypeError;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[7])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value))
                        pyargs[7] = value;
                    else
                        goto Sbk_QInputDialogFunc_getInt_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QInputDialog.getInt(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;
            int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : -2147483647;
            int cppArg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : 2147483647;
            int cppArg6 = pyargs[6] ? Shiboken::Converter<int >::toCpp(pyargs[6]) : 1;
            QFlags<Qt::WindowType> cppArg7 = pyargs[7] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[7]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
                // getInt(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
                // Begin code injection

                // TEMPLATE - fix_arg,arg,arg,arg,arg,arg,arg,bool*,arg - START
                bool ok_;
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int retval_ = QInputDialog::getInt(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, &ok_, cppArg7);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,arg,arg,arg,arg,arg,arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QInputDialogFunc_getInt_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString, QString, int = 0, int = -2147483647, int = 2147483647, int = 1, bool, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputDialog.getInt", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_getInteger(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 8) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.getInteger(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.getInteger(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOO:getInteger", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7])))
        return 0;


    // Overloaded function decisor
    // 0: getInteger(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
    if (numArgs >= 3 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // getInteger(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
        } else if (SbkNumber_Check(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // getInteger(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
            } else if (SbkNumber_Check(pyargs[4])) {
                if (numArgs == 5) {
                    overloadId = 0; // getInteger(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
                } else if (SbkNumber_Check(pyargs[5])) {
                    if (numArgs == 6) {
                        overloadId = 0; // getInteger(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
                    } else if (SbkNumber_Check(pyargs[6])) {
                        if (numArgs == 7) {
                            overloadId = 0; // getInteger(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
                        } else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[7])) {
                            overloadId = 0; // getInteger(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_getInteger_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "value");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "value";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QInputDialogFunc_getInteger_TypeError;
                }
                value = PyDict_GetItemString(kwds, "minValue");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "minValue";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QInputDialogFunc_getInteger_TypeError;
                }
                value = PyDict_GetItemString(kwds, "maxValue");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "maxValue";
                    else if (SbkNumber_Check(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QInputDialogFunc_getInteger_TypeError;
                }
                value = PyDict_GetItemString(kwds, "step");
                if (value) {
                    if (pyargs[6])
                        errorArgName = "step";
                    else if (SbkNumber_Check(value))
                        pyargs[6] = value;
                    else
                        goto Sbk_QInputDialogFunc_getInteger_TypeError;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[7])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value))
                        pyargs[7] = value;
                    else
                        goto Sbk_QInputDialogFunc_getInteger_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QInputDialog.getInteger(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 0;
            int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : -2147483647;
            int cppArg5 = pyargs[5] ? Shiboken::Converter<int >::toCpp(pyargs[5]) : 2147483647;
            int cppArg6 = pyargs[6] ? Shiboken::Converter<int >::toCpp(pyargs[6]) : 1;
            QFlags<Qt::WindowType> cppArg7 = pyargs[7] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[7]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
                // getInteger(QWidget*,QString,QString,int,int,int,int,bool*,QFlags<Qt::WindowType>)
                // Begin code injection

                // TEMPLATE - fix_arg,arg,arg,arg,arg,arg,arg,bool*,arg - START
                bool ok_;
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int retval_ = QInputDialog::getInteger(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, &ok_, cppArg7);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,arg,arg,arg,arg,arg,arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QInputDialogFunc_getInteger_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString, QString, int = 0, int = -2147483647, int = 2147483647, int = 1, bool, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputDialog.getInteger", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_getItem(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.getItem(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.getItem(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOO:getItem", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: getItem(QWidget*,QString,QString,QStringList,int,bool,bool*,QFlags<Qt::WindowType>)
    if (numArgs >= 4 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QStringList >::isConvertible(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // getItem(QWidget*,QString,QString,QStringList,int,bool,bool*,QFlags<Qt::WindowType>)
        } else if (SbkNumber_Check(pyargs[4])) {
            if (numArgs == 5) {
                overloadId = 0; // getItem(QWidget*,QString,QString,QStringList,int,bool,bool*,QFlags<Qt::WindowType>)
            } else if (SbkNumber_Check(pyargs[5])) {
                if (numArgs == 6) {
                    overloadId = 0; // getItem(QWidget*,QString,QString,QStringList,int,bool,bool*,QFlags<Qt::WindowType>)
                } else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[6])) {
                    overloadId = 0; // getItem(QWidget*,QString,QString,QStringList,int,bool,bool*,QFlags<Qt::WindowType>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_getItem_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "current");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "current";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QInputDialogFunc_getItem_TypeError;
                }
                value = PyDict_GetItemString(kwds, "editable");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "editable";
                    else if (SbkNumber_Check(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QInputDialogFunc_getItem_TypeError;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[6])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value))
                        pyargs[6] = value;
                    else
                        goto Sbk_QInputDialogFunc_getItem_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QInputDialog.getItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            QStringList cppArg3 = Shiboken::Converter<QStringList >::toCpp(pyargs[3]);
            int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 0;
            bool cppArg5 = pyargs[5] ? Shiboken::Converter<bool >::toCpp(pyargs[5]) : true;
            QFlags<Qt::WindowType> cppArg6 = pyargs[6] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[6]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
                // getItem(QWidget*,QString,QString,QStringList,int,bool,bool*,QFlags<Qt::WindowType>)
                // Begin code injection

                // TEMPLATE - fix_arg,arg,arg,arg,arg,arg,bool*,arg - START
                bool ok_;
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString retval_ = QInputDialog::getItem(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, &ok_, cppArg6);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,arg,arg,arg,arg,arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QInputDialogFunc_getItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString, QString, list, int = 0, bool = true, bool, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputDialog.getItem", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_getText(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.getText(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.getText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOO:getText", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: getText(QWidget*,QString,QString,QLineEdit::EchoMode,QString,bool*,QFlags<Qt::WindowType>)
    if (numArgs >= 3 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // getText(QWidget*,QString,QString,QLineEdit::EchoMode,QString,bool*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter< ::QLineEdit::EchoMode >::isConvertible(pyargs[3])) {
            if (numArgs == 4) {
                overloadId = 0; // getText(QWidget*,QString,QString,QLineEdit::EchoMode,QString,bool*,QFlags<Qt::WindowType>)
            } else if (Shiboken::Converter< QString >::isConvertible(pyargs[4])) {
                if (numArgs == 5) {
                    overloadId = 0; // getText(QWidget*,QString,QString,QLineEdit::EchoMode,QString,bool*,QFlags<Qt::WindowType>)
                } else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[5])) {
                    overloadId = 0; // getText(QWidget*,QString,QString,QLineEdit::EchoMode,QString,bool*,QFlags<Qt::WindowType>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_getText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "echo");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "echo";
                    else if (Shiboken::Converter< ::QLineEdit::EchoMode >::isConvertible(value))
                        pyargs[3] = value;
                    else
                        goto Sbk_QInputDialogFunc_getText_TypeError;
                }
                value = PyDict_GetItemString(kwds, "text");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "text";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[4] = value;
                    else
                        goto Sbk_QInputDialogFunc_getText_TypeError;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value))
                        pyargs[5] = value;
                    else
                        goto Sbk_QInputDialogFunc_getText_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QInputDialog.getText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            QLineEdit::EchoMode cppArg3 = pyargs[3] ? Shiboken::Converter<QLineEdit::EchoMode >::toCpp(pyargs[3]) : QLineEdit::Normal;
            QString cppArg4 = pyargs[4] ? Shiboken::Converter<QString >::toCpp(pyargs[4]) : QString();
            QFlags<Qt::WindowType> cppArg5 = pyargs[5] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[5]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
                // getText(QWidget*,QString,QString,QLineEdit::EchoMode,QString,bool*,QFlags<Qt::WindowType>)
                // Begin code injection

                // TEMPLATE - fix_arg,arg,arg,arg,arg,bool*,arg - START
                bool ok_;
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString retval_ = QInputDialog::getText(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, &ok_, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_arg,arg,arg,arg,arg,bool*,arg - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QInputDialogFunc_getText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, QString, QString, PySide.QtGui.QLineEdit.EchoMode = QLineEdit.Normal, QString = QString(), bool, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputDialog.getText", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_inputMode(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // inputMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QInputDialog::InputMode cppResult = const_cast<const QInputDialog*>(cppSelf)->inputMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QInputDialog::InputMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_intMaximum(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // intMaximum()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QInputDialog*>(cppSelf)->intMaximum();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_intMinimum(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // intMinimum()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QInputDialog*>(cppSelf)->intMinimum();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_intStep(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // intStep()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QInputDialog*>(cppSelf)->intStep();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_intValue(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // intValue()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QInputDialog*>(cppSelf)->intValue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_isComboBoxEditable(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isComboBoxEditable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QInputDialog*>(cppSelf)->isComboBoxEditable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_labelText(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // labelText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QInputDialog*>(cppSelf)->labelText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_minimumSizeHint(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minimumSizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QInputDialog*>(cppSelf)->::QInputDialog::minimumSizeHint() : const_cast<const QInputDialog*>(cppSelf)->minimumSizeHint());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_okButtonText(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // okButtonText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QInputDialog*>(cppSelf)->okButtonText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_open(PyObject* self, PyObject* args)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto Sbk_QInputDialogFunc_open_TypeError;

    if (!PyArg_UnpackTuple(args, "open", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: open()
    // 1: open(QObject*,const char*)
    if (numArgs == 0) {
        overloadId = 0; // open()
    } else if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
        overloadId = 1; // open(QObject*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_open_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // open()
            {

                if(!PyErr_Occurred()) {
                    // open()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->open();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // open(QObject*,const char*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // open(QObject*,const char*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->open(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_open_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QObject, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputDialog.open", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setCancelButtonText(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCancelButtonText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setCancelButtonText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setCancelButtonText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCancelButtonText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCancelButtonText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setCancelButtonText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setCancelButtonText", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setComboBoxEditable(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setComboBoxEditable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setComboBoxEditable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setComboBoxEditable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setComboBoxEditable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setComboBoxEditable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setComboBoxEditable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setComboBoxEditable", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setComboBoxItems(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setComboBoxItems(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setComboBoxItems(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setComboBoxItems_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setComboBoxItems(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setComboBoxItems(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setComboBoxItems_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setComboBoxItems", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setDoubleDecimals(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDoubleDecimals(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDoubleDecimals(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setDoubleDecimals_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDoubleDecimals(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDoubleDecimals(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setDoubleDecimals_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setDoubleDecimals", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setDoubleMaximum(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDoubleMaximum(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDoubleMaximum(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setDoubleMaximum_TypeError;

    // Call function/method
    {
        {
            double cppArg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDoubleMaximum(double)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDoubleMaximum(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setDoubleMaximum_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setDoubleMaximum", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setDoubleMinimum(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDoubleMinimum(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDoubleMinimum(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setDoubleMinimum_TypeError;

    // Call function/method
    {
        {
            double cppArg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDoubleMinimum(double)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDoubleMinimum(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setDoubleMinimum_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setDoubleMinimum", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setDoubleRange(PyObject* self, PyObject* args)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setDoubleRange", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setDoubleRange(double,double)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setDoubleRange(double,double)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setDoubleRange_TypeError;

    // Call function/method
    {
        {
            double cppArg0 = Shiboken::Converter<double >::toCpp(pyargs[0]);
            double cppArg1 = Shiboken::Converter<double >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setDoubleRange(double,double)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDoubleRange(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setDoubleRange_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputDialog.setDoubleRange", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setDoubleValue(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDoubleValue(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDoubleValue(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setDoubleValue_TypeError;

    // Call function/method
    {
        {
            double cppArg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDoubleValue(double)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDoubleValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setDoubleValue_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setDoubleValue", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setInputMode(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInputMode(QInputDialog::InputMode)
    if (Shiboken::Converter< ::QInputDialog::InputMode >::isConvertible(arg)) {
        overloadId = 0; // setInputMode(QInputDialog::InputMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setInputMode_TypeError;

    // Call function/method
    {
        {
            QInputDialog::InputMode cppArg0 = Shiboken::Converter<QInputDialog::InputMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setInputMode(QInputDialog::InputMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setInputMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setInputMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputDialog.InputMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setInputMode", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setIntMaximum(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIntMaximum(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIntMaximum(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setIntMaximum_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIntMaximum(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIntMaximum(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setIntMaximum_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setIntMaximum", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setIntMinimum(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIntMinimum(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIntMinimum(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setIntMinimum_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIntMinimum(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIntMinimum(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setIntMinimum_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setIntMinimum", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setIntRange(PyObject* self, PyObject* args)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setIntRange", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setIntRange(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setIntRange(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setIntRange_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setIntRange(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIntRange(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setIntRange_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputDialog.setIntRange", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setIntStep(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIntStep(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIntStep(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setIntStep_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIntStep(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIntStep(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setIntStep_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setIntStep", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setIntValue(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIntValue(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIntValue(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setIntValue_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIntValue(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIntValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setIntValue_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setIntValue", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setLabelText(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLabelText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setLabelText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setLabelText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLabelText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLabelText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setLabelText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setLabelText", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setOkButtonText(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOkButtonText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setOkButtonText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setOkButtonText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOkButtonText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOkButtonText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setOkButtonText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setOkButtonText", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setOption(PyObject* self, PyObject* args, PyObject* kwds)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.setOption(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QInputDialog.setOption(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setOption", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setOption(QInputDialog::InputDialogOption,bool)
    if (Shiboken::Converter< ::QInputDialog::InputDialogOption >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setOption(QInputDialog::InputDialogOption,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setOption(QInputDialog::InputDialogOption,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setOption_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "on");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "on";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QInputDialogFunc_setOption_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QInputDialog.setOption(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QInputDialog::InputDialogOption cppArg0 = Shiboken::Converter<QInputDialog::InputDialogOption >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setOption(QInputDialog::InputDialogOption,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOption(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputDialog.InputDialogOption, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QInputDialog.setOption", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setTextEchoMode(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextEchoMode(QLineEdit::EchoMode)
    if (Shiboken::Converter< ::QLineEdit::EchoMode >::isConvertible(arg)) {
        overloadId = 0; // setTextEchoMode(QLineEdit::EchoMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setTextEchoMode_TypeError;

    // Call function/method
    {
        {
            QLineEdit::EchoMode cppArg0 = Shiboken::Converter<QLineEdit::EchoMode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTextEchoMode(QLineEdit::EchoMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTextEchoMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setTextEchoMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLineEdit.EchoMode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setTextEchoMode", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setTextValue(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextValue(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setTextValue(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setTextValue_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTextValue(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTextValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setTextValue_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setTextValue", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_setVisible(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVisible(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_setVisible_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVisible(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QInputDialog::setVisible(cppArg0) : cppSelf->setVisible(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QInputDialogFunc_setVisible_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.setVisible", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_sizeHint(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QInputDialog*>(cppSelf)->::QInputDialog::sizeHint() : const_cast<const QInputDialog*>(cppSelf)->sizeHint());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_testOption(PyObject* self, PyObject* arg)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testOption(QInputDialog::InputDialogOption)const
    if (Shiboken::Converter< ::QInputDialog::InputDialogOption >::isConvertible(arg)) {
        overloadId = 0; // testOption(QInputDialog::InputDialogOption)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputDialogFunc_testOption_TypeError;

    // Call function/method
    {
        {
            QInputDialog::InputDialogOption cppArg0 = Shiboken::Converter<QInputDialog::InputDialogOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // testOption(QInputDialog::InputDialogOption)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QInputDialog*>(cppSelf)->testOption(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QInputDialogFunc_testOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputDialog.InputDialogOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QInputDialog.testOption", overloads);
        return 0;
}

static PyObject* Sbk_QInputDialogFunc_textEchoMode(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textEchoMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLineEdit::EchoMode cppResult = const_cast<const QInputDialog*>(cppSelf)->textEchoMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLineEdit::EchoMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QInputDialogFunc_textValue(PyObject* self)
{
    QInputDialog* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QInputDialog* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textValue()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QInputDialog*>(cppSelf)->textValue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QInputDialog_methods[] = {
    {"cancelButtonText", (PyCFunction)Sbk_QInputDialogFunc_cancelButtonText, METH_NOARGS},
    {"comboBoxItems", (PyCFunction)Sbk_QInputDialogFunc_comboBoxItems, METH_NOARGS},
    {"done", (PyCFunction)Sbk_QInputDialogFunc_done, METH_O},
    {"doubleDecimals", (PyCFunction)Sbk_QInputDialogFunc_doubleDecimals, METH_NOARGS},
    {"doubleMaximum", (PyCFunction)Sbk_QInputDialogFunc_doubleMaximum, METH_NOARGS},
    {"doubleMinimum", (PyCFunction)Sbk_QInputDialogFunc_doubleMinimum, METH_NOARGS},
    {"doubleValue", (PyCFunction)Sbk_QInputDialogFunc_doubleValue, METH_NOARGS},
    {"getDouble", (PyCFunction)Sbk_QInputDialogFunc_getDouble, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getInt", (PyCFunction)Sbk_QInputDialogFunc_getInt, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getInteger", (PyCFunction)Sbk_QInputDialogFunc_getInteger, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getItem", (PyCFunction)Sbk_QInputDialogFunc_getItem, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getText", (PyCFunction)Sbk_QInputDialogFunc_getText, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"inputMode", (PyCFunction)Sbk_QInputDialogFunc_inputMode, METH_NOARGS},
    {"intMaximum", (PyCFunction)Sbk_QInputDialogFunc_intMaximum, METH_NOARGS},
    {"intMinimum", (PyCFunction)Sbk_QInputDialogFunc_intMinimum, METH_NOARGS},
    {"intStep", (PyCFunction)Sbk_QInputDialogFunc_intStep, METH_NOARGS},
    {"intValue", (PyCFunction)Sbk_QInputDialogFunc_intValue, METH_NOARGS},
    {"isComboBoxEditable", (PyCFunction)Sbk_QInputDialogFunc_isComboBoxEditable, METH_NOARGS},
    {"labelText", (PyCFunction)Sbk_QInputDialogFunc_labelText, METH_NOARGS},
    {"minimumSizeHint", (PyCFunction)Sbk_QInputDialogFunc_minimumSizeHint, METH_NOARGS},
    {"okButtonText", (PyCFunction)Sbk_QInputDialogFunc_okButtonText, METH_NOARGS},
    {"open", (PyCFunction)Sbk_QInputDialogFunc_open, METH_VARARGS},
    {"setCancelButtonText", (PyCFunction)Sbk_QInputDialogFunc_setCancelButtonText, METH_O},
    {"setComboBoxEditable", (PyCFunction)Sbk_QInputDialogFunc_setComboBoxEditable, METH_O},
    {"setComboBoxItems", (PyCFunction)Sbk_QInputDialogFunc_setComboBoxItems, METH_O},
    {"setDoubleDecimals", (PyCFunction)Sbk_QInputDialogFunc_setDoubleDecimals, METH_O},
    {"setDoubleMaximum", (PyCFunction)Sbk_QInputDialogFunc_setDoubleMaximum, METH_O},
    {"setDoubleMinimum", (PyCFunction)Sbk_QInputDialogFunc_setDoubleMinimum, METH_O},
    {"setDoubleRange", (PyCFunction)Sbk_QInputDialogFunc_setDoubleRange, METH_VARARGS},
    {"setDoubleValue", (PyCFunction)Sbk_QInputDialogFunc_setDoubleValue, METH_O},
    {"setInputMode", (PyCFunction)Sbk_QInputDialogFunc_setInputMode, METH_O},
    {"setIntMaximum", (PyCFunction)Sbk_QInputDialogFunc_setIntMaximum, METH_O},
    {"setIntMinimum", (PyCFunction)Sbk_QInputDialogFunc_setIntMinimum, METH_O},
    {"setIntRange", (PyCFunction)Sbk_QInputDialogFunc_setIntRange, METH_VARARGS},
    {"setIntStep", (PyCFunction)Sbk_QInputDialogFunc_setIntStep, METH_O},
    {"setIntValue", (PyCFunction)Sbk_QInputDialogFunc_setIntValue, METH_O},
    {"setLabelText", (PyCFunction)Sbk_QInputDialogFunc_setLabelText, METH_O},
    {"setOkButtonText", (PyCFunction)Sbk_QInputDialogFunc_setOkButtonText, METH_O},
    {"setOption", (PyCFunction)Sbk_QInputDialogFunc_setOption, METH_VARARGS|METH_KEYWORDS},
    {"setTextEchoMode", (PyCFunction)Sbk_QInputDialogFunc_setTextEchoMode, METH_O},
    {"setTextValue", (PyCFunction)Sbk_QInputDialogFunc_setTextValue, METH_O},
    {"setVisible", (PyCFunction)Sbk_QInputDialogFunc_setVisible, METH_O},
    {"sizeHint", (PyCFunction)Sbk_QInputDialogFunc_sizeHint, METH_NOARGS},
    {"testOption", (PyCFunction)Sbk_QInputDialogFunc_testOption, METH_O},
    {"textEchoMode", (PyCFunction)Sbk_QInputDialogFunc_textEchoMode, METH_NOARGS},
    {"textValue", (PyCFunction)Sbk_QInputDialogFunc_textValue, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QInputDialogSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QInputDialog* me = reinterpret_cast<QInputDialog*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]))
        return static_cast<QDialog*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QInputDialog_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QInputDialog",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QInputDialog_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QInputDialog_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QInputDialog_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QInputDialog*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QInputDialog_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QInputDialog*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QInputDialog_Type;
    return 0;
}


void init_QInputDialog(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QINPUTDIALOG_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QInputDialog_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QInputDialog_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QInputDialog_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QInputDialog_Type, &QInputDialog::staticMetaObject);    Sbk_QInputDialog_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QInputDialog_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QInputDialog_Type, &Sbk_QInputDialogSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QInputDialog_Type, &Shiboken::callCppDestructor<QInputDialog >);
    Py_INCREF((PyObject*)&Sbk_QInputDialog_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QInputDialog_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QInputDialog_Type, &Sbk_QInputDialog_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QDIALOG_IDX]), &Sbk_QInputDialog_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QInputDialog_Type, "QInputDialog*");
    PyModule_AddObject(module, "QInputDialog",
        ((PyObject*)&Sbk_QInputDialog_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: InputMode
    PyTypeObject* SbkPySide_QtGui_QInputDialog_InputMode = Shiboken::Enum::newType("PySide.QtGui.QInputDialog.InputMode");
    SbkPySide_QtGuiTypes[SBK_QINPUTDIALOG_INPUTMODE_IDX] = SbkPySide_QtGui_QInputDialog_InputMode;
    if (PyType_Ready(SbkPySide_QtGui_QInputDialog_InputMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QInputDialog_Type.super.ht_type.tp_dict,
            "InputMode",((PyObject*)SbkPySide_QtGui_QInputDialog_InputMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QInputDialog_InputMode,(long) QInputDialog::TextInput, "TextInput");
    PyDict_SetItemString(Sbk_QInputDialog_Type.super.ht_type.tp_dict,"TextInput", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QInputDialog_InputMode->tp_dict,"TextInput", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QInputDialog_InputMode,(long) QInputDialog::IntInput, "IntInput");
    PyDict_SetItemString(Sbk_QInputDialog_Type.super.ht_type.tp_dict,"IntInput", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QInputDialog_InputMode->tp_dict,"IntInput", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QInputDialog_InputMode,(long) QInputDialog::DoubleInput, "DoubleInput");
    PyDict_SetItemString(Sbk_QInputDialog_Type.super.ht_type.tp_dict,"DoubleInput", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QInputDialog_InputMode->tp_dict,"DoubleInput", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QInputDialog::InputMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::InputMode");
    // end of enum InputMode

    // init enum: InputDialogOption
    PyTypeObject* SbkPySide_QtGui_QInputDialog_InputDialogOption = Shiboken::Enum::newType("PySide.QtGui.QInputDialog.InputDialogOption");
    SbkPySide_QtGuiTypes[SBK_QINPUTDIALOG_INPUTDIALOGOPTION_IDX] = SbkPySide_QtGui_QInputDialog_InputDialogOption;
    if (PyType_Ready(SbkPySide_QtGui_QInputDialog_InputDialogOption) < 0)
        return;
    PyDict_SetItemString(Sbk_QInputDialog_Type.super.ht_type.tp_dict,
            "InputDialogOption",((PyObject*)SbkPySide_QtGui_QInputDialog_InputDialogOption));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QInputDialog_InputDialogOption,(long) QInputDialog::NoButtons, "NoButtons");
    PyDict_SetItemString(Sbk_QInputDialog_Type.super.ht_type.tp_dict,"NoButtons", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QInputDialog_InputDialogOption->tp_dict,"NoButtons", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QInputDialog_InputDialogOption,(long) QInputDialog::UseListViewForComboBoxItems, "UseListViewForComboBoxItems");
    PyDict_SetItemString(Sbk_QInputDialog_Type.super.ht_type.tp_dict,"UseListViewForComboBoxItems", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QInputDialog_InputDialogOption->tp_dict,"UseListViewForComboBoxItems", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QInputDialog::InputDialogOption");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::InputDialogOption");
    // end of enum InputDialogOption

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("textValueSelected", "QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QInputDialog_Type, "textValueSelected", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("textValueChanged", "QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QInputDialog_Type, "textValueChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("intValueSelected", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QInputDialog_Type, "intValueSelected", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("doubleValueSelected", "double", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QInputDialog_Type, "doubleValueSelected", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("doubleValueChanged", "double", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QInputDialog_Type, "doubleValueChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("intValueChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QInputDialog_Type, "intValueChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QInputDialog >("QInputDialog*");
    Shiboken::TypeResolver::createObjectTypeResolver<QInputDialog >(typeid(QInputDialog).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QInputDialog >(typeid(QInputDialogWrapper).name());
    qRegisterMetaType< ::QInputDialog* >("QInputDialog*");
    qRegisterMetaType< ::QInputDialog::InputMode >("QInputDialog::InputMode");
    qRegisterMetaType< ::QInputDialog::InputDialogOption >("QInputDialog::InputDialogOption");
}

