/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qinputmethodevent_attribute_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QInputMethodEvent_Attribute_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QInputMethodEvent::Attribute >()))
        return -1;

    QInputMethodEvent::Attribute* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QInputMethodEvent_Attribute_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "Attribute", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: Attribute(QInputMethodEvent::AttributeType,int,int,QVariant)
    // 1: Attribute(QInputMethodEvent::Attribute)
    if (numArgs == 1 && Shiboken::Converter< ::QInputMethodEvent::Attribute >::isConvertible(pyargs[0])) {
        overloadId = 1; // Attribute(QInputMethodEvent::Attribute)
    } else if (numArgs == 4 && Shiboken::Converter< ::QInputMethodEvent::AttributeType >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[3])) {
        overloadId = 0; // Attribute(QInputMethodEvent::AttributeType,int,int,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QInputMethodEvent_Attribute_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // Attribute(QInputMethodEvent::AttributeType,int,int,QVariant)
            {
                QInputMethodEvent::AttributeType cppArg0 = Shiboken::Converter<QInputMethodEvent::AttributeType >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                QVariant cppArg3 = Shiboken::Converter<QVariant >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // Attribute(QInputMethodEvent::AttributeType,int,int,QVariant)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QInputMethodEvent::Attribute(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // Attribute(QInputMethodEvent::Attribute)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QInputMethodEvent::Attribute cppArg0 = Shiboken::Converter<QInputMethodEvent::Attribute >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // Attribute(QInputMethodEvent::Attribute)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QInputMethodEvent::Attribute(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QInputMethodEvent::Attribute >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QInputMethodEvent_Attribute_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QInputMethodEvent_Attribute_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputMethodEvent.AttributeType, int, int, QVariant", "PySide.QtGui.QInputMethodEvent::Attribute", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.Attribute", overloads);
        return -1;
}

static PyObject *Sbk_QInputMethodEvent_Attribute___copy__(PyObject *self)
{
        QInputMethodEvent::Attribute* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QInputMethodEvent::Attribute*>::toCpp(self);
        PyObject* pyResult = 0;
        QInputMethodEvent::Attribute* copy = new QInputMethodEvent::Attribute(*cppSelf);
        pyResult = Shiboken::Converter<QInputMethodEvent::Attribute*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QInputMethodEvent_Attribute_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QInputMethodEvent_Attribute___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QInputMethodEvent_Attribute_get_length(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QInputMethodEvent::Attribute* >::toCpp(self)->length);
    return val;
}

static int Sbk_QInputMethodEvent_Attribute_set_length(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'length' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'length', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QInputMethodEvent::Attribute* >::toCpp(self)->length = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QInputMethodEvent_Attribute_get_type(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::QInputMethodEvent::AttributeType >::toPython( Shiboken::Converter< QInputMethodEvent::Attribute* >::toCpp(self)->type);
    return val;
}

static int Sbk_QInputMethodEvent_Attribute_set_type(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'type' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QInputMethodEvent::AttributeType >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'type', 'AttributeType' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QInputMethodEvent::Attribute* >::toCpp(self)->type = Shiboken::Converter< ::QInputMethodEvent::AttributeType >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QInputMethodEvent_Attribute_get_value(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< QVariant >::toPython( Shiboken::Converter< QInputMethodEvent::Attribute* >::toCpp(self)->value);
    return val;
}

static int Sbk_QInputMethodEvent_Attribute_set_value(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'value' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QVariant >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'value', 'QVariant' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QInputMethodEvent::Attribute* >::toCpp(self)->value = Shiboken::Converter< QVariant >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QInputMethodEvent_Attribute_get_start(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QInputMethodEvent::Attribute* >::toCpp(self)->start);
    return val;
}

static int Sbk_QInputMethodEvent_Attribute_set_start(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'start' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'start', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QInputMethodEvent::Attribute* >::toCpp(self)->start = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

// Getters and Setters for Attribute
static PyGetSetDef Sbk_QInputMethodEvent_Attribute_getsetlist[] = {
    {const_cast<char*>("length"), Sbk_QInputMethodEvent_Attribute_get_length, Sbk_QInputMethodEvent_Attribute_set_length},
    {const_cast<char*>("type"), Sbk_QInputMethodEvent_Attribute_get_type, Sbk_QInputMethodEvent_Attribute_set_type},
    {const_cast<char*>("value"), Sbk_QInputMethodEvent_Attribute_get_value, Sbk_QInputMethodEvent_Attribute_set_value},
    {const_cast<char*>("start"), Sbk_QInputMethodEvent_Attribute_get_start, Sbk_QInputMethodEvent_Attribute_set_start},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QInputMethodEvent_Attribute_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QInputMethodEvent.Attribute",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QInputMethodEvent_Attribute_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QInputMethodEvent_Attribute_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QInputMethodEvent_Attribute_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QInputMethodEvent_Attribute(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QINPUTMETHODEVENT_ATTRIBUTE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QInputMethodEvent_Attribute_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QInputMethodEvent_Attribute_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QInputMethodEvent_Attribute_Type, &Shiboken::callCppDestructor<QInputMethodEvent::Attribute >);
    Py_INCREF((PyObject*)&Sbk_QInputMethodEvent_Attribute_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QInputMethodEvent_Attribute_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QInputMethodEvent_Attribute_Type, "QInputMethodEvent::Attribute");
    PyDict_SetItemString(module,"Attribute", (PyObject*)&Sbk_QInputMethodEvent_Attribute_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QInputMethodEvent::Attribute >("QInputMethodEvent::Attribute");
    Shiboken::TypeResolver::createObjectTypeResolver<QInputMethodEvent::Attribute >("QInputMethodEvent::Attribute*");
    Shiboken::TypeResolver::createValueTypeResolver<QInputMethodEvent::Attribute >(typeid(QInputMethodEvent::Attribute).name());
    qRegisterMetaType< ::QInputMethodEvent::Attribute* >("Attribute*");
    qRegisterMetaType< ::QInputMethodEvent::Attribute* >("QInputMethodEvent::Attribute*");
}

