/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qmainwindow_wrapper.h"

// Extra includes
#include <QList>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qdockwidget.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmainwindow.h>
#include <qmargins.h>
#include <qmenu.h>
#include <qmenubar.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstatusbar.h>
#include <qstyle.h>
#include <qtoolbar.h>
#include <qwidget.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QMainWindowWrapper::QMainWindowWrapper(QWidget * parent, QFlags<Qt::WindowType> flags) : QMainWindow(parent, flags) {
    // ... middle
}

void QMainWindowWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::changeEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::changeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QMainWindowWrapper::closeEvent(QCloseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QMainWindowWrapper::contextMenuEvent(QContextMenuEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QMainWindow::contextMenuEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QMenu * QMainWindowWrapper::createPopupMenu()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createPopupMenu"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QMainWindow::createPopupMenu();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QMenu * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.createPopupMenu", Shiboken::SbkType<QMenu >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QMenu * cppResult(Shiboken::Converter< ::QMenu * >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QMainWindowWrapper::devType() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QMainWindowWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QMainWindowWrapper::event(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QMainWindow::event(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QMainWindowWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QMainWindowWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QMainWindowWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QMainWindowWrapper::inputMethodQuery(Qt::InputMethodQuery arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::inputMethodQuery(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::languageChange()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QMainWindowWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QMainWindowWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return int(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QMainWindowWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.minimumSizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::mouseMoveEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::mouseReleaseEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QMainWindowWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::paintEvent(QPaintEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QMainWindowWrapper::showEvent(QShowEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::showEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QMainWindowWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QSize();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QMainWindow.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QMainWindowWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QMainWindowWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QMainWindowWrapper::wheelEvent(QWheelEvent * event)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::wheelEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QMainWindowWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QMainWindowWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QMainWindow::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QMainWindowWrapper::~QMainWindowWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMainWindow_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QMainWindow >()))
        return -1;

    QMainWindowWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"flags", "parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QMainWindow", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QMainWindow(QWidget*,QFlags<Qt::WindowType>)
    if (numArgs == 0) {
        overloadId = 0; // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
        } else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindow_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QMainWindow_Init_TypeError;
                }
                value = PyDict_GetItemString(kwds, "flags");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "flags";
                    else if (Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QMainWindow_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;
            QFlags<Qt::WindowType> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<Qt::WindowType> >::toCpp(pyargs[1]) : QFlags<Qt::WindowType>(0);

            if(!PyErr_Occurred()) {
                // QMainWindow(QWidget*,QFlags<Qt::WindowType>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QMainWindowWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QMainWindow >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QMainWindow_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 2))
        return -1;


    return 1;

    Sbk_QMainWindow_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None, PySide.QtCore.Qt.WindowFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow", overloads);
        return -1;
}

static PyObject* Sbk_QMainWindowFunc_addDockWidget(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addDockWidget", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addDockWidget(Qt::DockWidgetArea,QDockWidget*)
    // 1: addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
    if (numArgs >= 2 && Shiboken::Converter< ::Qt::DockWidgetArea >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QDockWidget * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // addDockWidget(Qt::DockWidgetArea,QDockWidget*)
        } else if (numArgs == 3 && Shiboken::Converter< ::Qt::Orientation >::isConvertible(pyargs[2])) {
            overloadId = 1; // addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_addDockWidget_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addDockWidget(Qt::DockWidgetArea,QDockWidget*)
            {
                Qt::DockWidgetArea cppArg0 = Shiboken::Converter<Qt::DockWidgetArea >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QDockWidget * cppArg1 = Shiboken::Converter<QDockWidget * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addDockWidget(Qt::DockWidgetArea,QDockWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addDockWidget(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
            case 1: // addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
            {
                Qt::DockWidgetArea cppArg0 = Shiboken::Converter<Qt::DockWidgetArea >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QDockWidget * cppArg1 = Shiboken::Converter<QDockWidget * >::toCpp(pyargs[1]);
                Qt::Orientation cppArg2 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // addDockWidget(Qt::DockWidgetArea,QDockWidget*,Qt::Orientation)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addDockWidget(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[1]);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_addDockWidget_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DockWidgetArea, PySide.QtGui.QDockWidget", "PySide.QtCore.Qt.DockWidgetArea, PySide.QtGui.QDockWidget, PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.addDockWidget", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_addToolBar(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addToolBar", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addToolBar(QToolBar*)
    // 1: addToolBar(Qt::ToolBarArea,QToolBar*)
    // 2: addToolBar(QString)
    if (numArgs == 2 && Shiboken::Converter< ::Qt::ToolBarArea >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QToolBar * >::isConvertible(pyargs[1])) {
        overloadId = 1; // addToolBar(Qt::ToolBarArea,QToolBar*)
    } else if (numArgs == 1 && Shiboken::Converter< ::QToolBar * >::isConvertible(pyargs[0])) {
        overloadId = 0; // addToolBar(QToolBar*)
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 2; // addToolBar(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_addToolBar_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // addToolBar(QToolBar*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QToolBar * cppArg0 = Shiboken::Converter<QToolBar * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // addToolBar(QToolBar*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addToolBar(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 1: // addToolBar(Qt::ToolBarArea,QToolBar*)
            {
                Qt::ToolBarArea cppArg0 = Shiboken::Converter<Qt::ToolBarArea >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QToolBar * cppArg1 = Shiboken::Converter<QToolBar * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // addToolBar(Qt::ToolBarArea,QToolBar*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->addToolBar(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 2: // addToolBar(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // addToolBar(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QToolBar * cppResult = cppSelf->addToolBar(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QToolBar * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_addToolBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", "PySide.QtCore.Qt.ToolBarArea, PySide.QtGui.QToolBar", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.addToolBar", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_addToolBarBreak(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMainWindow.addToolBarBreak(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:addToolBarBreak", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: addToolBarBreak(Qt::ToolBarArea)
    if (numArgs == 0) {
        overloadId = 0; // addToolBarBreak(Qt::ToolBarArea)
    } else if (Shiboken::Converter< ::Qt::ToolBarArea >::isConvertible(pyargs[0])) {
        overloadId = 0; // addToolBarBreak(Qt::ToolBarArea)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_addToolBarBreak_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "area");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "area";
                    else if (Shiboken::Converter< ::Qt::ToolBarArea >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QMainWindowFunc_addToolBarBreak_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow.addToolBarBreak(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::ToolBarArea cppArg0 = pyargs[0] ? Shiboken::Converter<Qt::ToolBarArea >::toCpp(pyargs[0]) : Qt::TopToolBarArea;

            if(!PyErr_Occurred()) {
                // addToolBarBreak(Qt::ToolBarArea)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addToolBarBreak(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_addToolBarBreak_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ToolBarArea = Qt.TopToolBarArea", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.addToolBarBreak", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_centralWidget(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // centralWidget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QMainWindow*>(cppSelf)->centralWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_contextMenuEvent(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextMenuEvent(QContextMenuEvent*)
    if (Shiboken::Converter< ::QContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_contextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QContextMenuEvent * cppArg0 = Shiboken::Converter<QContextMenuEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // contextMenuEvent(QContextMenuEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QMainWindow::contextMenuEvent(cppArg0) : cppSelf->contextMenuEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_contextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.contextMenuEvent", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_corner(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: corner(Qt::Corner)const
    if (Shiboken::Converter< ::Qt::Corner >::isConvertible(arg)) {
        overloadId = 0; // corner(Qt::Corner)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_corner_TypeError;

    // Call function/method
    {
        {
            Qt::Corner cppArg0 = Shiboken::Converter<Qt::Corner >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // corner(Qt::Corner)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::DockWidgetArea cppResult = const_cast<const QMainWindow*>(cppSelf)->corner(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::DockWidgetArea >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_corner_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Corner", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.corner", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_createPopupMenu(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // createPopupMenu()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMenu * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QMainWindow::createPopupMenu() : cppSelf->createPopupMenu());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMenu * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_dockOptions(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dockOptions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QMainWindow::DockOption> cppResult = const_cast<const QMainWindow*>(cppSelf)->dockOptions();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QMainWindow::DockOption> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_dockWidgetArea(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: dockWidgetArea(QDockWidget*)const
    if (Shiboken::Converter< ::QDockWidget * >::isConvertible(arg)) {
        overloadId = 0; // dockWidgetArea(QDockWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_dockWidgetArea_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDockWidget * cppArg0 = Shiboken::Converter<QDockWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dockWidgetArea(QDockWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::DockWidgetArea cppResult = const_cast<const QMainWindow*>(cppSelf)->dockWidgetArea(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::DockWidgetArea >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_dockWidgetArea_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.dockWidgetArea", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_documentMode(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // documentMode()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QMainWindow*>(cppSelf)->documentMode();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_event(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QMainWindow::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.event", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_iconSize(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // iconSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QMainWindow*>(cppSelf)->iconSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_insertToolBar(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertToolBar", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertToolBar(QToolBar*,QToolBar*)
    if (numArgs == 2 && Shiboken::Converter< ::QToolBar * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QToolBar * >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertToolBar(QToolBar*,QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_insertToolBar_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QToolBar * cppArg0 = Shiboken::Converter<QToolBar * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QToolBar * cppArg1 = Shiboken::Converter<QToolBar * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertToolBar(QToolBar*,QToolBar*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertToolBar(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_insertToolBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar, PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.insertToolBar", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_insertToolBarBreak(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertToolBarBreak(QToolBar*)
    if (Shiboken::Converter< ::QToolBar * >::isConvertible(arg)) {
        overloadId = 0; // insertToolBarBreak(QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_insertToolBarBreak_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QToolBar * cppArg0 = Shiboken::Converter<QToolBar * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // insertToolBarBreak(QToolBar*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertToolBarBreak(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_insertToolBarBreak_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.insertToolBarBreak", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_isAnimated(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isAnimated()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QMainWindow*>(cppSelf)->isAnimated();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_isDockNestingEnabled(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isDockNestingEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QMainWindow*>(cppSelf)->isDockNestingEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_isSeparator(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSeparator(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // isSeparator(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_isSeparator_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isSeparator(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QMainWindow*>(cppSelf)->isSeparator(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_isSeparator_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.isSeparator", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_menuBar(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // menuBar()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMenuBar * cppResult = const_cast<const QMainWindow*>(cppSelf)->menuBar();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMenuBar * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_menuWidget(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // menuWidget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QMainWindow*>(cppSelf)->menuWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_removeDockWidget(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeDockWidget(QDockWidget*)
    if (Shiboken::Converter< ::QDockWidget * >::isConvertible(arg)) {
        overloadId = 0; // removeDockWidget(QDockWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_removeDockWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDockWidget * cppArg0 = Shiboken::Converter<QDockWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeDockWidget(QDockWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeDockWidget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(Py_None, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_removeDockWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.removeDockWidget", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_removeToolBar(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeToolBar(QToolBar*)
    if (Shiboken::Converter< ::QToolBar * >::isConvertible(arg)) {
        overloadId = 0; // removeToolBar(QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_removeToolBar_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QToolBar * cppArg0 = Shiboken::Converter<QToolBar * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeToolBar(QToolBar*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeToolBar(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(Py_None, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_removeToolBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.removeToolBar", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_removeToolBarBreak(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeToolBarBreak(QToolBar*)
    if (Shiboken::Converter< ::QToolBar * >::isConvertible(arg)) {
        overloadId = 0; // removeToolBarBreak(QToolBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_removeToolBarBreak_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QToolBar * cppArg0 = Shiboken::Converter<QToolBar * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeToolBarBreak(QToolBar*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeToolBarBreak(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_removeToolBarBreak_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.removeToolBarBreak", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_restoreDockWidget(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: restoreDockWidget(QDockWidget*)
    if (Shiboken::Converter< ::QDockWidget * >::isConvertible(arg)) {
        overloadId = 0; // restoreDockWidget(QDockWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_restoreDockWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDockWidget * cppArg0 = Shiboken::Converter<QDockWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // restoreDockWidget(QDockWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->restoreDockWidget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_restoreDockWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.restoreDockWidget", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_restoreState(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMainWindow.restoreState(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMainWindow.restoreState(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:restoreState", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: restoreState(QByteArray,int)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // restoreState(QByteArray,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // restoreState(QByteArray,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_restoreState_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "version");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "version";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QMainWindowFunc_restoreState_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow.restoreState(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // restoreState(QByteArray,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->restoreState(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_restoreState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.restoreState", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_saveState(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QMainWindow.saveState(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:saveState", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: saveState(int)const
    if (numArgs == 0) {
        overloadId = 0; // saveState(int)const
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // saveState(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_saveState_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "version");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "version";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QMainWindowFunc_saveState_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QMainWindow.saveState(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // saveState(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = const_cast<const QMainWindow*>(cppSelf)->saveState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_saveState_TypeError:
        const char* overloads[] = {"int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.saveState", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setAnimated(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAnimated(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAnimated(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setAnimated_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAnimated(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAnimated(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setAnimated_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setAnimated", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setCentralWidget(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCentralWidget(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setCentralWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setCentralWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCentralWidget(QWidget*)
                // Begin code injection

                // TEMPLATE - replace_child - START
                QWidget* oldChild = cppSelf->centralWidget();
                if (oldChild) {
                   Shiboken::AutoDecRef pyChild(Shiboken::Converter<QWidget* >::toPython(oldChild));
                   Shiboken::Object::setParent(NULL, pyChild);
                }
                Shiboken::Object::setParent(self, arg);
                // TEMPLATE - replace_child - END

                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCentralWidget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setCentralWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setCentralWidget", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setCorner(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCorner", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setCorner(Qt::Corner,Qt::DockWidgetArea)
    if (numArgs == 2 && Shiboken::Converter< ::Qt::Corner >::isConvertible(pyargs[0]) && Shiboken::Converter< ::Qt::DockWidgetArea >::isConvertible(pyargs[1])) {
        overloadId = 0; // setCorner(Qt::Corner,Qt::DockWidgetArea)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setCorner_TypeError;

    // Call function/method
    {
        {
            Qt::Corner cppArg0 = Shiboken::Converter<Qt::Corner >::toCpp(pyargs[0]);
            Qt::DockWidgetArea cppArg1 = Shiboken::Converter<Qt::DockWidgetArea >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setCorner(Qt::Corner,Qt::DockWidgetArea)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCorner(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setCorner_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Corner, PySide.QtCore.Qt.DockWidgetArea", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.setCorner", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setDockNestingEnabled(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDockNestingEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDockNestingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setDockNestingEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDockNestingEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDockNestingEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setDockNestingEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setDockNestingEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setDockOptions(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDockOptions(QFlags<QMainWindow::DockOption>)
    if (Shiboken::Converter< ::QFlags<QMainWindow::DockOption> >::isConvertible(arg)) {
        overloadId = 0; // setDockOptions(QFlags<QMainWindow::DockOption>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setDockOptions_TypeError;

    // Call function/method
    {
        {
            QFlags<QMainWindow::DockOption> cppArg0 = Shiboken::Converter<QFlags<QMainWindow::DockOption> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDockOptions(QFlags<QMainWindow::DockOption>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDockOptions(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setDockOptions_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMainWindow.DockOptions", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setDockOptions", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setDocumentMode(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocumentMode(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDocumentMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setDocumentMode_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDocumentMode(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDocumentMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setDocumentMode_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setDocumentMode", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setIconSize(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIconSize(QSize)
    if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // setIconSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setIconSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIconSize(QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIconSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setIconSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setIconSize", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setMenuBar(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMenuBar(QMenuBar*)
    if (Shiboken::Converter< ::QMenuBar * >::isConvertible(arg)) {
        overloadId = 0; // setMenuBar(QMenuBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setMenuBar_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMenuBar * cppArg0 = Shiboken::Converter<QMenuBar * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMenuBar(QMenuBar*)
                // Begin code injection

                // TEMPLATE - replace_child - START
                QMenuBar* oldChild = cppSelf->menuBar();
                if (oldChild) {
                   Shiboken::AutoDecRef pyChild(Shiboken::Converter<QMenuBar* >::toPython(oldChild));
                   Shiboken::Object::setParent(NULL, pyChild);
                }
                Shiboken::Object::setParent(self, arg);
                // TEMPLATE - replace_child - END

                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMenuBar(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setMenuBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMenuBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setMenuBar", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setMenuWidget(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMenuWidget(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setMenuWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setMenuWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMenuWidget(QWidget*)
                // Begin code injection

                // TEMPLATE - replace_child - START
                QWidget* oldChild = cppSelf->menuWidget();
                if (oldChild) {
                   Shiboken::AutoDecRef pyChild(Shiboken::Converter<QWidget* >::toPython(oldChild));
                   Shiboken::Object::setParent(NULL, pyChild);
                }
                Shiboken::Object::setParent(self, arg);
                // TEMPLATE - replace_child - END

                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMenuWidget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setMenuWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setMenuWidget", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setStatusBar(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStatusBar(QStatusBar*)
    if (Shiboken::Converter< ::QStatusBar * >::isConvertible(arg)) {
        overloadId = 0; // setStatusBar(QStatusBar*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setStatusBar_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QStatusBar * cppArg0 = Shiboken::Converter<QStatusBar * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStatusBar(QStatusBar*)
                // Begin code injection

                // TEMPLATE - replace_child - START
                QStatusBar* oldChild = cppSelf->statusBar();
                if (oldChild) {
                   Shiboken::AutoDecRef pyChild(Shiboken::Converter<QStatusBar* >::toPython(oldChild));
                   Shiboken::Object::setParent(NULL, pyChild);
                }
                Shiboken::Object::setParent(self, arg);
                // TEMPLATE - replace_child - END

                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStatusBar(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setStatusBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStatusBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setStatusBar", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setTabPosition(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setTabPosition", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setTabPosition(QFlags<Qt::DockWidgetArea>,QTabWidget::TabPosition)
    if (numArgs == 2 && Shiboken::Converter< ::QFlags<Qt::DockWidgetArea> >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QTabWidget::TabPosition >::isConvertible(pyargs[1])) {
        overloadId = 0; // setTabPosition(QFlags<Qt::DockWidgetArea>,QTabWidget::TabPosition)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setTabPosition_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::DockWidgetArea> cppArg0 = Shiboken::Converter<QFlags<Qt::DockWidgetArea> >::toCpp(pyargs[0]);
            QTabWidget::TabPosition cppArg1 = Shiboken::Converter<QTabWidget::TabPosition >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setTabPosition(QFlags<Qt::DockWidgetArea>,QTabWidget::TabPosition)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTabPosition(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setTabPosition_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DockWidgetAreas, PySide.QtGui.QTabWidget.TabPosition", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.setTabPosition", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setTabShape(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabShape(QTabWidget::TabShape)
    if (Shiboken::Converter< ::QTabWidget::TabShape >::isConvertible(arg)) {
        overloadId = 0; // setTabShape(QTabWidget::TabShape)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setTabShape_TypeError;

    // Call function/method
    {
        {
            QTabWidget::TabShape cppArg0 = Shiboken::Converter<QTabWidget::TabShape >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTabShape(QTabWidget::TabShape)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTabShape(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setTabShape_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTabWidget.TabShape", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setTabShape", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setToolButtonStyle(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setToolButtonStyle(Qt::ToolButtonStyle)
    if (Shiboken::Converter< ::Qt::ToolButtonStyle >::isConvertible(arg)) {
        overloadId = 0; // setToolButtonStyle(Qt::ToolButtonStyle)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setToolButtonStyle_TypeError;

    // Call function/method
    {
        {
            Qt::ToolButtonStyle cppArg0 = Shiboken::Converter<Qt::ToolButtonStyle >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setToolButtonStyle(Qt::ToolButtonStyle)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setToolButtonStyle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setToolButtonStyle_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ToolButtonStyle", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setToolButtonStyle", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_setUnifiedTitleAndToolBarOnMac(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUnifiedTitleAndToolBarOnMac(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUnifiedTitleAndToolBarOnMac(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_setUnifiedTitleAndToolBarOnMac_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUnifiedTitleAndToolBarOnMac(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUnifiedTitleAndToolBarOnMac(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_setUnifiedTitleAndToolBarOnMac_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.setUnifiedTitleAndToolBarOnMac", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_splitDockWidget(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "splitDockWidget", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: splitDockWidget(QDockWidget*,QDockWidget*,Qt::Orientation)
    if (numArgs == 3 && Shiboken::Converter< ::QDockWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QDockWidget * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::Qt::Orientation >::isConvertible(pyargs[2])) {
        overloadId = 0; // splitDockWidget(QDockWidget*,QDockWidget*,Qt::Orientation)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_splitDockWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QDockWidget * cppArg0 = Shiboken::Converter<QDockWidget * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QDockWidget * cppArg1 = Shiboken::Converter<QDockWidget * >::toCpp(pyargs[1]);
            Qt::Orientation cppArg2 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // splitDockWidget(QDockWidget*,QDockWidget*,Qt::Orientation)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->splitDockWidget(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_splitDockWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget, PySide.QtGui.QDockWidget, PySide.QtCore.Qt.Orientation", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.splitDockWidget", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_statusBar(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // statusBar()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStatusBar * cppResult = const_cast<const QMainWindow*>(cppSelf)->statusBar();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStatusBar * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_tabPosition(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: tabPosition(Qt::DockWidgetArea)const
    if (Shiboken::Converter< ::Qt::DockWidgetArea >::isConvertible(arg)) {
        overloadId = 0; // tabPosition(Qt::DockWidgetArea)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_tabPosition_TypeError;

    // Call function/method
    {
        {
            Qt::DockWidgetArea cppArg0 = Shiboken::Converter<Qt::DockWidgetArea >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // tabPosition(Qt::DockWidgetArea)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTabWidget::TabPosition cppResult = const_cast<const QMainWindow*>(cppSelf)->tabPosition(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTabWidget::TabPosition >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_tabPosition_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DockWidgetArea", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.tabPosition", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_tabShape(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // tabShape()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTabWidget::TabShape cppResult = const_cast<const QMainWindow*>(cppSelf)->tabShape();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTabWidget::TabShape >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_tabifiedDockWidgets(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: tabifiedDockWidgets(QDockWidget*)const
    if (Shiboken::Converter< ::QDockWidget * >::isConvertible(arg)) {
        overloadId = 0; // tabifiedDockWidgets(QDockWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_tabifiedDockWidgets_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDockWidget * cppArg0 = Shiboken::Converter<QDockWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // tabifiedDockWidgets(QDockWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QDockWidget * > cppResult = const_cast<const QMainWindow*>(cppSelf)->tabifiedDockWidgets(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QDockWidget * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_tabifiedDockWidgets_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.tabifiedDockWidgets", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_tabifyDockWidget(PyObject* self, PyObject* args)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "tabifyDockWidget", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: tabifyDockWidget(QDockWidget*,QDockWidget*)
    if (numArgs == 2 && Shiboken::Converter< ::QDockWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QDockWidget * >::isConvertible(pyargs[1])) {
        overloadId = 0; // tabifyDockWidget(QDockWidget*,QDockWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_tabifyDockWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QDockWidget * cppArg0 = Shiboken::Converter<QDockWidget * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QDockWidget * cppArg1 = Shiboken::Converter<QDockWidget * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // tabifyDockWidget(QDockWidget*,QDockWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->tabifyDockWidget(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMainWindowFunc_tabifyDockWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDockWidget, PySide.QtGui.QDockWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMainWindow.tabifyDockWidget", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_toolBarArea(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toolBarArea(QToolBar*)const
    if (Shiboken::Converter< ::QToolBar * >::isConvertible(arg)) {
        overloadId = 0; // toolBarArea(QToolBar*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_toolBarArea_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QToolBar * cppArg0 = Shiboken::Converter<QToolBar * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toolBarArea(QToolBar*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::ToolBarArea cppResult = const_cast<const QMainWindow*>(cppSelf)->toolBarArea(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::ToolBarArea >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_toolBarArea_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.toolBarArea", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_toolBarBreak(PyObject* self, PyObject* arg)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toolBarBreak(QToolBar*)const
    if (Shiboken::Converter< ::QToolBar * >::isConvertible(arg)) {
        overloadId = 0; // toolBarBreak(QToolBar*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMainWindowFunc_toolBarBreak_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QToolBar * cppArg0 = Shiboken::Converter<QToolBar * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toolBarBreak(QToolBar*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QMainWindow*>(cppSelf)->toolBarBreak(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMainWindowFunc_toolBarBreak_TypeError:
        const char* overloads[] = {"PySide.QtGui.QToolBar", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMainWindow.toolBarBreak", overloads);
        return 0;
}

static PyObject* Sbk_QMainWindowFunc_toolButtonStyle(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toolButtonStyle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::ToolButtonStyle cppResult = const_cast<const QMainWindow*>(cppSelf)->toolButtonStyle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::ToolButtonStyle >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMainWindowFunc_unifiedTitleAndToolBarOnMac(PyObject* self)
{
    QMainWindow* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMainWindow* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unifiedTitleAndToolBarOnMac()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QMainWindow*>(cppSelf)->unifiedTitleAndToolBarOnMac();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QMainWindow_methods[] = {
    {"addDockWidget", (PyCFunction)Sbk_QMainWindowFunc_addDockWidget, METH_VARARGS},
    {"addToolBar", (PyCFunction)Sbk_QMainWindowFunc_addToolBar, METH_VARARGS},
    {"addToolBarBreak", (PyCFunction)Sbk_QMainWindowFunc_addToolBarBreak, METH_VARARGS|METH_KEYWORDS},
    {"centralWidget", (PyCFunction)Sbk_QMainWindowFunc_centralWidget, METH_NOARGS},
    {"contextMenuEvent", (PyCFunction)Sbk_QMainWindowFunc_contextMenuEvent, METH_O},
    {"corner", (PyCFunction)Sbk_QMainWindowFunc_corner, METH_O},
    {"createPopupMenu", (PyCFunction)Sbk_QMainWindowFunc_createPopupMenu, METH_NOARGS},
    {"dockOptions", (PyCFunction)Sbk_QMainWindowFunc_dockOptions, METH_NOARGS},
    {"dockWidgetArea", (PyCFunction)Sbk_QMainWindowFunc_dockWidgetArea, METH_O},
    {"documentMode", (PyCFunction)Sbk_QMainWindowFunc_documentMode, METH_NOARGS},
    {"event", (PyCFunction)Sbk_QMainWindowFunc_event, METH_O},
    {"iconSize", (PyCFunction)Sbk_QMainWindowFunc_iconSize, METH_NOARGS},
    {"insertToolBar", (PyCFunction)Sbk_QMainWindowFunc_insertToolBar, METH_VARARGS},
    {"insertToolBarBreak", (PyCFunction)Sbk_QMainWindowFunc_insertToolBarBreak, METH_O},
    {"isAnimated", (PyCFunction)Sbk_QMainWindowFunc_isAnimated, METH_NOARGS},
    {"isDockNestingEnabled", (PyCFunction)Sbk_QMainWindowFunc_isDockNestingEnabled, METH_NOARGS},
    {"isSeparator", (PyCFunction)Sbk_QMainWindowFunc_isSeparator, METH_O},
    {"menuBar", (PyCFunction)Sbk_QMainWindowFunc_menuBar, METH_NOARGS},
    {"menuWidget", (PyCFunction)Sbk_QMainWindowFunc_menuWidget, METH_NOARGS},
    {"removeDockWidget", (PyCFunction)Sbk_QMainWindowFunc_removeDockWidget, METH_O},
    {"removeToolBar", (PyCFunction)Sbk_QMainWindowFunc_removeToolBar, METH_O},
    {"removeToolBarBreak", (PyCFunction)Sbk_QMainWindowFunc_removeToolBarBreak, METH_O},
    {"restoreDockWidget", (PyCFunction)Sbk_QMainWindowFunc_restoreDockWidget, METH_O},
    {"restoreState", (PyCFunction)Sbk_QMainWindowFunc_restoreState, METH_VARARGS|METH_KEYWORDS},
    {"saveState", (PyCFunction)Sbk_QMainWindowFunc_saveState, METH_VARARGS|METH_KEYWORDS},
    {"setAnimated", (PyCFunction)Sbk_QMainWindowFunc_setAnimated, METH_O},
    {"setCentralWidget", (PyCFunction)Sbk_QMainWindowFunc_setCentralWidget, METH_O},
    {"setCorner", (PyCFunction)Sbk_QMainWindowFunc_setCorner, METH_VARARGS},
    {"setDockNestingEnabled", (PyCFunction)Sbk_QMainWindowFunc_setDockNestingEnabled, METH_O},
    {"setDockOptions", (PyCFunction)Sbk_QMainWindowFunc_setDockOptions, METH_O},
    {"setDocumentMode", (PyCFunction)Sbk_QMainWindowFunc_setDocumentMode, METH_O},
    {"setIconSize", (PyCFunction)Sbk_QMainWindowFunc_setIconSize, METH_O},
    {"setMenuBar", (PyCFunction)Sbk_QMainWindowFunc_setMenuBar, METH_O},
    {"setMenuWidget", (PyCFunction)Sbk_QMainWindowFunc_setMenuWidget, METH_O},
    {"setStatusBar", (PyCFunction)Sbk_QMainWindowFunc_setStatusBar, METH_O},
    {"setTabPosition", (PyCFunction)Sbk_QMainWindowFunc_setTabPosition, METH_VARARGS},
    {"setTabShape", (PyCFunction)Sbk_QMainWindowFunc_setTabShape, METH_O},
    {"setToolButtonStyle", (PyCFunction)Sbk_QMainWindowFunc_setToolButtonStyle, METH_O},
    {"setUnifiedTitleAndToolBarOnMac", (PyCFunction)Sbk_QMainWindowFunc_setUnifiedTitleAndToolBarOnMac, METH_O},
    {"splitDockWidget", (PyCFunction)Sbk_QMainWindowFunc_splitDockWidget, METH_VARARGS},
    {"statusBar", (PyCFunction)Sbk_QMainWindowFunc_statusBar, METH_NOARGS},
    {"tabPosition", (PyCFunction)Sbk_QMainWindowFunc_tabPosition, METH_O},
    {"tabShape", (PyCFunction)Sbk_QMainWindowFunc_tabShape, METH_NOARGS},
    {"tabifiedDockWidgets", (PyCFunction)Sbk_QMainWindowFunc_tabifiedDockWidgets, METH_O},
    {"tabifyDockWidget", (PyCFunction)Sbk_QMainWindowFunc_tabifyDockWidget, METH_VARARGS},
    {"toolBarArea", (PyCFunction)Sbk_QMainWindowFunc_toolBarArea, METH_O},
    {"toolBarBreak", (PyCFunction)Sbk_QMainWindowFunc_toolBarBreak, METH_O},
    {"toolButtonStyle", (PyCFunction)Sbk_QMainWindowFunc_toolButtonStyle, METH_NOARGS},
    {"unifiedTitleAndToolBarOnMac", (PyCFunction)Sbk_QMainWindowFunc_unifiedTitleAndToolBarOnMac, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QMainWindowSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QMainWindow* me = reinterpret_cast<QMainWindow*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QMainWindow_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMainWindow",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QMainWindow_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QMainWindow_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QMainWindow_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QMainWindow*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QMainWindow_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QMainWindow*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QMainWindow_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QMainWindow_DockOption___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QMainWindow::DockOptions >::toPython(
        Shiboken::Converter<QMainWindow::DockOptions>::toCpp(self)
        & Shiboken::Converter< QMainWindow::DockOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QMainWindow_DockOption___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QMainWindow::DockOptions >::toPython(
        Shiboken::Converter<QMainWindow::DockOptions>::toCpp(self)
        | Shiboken::Converter< QMainWindow::DockOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QMainWindow_DockOption___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QMainWindow::DockOptions >::toPython(
        Shiboken::Converter<QMainWindow::DockOptions>::toCpp(self)
        ^ Shiboken::Converter< QMainWindow::DockOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QMainWindow_DockOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QMainWindow::DockOptions >::toPython(
        ~Shiboken::Converter<QMainWindow::DockOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QMainWindow_DockOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QMainWindow_DockOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QMainWindow_DockOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QMainWindow_DockOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QMainWindow_DockOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QMainWindow_DockOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "DockOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QMainWindow_DockOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QMainWindow(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMAINWINDOW_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QMainWindow_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QMainWindow_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QMainWindow_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QMainWindow_Type, &QMainWindow::staticMetaObject);    Sbk_QMainWindow_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QMainWindow_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QMainWindow_Type, &Sbk_QMainWindowSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QMainWindow_Type, &Shiboken::callCppDestructor<QMainWindow >);
    Py_INCREF((PyObject*)&Sbk_QMainWindow_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QMainWindow_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QMainWindow_Type, &Sbk_QMainWindow_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]), &Sbk_QMainWindow_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QMainWindow_Type, "QMainWindow*");
    PyModule_AddObject(module, "QMainWindow",
        ((PyObject*)&Sbk_QMainWindow_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: DockOption
    PyTypeObject* SbkPySide_QtGui_QMainWindow_DockOption = Shiboken::Enum::newType("PySide.QtGui.QMainWindow.DockOption");
    SbkPySide_QtGui_QMainWindow_DockOption->tp_as_number = &SbkPySide_QtGui_QMainWindow_DockOption_as_number;
    SbkPySide_QtGuiTypes[SBK_QMAINWINDOW_DOCKOPTION_IDX] = SbkPySide_QtGui_QMainWindow_DockOption;
    if (PyType_Ready(SbkPySide_QtGui_QMainWindow_DockOption) < 0)
        return;
    PyDict_SetItemString(Sbk_QMainWindow_Type.super.ht_type.tp_dict,
            "DockOption",((PyObject*)SbkPySide_QtGui_QMainWindow_DockOption));

    // init flags class: QFlags<QMainWindow::DockOption>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QMAINWINDOW_DOCKOPTION__IDX] = &SbkPySide_QtGui_QMainWindow_DockOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QMainWindow_DockOptions_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QMainWindow_Type.super.ht_type.tp_dict,
            "DockOptions",((PyObject*)&SbkPySide_QtGui_QMainWindow_DockOptions_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QMainWindow_DockOption,(long) QMainWindow::AnimatedDocks, "AnimatedDocks");
    PyDict_SetItemString(Sbk_QMainWindow_Type.super.ht_type.tp_dict,"AnimatedDocks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QMainWindow_DockOption->tp_dict,"AnimatedDocks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QMainWindow_DockOption,(long) QMainWindow::AllowNestedDocks, "AllowNestedDocks");
    PyDict_SetItemString(Sbk_QMainWindow_Type.super.ht_type.tp_dict,"AllowNestedDocks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QMainWindow_DockOption->tp_dict,"AllowNestedDocks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QMainWindow_DockOption,(long) QMainWindow::AllowTabbedDocks, "AllowTabbedDocks");
    PyDict_SetItemString(Sbk_QMainWindow_Type.super.ht_type.tp_dict,"AllowTabbedDocks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QMainWindow_DockOption->tp_dict,"AllowTabbedDocks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QMainWindow_DockOption,(long) QMainWindow::ForceTabbedDocks, "ForceTabbedDocks");
    PyDict_SetItemString(Sbk_QMainWindow_Type.super.ht_type.tp_dict,"ForceTabbedDocks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QMainWindow_DockOption->tp_dict,"ForceTabbedDocks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QMainWindow_DockOption,(long) QMainWindow::VerticalTabs, "VerticalTabs");
    PyDict_SetItemString(Sbk_QMainWindow_Type.super.ht_type.tp_dict,"VerticalTabs", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QMainWindow_DockOption->tp_dict,"VerticalTabs", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMainWindow::DockOption");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::DockOption");
    // end of enum DockOption

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("iconSizeChanged", "QSize", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QMainWindow_Type, "iconSizeChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("toolButtonStyleChanged", "ToolButtonStyle", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QMainWindow_Type, "toolButtonStyleChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QMainWindow >("QMainWindow*");
    Shiboken::TypeResolver::createObjectTypeResolver<QMainWindow >(typeid(QMainWindow).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QMainWindow >(typeid(QMainWindowWrapper).name());
    qRegisterMetaType< ::QMainWindow* >("QMainWindow*");
    qRegisterMetaType< ::QMainWindow::DockOption >("QMainWindow::DockOption");
    qRegisterMetaType< ::QMainWindow::DockOptions >("QMainWindow::DockOptions");
}

