/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qmatrix_wrapper.h"

// Extra includes
#include <QPainterPath>
#include <qdatastream.h>
#include <qline.h>
#include <qmatrix.h>
#include <qpainterpath.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>
#include <qregion.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMatrix_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QMatrix >()))
        return -1;

    QMatrix* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5)
        goto Sbk_QMatrix_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QMatrix", 0, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return -1;

    // Overloaded function decisor
    // 0: QMatrix()
    // 1: QMatrix(QMatrix)
    // 2: QMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QMatrix()
    } else if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 2; // QMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QMatrix >::isConvertible(pyargs[0])) {
        overloadId = 1; // QMatrix(QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrix_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMatrix()
            {

                if(!PyErr_Occurred()) {
                    // QMatrix()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QMatrix();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QMatrix(QMatrix)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QMatrix cppArg0 = Shiboken::Converter<QMatrix >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QMatrix(QMatrix)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QMatrix(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
                qreal cppArg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
                qreal cppArg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                    // QMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QMatrix(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QMatrix >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QMatrix_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QMatrix_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QMatrix", "float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix", overloads);
        return -1;
}

static PyObject* Sbk_QMatrixFunc___reduce__(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection

                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(dddddd))", PyObject_Type(self), cppSelf->m11(), cppSelf->m12(), cppSelf->m21(), cppSelf->m22(), cppSelf->dx(), cppSelf->dy());
                // TEMPLATE - reduce_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc___repr__(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __repr__()
                // Begin code injection

                // TEMPLATE - repr_code - START
                QString format = QString().sprintf("%s(%f, %f, %f, %f, %f, %f)", ((PyObject*)self)->ob_type->tp_name, cppSelf->m11(), cppSelf->m12(), cppSelf->m21(), cppSelf->m22(), cppSelf->dx(), cppSelf->dy());
                pyResult = PyString_FromString(qPrintable(format));
                // TEMPLATE - repr_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_det(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // det()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QMatrix*>(cppSelf)->det();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_determinant(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // determinant()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QMatrix*>(cppSelf)->determinant();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_dx(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dx()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QMatrix*>(cppSelf)->dx();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_dy(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QMatrix*>(cppSelf)->dy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_inverted(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // inverted(bool*)const
                // Begin code injection

                // TEMPLATE - fix_bool* - START
                bool ok_;
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMatrix retval_ = cppSelf->inverted(&ok_);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::makeTuple(retval_, ok_);
                // TEMPLATE - fix_bool* - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_isIdentity(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isIdentity()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QMatrix*>(cppSelf)->isIdentity();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_isInvertible(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isInvertible()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QMatrix*>(cppSelf)->isInvertible();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_m11(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // m11()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QMatrix*>(cppSelf)->m11();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_m12(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // m12()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QMatrix*>(cppSelf)->m12();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_m21(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // m21()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QMatrix*>(cppSelf)->m21();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_m22(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // m22()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QMatrix*>(cppSelf)->m22();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMatrixFunc_map(PyObject* self, PyObject* args)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "map", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: map(QLine)const
    // 1: map(QLineF)const
    // 2: map(QPainterPath)const
    // 3: map(QPoint)const
    // 4: map(QPointF)const
    // 5: map(QPolygon)const
    // 6: map(QPolygonF)const
    // 7: map(QRegion)const
    // 8: map(int,int,int*,int*)const
    // 9: map(qreal,qreal,qreal*,qreal*)const
    if (numArgs == 2 && PyFloat_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 9; // map(qreal,qreal,qreal*,qreal*)const
    } else if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 8; // map(int,int,int*,int*)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPolygon >::isConvertible(pyargs[0])) {
        overloadId = 5; // map(QPolygon)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QRegion >::isConvertible(pyargs[0])) {
        overloadId = 7; // map(QRegion)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPolygonF >::isConvertible(pyargs[0])) {
        overloadId = 6; // map(QPolygonF)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 3; // map(QPoint)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 4; // map(QPointF)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPainterPath >::isConvertible(pyargs[0])) {
        overloadId = 2; // map(QPainterPath)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QLine >::isConvertible(pyargs[0])) {
        overloadId = 0; // map(QLine)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QLineF >::isConvertible(pyargs[0])) {
        overloadId = 1; // map(QLineF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc_map_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // map(QLine)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QLine cppArg0 = Shiboken::Converter<QLine >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // map(QLine)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QLine cppResult = const_cast<const QMatrix*>(cppSelf)->map(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QLine >::toPython(cppResult);
                }
                break;
            }
            case 1: // map(QLineF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QLineF cppArg0 = Shiboken::Converter<QLineF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // map(QLineF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QLineF cppResult = const_cast<const QMatrix*>(cppSelf)->map(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QLineF >::toPython(cppResult);
                }
                break;
            }
            case 2: // map(QPainterPath)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPainterPath cppArg0 = Shiboken::Converter<QPainterPath >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // map(QPainterPath)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPainterPath cppResult = const_cast<const QMatrix*>(cppSelf)->map(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPainterPath >::toPython(cppResult);
                }
                break;
            }
            case 3: // map(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // map(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPoint cppResult = const_cast<const QMatrix*>(cppSelf)->map(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
                }
                break;
            }
            case 4: // map(QPointF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // map(QPointF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPointF cppResult = const_cast<const QMatrix*>(cppSelf)->map(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
                }
                break;
            }
            case 5: // map(QPolygon)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPolygon cppArg0 = Shiboken::Converter<QPolygon >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // map(QPolygon)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygon cppResult = const_cast<const QMatrix*>(cppSelf)->map(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
                }
                break;
            }
            case 6: // map(QPolygonF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // map(QPolygonF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygonF cppResult = const_cast<const QMatrix*>(cppSelf)->map(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 7: // map(QRegion)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRegion cppArg0 = Shiboken::Converter<QRegion >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // map(QRegion)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRegion cppResult = const_cast<const QMatrix*>(cppSelf)->map(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRegion >::toPython(cppResult);
                }
                break;
            }
            case 8: // map(int,int,int*,int*)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // map(int,int,int*,int*)const
                    // Begin code injection

                    // TEMPLATE - qmatrix_map - START
                    int a, b;
                    cppSelf->map(cppArg0, cppArg1, &a, &b);
                    pyResult = Shiboken::makeTuple(a, b);
                    // TEMPLATE - qmatrix_map - END

                    // End of code injection


                }
                break;
            }
            case 9: // map(qreal,qreal,qreal*,qreal*)const
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // map(qreal,qreal,qreal*,qreal*)const
                    // Begin code injection

                    // TEMPLATE - qmatrix_map - START
                    qreal a, b;
                    cppSelf->map(cppArg0, cppArg1, &a, &b);
                    pyResult = Shiboken::makeTuple(a, b);
                    // TEMPLATE - qmatrix_map - END

                    // End of code injection


                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMatrixFunc_map_TypeError:
        const char* overloads[] = {"PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtGui.QPainterPath", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", "PySide.QtGui.QRegion", "int, int, int, int", "float, float, qreal, qreal", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix.map", overloads);
        return 0;
}

static PyObject* Sbk_QMatrixFunc_mapRect(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapRect(QRect)const
    // 1: mapRect(QRectF)const
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // mapRect(QRect)const
    } else if (Shiboken::Converter< ::QRectF >::isConvertible(arg)) {
        overloadId = 1; // mapRect(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc_mapRect_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // mapRect(QRect)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // mapRect(QRect)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRect cppResult = const_cast<const QMatrix*>(cppSelf)->mapRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
                }
                break;
            }
            case 1: // mapRect(QRectF)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // mapRect(QRectF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QRectF cppResult = const_cast<const QMatrix*>(cppSelf)->mapRect(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMatrixFunc_mapRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", "PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.mapRect", overloads);
        return 0;
}

static PyObject* Sbk_QMatrixFunc_mapToPolygon(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mapToPolygon(QRect)const
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // mapToPolygon(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc_mapToPolygon_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mapToPolygon(QRect)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygon cppResult = const_cast<const QMatrix*>(cppSelf)->mapToPolygon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMatrixFunc_mapToPolygon_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.mapToPolygon", overloads);
        return 0;
}

static PyObject* Sbk_QMatrixFunc_reset(PyObject* self)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // reset()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->reset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QMatrixFunc_rotate(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: rotate(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // rotate(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc_rotate_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // rotate(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMatrix & cppResult = cppSelf->rotate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMatrix & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMatrixFunc_rotate_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.rotate", overloads);
        return 0;
}

static PyObject* Sbk_QMatrixFunc_scale(PyObject* self, PyObject* args)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scale", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scale(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc_scale_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // scale(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMatrix & cppResult = cppSelf->scale(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMatrix & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMatrixFunc_scale_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix.scale", overloads);
        return 0;
}

static PyObject* Sbk_QMatrixFunc_setMatrix(PyObject* self, PyObject* args)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMatrix", 6, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: setMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
    if (numArgs == 6 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3]) && SbkNumber_Check(pyargs[4]) && SbkNumber_Check(pyargs[5])) {
        overloadId = 0; // setMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc_setMatrix_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
            qreal cppArg4 = Shiboken::Converter<qreal >::toCpp(pyargs[4]);
            qreal cppArg5 = Shiboken::Converter<qreal >::toCpp(pyargs[5]);

            if(!PyErr_Occurred()) {
                // setMatrix(qreal,qreal,qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMatrix(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMatrixFunc_setMatrix_TypeError:
        const char* overloads[] = {"float, float, float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix.setMatrix", overloads);
        return 0;
}

static PyObject* Sbk_QMatrixFunc_shear(PyObject* self, PyObject* args)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shear", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shear(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc_shear_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // shear(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMatrix & cppResult = cppSelf->shear(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMatrix & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMatrixFunc_shear_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix.shear", overloads);
        return 0;
}

static PyObject* Sbk_QMatrixFunc_translate(PyObject* self, PyObject* args)
{
    QMatrix* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // translate(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc_translate_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // translate(qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMatrix & cppResult = cppSelf->translate(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMatrix & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMatrixFunc_translate_TypeError:
        const char* overloads[] = {"float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMatrix.translate", overloads);
        return 0;
}

static PyObject *Sbk_QMatrix___copy__(PyObject *self)
{
        QMatrix* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QMatrix*>::toCpp(self);
        PyObject* pyResult = 0;
        QMatrix* copy = new QMatrix(*cppSelf);
        pyResult = Shiboken::Converter<QMatrix*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QMatrix_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QMatrixFunc___reduce__, METH_NOARGS},
    {"det", (PyCFunction)Sbk_QMatrixFunc_det, METH_NOARGS},
    {"determinant", (PyCFunction)Sbk_QMatrixFunc_determinant, METH_NOARGS},
    {"dx", (PyCFunction)Sbk_QMatrixFunc_dx, METH_NOARGS},
    {"dy", (PyCFunction)Sbk_QMatrixFunc_dy, METH_NOARGS},
    {"inverted", (PyCFunction)Sbk_QMatrixFunc_inverted, METH_NOARGS},
    {"isIdentity", (PyCFunction)Sbk_QMatrixFunc_isIdentity, METH_NOARGS},
    {"isInvertible", (PyCFunction)Sbk_QMatrixFunc_isInvertible, METH_NOARGS},
    {"m11", (PyCFunction)Sbk_QMatrixFunc_m11, METH_NOARGS},
    {"m12", (PyCFunction)Sbk_QMatrixFunc_m12, METH_NOARGS},
    {"m21", (PyCFunction)Sbk_QMatrixFunc_m21, METH_NOARGS},
    {"m22", (PyCFunction)Sbk_QMatrixFunc_m22, METH_NOARGS},
    {"map", (PyCFunction)Sbk_QMatrixFunc_map, METH_VARARGS},
    {"mapRect", (PyCFunction)Sbk_QMatrixFunc_mapRect, METH_O},
    {"mapToPolygon", (PyCFunction)Sbk_QMatrixFunc_mapToPolygon, METH_O},
    {"reset", (PyCFunction)Sbk_QMatrixFunc_reset, METH_NOARGS},
    {"rotate", (PyCFunction)Sbk_QMatrixFunc_rotate, METH_O},
    {"scale", (PyCFunction)Sbk_QMatrixFunc_scale, METH_VARARGS},
    {"setMatrix", (PyCFunction)Sbk_QMatrixFunc_setMatrix, METH_VARARGS},
    {"shear", (PyCFunction)Sbk_QMatrixFunc_shear, METH_VARARGS},
    {"translate", (PyCFunction)Sbk_QMatrixFunc_translate, METH_VARARGS},

    {"__copy__", (PyCFunction)Sbk_QMatrix___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QMatrixFunc___mul__(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QMatrix >::checkType(arg) && !Shiboken::Converter< ::QMatrix >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QLine,QMatrix)
    // 1: operator*(QLineF,QMatrix)
    // 2: operator*(QMatrix)const
    // 3: operator*(QPoint,QMatrix)
    // 4: operator*(QPointF,QMatrix)
    if (isReverse && Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 3; // operator*(QPoint,QMatrix)
    } else if (isReverse && Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 4; // operator*(QPointF,QMatrix)
    } else if (!isReverse && Shiboken::Converter< ::QMatrix >::isConvertible(arg)) {
        overloadId = 2; // operator*(QMatrix)const
    } else if (isReverse && Shiboken::Converter< ::QLine >::isConvertible(arg)) {
        overloadId = 0; // operator*(QLine,QMatrix)
    } else if (isReverse && Shiboken::Converter< ::QLineF >::isConvertible(arg)) {
        overloadId = 1; // operator*(QLineF,QMatrix)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QLine,QMatrix)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QLine cppArg0 = Shiboken::Converter<QLine >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QLine,QMatrix) [reverse operator]
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QLine cppResult = (cppArg0) * (*cppSelf);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QLine >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QLineF,QMatrix)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QLineF cppArg0 = Shiboken::Converter<QLineF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QLineF,QMatrix) [reverse operator]
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QLineF cppResult = (cppArg0) * (*cppSelf);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QLineF >::toPython(cppResult);
                }
                break;
            }
            case 2: // operator*(QMatrix)const
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QMatrix cppArg0 = Shiboken::Converter<QMatrix >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QMatrix)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QMatrix cppResult = (*cppSelf) * (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QMatrix >::toPython(cppResult);
                }
                break;
            }
            case 3: // operator*(QPoint,QMatrix)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QPoint,QMatrix) [reverse operator]
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPoint cppResult = (cppArg0) * (*cppSelf);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
                }
                break;
            }
            case 4: // operator*(QPointF,QMatrix)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QPointF,QMatrix) [reverse operator]
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPointF cppResult = (cppArg0) * (*cppSelf);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMatrixFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtCore.QLine", "PySide.QtCore.QLineF", "PySide.QtGui.QMatrix", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.__mul__", overloads);
        return 0;
}

static PyObject* Sbk_QMatrixFunc___imul__(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QMatrix >::checkType(arg) && !Shiboken::Converter< ::QMatrix >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(QMatrix)
    if (!isReverse && Shiboken::Converter< ::QMatrix >::isConvertible(arg)) {
        overloadId = 0; // operator*=(QMatrix)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc___imul___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMatrix cppArg0 = Shiboken::Converter<QMatrix >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator*=(QMatrix)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) *= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QMatrixFunc___imul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.__imul__", overloads);
        return 0;
}

static PyObject* Sbk_QMatrixFunc___lshift__(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QMatrix >::checkType(arg) && !Shiboken::Converter< ::QMatrix >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QMatrix)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QMatrix)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QMatrix) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMatrixFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QMatrixFunc___rshift__(PyObject* self, PyObject* arg)
{
    QMatrix* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QMatrix >::checkType(arg) && !Shiboken::Converter< ::QMatrix >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMatrix* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QMatrix&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QMatrix&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMatrixFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QMatrix&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMatrixFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QMatrix.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QMatrix_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)Sbk_QMatrixFunc___mul__,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QMatrixFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QMatrixFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)Sbk_QMatrixFunc___imul__,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QMatrix_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QMatrix& cppSelf = *Shiboken::Converter< QMatrix* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QMatrix >::isConvertible(arg)) {
                // operator!=(const QMatrix & arg__1) const
                QMatrix cppArg0 = Shiboken::Converter< ::QMatrix >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QMatrix >::isConvertible(arg)) {
                // operator==(const QMatrix & arg__1) const
                QMatrix cppArg0 = Shiboken::Converter< ::QMatrix >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QMatrix_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QMatrix_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QMatrix_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMatrix",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QMatrixFunc___repr__,
    /*tp_as_number*/        &Sbk_QMatrix_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QMatrix_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QMatrix_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QMatrix_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QMatrix(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMATRIX_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QMatrix_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QMatrix_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QMatrix_Type, &Shiboken::callCppDestructor<QMatrix >);
    Py_INCREF((PyObject*)&Sbk_QMatrix_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QMatrix_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QMatrix_Type, "QMatrix");
    PyModule_AddObject(module, "QMatrix",
        ((PyObject*)&Sbk_QMatrix_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QMatrix >("QMatrix");
    Shiboken::TypeResolver::createObjectTypeResolver<QMatrix >("QMatrix*");
    Shiboken::TypeResolver::createValueTypeResolver<QMatrix >(typeid(QMatrix).name());
    qRegisterMetaType< ::QMatrix >("QMatrix");
}

