/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qshortcut_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qkeysequence.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QShortcutWrapper::QShortcutWrapper(QWidget * parent) : QShortcut(parent) {
    // ... middle
}

QShortcutWrapper::QShortcutWrapper(const QKeySequence & key, QWidget * parent, const char * member, const char * ambiguousMember, Qt::ShortcutContext context) : QShortcut(key, parent, member, ambiguousMember, context) {
    // ... middle
}

void QShortcutWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QShortcutWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QShortcutWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QShortcutWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QShortcutWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QShortcut::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QShortcut.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QShortcutWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QShortcut.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QShortcutWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QShortcutWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QShortcutWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QShortcut::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QShortcutWrapper::~QShortcutWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QShortcut_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QShortcut >()))
        return -1;

    QShortcutWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"ambiguousMember", "arg__4", "context", "member"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QShortcut(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QShortcut", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QShortcut(QKeySequence,QWidget*,PyCallable*,Qt::ShortcutContext)
    // 1: QShortcut(QWidget*)
    // 2: QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
    if (numArgs == 1 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QShortcut(QWidget*)
    } else if (numArgs >= 2 && Shiboken::Converter< ::QKeySequence >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
        } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
            } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 2; // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
                } else if (Shiboken::Converter< ::Qt::ShortcutContext >::isConvertible(pyargs[4])) {
                    overloadId = 2; // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
                }
            }
        } else if (PyCallable_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // QShortcut(QKeySequence,QWidget*,PyCallable*,Qt::ShortcutContext)
            } else if (Shiboken::Converter< ::Qt::ShortcutContext >::isConvertible(pyargs[3])) {
                overloadId = 0; // QShortcut(QKeySequence,QWidget*,PyCallable*,Qt::ShortcutContext)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QShortcut_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QShortcut(QKeySequence,QWidget*,PyCallable*,Qt::ShortcutContext)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "arg__4");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "arg__4";
                        else if (Shiboken::Converter< ::Qt::ShortcutContext >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QShortcut_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QShortcut(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QKeySequence cppArg0 = Shiboken::Converter<QKeySequence >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QWidget * cppArg1 = Shiboken::Converter<QWidget * >::toCpp(pyargs[1]);
                Qt::ShortcutContext cppArg3 = pyargs[3] ? Shiboken::Converter<Qt::ShortcutContext >::toCpp(pyargs[3]) : Qt::WindowShortcut;

                if(!PyErr_Occurred()) {
                    // QShortcut(QKeySequence,QWidget*,PyCallable*,Qt::ShortcutContext)
                    overloadId = 0;
                    // Begin code injection

                    cptr = new QShortcutWrapper(cppArg0, cppArg1);

                    // End of code injection

                }
                break;
            }
            case 1: // QShortcut(QWidget*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QShortcut(QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QShortcutWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 2: // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "member");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "member";
                        else if (Shiboken::Converter< const char * >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QShortcut_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "ambiguousMember");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "ambiguousMember";
                        else if (Shiboken::Converter< const char * >::isConvertible(value))
                            pyargs[3] = value;
                        else
                            goto Sbk_QShortcut_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "context");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "context";
                        else if (Shiboken::Converter< ::Qt::ShortcutContext >::isConvertible(value))
                            pyargs[4] = value;
                        else
                            goto Sbk_QShortcut_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QShortcut(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QKeySequence cppArg0 = Shiboken::Converter<QKeySequence >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QWidget * cppArg1 = Shiboken::Converter<QWidget * >::toCpp(pyargs[1]);
                const char * cppArg2 = pyargs[2] ? Shiboken::Converter<const char * >::toCpp(pyargs[2]) : 0;
                const char * cppArg3 = pyargs[3] ? Shiboken::Converter<const char * >::toCpp(pyargs[3]) : 0;
                Qt::ShortcutContext cppArg4 = pyargs[4] ? Shiboken::Converter<Qt::ShortcutContext >::toCpp(pyargs[4]) : Qt::WindowShortcut;

                if(!PyErr_Occurred()) {
                    // QShortcut(QKeySequence,QWidget*,const char*,const char*,Qt::ShortcutContext)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QShortcutWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[1], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QShortcut >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QShortcut_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 4))
        return -1;
    switch(overloadId) {
        case 0:
        {
            // Begin code injection

            Shiboken::AutoDecRef result(PyObject_CallMethod(self, "connect", "OsO", self, SIGNAL(activated()), pyargs[3-1]));
            if (!result.isNull())
                Shiboken::Object::setParent(pyargs[2-1], self);

            // End of code injection
        }
}


    return 1;

    Sbk_QShortcut_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence, PySide.QtGui.QWidget, PyCallable, PySide.QtCore.Qt.ShortcutContext = Qt.WindowShortcut", "PySide.QtGui.QWidget", "PySide.QtGui.QKeySequence, PySide.QtGui.QWidget, str = None, str = None, PySide.QtCore.Qt.ShortcutContext = Qt.WindowShortcut", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QShortcut", overloads);
        return -1;
}

static PyObject* Sbk_QShortcutFunc_autoRepeat(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // autoRepeat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QShortcut*>(cppSelf)->autoRepeat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QShortcutFunc_context(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // context()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::ShortcutContext cppResult = cppSelf->context();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::ShortcutContext >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QShortcutFunc_event(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QShortcutFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QShortcut::event(cppArg0) : cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QShortcutFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.event", overloads);
        return 0;
}

static PyObject* Sbk_QShortcutFunc_id(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // id()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QShortcut*>(cppSelf)->id();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QShortcutFunc_isEnabled(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QShortcut*>(cppSelf)->isEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QShortcutFunc_key(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // key()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QKeySequence cppResult = const_cast<const QShortcut*>(cppSelf)->key();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QKeySequence >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QShortcutFunc_parentWidget(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // parentWidget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = const_cast<const QShortcut*>(cppSelf)->parentWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QShortcutFunc_setAutoRepeat(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoRepeat(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoRepeat(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QShortcutFunc_setAutoRepeat_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAutoRepeat(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAutoRepeat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QShortcutFunc_setAutoRepeat_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.setAutoRepeat", overloads);
        return 0;
}

static PyObject* Sbk_QShortcutFunc_setContext(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setContext(Qt::ShortcutContext)
    if (Shiboken::Converter< ::Qt::ShortcutContext >::isConvertible(arg)) {
        overloadId = 0; // setContext(Qt::ShortcutContext)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QShortcutFunc_setContext_TypeError;

    // Call function/method
    {
        {
            Qt::ShortcutContext cppArg0 = Shiboken::Converter<Qt::ShortcutContext >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setContext(Qt::ShortcutContext)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setContext(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QShortcutFunc_setContext_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.ShortcutContext", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.setContext", overloads);
        return 0;
}

static PyObject* Sbk_QShortcutFunc_setEnabled(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QShortcutFunc_setEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QShortcutFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.setEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QShortcutFunc_setKey(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setKey(QKeySequence)
    if (Shiboken::Converter< ::QKeySequence >::isConvertible(arg)) {
        overloadId = 0; // setKey(QKeySequence)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QShortcutFunc_setKey_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QKeySequence cppArg0 = Shiboken::Converter<QKeySequence >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setKey(QKeySequence)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setKey(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QShortcutFunc_setKey_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.setKey", overloads);
        return 0;
}

static PyObject* Sbk_QShortcutFunc_setWhatsThis(PyObject* self, PyObject* arg)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWhatsThis(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setWhatsThis(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QShortcutFunc_setWhatsThis_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWhatsThis(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWhatsThis(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QShortcutFunc_setWhatsThis_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QShortcut.setWhatsThis", overloads);
        return 0;
}

static PyObject* Sbk_QShortcutFunc_whatsThis(PyObject* self)
{
    QShortcut* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcut* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // whatsThis()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QShortcut*>(cppSelf)->whatsThis();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QShortcut_methods[] = {
    {"autoRepeat", (PyCFunction)Sbk_QShortcutFunc_autoRepeat, METH_NOARGS},
    {"context", (PyCFunction)Sbk_QShortcutFunc_context, METH_NOARGS},
    {"event", (PyCFunction)Sbk_QShortcutFunc_event, METH_O},
    {"id", (PyCFunction)Sbk_QShortcutFunc_id, METH_NOARGS},
    {"isEnabled", (PyCFunction)Sbk_QShortcutFunc_isEnabled, METH_NOARGS},
    {"key", (PyCFunction)Sbk_QShortcutFunc_key, METH_NOARGS},
    {"parentWidget", (PyCFunction)Sbk_QShortcutFunc_parentWidget, METH_NOARGS},
    {"setAutoRepeat", (PyCFunction)Sbk_QShortcutFunc_setAutoRepeat, METH_O},
    {"setContext", (PyCFunction)Sbk_QShortcutFunc_setContext, METH_O},
    {"setEnabled", (PyCFunction)Sbk_QShortcutFunc_setEnabled, METH_O},
    {"setKey", (PyCFunction)Sbk_QShortcutFunc_setKey, METH_O},
    {"setWhatsThis", (PyCFunction)Sbk_QShortcutFunc_setWhatsThis, METH_O},
    {"whatsThis", (PyCFunction)Sbk_QShortcutFunc_whatsThis, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QShortcut_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QShortcut",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QShortcut_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QShortcut_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QShortcut_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QShortcut*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QShortcut_Type;
    return 0;
}


void init_QShortcut(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSHORTCUT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QShortcut_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QShortcut_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QShortcut_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QShortcut_Type, &QShortcut::staticMetaObject);    Sbk_QShortcut_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QShortcut_Type, &Shiboken::callCppDestructor<QShortcut >);
    Py_INCREF((PyObject*)&Sbk_QShortcut_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QShortcut_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QShortcut_Type, &Sbk_QShortcut_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QShortcut_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QShortcut_Type, "QShortcut*");
    PyModule_AddObject(module, "QShortcut",
        ((PyObject*)&Sbk_QShortcut_Type));

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("activated", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QShortcut_Type, "activated", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("activatedAmbiguously", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QShortcut_Type, "activatedAmbiguously", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QShortcut >("QShortcut*");
    Shiboken::TypeResolver::createObjectTypeResolver<QShortcut >(typeid(QShortcut).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QShortcut >(typeid(QShortcutWrapper).name());
    qRegisterMetaType< ::QShortcut* >("QShortcut*");
}

