/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qshortcutevent_wrapper.h"

// Extra includes
#include <qkeysequence.h>


// Native ---------------------------------------------------------

QShortcutEventWrapper::QShortcutEventWrapper(const QKeySequence & key, int id, bool ambiguous) : QShortcutEvent(key, id, ambiguous) {
    // ... middle
}

QShortcutEventWrapper::~QShortcutEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QShortcutEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QShortcutEvent >()))
        return -1;

    QShortcutEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QShortcutEvent(): too many arguments");
        return -1;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QShortcutEvent(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QShortcutEvent", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QShortcutEvent(QKeySequence,int,bool)
    if (numArgs >= 2 && Shiboken::Converter< ::QKeySequence >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // QShortcutEvent(QKeySequence,int,bool)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // QShortcutEvent(QKeySequence,int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QShortcutEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "ambiguous");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "ambiguous";
                    else if (SbkNumber_Check(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QShortcutEvent_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QShortcutEvent(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QKeySequence cppArg0 = Shiboken::Converter<QKeySequence >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            bool cppArg2 = pyargs[2] ? Shiboken::Converter<bool >::toCpp(pyargs[2]) : false;

            if(!PyErr_Occurred()) {
                // QShortcutEvent(QKeySequence,int,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QShortcutEventWrapper(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QShortcutEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QShortcutEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QShortcutEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QKeySequence, int, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QShortcutEvent", overloads);
        return -1;
}

static PyObject* Sbk_QShortcutEventFunc_isAmbiguous(PyObject* self)
{
    QShortcutEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcutEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isAmbiguous()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QShortcutEvent*>(cppSelf)->isAmbiguous();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QShortcutEventFunc_key(PyObject* self)
{
    QShortcutEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcutEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // key()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QKeySequence & cppResult = const_cast<const QShortcutEvent*>(cppSelf)->key();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QKeySequence >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QShortcutEventFunc_shortcutId(PyObject* self)
{
    QShortcutEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QShortcutEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // shortcutId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QShortcutEvent*>(cppSelf)->shortcutId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QShortcutEvent_methods[] = {
    {"isAmbiguous", (PyCFunction)Sbk_QShortcutEventFunc_isAmbiguous, METH_NOARGS},
    {"key", (PyCFunction)Sbk_QShortcutEventFunc_key, METH_NOARGS},
    {"shortcutId", (PyCFunction)Sbk_QShortcutEventFunc_shortcutId, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QShortcutEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QShortcutEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QShortcutEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QShortcutEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QShortcutEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QShortcutEvent*>(cptr)->type() == QEvent::Shortcut)
        return &Sbk_QShortcutEvent_Type;
    return 0;
}


void init_QShortcutEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSHORTCUTEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QShortcutEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QShortcutEvent_Type);
    Sbk_QShortcutEvent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QShortcutEvent_Type, &Shiboken::callCppDestructor<QShortcutEvent >);
    Py_INCREF((PyObject*)&Sbk_QShortcutEvent_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QShortcutEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QShortcutEvent_Type, &Sbk_QShortcutEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]), &Sbk_QShortcutEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QShortcutEvent_Type, "QShortcutEvent*");
    PyModule_AddObject(module, "QShortcutEvent",
        ((PyObject*)&Sbk_QShortcutEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QShortcutEvent >("QShortcutEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QShortcutEvent >(typeid(QShortcutEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QShortcutEvent >(typeid(QShortcutEventWrapper).name());
    qRegisterMetaType< ::QShortcutEvent* >("QShortcutEvent*");
}

