/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qsizepolicy_wrapper.h"

// Extra includes
#include <qdatastream.h>
#include <qsizepolicy.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSizePolicy_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSizePolicy >()))
        return -1;

    QSizePolicy* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QSizePolicy", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QSizePolicy()
    // 1: QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
    // 2: QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
    // 3: QSizePolicy(QSizePolicy)
    if (numArgs == 0) {
        overloadId = 0; // QSizePolicy()
    } else if (numArgs == 1 && Shiboken::Converter< ::QSizePolicy >::isConvertible(pyargs[0])) {
        overloadId = 3; // QSizePolicy(QSizePolicy)
    } else if (numArgs >= 2 && Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
        } else if (numArgs == 3 && Shiboken::Converter< ::QSizePolicy::ControlType >::isConvertible(pyargs[2])) {
            overloadId = 2; // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicy_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSizePolicy()
            {

                if(!PyErr_Occurred()) {
                    // QSizePolicy()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSizePolicy();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
            {
                QSizePolicy::Policy cppArg0 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[0]);
                QSizePolicy::Policy cppArg1 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSizePolicy(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
            {
                QSizePolicy::Policy cppArg0 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[0]);
                QSizePolicy::Policy cppArg1 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(pyargs[1]);
                QSizePolicy::ControlType cppArg2 = Shiboken::Converter<QSizePolicy::ControlType >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // QSizePolicy(QSizePolicy::Policy,QSizePolicy::Policy,QSizePolicy::ControlType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSizePolicy(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QSizePolicy(QSizePolicy)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSizePolicy cppArg0 = Shiboken::Converter<QSizePolicy >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QSizePolicy(QSizePolicy)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSizePolicy(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSizePolicy >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSizePolicy_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSizePolicy_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QSizePolicy.Policy, PySide.QtGui.QSizePolicy.Policy", "PySide.QtGui.QSizePolicy.Policy, PySide.QtGui.QSizePolicy.Policy, PySide.QtGui.QSizePolicy.ControlType", "PySide.QtGui.QSizePolicy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QSizePolicy", overloads);
        return -1;
}

static PyObject* Sbk_QSizePolicyFunc_controlType(PyObject* self)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // controlType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSizePolicy::ControlType cppResult = const_cast<const QSizePolicy*>(cppSelf)->controlType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSizePolicy::ControlType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_expandingDirections(PyObject* self)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // expandingDirections()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::Orientation> cppResult = const_cast<const QSizePolicy*>(cppSelf)->expandingDirections();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::Orientation> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_hasHeightForWidth(PyObject* self)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasHeightForWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QSizePolicy*>(cppSelf)->hasHeightForWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_horizontalPolicy(PyObject* self)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // horizontalPolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSizePolicy::Policy cppResult = const_cast<const QSizePolicy*>(cppSelf)->horizontalPolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSizePolicy::Policy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_horizontalStretch(PyObject* self)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // horizontalStretch()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QSizePolicy*>(cppSelf)->horizontalStretch();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_setControlType(PyObject* self, PyObject* arg)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setControlType(QSizePolicy::ControlType)
    if (Shiboken::Converter< ::QSizePolicy::ControlType >::isConvertible(arg)) {
        overloadId = 0; // setControlType(QSizePolicy::ControlType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setControlType_TypeError;

    // Call function/method
    {
        {
            QSizePolicy::ControlType cppArg0 = Shiboken::Converter<QSizePolicy::ControlType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setControlType(QSizePolicy::ControlType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setControlType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setControlType_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy.ControlType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSizePolicy.setControlType", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setHeightForWidth(PyObject* self, PyObject* arg)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHeightForWidth(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHeightForWidth(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setHeightForWidth_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHeightForWidth(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHeightForWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setHeightForWidth_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSizePolicy.setHeightForWidth", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setHorizontalPolicy(PyObject* self, PyObject* arg)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHorizontalPolicy(QSizePolicy::Policy)
    if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(arg)) {
        overloadId = 0; // setHorizontalPolicy(QSizePolicy::Policy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setHorizontalPolicy_TypeError;

    // Call function/method
    {
        {
            QSizePolicy::Policy cppArg0 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHorizontalPolicy(QSizePolicy::Policy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHorizontalPolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setHorizontalPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy.Policy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSizePolicy.setHorizontalPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setHorizontalStretch(PyObject* self, PyObject* arg)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHorizontalStretch(uchar)
    if (Shiboken::Converter< unsigned char >::isConvertible(arg)) {
        overloadId = 0; // setHorizontalStretch(uchar)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setHorizontalStretch_TypeError;

    // Call function/method
    {
        {
            uchar cppArg0 = Shiboken::Converter<uchar >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHorizontalStretch(uchar)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHorizontalStretch(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setHorizontalStretch_TypeError:
        const char* overloads[] = {"unsigned char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSizePolicy.setHorizontalStretch", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setVerticalPolicy(PyObject* self, PyObject* arg)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalPolicy(QSizePolicy::Policy)
    if (Shiboken::Converter< ::QSizePolicy::Policy >::isConvertible(arg)) {
        overloadId = 0; // setVerticalPolicy(QSizePolicy::Policy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setVerticalPolicy_TypeError;

    // Call function/method
    {
        {
            QSizePolicy::Policy cppArg0 = Shiboken::Converter<QSizePolicy::Policy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVerticalPolicy(QSizePolicy::Policy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVerticalPolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setVerticalPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSizePolicy.Policy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSizePolicy.setVerticalPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_setVerticalStretch(PyObject* self, PyObject* arg)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalStretch(uchar)
    if (Shiboken::Converter< unsigned char >::isConvertible(arg)) {
        overloadId = 0; // setVerticalStretch(uchar)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc_setVerticalStretch_TypeError;

    // Call function/method
    {
        {
            uchar cppArg0 = Shiboken::Converter<uchar >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVerticalStretch(uchar)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVerticalStretch(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSizePolicyFunc_setVerticalStretch_TypeError:
        const char* overloads[] = {"unsigned char", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSizePolicy.setVerticalStretch", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc_transpose(PyObject* self)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // transpose()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->transpose();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QSizePolicyFunc_verticalPolicy(PyObject* self)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // verticalPolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSizePolicy::Policy cppResult = const_cast<const QSizePolicy*>(cppSelf)->verticalPolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSizePolicy::Policy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSizePolicyFunc_verticalStretch(PyObject* self)
{
    QSizePolicy* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // verticalStretch()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QSizePolicy*>(cppSelf)->verticalStretch();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QSizePolicy___copy__(PyObject *self)
{
        QSizePolicy* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QSizePolicy*>::toCpp(self);
        PyObject* pyResult = 0;
        QSizePolicy* copy = new QSizePolicy(*cppSelf);
        pyResult = Shiboken::Converter<QSizePolicy*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QSizePolicy_methods[] = {
    {"controlType", (PyCFunction)Sbk_QSizePolicyFunc_controlType, METH_NOARGS},
    {"expandingDirections", (PyCFunction)Sbk_QSizePolicyFunc_expandingDirections, METH_NOARGS},
    {"hasHeightForWidth", (PyCFunction)Sbk_QSizePolicyFunc_hasHeightForWidth, METH_NOARGS},
    {"horizontalPolicy", (PyCFunction)Sbk_QSizePolicyFunc_horizontalPolicy, METH_NOARGS},
    {"horizontalStretch", (PyCFunction)Sbk_QSizePolicyFunc_horizontalStretch, METH_NOARGS},
    {"setControlType", (PyCFunction)Sbk_QSizePolicyFunc_setControlType, METH_O},
    {"setHeightForWidth", (PyCFunction)Sbk_QSizePolicyFunc_setHeightForWidth, METH_O},
    {"setHorizontalPolicy", (PyCFunction)Sbk_QSizePolicyFunc_setHorizontalPolicy, METH_O},
    {"setHorizontalStretch", (PyCFunction)Sbk_QSizePolicyFunc_setHorizontalStretch, METH_O},
    {"setVerticalPolicy", (PyCFunction)Sbk_QSizePolicyFunc_setVerticalPolicy, METH_O},
    {"setVerticalStretch", (PyCFunction)Sbk_QSizePolicyFunc_setVerticalStretch, METH_O},
    {"transpose", (PyCFunction)Sbk_QSizePolicyFunc_transpose, METH_NOARGS},
    {"verticalPolicy", (PyCFunction)Sbk_QSizePolicyFunc_verticalPolicy, METH_NOARGS},
    {"verticalStretch", (PyCFunction)Sbk_QSizePolicyFunc_verticalStretch, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QSizePolicy___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QSizePolicyFunc___lshift__(PyObject* self, PyObject* arg)
{
    QSizePolicy* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QSizePolicy >::checkType(arg) && !Shiboken::Converter< ::QSizePolicy >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QSizePolicy)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QSizePolicy)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QSizePolicy) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSizePolicyFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSizePolicy.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QSizePolicyFunc___rshift__(PyObject* self, PyObject* arg)
{
    QSizePolicy* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QSizePolicy >::checkType(arg) && !Shiboken::Converter< ::QSizePolicy >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSizePolicy* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QSizePolicy&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QSizePolicy&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSizePolicyFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QSizePolicy&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSizePolicyFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QSizePolicy.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QSizePolicy_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QSizePolicyFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QSizePolicyFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QSizePolicy_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QSizePolicy& cppSelf = *Shiboken::Converter< QSizePolicy* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QSizePolicy >::isConvertible(arg)) {
                // operator!=(const QSizePolicy & s) const
                QSizePolicy cppArg0 = Shiboken::Converter< ::QSizePolicy >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QSizePolicy >::isConvertible(arg)) {
                // operator==(const QSizePolicy & s) const
                QSizePolicy cppArg0 = Shiboken::Converter< ::QSizePolicy >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QSizePolicy_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QSizePolicy_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSizePolicy_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QSizePolicy",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QSizePolicy_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QSizePolicy_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSizePolicy_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSizePolicy_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QSizePolicy_ControlType___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QSizePolicy::ControlTypes >::toPython(
        Shiboken::Converter<QSizePolicy::ControlTypes>::toCpp(self)
        & Shiboken::Converter< QSizePolicy::ControlTypes >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QSizePolicy_ControlType___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QSizePolicy::ControlTypes >::toPython(
        Shiboken::Converter<QSizePolicy::ControlTypes>::toCpp(self)
        | Shiboken::Converter< QSizePolicy::ControlTypes >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QSizePolicy_ControlType___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QSizePolicy::ControlTypes >::toPython(
        Shiboken::Converter<QSizePolicy::ControlTypes>::toCpp(self)
        ^ Shiboken::Converter< QSizePolicy::ControlTypes >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QSizePolicy_ControlType___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QSizePolicy::ControlTypes >::toPython(
        ~Shiboken::Converter<QSizePolicy::ControlTypes >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QSizePolicy_ControlType_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QSizePolicy_ControlType___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QSizePolicy_ControlType___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QSizePolicy_ControlType___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QSizePolicy_ControlType___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QSizePolicy_ControlTypes_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ControlTypes",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QSizePolicy_ControlType_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QSizePolicy(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSizePolicy_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSizePolicy_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSizePolicy_Type, &Shiboken::callCppDestructor<QSizePolicy >);
    Py_INCREF((PyObject*)&Sbk_QSizePolicy_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QSizePolicy_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSizePolicy_Type, "QSizePolicy");
    PyModule_AddObject(module, "QSizePolicy",
        ((PyObject*)&Sbk_QSizePolicy_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ControlType
    PyTypeObject* SbkPySide_QtGui_QSizePolicy_ControlType = Shiboken::Enum::newType("PySide.QtGui.QSizePolicy.ControlType");
    SbkPySide_QtGui_QSizePolicy_ControlType->tp_as_number = &SbkPySide_QtGui_QSizePolicy_ControlType_as_number;
    SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_CONTROLTYPE_IDX] = SbkPySide_QtGui_QSizePolicy_ControlType;
    if (PyType_Ready(SbkPySide_QtGui_QSizePolicy_ControlType) < 0)
        return;
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,
            "ControlType",((PyObject*)SbkPySide_QtGui_QSizePolicy_ControlType));

    // init flags class: QFlags<QSizePolicy::ControlType>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QSIZEPOLICY_CONTROLTYPE__IDX] = &SbkPySide_QtGui_QSizePolicy_ControlTypes_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QSizePolicy_ControlTypes_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,
            "ControlTypes",((PyObject*)&SbkPySide_QtGui_QSizePolicy_ControlTypes_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::DefaultType, "DefaultType");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"DefaultType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"DefaultType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::ButtonBox, "ButtonBox");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"ButtonBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"ButtonBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::CheckBox, "CheckBox");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"CheckBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"CheckBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::ComboBox, "ComboBox");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"ComboBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"ComboBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::Frame, "Frame");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"Frame", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"Frame", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::GroupBox, "GroupBox");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"GroupBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"GroupBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::Label, "Label");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"Label", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"Label", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::Line, "Line");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"Line", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"Line", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::LineEdit, "LineEdit");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"LineEdit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"LineEdit", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::PushButton, "PushButton");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"PushButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"PushButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::RadioButton, "RadioButton");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"RadioButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"RadioButton", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::Slider, "Slider");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"Slider", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"Slider", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::SpinBox, "SpinBox");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"SpinBox", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"SpinBox", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::TabWidget, "TabWidget");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"TabWidget", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"TabWidget", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_ControlType,(long) QSizePolicy::ToolButton, "ToolButton");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"ToolButton", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_ControlType->tp_dict,"ToolButton", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSizePolicy::ControlType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ControlType");
    // end of enum ControlType

    // init enum: PolicyFlag
    PyTypeObject* SbkPySide_QtGui_QSizePolicy_PolicyFlag = Shiboken::Enum::newType("PySide.QtGui.QSizePolicy.PolicyFlag");
    SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICYFLAG_IDX] = SbkPySide_QtGui_QSizePolicy_PolicyFlag;
    if (PyType_Ready(SbkPySide_QtGui_QSizePolicy_PolicyFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,
            "PolicyFlag",((PyObject*)SbkPySide_QtGui_QSizePolicy_PolicyFlag));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_PolicyFlag,(long) QSizePolicy::GrowFlag, "GrowFlag");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"GrowFlag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_PolicyFlag->tp_dict,"GrowFlag", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_PolicyFlag,(long) QSizePolicy::ExpandFlag, "ExpandFlag");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"ExpandFlag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_PolicyFlag->tp_dict,"ExpandFlag", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_PolicyFlag,(long) QSizePolicy::ShrinkFlag, "ShrinkFlag");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"ShrinkFlag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_PolicyFlag->tp_dict,"ShrinkFlag", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_PolicyFlag,(long) QSizePolicy::IgnoreFlag, "IgnoreFlag");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"IgnoreFlag", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_PolicyFlag->tp_dict,"IgnoreFlag", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSizePolicy::PolicyFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PolicyFlag");
    // end of enum PolicyFlag

    // init enum: Policy
    PyTypeObject* SbkPySide_QtGui_QSizePolicy_Policy = Shiboken::Enum::newType("PySide.QtGui.QSizePolicy.Policy");
    SbkPySide_QtGuiTypes[SBK_QSIZEPOLICY_POLICY_IDX] = SbkPySide_QtGui_QSizePolicy_Policy;
    if (PyType_Ready(SbkPySide_QtGui_QSizePolicy_Policy) < 0)
        return;
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,
            "Policy",((PyObject*)SbkPySide_QtGui_QSizePolicy_Policy));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_Policy,(long) QSizePolicy::Fixed, "Fixed");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"Fixed", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_Policy->tp_dict,"Fixed", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_Policy,(long) QSizePolicy::Minimum, "Minimum");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"Minimum", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_Policy->tp_dict,"Minimum", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_Policy,(long) QSizePolicy::Maximum, "Maximum");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"Maximum", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_Policy->tp_dict,"Maximum", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_Policy,(long) QSizePolicy::Preferred, "Preferred");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"Preferred", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_Policy->tp_dict,"Preferred", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_Policy,(long) QSizePolicy::MinimumExpanding, "MinimumExpanding");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"MinimumExpanding", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_Policy->tp_dict,"MinimumExpanding", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_Policy,(long) QSizePolicy::Expanding, "Expanding");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"Expanding", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_Policy->tp_dict,"Expanding", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QSizePolicy_Policy,(long) QSizePolicy::Ignored, "Ignored");
    PyDict_SetItemString(Sbk_QSizePolicy_Type.super.ht_type.tp_dict,"Ignored", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QSizePolicy_Policy->tp_dict,"Ignored", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSizePolicy::Policy");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Policy");
    // end of enum Policy


    Shiboken::TypeResolver::createValueTypeResolver<QSizePolicy >("QSizePolicy");
    Shiboken::TypeResolver::createObjectTypeResolver<QSizePolicy >("QSizePolicy*");
    Shiboken::TypeResolver::createValueTypeResolver<QSizePolicy >(typeid(QSizePolicy).name());
    qRegisterMetaType< ::QSizePolicy >("QSizePolicy");
    qRegisterMetaType< ::QSizePolicy::ControlType >("QSizePolicy::ControlType");
    qRegisterMetaType< ::QSizePolicy::ControlTypes >("QSizePolicy::ControlTypes");
    qRegisterMetaType< ::QSizePolicy::PolicyFlag >("QSizePolicy::PolicyFlag");
    qRegisterMetaType< ::QSizePolicy::Policy >("QSizePolicy::Policy");
}

