/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiontitlebar_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionTitleBar_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionTitleBar >()))
        return -1;

    QStyleOptionTitleBar* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionTitleBar", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionTitleBar()
    // 1: QStyleOptionTitleBar(QStyleOptionTitleBar)
    // 2: QStyleOptionTitleBar(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionTitleBar()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // QStyleOptionTitleBar(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionTitleBar >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionTitleBar(QStyleOptionTitleBar)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionTitleBar_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionTitleBar()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionTitleBar()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionTitleBar();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionTitleBar(QStyleOptionTitleBar)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionTitleBar cppArg0 = Shiboken::Converter<QStyleOptionTitleBar >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionTitleBar(QStyleOptionTitleBar)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionTitleBar(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionTitleBar(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionTitleBar(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionTitleBar(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionTitleBar >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionTitleBar_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionTitleBar_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionTitleBar", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionTitleBar", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionTitleBar___copy__(PyObject *self)
{
        QStyleOptionTitleBar* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionTitleBar*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionTitleBar* copy = new QStyleOptionTitleBar(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionTitleBar*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionTitleBar_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionTitleBar___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionTitleBar_get_titleBarFlags(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::QFlags<Qt::WindowType> >::toPython( Shiboken::Converter< QStyleOptionTitleBar* >::toCpp(self)->titleBarFlags);
    return val;
}

static int Sbk_QStyleOptionTitleBar_set_titleBarFlags(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'titleBarFlags' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<Qt::WindowType> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'titleBarFlags', 'WindowFlags' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionTitleBar* >::toCpp(self)->titleBarFlags = Shiboken::Converter< ::QFlags<Qt::WindowType> >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionTitleBar_get_icon(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionTitleBar* >::toCpp(self)->icon);
    Shiboken::Object::releaseOwnership(val);
    Shiboken::Object::setParent(self, val);
    return val;
}

static int Sbk_QStyleOptionTitleBar_set_icon(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'icon' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QIcon >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'icon', 'QIcon' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionTitleBar* >::toCpp(self)->icon = Shiboken::Converter< ::QIcon >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionTitleBar_get_text(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< QString >::toPython( Shiboken::Converter< QStyleOptionTitleBar* >::toCpp(self)->text);
    return val;
}

static int Sbk_QStyleOptionTitleBar_set_text(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'text' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'text', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionTitleBar* >::toCpp(self)->text = Shiboken::Converter< QString >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionTitleBar_get_titleBarState(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< int >::toPython( Shiboken::Converter< QStyleOptionTitleBar* >::toCpp(self)->titleBarState);
    return val;
}

static int Sbk_QStyleOptionTitleBar_set_titleBarState(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'titleBarState' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'titleBarState', 'int' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionTitleBar* >::toCpp(self)->titleBarState = Shiboken::Converter< int >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionTitleBar
static PyGetSetDef Sbk_QStyleOptionTitleBar_getsetlist[] = {
    {const_cast<char*>("titleBarFlags"), Sbk_QStyleOptionTitleBar_get_titleBarFlags, Sbk_QStyleOptionTitleBar_set_titleBarFlags},
    {const_cast<char*>("icon"), Sbk_QStyleOptionTitleBar_get_icon, Sbk_QStyleOptionTitleBar_set_icon},
    {const_cast<char*>("text"), Sbk_QStyleOptionTitleBar_get_text, Sbk_QStyleOptionTitleBar_set_text},
    {const_cast<char*>("titleBarState"), Sbk_QStyleOptionTitleBar_get_titleBarState, Sbk_QStyleOptionTitleBar_set_titleBarState},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionTitleBar_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionTitleBar",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionTitleBar_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionTitleBar_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionTitleBar_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionTitleBar(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTITLEBAR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionTitleBar_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionTitleBar_Type);
    Sbk_QStyleOptionTitleBar_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONCOMPLEX_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionTitleBar_Type, &Shiboken::callCppDestructor<QStyleOptionTitleBar >);
    Py_INCREF((PyObject*)&Sbk_QStyleOptionTitleBar_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionTitleBar_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionTitleBar_Type, "QStyleOptionTitleBar");
    PyModule_AddObject(module, "QStyleOptionTitleBar",
        ((PyObject*)&Sbk_QStyleOptionTitleBar_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionTitleBar.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTITLEBAR_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionTitleBar_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionVersion,(long) QStyleOptionTitleBar::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionTitleBar_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionTitleBar::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionType = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionTitleBar.StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONTITLEBAR_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionTitleBar_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionType,(long) QStyleOptionTitleBar::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleOptionTitleBar_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionTitleBar_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionTitleBar::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionTitleBar >("QStyleOptionTitleBar");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionTitleBar >("QStyleOptionTitleBar*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionTitleBar >(typeid(QStyleOptionTitleBar).name());
    qRegisterMetaType< ::QStyleOptionTitleBar >("QStyleOptionTitleBar");
    qRegisterMetaType< ::QStyleOptionTitleBar::StyleOptionVersion >("QStyleOptionTitleBar::StyleOptionVersion");
    qRegisterMetaType< ::QStyleOptionTitleBar::StyleOptionType >("QStyleOptionTitleBar::StyleOptionType");
}

