/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionviewitemv4_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionViewItemV4_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionViewItemV4 >()))
        return -1;

    QStyleOptionViewItemV4* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionViewItemV4", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionViewItemV4()
    // 1: QStyleOptionViewItemV4(QStyleOptionViewItem)
    // 2: QStyleOptionViewItemV4(QStyleOptionViewItemV4)
    // 3: QStyleOptionViewItemV4(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionViewItemV4()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 3; // QStyleOptionViewItemV4(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionViewItemV4 >::isConvertible(pyargs[0])) {
        overloadId = 2; // QStyleOptionViewItemV4(QStyleOptionViewItemV4)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionViewItem >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionViewItemV4(QStyleOptionViewItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionViewItemV4_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionViewItemV4()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItemV4()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItemV4();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionViewItemV4(QStyleOptionViewItem)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionViewItem cppArg0 = Shiboken::Converter<QStyleOptionViewItem >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItemV4(QStyleOptionViewItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItemV4(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionViewItemV4(QStyleOptionViewItemV4)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionViewItemV4 cppArg0 = Shiboken::Converter<QStyleOptionViewItemV4 >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItemV4(QStyleOptionViewItemV4)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItemV4(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QStyleOptionViewItemV4(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItemV4(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItemV4(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionViewItemV4 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionViewItemV4_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionViewItemV4_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionViewItem", "PySide.QtGui.QStyleOptionViewItemV4", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionViewItemV4", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionViewItemV4___copy__(PyObject *self)
{
        QStyleOptionViewItemV4* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionViewItemV4*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionViewItemV4* copy = new QStyleOptionViewItemV4(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionViewItemV4*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionViewItemV4_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionViewItemV4___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionViewItemV4_get_checkState(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::Qt::CheckState >::toPython( Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->checkState);
    return val;
}

static int Sbk_QStyleOptionViewItemV4_set_checkState(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'checkState' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::Qt::CheckState >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'checkState', 'CheckState' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->checkState = Shiboken::Converter< ::Qt::CheckState >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItemV4_get_viewItemPosition(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< ::QStyleOptionViewItemV4::ViewItemPosition >::toPython( Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->viewItemPosition);
    return val;
}

static int Sbk_QStyleOptionViewItemV4_set_viewItemPosition(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'viewItemPosition' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QStyleOptionViewItemV4::ViewItemPosition >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'viewItemPosition', 'ViewItemPosition' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->viewItemPosition = Shiboken::Converter< ::QStyleOptionViewItemV4::ViewItemPosition >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItemV4_get_icon(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->icon);
    Shiboken::Object::releaseOwnership(val);
    Shiboken::Object::setParent(self, val);
    return val;
}

static int Sbk_QStyleOptionViewItemV4_set_icon(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'icon' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QIcon >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'icon', 'QIcon' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->icon = Shiboken::Converter< ::QIcon >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItemV4_get_backgroundBrush(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->backgroundBrush);
    Shiboken::Object::releaseOwnership(val);
    Shiboken::Object::setParent(self, val);
    return val;
}

static int Sbk_QStyleOptionViewItemV4_set_backgroundBrush(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'backgroundBrush' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QBrush >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'backgroundBrush', 'QBrush' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->backgroundBrush = Shiboken::Converter< ::QBrush >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItemV4_get_index(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->index);
    Shiboken::Object::releaseOwnership(val);
    Shiboken::Object::setParent(self, val);
    return val;
}

static int Sbk_QStyleOptionViewItemV4_set_index(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'index' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QModelIndex >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'index', 'QModelIndex' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->index = Shiboken::Converter< ::QModelIndex >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionViewItemV4_get_text(PyObject* self, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    PyObject* val = Shiboken::Converter< QString >::toPython( Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->text);
    return val;
}

static int Sbk_QStyleOptionViewItemV4_set_text(PyObject* self, PyObject* value, void*)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'text' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< QString >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'text', 'QString' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItemV4* >::toCpp(self)->text = Shiboken::Converter< QString >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionViewItemV4
static PyGetSetDef Sbk_QStyleOptionViewItemV4_getsetlist[] = {
    {const_cast<char*>("checkState"), Sbk_QStyleOptionViewItemV4_get_checkState, Sbk_QStyleOptionViewItemV4_set_checkState},
    {const_cast<char*>("viewItemPosition"), Sbk_QStyleOptionViewItemV4_get_viewItemPosition, Sbk_QStyleOptionViewItemV4_set_viewItemPosition},
    {const_cast<char*>("icon"), Sbk_QStyleOptionViewItemV4_get_icon, Sbk_QStyleOptionViewItemV4_set_icon},
    {const_cast<char*>("backgroundBrush"), Sbk_QStyleOptionViewItemV4_get_backgroundBrush, Sbk_QStyleOptionViewItemV4_set_backgroundBrush},
    {const_cast<char*>("index"), Sbk_QStyleOptionViewItemV4_get_index, Sbk_QStyleOptionViewItemV4_set_index},
    {const_cast<char*>("text"), Sbk_QStyleOptionViewItemV4_get_text, Sbk_QStyleOptionViewItemV4_set_text},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionViewItemV4_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionViewItemV4",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionViewItemV4_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionViewItemV4_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionViewItemV4_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionViewItemV4(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEMV4_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionViewItemV4_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionViewItemV4_Type);
    Sbk_QStyleOptionViewItemV4_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEMV3_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionViewItemV4_Type, &Shiboken::callCppDestructor<QStyleOptionViewItemV4 >);
    Py_INCREF((PyObject*)&Sbk_QStyleOptionViewItemV4_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionViewItemV4_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionViewItemV4_Type, "QStyleOptionViewItemV4");
    PyModule_AddObject(module, "QStyleOptionViewItemV4",
        ((PyObject*)&Sbk_QStyleOptionViewItemV4_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ViewItemPosition
    PyTypeObject* SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionViewItemV4.ViewItemPosition");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEMV4_VIEWITEMPOSITION_IDX] = SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV4_Type.super.ht_type.tp_dict,
            "ViewItemPosition",((PyObject*)SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition,(long) QStyleOptionViewItemV4::Invalid, "Invalid");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV4_Type.super.ht_type.tp_dict,"Invalid", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition->tp_dict,"Invalid", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition,(long) QStyleOptionViewItemV4::Beginning, "Beginning");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV4_Type.super.ht_type.tp_dict,"Beginning", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition->tp_dict,"Beginning", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition,(long) QStyleOptionViewItemV4::Middle, "Middle");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV4_Type.super.ht_type.tp_dict,"Middle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition->tp_dict,"Middle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition,(long) QStyleOptionViewItemV4::End, "End");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV4_Type.super.ht_type.tp_dict,"End", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition->tp_dict,"End", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition,(long) QStyleOptionViewItemV4::OnlyOne, "OnlyOne");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV4_Type.super.ht_type.tp_dict,"OnlyOne", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV4_ViewItemPosition->tp_dict,"OnlyOne", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionViewItemV4::ViewItemPosition");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ViewItemPosition");
    // end of enum ViewItemPosition

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionViewItemV4_StyleOptionVersion = Shiboken::Enum::newType("PySide.QtGui.QStyleOptionViewItemV4.StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEMV4_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionViewItemV4_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionViewItemV4_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV4_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionViewItemV4_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV4_StyleOptionVersion,(long) QStyleOptionViewItemV4::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV4_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV4_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionViewItemV4::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionViewItemV4 >("QStyleOptionViewItemV4");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionViewItemV4 >("QStyleOptionViewItemV4*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionViewItemV4 >(typeid(QStyleOptionViewItemV4).name());
    qRegisterMetaType< ::QStyleOptionViewItemV4 >("QStyleOptionViewItemV4");
    qRegisterMetaType< ::QStyleOptionViewItemV4::ViewItemPosition >("QStyleOptionViewItemV4::ViewItemPosition");
    qRegisterMetaType< ::QStyleOptionViewItemV4::StyleOptionVersion >("QStyleOptionViewItemV4::StyleOptionVersion");
}

