/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextblock_iterator_wrapper.h"

// Extra includes
#include <QTextBlock>
#include <qtextobject.h>



// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QTextBlock_iteratorFunc___iter__(PyObject* self)
{
    QTextBlock::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlock::iterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __iter__()
                // Begin code injection

                // TEMPLATE - __iter__ - START
                Py_INCREF(self);
                pyResult = self;
                // TEMPLATE - __iter__ - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlock_iteratorFunc___next__(PyObject* self)
{
    QTextBlock::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlock::iterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __next__()
                // Begin code injection

                // TEMPLATE - __next__ - START
                if (!cppSelf->atEnd())
                  pyResult = Shiboken::Converter<QTextBlock::iterator >::toPython((*cppSelf)++);
                // TEMPLATE - __next__ - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlock_iteratorFunc_atEnd(PyObject* self)
{
    QTextBlock::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlock::iterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // atEnd()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextBlock::iterator*>(cppSelf)->atEnd();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlock_iteratorFunc_fragment(PyObject* self)
{
    QTextBlock::iterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlock::iterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fragment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextFragment cppResult = const_cast<const QTextBlock::iterator*>(cppSelf)->fragment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextFragment >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static int
Sbk_QTextBlock_iterator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextBlock::iterator >()))
        return -1;

    QTextBlock::iterator* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "iterator", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: iterator()
    // 1: iterator(QTextBlock::iterator)
    if (numArgs == 0) {
        overloadId = 0; // iterator()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextBlock::iterator >::isConvertible(pyargs[0])) {
        overloadId = 1; // iterator(QTextBlock::iterator)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlock_iterator_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // iterator()
            {

                if(!PyErr_Occurred()) {
                    // iterator()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextBlock::iterator();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // iterator(QTextBlock::iterator)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextBlock::iterator cppArg0 = Shiboken::Converter<QTextBlock::iterator >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // iterator(QTextBlock::iterator)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextBlock::iterator(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextBlock::iterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextBlock_iterator_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextBlock_iterator_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextBlock::iterator", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.iterator", overloads);
        return -1;
}

static PyObject *Sbk_QTextBlock_iterator___copy__(PyObject *self)
{
        QTextBlock::iterator* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextBlock::iterator*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextBlock::iterator* copy = new QTextBlock::iterator(*cppSelf);
        pyResult = Shiboken::Converter<QTextBlock::iterator*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextBlock_iterator_methods[] = {
    {"atEnd", (PyCFunction)Sbk_QTextBlock_iteratorFunc_atEnd, METH_NOARGS},
    {"fragment", (PyCFunction)Sbk_QTextBlock_iteratorFunc_fragment, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextBlock_iterator___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QTextBlock_iteratorFunc___iadd__(PyObject* self, PyObject* arg)
{
    QTextBlock::iterator* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QTextBlock::iterator >::checkType(arg) && !Shiboken::Converter< ::QTextBlock::iterator >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlock::iterator* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__riadd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__riadd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator++(int)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator++(int)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlock_iteratorFunc___iadd___TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator++(int)

                for(int i=0; i < cppArg0; i++, (*cppSelf)++);
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlock::iterator cppResult = (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlock::iterator >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextBlock_iteratorFunc___iadd___TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.iterator.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlock_iteratorFunc___isub__(PyObject* self, PyObject* arg)
{
    QTextBlock::iterator* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QTextBlock::iterator >::checkType(arg) && !Shiboken::Converter< ::QTextBlock::iterator >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlock::iterator* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__risub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__risub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator--(int)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator--(int)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlock_iteratorFunc___isub___TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator--(int)

                for(int i=0; i < cppArg0; i++, (*cppSelf)--);
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlock::iterator cppResult = (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlock::iterator >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextBlock_iteratorFunc___isub___TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.iterator.__isub__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QTextBlock_iterator_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)Sbk_QTextBlock_iteratorFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)Sbk_QTextBlock_iteratorFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QTextBlock_iterator_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QTextBlock::iterator& cppSelf = *Shiboken::Converter< QTextBlock::iterator* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QTextBlock::iterator >::isConvertible(arg)) {
                // operator!=(const QTextBlock::iterator & o) const
                QTextBlock::iterator cppArg0 = Shiboken::Converter< ::QTextBlock::iterator >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QTextBlock::iterator >::isConvertible(arg)) {
                // operator==(const QTextBlock::iterator & o) const
                QTextBlock::iterator cppArg0 = Shiboken::Converter< ::QTextBlock::iterator >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QTextBlock_iterator_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QTextBlock_iterator_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextBlock_iterator_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextBlock.iterator",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QTextBlock_iterator_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QTextBlock_iterator_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             Sbk_QTextBlock_iteratorFunc___iter__,
    /*tp_iternext*/         Sbk_QTextBlock_iteratorFunc___next__,
    /*tp_methods*/          Sbk_QTextBlock_iterator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextBlock_iterator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextBlock_iterator(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTBLOCK_ITERATOR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextBlock_iterator_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextBlock_iterator_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextBlock_iterator_Type, &Shiboken::callCppDestructor<QTextBlock::iterator >);
    Py_INCREF((PyObject*)&Sbk_QTextBlock_iterator_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextBlock_iterator_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextBlock_iterator_Type, "QTextBlock::iterator");
    PyDict_SetItemString(module,"iterator", (PyObject*)&Sbk_QTextBlock_iterator_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QTextBlock::iterator >("QTextBlock::iterator");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextBlock::iterator >("QTextBlock::iterator*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextBlock::iterator >(typeid(QTextBlock::iterator).name());
    qRegisterMetaType< ::QTextBlock::iterator >("iterator");
    qRegisterMetaType< ::QTextBlock::iterator >("QTextBlock::iterator");
}

