/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qtextdocument_wrapper.h"

// Extra includes
#include <QList>
#include <QTextBlock>
#include <QTextCursor>
#include <QTextFormat>
#include <QVector>
#include <qabstracttextdocumentlayout.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qfont.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qprinter.h>
#include <qrect.h>
#include <qregexp.h>
#include <qsize.h>
#include <qtextcursor.h>
#include <qtextdocument.h>
#include <qtextformat.h>
#include <qtextobject.h>
#include <qtextoption.h>
#include <qthread.h>
#include <qurl.h>


// Native ---------------------------------------------------------

QTextDocumentWrapper::QTextDocumentWrapper(QObject * parent) : QTextDocument(parent) {
    // ... middle
}

QTextDocumentWrapper::QTextDocumentWrapper(const QString & text, QObject * parent) : QTextDocument(text, parent) {
    // ... middle
}

void QTextDocumentWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextDocumentWrapper::clear()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "clear"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTextDocument::clear();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTextDocumentWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QTextObject * QTextDocumentWrapper::createObject(const QTextFormat & f)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createObject"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTextDocument::createObject(f);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTextFormat >::toPython(f)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QTextObject * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextDocument.createObject", Shiboken::SbkType<QTextObject >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QTextObject * cppResult(Shiboken::Converter< ::QTextObject * >::toCpp(pyResult));
    return cppResult;
}

void QTextDocumentWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTextDocumentWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QTextDocumentWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextDocument.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QTextDocumentWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextDocument.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

QVariant QTextDocumentWrapper::loadResource(int type, const QUrl & name)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "loadResource"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTextDocument::loadResource(type, name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iN)",
        type,
        Shiboken::Converter< ::QUrl >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTextDocument.loadResource", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QTextDocumentWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QTextDocumentWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QTextDocumentWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QTextDocument::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QTextDocumentWrapper::~QTextDocumentWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextDocument_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextDocument >()))
        return -1;

    QTextDocumentWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OO:QTextDocument", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QTextDocument(QObject*)
    // 1: QTextDocument(QString,QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QTextDocument(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QTextDocument(QObject*)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QTextDocument(QString,QObject*)
        } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1])) {
            overloadId = 1; // QTextDocument(QString,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocument_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextDocument(QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[0] = value;
                        else
                            goto Sbk_QTextDocument_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                    // QTextDocument(QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextDocumentWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QTextDocument(QString,QObject*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QTextDocument_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QObject * cppArg1 = pyargs[1] ? Shiboken::Converter<QObject * >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // QTextDocument(QString,QObject*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextDocumentWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[1], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextDocument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextDocument_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QTextDocument_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", "QString, PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument", overloads);
        return -1;
}

static PyObject* Sbk_QTextDocumentFunc_addResource(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addResource", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: addResource(int,QUrl,QVariant)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[2])) {
        overloadId = 0; // addResource(int,QUrl,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_addResource_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QUrl cppArg1 = Shiboken::Converter<QUrl >::toCpp(pyargs[1]);
            QVariant cppArg2 = Shiboken::Converter<QVariant >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // addResource(int,QUrl,QVariant)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addResource(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_addResource_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QUrl, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.addResource", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_adjustSize(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // adjustSize()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->adjustSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextDocumentFunc_allFormats(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // allFormats()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QTextFormat > cppResult = const_cast<const QTextDocument*>(cppSelf)->allFormats();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QTextFormat > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_availableRedoSteps(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // availableRedoSteps()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextDocument*>(cppSelf)->availableRedoSteps();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_availableUndoSteps(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // availableUndoSteps()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextDocument*>(cppSelf)->availableUndoSteps();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_begin(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // begin()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlock cppResult = const_cast<const QTextDocument*>(cppSelf)->begin();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlock >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_blockCount(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // blockCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextDocument*>(cppSelf)->blockCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_characterAt(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: characterAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // characterAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_characterAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // characterAt(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = const_cast<const QTextDocument*>(cppSelf)->characterAt(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_characterAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.characterAt", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_characterCount(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // characterCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextDocument*>(cppSelf)->characterCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_clear(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QTextDocument::clear() : cppSelf->clear());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextDocumentFunc_clearUndoRedoStacks(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.clearUndoRedoStacks(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:clearUndoRedoStacks", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: clearUndoRedoStacks(QTextDocument::Stacks)
    if (numArgs == 0) {
        overloadId = 0; // clearUndoRedoStacks(QTextDocument::Stacks)
    } else if (Shiboken::Converter< ::QTextDocument::Stacks >::isConvertible(pyargs[0])) {
        overloadId = 0; // clearUndoRedoStacks(QTextDocument::Stacks)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_clearUndoRedoStacks_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "historyToClear");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "historyToClear";
                    else if (Shiboken::Converter< ::QTextDocument::Stacks >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QTextDocumentFunc_clearUndoRedoStacks_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.clearUndoRedoStacks(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QTextDocument::Stacks cppArg0 = pyargs[0] ? Shiboken::Converter<QTextDocument::Stacks >::toCpp(pyargs[0]) : QTextDocument::UndoAndRedoStacks;

            if(!PyErr_Occurred()) {
                // clearUndoRedoStacks(QTextDocument::Stacks)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearUndoRedoStacks(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_clearUndoRedoStacks_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocument.Stacks = UndoAndRedoStacks", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.clearUndoRedoStacks", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_clone(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.clone(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:clone", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: clone(QObject*)const
    if (numArgs == 0) {
        overloadId = 0; // clone(QObject*)const
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // clone(QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_clone_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QTextDocumentFunc_clone_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.clone(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // clone(QObject*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextDocument * cppResult = const_cast<const QTextDocument*>(cppSelf)->clone(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextDocument * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_clone_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.clone", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_createObject(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createObject(QTextFormat)
    if (Shiboken::Converter< ::QTextFormat >::isConvertible(arg)) {
        overloadId = 0; // createObject(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_createObject_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextFormat cppArg0 = Shiboken::Converter<QTextFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // createObject(QTextFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextObject * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QTextDocument::createObject(cppArg0) : cppSelf->createObject(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_createObject_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.createObject", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_defaultFont(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultFont()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont cppResult = const_cast<const QTextDocument*>(cppSelf)->defaultFont();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_defaultStyleSheet(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultStyleSheet()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextDocument*>(cppSelf)->defaultStyleSheet();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_defaultTextOption(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultTextOption()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextOption cppResult = const_cast<const QTextDocument*>(cppSelf)->defaultTextOption();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextOption >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_documentLayout(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // documentLayout()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractTextDocumentLayout * cppResult = const_cast<const QTextDocument*>(cppSelf)->documentLayout();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractTextDocumentLayout * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_documentMargin(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // documentMargin()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextDocument*>(cppSelf)->documentMargin();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_drawContents(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.drawContents(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.drawContents(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:drawContents", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: drawContents(QPainter*,QRectF)
    if (Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // drawContents(QPainter*,QRectF)
        } else if (Shiboken::Converter< ::QRectF >::isConvertible(pyargs[1])) {
            overloadId = 0; // drawContents(QPainter*,QRectF)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_drawContents_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "rect");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "rect";
                    else if (Shiboken::Converter< ::QRectF >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QTextDocumentFunc_drawContents_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.drawContents(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRectF cppArg1_tmp = QRectF();
            QRectF cppArg1 = pyargs[1] ? Shiboken::Converter<QRectF >::toCpp(pyargs[1]) : cppArg1_tmp;

            if(!PyErr_Occurred()) {
                // drawContents(QPainter*,QRectF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->drawContents(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_drawContents_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRectF = QRectF()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.drawContents", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_end(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // end()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlock cppResult = const_cast<const QTextDocument*>(cppSelf)->end();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlock >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_find(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:find", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: find(QRegExp,QTextCursor,QFlags<QTextDocument::FindFlag>)const
    // 1: find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
    // 2: find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
    // 3: find(QString,int,QFlags<QTextDocument::FindFlag>)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // find(QString,int,QFlags<QTextDocument::FindFlag>)const
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // find(QString,int,QFlags<QTextDocument::FindFlag>)const
            } else if (Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::isConvertible(pyargs[2])) {
                overloadId = 3; // find(QString,int,QFlags<QTextDocument::FindFlag>)const
            }
        } else if (Shiboken::Converter< ::QTextCursor >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            } else if (Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::isConvertible(pyargs[2])) {
                overloadId = 2; // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            }
        }
    } else if (Shiboken::Converter< ::QRegExp >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
            } else if (Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::isConvertible(pyargs[2])) {
                overloadId = 1; // find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
            }
        } else if (Shiboken::Converter< ::QTextCursor >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // find(QRegExp,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            } else if (Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::isConvertible(pyargs[2])) {
                overloadId = 0; // find(QRegExp,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_find_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // find(QRegExp,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "options";
                        else if (Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QTextDocumentFunc_find_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRegExp cppArg0 = Shiboken::Converter<QRegExp >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QTextCursor cppArg1 = Shiboken::Converter<QTextCursor >::toCpp(pyargs[1]);
                QFlags<QTextDocument::FindFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::toCpp(pyargs[2]) : QFlags<QTextDocument::FindFlag>(0);

                if(!PyErr_Occurred()) {
                    // find(QRegExp,QTextCursor,QFlags<QTextDocument::FindFlag>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextCursor cppResult = const_cast<const QTextDocument*>(cppSelf)->find(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextCursor >::toPython(cppResult);
                }
                break;
            }
            case 1: // find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "from";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QTextDocumentFunc_find_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "options";
                        else if (Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QTextDocumentFunc_find_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRegExp cppArg0 = Shiboken::Converter<QRegExp >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;
                QFlags<QTextDocument::FindFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::toCpp(pyargs[2]) : QFlags<QTextDocument::FindFlag>(0);

                if(!PyErr_Occurred()) {
                    // find(QRegExp,int,QFlags<QTextDocument::FindFlag>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextCursor cppResult = const_cast<const QTextDocument*>(cppSelf)->find(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextCursor >::toPython(cppResult);
                }
                break;
            }
            case 2: // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "options";
                        else if (Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QTextDocumentFunc_find_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QTextCursor cppArg1 = Shiboken::Converter<QTextCursor >::toCpp(pyargs[1]);
                QFlags<QTextDocument::FindFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::toCpp(pyargs[2]) : QFlags<QTextDocument::FindFlag>(0);

                if(!PyErr_Occurred()) {
                    // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextCursor cppResult = const_cast<const QTextDocument*>(cppSelf)->find(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextCursor >::toPython(cppResult);
                }
                break;
            }
            case 3: // find(QString,int,QFlags<QTextDocument::FindFlag>)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "from";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QTextDocumentFunc_find_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "options");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "options";
                        else if (Shiboken::Converter< ::QFlags<QTextDocument::FindFlag> >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QTextDocumentFunc_find_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.find(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;
                QFlags<QTextDocument::FindFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<QTextDocument::FindFlag> >::toCpp(pyargs[2]) : QFlags<QTextDocument::FindFlag>(0);

                if(!PyErr_Occurred()) {
                    // find(QString,int,QFlags<QTextDocument::FindFlag>)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextCursor cppResult = const_cast<const QTextDocument*>(cppSelf)->find(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextCursor >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_find_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRegExp, PySide.QtGui.QTextCursor, PySide.QtGui.QTextDocument.FindFlags = 0", "PySide.QtCore.QRegExp, int = 0, PySide.QtGui.QTextDocument.FindFlags = 0", "QString, PySide.QtGui.QTextCursor, PySide.QtGui.QTextDocument.FindFlags = 0", "QString, int = 0, PySide.QtGui.QTextDocument.FindFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.find", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_findBlock(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findBlock(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // findBlock(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_findBlock_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // findBlock(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlock cppResult = const_cast<const QTextDocument*>(cppSelf)->findBlock(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlock >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_findBlock_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.findBlock", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_findBlockByLineNumber(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findBlockByLineNumber(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // findBlockByLineNumber(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_findBlockByLineNumber_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // findBlockByLineNumber(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlock cppResult = const_cast<const QTextDocument*>(cppSelf)->findBlockByLineNumber(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlock >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_findBlockByLineNumber_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.findBlockByLineNumber", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_findBlockByNumber(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findBlockByNumber(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // findBlockByNumber(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_findBlockByNumber_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // findBlockByNumber(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlock cppResult = const_cast<const QTextDocument*>(cppSelf)->findBlockByNumber(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlock >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_findBlockByNumber_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.findBlockByNumber", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_firstBlock(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // firstBlock()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlock cppResult = const_cast<const QTextDocument*>(cppSelf)->firstBlock();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlock >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_frameAt(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: frameAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // frameAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_frameAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // frameAt(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextFrame * cppResult = const_cast<const QTextDocument*>(cppSelf)->frameAt(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextFrame * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_frameAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.frameAt", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_idealWidth(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // idealWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextDocument*>(cppSelf)->idealWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_indentWidth(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // indentWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextDocument*>(cppSelf)->indentWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_isEmpty(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextDocument*>(cppSelf)->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_isModified(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isModified()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextDocument*>(cppSelf)->isModified();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_isRedoAvailable(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isRedoAvailable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextDocument*>(cppSelf)->isRedoAvailable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_isUndoAvailable(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isUndoAvailable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextDocument*>(cppSelf)->isUndoAvailable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_isUndoRedoEnabled(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isUndoRedoEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextDocument*>(cppSelf)->isUndoRedoEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_lastBlock(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastBlock()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlock cppResult = const_cast<const QTextDocument*>(cppSelf)->lastBlock();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlock >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_lineCount(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lineCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextDocument*>(cppSelf)->lineCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_loadResource(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "loadResource", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: loadResource(int,QUrl)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1])) {
        overloadId = 0; // loadResource(int,QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_loadResource_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QUrl cppArg1 = Shiboken::Converter<QUrl >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // loadResource(int,QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QTextDocument::loadResource(cppArg0, cppArg1) : cppSelf->loadResource(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_loadResource_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.loadResource", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_markContentsDirty(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "markContentsDirty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: markContentsDirty(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // markContentsDirty(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_markContentsDirty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // markContentsDirty(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->markContentsDirty(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_markContentsDirty_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.markContentsDirty", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_maximumBlockCount(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // maximumBlockCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextDocument*>(cppSelf)->maximumBlockCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_metaInformation(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metaInformation(QTextDocument::MetaInformation)const
    if (Shiboken::Converter< ::QTextDocument::MetaInformation >::isConvertible(arg)) {
        overloadId = 0; // metaInformation(QTextDocument::MetaInformation)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_metaInformation_TypeError;

    // Call function/method
    {
        {
            QTextDocument::MetaInformation cppArg0 = Shiboken::Converter<QTextDocument::MetaInformation >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // metaInformation(QTextDocument::MetaInformation)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextDocument*>(cppSelf)->metaInformation(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_metaInformation_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocument.MetaInformation", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.metaInformation", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_object(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: object(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // object(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_object_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // object(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextObject * cppResult = const_cast<const QTextDocument*>(cppSelf)->object(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_object_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.object", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_objectForFormat(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: objectForFormat(QTextFormat)const
    if (Shiboken::Converter< ::QTextFormat >::isConvertible(arg)) {
        overloadId = 0; // objectForFormat(QTextFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_objectForFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextFormat cppArg0 = Shiboken::Converter<QTextFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // objectForFormat(QTextFormat)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextObject * cppResult = const_cast<const QTextDocument*>(cppSelf)->objectForFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_objectForFormat_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.objectForFormat", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_pageCount(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pageCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextDocument*>(cppSelf)->pageCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_pageSize(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pageSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSizeF cppResult = const_cast<const QTextDocument*>(cppSelf)->pageSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSizeF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_print_(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: print(QPrinter*)const
    if (Shiboken::Converter< ::QPrinter * >::isConvertible(arg)) {
        overloadId = 0; // print(QPrinter*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_print__TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPrinter * cppArg0 = Shiboken::Converter<QPrinter * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // print(QPrinter*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const_cast<const QTextDocument*>(cppSelf)->print(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_print__TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrinter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.print_", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_redo(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "redo", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: redo()
    // 1: redo(QTextCursor*)
    if (numArgs == 0) {
        overloadId = 0; // redo()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextCursor * >::isConvertible(pyargs[0])) {
        overloadId = 1; // redo(QTextCursor*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_redo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // redo()
            {

                if(!PyErr_Occurred()) {
                    // redo()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->redo();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // redo(QTextCursor*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTextCursor * cppArg0 = Shiboken::Converter<QTextCursor * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // redo(QTextCursor*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->redo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_redo_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextCursor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.redo", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_resource(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resource", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: resource(int,QUrl)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1])) {
        overloadId = 0; // resource(int,QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_resource_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QUrl cppArg1 = Shiboken::Converter<QUrl >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // resource(int,QUrl)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = const_cast<const QTextDocument*>(cppSelf)->resource(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_resource_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.resource", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_revision(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // revision()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextDocument*>(cppSelf)->revision();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_rootFrame(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rootFrame()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextFrame * cppResult = const_cast<const QTextDocument*>(cppSelf)->rootFrame();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextFrame * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_setDefaultFont(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultFont(QFont)
    if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
        overloadId = 0; // setDefaultFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setDefaultFont_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultFont(QFont)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDefaultFont(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setDefaultFont_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setDefaultFont", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setDefaultStyleSheet(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultStyleSheet(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setDefaultStyleSheet(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setDefaultStyleSheet_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultStyleSheet(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDefaultStyleSheet(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setDefaultStyleSheet_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setDefaultStyleSheet", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setDefaultTextOption(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultTextOption(QTextOption)
    if (Shiboken::Converter< ::QTextOption >::isConvertible(arg)) {
        overloadId = 0; // setDefaultTextOption(QTextOption)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setDefaultTextOption_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextOption cppArg0 = Shiboken::Converter<QTextOption >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultTextOption(QTextOption)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDefaultTextOption(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setDefaultTextOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextOption", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setDefaultTextOption", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setDocumentLayout(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocumentLayout(QAbstractTextDocumentLayout*)
    if (Shiboken::Converter< ::QAbstractTextDocumentLayout * >::isConvertible(arg)) {
        overloadId = 0; // setDocumentLayout(QAbstractTextDocumentLayout*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setDocumentLayout_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractTextDocumentLayout * cppArg0 = Shiboken::Converter<QAbstractTextDocumentLayout * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDocumentLayout(QAbstractTextDocumentLayout*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDocumentLayout(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setDocumentLayout_TypeError:
        const char* overloads[] = {"PySide.QtGui.QAbstractTextDocumentLayout", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setDocumentLayout", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setDocumentMargin(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDocumentMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDocumentMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setDocumentMargin_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDocumentMargin(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDocumentMargin(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setDocumentMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setDocumentMargin", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setHtml(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHtml(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setHtml_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHtml(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHtml(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setHtml_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setHtml", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setIndentWidth(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIndentWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIndentWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setIndentWidth_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIndentWidth(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIndentWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setIndentWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setIndentWidth", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setMaximumBlockCount(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumBlockCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumBlockCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setMaximumBlockCount_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMaximumBlockCount(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMaximumBlockCount(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setMaximumBlockCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setMaximumBlockCount", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setMetaInformation(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setMetaInformation", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setMetaInformation(QTextDocument::MetaInformation,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QTextDocument::MetaInformation >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setMetaInformation(QTextDocument::MetaInformation,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setMetaInformation_TypeError;

    // Call function/method
    {
        {
            QTextDocument::MetaInformation cppArg0 = Shiboken::Converter<QTextDocument::MetaInformation >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setMetaInformation(QTextDocument::MetaInformation,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMetaInformation(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setMetaInformation_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextDocument.MetaInformation, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.setMetaInformation", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setModified(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.setModified(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:setModified", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: setModified(bool)
    if (numArgs == 0) {
        overloadId = 0; // setModified(bool)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // setModified(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setModified_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "m");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "m";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QTextDocumentFunc_setModified_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.setModified(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cppArg0 = pyargs[0] ? Shiboken::Converter<bool >::toCpp(pyargs[0]) : true;

            if(!PyErr_Occurred()) {
                // setModified(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setModified(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setModified_TypeError:
        const char* overloads[] = {"bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.setModified", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setPageSize(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPageSize(QSizeF)
    if (Shiboken::Converter< ::QSizeF >::isConvertible(arg)) {
        overloadId = 0; // setPageSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setPageSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSizeF cppArg0 = Shiboken::Converter<QSizeF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPageSize(QSizeF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPageSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setPageSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSizeF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setPageSize", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setPlainText(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPlainText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setPlainText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPlainText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPlainText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setPlainText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setPlainText", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setTextWidth(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextWidth(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTextWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setTextWidth_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTextWidth(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTextWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setTextWidth_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setTextWidth", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setUndoRedoEnabled(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUndoRedoEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUndoRedoEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setUndoRedoEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUndoRedoEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUndoRedoEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setUndoRedoEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setUndoRedoEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_setUseDesignMetrics(PyObject* self, PyObject* arg)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUseDesignMetrics(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUseDesignMetrics(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_setUseDesignMetrics_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUseDesignMetrics(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUseDesignMetrics(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_setUseDesignMetrics_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocument.setUseDesignMetrics", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_size(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSizeF cppResult = const_cast<const QTextDocument*>(cppSelf)->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSizeF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_textWidth(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextDocument*>(cppSelf)->textWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_toHtml(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTextDocument.toHtml(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toHtml", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toHtml(QByteArray)const
    if (numArgs == 0) {
        overloadId = 0; // toHtml(QByteArray)const
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        overloadId = 0; // toHtml(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_toHtml_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "encoding");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "encoding";
                    else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QTextDocumentFunc_toHtml_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTextDocument.toHtml(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0_tmp = QByteArray();
            QByteArray cppArg0 = pyargs[0] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[0]) : cppArg0_tmp;

            if(!PyErr_Occurred()) {
                // toHtml(QByteArray)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextDocument*>(cppSelf)->toHtml(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFunc_toHtml_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.toHtml", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_toPlainText(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toPlainText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextDocument*>(cppSelf)->toPlainText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFunc_undo(PyObject* self, PyObject* args)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "undo", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: undo()
    // 1: undo(QTextCursor*)
    if (numArgs == 0) {
        overloadId = 0; // undo()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextCursor * >::isConvertible(pyargs[0])) {
        overloadId = 1; // undo(QTextCursor*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFunc_undo_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // undo()
            {

                if(!PyErr_Occurred()) {
                    // undo()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->undo();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // undo(QTextCursor*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTextCursor * cppArg0 = Shiboken::Converter<QTextCursor * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // undo(QTextCursor*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->undo(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextDocumentFunc_undo_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextCursor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocument.undo", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFunc_useDesignMetrics(PyObject* self)
{
    QTextDocument* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocument* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // useDesignMetrics()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextDocument*>(cppSelf)->useDesignMetrics();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QTextDocument_methods[] = {
    {"addResource", (PyCFunction)Sbk_QTextDocumentFunc_addResource, METH_VARARGS},
    {"adjustSize", (PyCFunction)Sbk_QTextDocumentFunc_adjustSize, METH_NOARGS},
    {"allFormats", (PyCFunction)Sbk_QTextDocumentFunc_allFormats, METH_NOARGS},
    {"availableRedoSteps", (PyCFunction)Sbk_QTextDocumentFunc_availableRedoSteps, METH_NOARGS},
    {"availableUndoSteps", (PyCFunction)Sbk_QTextDocumentFunc_availableUndoSteps, METH_NOARGS},
    {"begin", (PyCFunction)Sbk_QTextDocumentFunc_begin, METH_NOARGS},
    {"blockCount", (PyCFunction)Sbk_QTextDocumentFunc_blockCount, METH_NOARGS},
    {"characterAt", (PyCFunction)Sbk_QTextDocumentFunc_characterAt, METH_O},
    {"characterCount", (PyCFunction)Sbk_QTextDocumentFunc_characterCount, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QTextDocumentFunc_clear, METH_NOARGS},
    {"clearUndoRedoStacks", (PyCFunction)Sbk_QTextDocumentFunc_clearUndoRedoStacks, METH_VARARGS|METH_KEYWORDS},
    {"clone", (PyCFunction)Sbk_QTextDocumentFunc_clone, METH_VARARGS|METH_KEYWORDS},
    {"createObject", (PyCFunction)Sbk_QTextDocumentFunc_createObject, METH_O},
    {"defaultFont", (PyCFunction)Sbk_QTextDocumentFunc_defaultFont, METH_NOARGS},
    {"defaultStyleSheet", (PyCFunction)Sbk_QTextDocumentFunc_defaultStyleSheet, METH_NOARGS},
    {"defaultTextOption", (PyCFunction)Sbk_QTextDocumentFunc_defaultTextOption, METH_NOARGS},
    {"documentLayout", (PyCFunction)Sbk_QTextDocumentFunc_documentLayout, METH_NOARGS},
    {"documentMargin", (PyCFunction)Sbk_QTextDocumentFunc_documentMargin, METH_NOARGS},
    {"drawContents", (PyCFunction)Sbk_QTextDocumentFunc_drawContents, METH_VARARGS|METH_KEYWORDS},
    {"end", (PyCFunction)Sbk_QTextDocumentFunc_end, METH_NOARGS},
    {"find", (PyCFunction)Sbk_QTextDocumentFunc_find, METH_VARARGS|METH_KEYWORDS},
    {"findBlock", (PyCFunction)Sbk_QTextDocumentFunc_findBlock, METH_O},
    {"findBlockByLineNumber", (PyCFunction)Sbk_QTextDocumentFunc_findBlockByLineNumber, METH_O},
    {"findBlockByNumber", (PyCFunction)Sbk_QTextDocumentFunc_findBlockByNumber, METH_O},
    {"firstBlock", (PyCFunction)Sbk_QTextDocumentFunc_firstBlock, METH_NOARGS},
    {"frameAt", (PyCFunction)Sbk_QTextDocumentFunc_frameAt, METH_O},
    {"idealWidth", (PyCFunction)Sbk_QTextDocumentFunc_idealWidth, METH_NOARGS},
    {"indentWidth", (PyCFunction)Sbk_QTextDocumentFunc_indentWidth, METH_NOARGS},
    {"isEmpty", (PyCFunction)Sbk_QTextDocumentFunc_isEmpty, METH_NOARGS},
    {"isModified", (PyCFunction)Sbk_QTextDocumentFunc_isModified, METH_NOARGS},
    {"isRedoAvailable", (PyCFunction)Sbk_QTextDocumentFunc_isRedoAvailable, METH_NOARGS},
    {"isUndoAvailable", (PyCFunction)Sbk_QTextDocumentFunc_isUndoAvailable, METH_NOARGS},
    {"isUndoRedoEnabled", (PyCFunction)Sbk_QTextDocumentFunc_isUndoRedoEnabled, METH_NOARGS},
    {"lastBlock", (PyCFunction)Sbk_QTextDocumentFunc_lastBlock, METH_NOARGS},
    {"lineCount", (PyCFunction)Sbk_QTextDocumentFunc_lineCount, METH_NOARGS},
    {"loadResource", (PyCFunction)Sbk_QTextDocumentFunc_loadResource, METH_VARARGS},
    {"markContentsDirty", (PyCFunction)Sbk_QTextDocumentFunc_markContentsDirty, METH_VARARGS},
    {"maximumBlockCount", (PyCFunction)Sbk_QTextDocumentFunc_maximumBlockCount, METH_NOARGS},
    {"metaInformation", (PyCFunction)Sbk_QTextDocumentFunc_metaInformation, METH_O},
    {"object", (PyCFunction)Sbk_QTextDocumentFunc_object, METH_O},
    {"objectForFormat", (PyCFunction)Sbk_QTextDocumentFunc_objectForFormat, METH_O},
    {"pageCount", (PyCFunction)Sbk_QTextDocumentFunc_pageCount, METH_NOARGS},
    {"pageSize", (PyCFunction)Sbk_QTextDocumentFunc_pageSize, METH_NOARGS},
    {"print_", (PyCFunction)Sbk_QTextDocumentFunc_print_, METH_O},
    {"redo", (PyCFunction)Sbk_QTextDocumentFunc_redo, METH_VARARGS},
    {"resource", (PyCFunction)Sbk_QTextDocumentFunc_resource, METH_VARARGS},
    {"revision", (PyCFunction)Sbk_QTextDocumentFunc_revision, METH_NOARGS},
    {"rootFrame", (PyCFunction)Sbk_QTextDocumentFunc_rootFrame, METH_NOARGS},
    {"setDefaultFont", (PyCFunction)Sbk_QTextDocumentFunc_setDefaultFont, METH_O},
    {"setDefaultStyleSheet", (PyCFunction)Sbk_QTextDocumentFunc_setDefaultStyleSheet, METH_O},
    {"setDefaultTextOption", (PyCFunction)Sbk_QTextDocumentFunc_setDefaultTextOption, METH_O},
    {"setDocumentLayout", (PyCFunction)Sbk_QTextDocumentFunc_setDocumentLayout, METH_O},
    {"setDocumentMargin", (PyCFunction)Sbk_QTextDocumentFunc_setDocumentMargin, METH_O},
    {"setHtml", (PyCFunction)Sbk_QTextDocumentFunc_setHtml, METH_O},
    {"setIndentWidth", (PyCFunction)Sbk_QTextDocumentFunc_setIndentWidth, METH_O},
    {"setMaximumBlockCount", (PyCFunction)Sbk_QTextDocumentFunc_setMaximumBlockCount, METH_O},
    {"setMetaInformation", (PyCFunction)Sbk_QTextDocumentFunc_setMetaInformation, METH_VARARGS},
    {"setModified", (PyCFunction)Sbk_QTextDocumentFunc_setModified, METH_VARARGS|METH_KEYWORDS},
    {"setPageSize", (PyCFunction)Sbk_QTextDocumentFunc_setPageSize, METH_O},
    {"setPlainText", (PyCFunction)Sbk_QTextDocumentFunc_setPlainText, METH_O},
    {"setTextWidth", (PyCFunction)Sbk_QTextDocumentFunc_setTextWidth, METH_O},
    {"setUndoRedoEnabled", (PyCFunction)Sbk_QTextDocumentFunc_setUndoRedoEnabled, METH_O},
    {"setUseDesignMetrics", (PyCFunction)Sbk_QTextDocumentFunc_setUseDesignMetrics, METH_O},
    {"size", (PyCFunction)Sbk_QTextDocumentFunc_size, METH_NOARGS},
    {"textWidth", (PyCFunction)Sbk_QTextDocumentFunc_textWidth, METH_NOARGS},
    {"toHtml", (PyCFunction)Sbk_QTextDocumentFunc_toHtml, METH_VARARGS|METH_KEYWORDS},
    {"toPlainText", (PyCFunction)Sbk_QTextDocumentFunc_toPlainText, METH_NOARGS},
    {"undo", (PyCFunction)Sbk_QTextDocumentFunc_undo, METH_VARARGS},
    {"useDesignMetrics", (PyCFunction)Sbk_QTextDocumentFunc_useDesignMetrics, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextDocument_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextDocument",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextDocument_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextDocument_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QTextDocument_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QTextDocument*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QTextDocument_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QTextDocument_FindFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextDocument::FindFlags >::toPython(
        Shiboken::Converter<QTextDocument::FindFlags>::toCpp(self)
        & Shiboken::Converter< QTextDocument::FindFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextDocument_FindFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextDocument::FindFlags >::toPython(
        Shiboken::Converter<QTextDocument::FindFlags>::toCpp(self)
        | Shiboken::Converter< QTextDocument::FindFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextDocument_FindFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextDocument::FindFlags >::toPython(
        Shiboken::Converter<QTextDocument::FindFlags>::toCpp(self)
        ^ Shiboken::Converter< QTextDocument::FindFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextDocument_FindFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextDocument::FindFlags >::toPython(
        ~Shiboken::Converter<QTextDocument::FindFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QTextDocument_FindFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QTextDocument_FindFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QTextDocument_FindFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QTextDocument_FindFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QTextDocument_FindFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QTextDocument_FindFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FindFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QTextDocument_FindFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QTextDocument(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextDocument_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextDocument_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QTextDocument_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QTextDocument_Type, &QTextDocument::staticMetaObject);    Sbk_QTextDocument_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextDocument_Type, &Shiboken::callCppDestructor<QTextDocument >);
    Py_INCREF((PyObject*)&Sbk_QTextDocument_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextDocument_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QTextDocument_Type, &Sbk_QTextDocument_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QTextDocument_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextDocument_Type, "QTextDocument*");
    PyModule_AddObject(module, "QTextDocument",
        ((PyObject*)&Sbk_QTextDocument_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ResourceType
    PyTypeObject* SbkPySide_QtGui_QTextDocument_ResourceType = Shiboken::Enum::newType("PySide.QtGui.QTextDocument.ResourceType");
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENT_RESOURCETYPE_IDX] = SbkPySide_QtGui_QTextDocument_ResourceType;
    if (PyType_Ready(SbkPySide_QtGui_QTextDocument_ResourceType) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,
            "ResourceType",((PyObject*)SbkPySide_QtGui_QTextDocument_ResourceType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_ResourceType,(long) QTextDocument::HtmlResource, "HtmlResource");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"HtmlResource", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_ResourceType->tp_dict,"HtmlResource", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_ResourceType,(long) QTextDocument::ImageResource, "ImageResource");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"ImageResource", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_ResourceType->tp_dict,"ImageResource", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_ResourceType,(long) QTextDocument::StyleSheetResource, "StyleSheetResource");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"StyleSheetResource", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_ResourceType->tp_dict,"StyleSheetResource", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_ResourceType,(long) QTextDocument::UserResource, "UserResource");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"UserResource", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_ResourceType->tp_dict,"UserResource", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextDocument::ResourceType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ResourceType");
    // end of enum ResourceType

    // init enum: Stacks
    PyTypeObject* SbkPySide_QtGui_QTextDocument_Stacks = Shiboken::Enum::newType("PySide.QtGui.QTextDocument.Stacks");
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENT_STACKS_IDX] = SbkPySide_QtGui_QTextDocument_Stacks;
    if (PyType_Ready(SbkPySide_QtGui_QTextDocument_Stacks) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,
            "Stacks",((PyObject*)SbkPySide_QtGui_QTextDocument_Stacks));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_Stacks,(long) QTextDocument::UndoStack, "UndoStack");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"UndoStack", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_Stacks->tp_dict,"UndoStack", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_Stacks,(long) QTextDocument::RedoStack, "RedoStack");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"RedoStack", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_Stacks->tp_dict,"RedoStack", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_Stacks,(long) QTextDocument::UndoAndRedoStacks, "UndoAndRedoStacks");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"UndoAndRedoStacks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_Stacks->tp_dict,"UndoAndRedoStacks", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextDocument::Stacks");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Stacks");
    // end of enum Stacks

    // init enum: FindFlag
    PyTypeObject* SbkPySide_QtGui_QTextDocument_FindFlag = Shiboken::Enum::newType("PySide.QtGui.QTextDocument.FindFlag");
    SbkPySide_QtGui_QTextDocument_FindFlag->tp_as_number = &SbkPySide_QtGui_QTextDocument_FindFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENT_FINDFLAG_IDX] = SbkPySide_QtGui_QTextDocument_FindFlag;
    if (PyType_Ready(SbkPySide_QtGui_QTextDocument_FindFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,
            "FindFlag",((PyObject*)SbkPySide_QtGui_QTextDocument_FindFlag));

    // init flags class: QFlags<QTextDocument::FindFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QTEXTDOCUMENT_FINDFLAG__IDX] = &SbkPySide_QtGui_QTextDocument_FindFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextDocument_FindFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,
            "FindFlags",((PyObject*)&SbkPySide_QtGui_QTextDocument_FindFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_FindFlag,(long) QTextDocument::FindBackward, "FindBackward");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"FindBackward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_FindFlag->tp_dict,"FindBackward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_FindFlag,(long) QTextDocument::FindCaseSensitively, "FindCaseSensitively");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"FindCaseSensitively", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_FindFlag->tp_dict,"FindCaseSensitively", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_FindFlag,(long) QTextDocument::FindWholeWords, "FindWholeWords");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"FindWholeWords", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_FindFlag->tp_dict,"FindWholeWords", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextDocument::FindFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FindFlag");
    // end of enum FindFlag

    // init enum: MetaInformation
    PyTypeObject* SbkPySide_QtGui_QTextDocument_MetaInformation = Shiboken::Enum::newType("PySide.QtGui.QTextDocument.MetaInformation");
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENT_METAINFORMATION_IDX] = SbkPySide_QtGui_QTextDocument_MetaInformation;
    if (PyType_Ready(SbkPySide_QtGui_QTextDocument_MetaInformation) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,
            "MetaInformation",((PyObject*)SbkPySide_QtGui_QTextDocument_MetaInformation));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_MetaInformation,(long) QTextDocument::DocumentTitle, "DocumentTitle");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"DocumentTitle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_MetaInformation->tp_dict,"DocumentTitle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextDocument_MetaInformation,(long) QTextDocument::DocumentUrl, "DocumentUrl");
    PyDict_SetItemString(Sbk_QTextDocument_Type.super.ht_type.tp_dict,"DocumentUrl", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextDocument_MetaInformation->tp_dict,"DocumentUrl", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextDocument::MetaInformation");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::MetaInformation");
    // end of enum MetaInformation

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("undoCommandAdded", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTextDocument_Type, "undoCommandAdded", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("modificationChanged", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTextDocument_Type, "modificationChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("undoAvailable", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTextDocument_Type, "undoAvailable", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("blockCountChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTextDocument_Type, "blockCountChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("documentLayoutChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTextDocument_Type, "documentLayoutChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("cursorPositionChanged", "QTextCursor", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTextDocument_Type, "cursorPositionChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("redoAvailable", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTextDocument_Type, "redoAvailable", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("contentsChange", "int,int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTextDocument_Type, "contentsChange", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("contentsChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTextDocument_Type, "contentsChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QTextDocument >("QTextDocument*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextDocument >(typeid(QTextDocument).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTextDocument >(typeid(QTextDocumentWrapper).name());
    qRegisterMetaType< ::QTextDocument* >("QTextDocument*");
    qRegisterMetaType< ::QTextDocument::ResourceType >("QTextDocument::ResourceType");
    qRegisterMetaType< ::QTextDocument::Stacks >("QTextDocument::Stacks");
    qRegisterMetaType< ::QTextDocument::FindFlag >("QTextDocument::FindFlag");
    qRegisterMetaType< ::QTextDocument::FindFlags >("QTextDocument::FindFlags");
    qRegisterMetaType< ::QTextDocument::MetaInformation >("QTextDocument::MetaInformation");
}

