/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextdocumentfragment_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qtextcursor.h>
#include <qtextdocument.h>
#include <qtextdocumentfragment.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextDocumentFragment_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextDocumentFragment >()))
        return -1;

    QTextDocumentFragment* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextDocumentFragment", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QTextDocumentFragment()
    // 1: QTextDocumentFragment(QTextCursor)
    // 2: QTextDocumentFragment(const QTextDocument*)
    // 3: QTextDocumentFragment(QTextDocumentFragment)
    if (numArgs == 0) {
        overloadId = 0; // QTextDocumentFragment()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextDocumentFragment >::isConvertible(pyargs[0])) {
        overloadId = 3; // QTextDocumentFragment(QTextDocumentFragment)
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextDocument * >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTextDocumentFragment(const QTextDocument*)
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextCursor >::isConvertible(pyargs[0])) {
        overloadId = 1; // QTextDocumentFragment(QTextCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFragment_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextDocumentFragment()
            {

                if(!PyErr_Occurred()) {
                    // QTextDocumentFragment()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextDocumentFragment();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextDocumentFragment(QTextCursor)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextCursor cppArg0 = Shiboken::Converter<QTextCursor >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextDocumentFragment(QTextCursor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextDocumentFragment(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTextDocumentFragment(const QTextDocument*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextDocument * cppArg0 = Shiboken::Converter<QTextDocument * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextDocumentFragment(const QTextDocument*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextDocumentFragment(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QTextDocumentFragment(QTextDocumentFragment)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextDocumentFragment cppArg0 = Shiboken::Converter<QTextDocumentFragment >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextDocumentFragment(QTextDocumentFragment)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextDocumentFragment(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextDocumentFragment >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextDocumentFragment_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextDocumentFragment_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextCursor", "PySide.QtGui.QTextDocument", "PySide.QtGui.QTextDocumentFragment", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocumentFragment", overloads);
        return -1;
}

static PyObject* Sbk_QTextDocumentFragmentFunc_fromHtml(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fromHtml", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromHtml(QString)
    // 1: fromHtml(QString,const QTextDocument*)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromHtml(QString)
        } else if (numArgs == 2 && Shiboken::Converter< ::QTextDocument * >::isConvertible(pyargs[1])) {
            overloadId = 1; // fromHtml(QString,const QTextDocument*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFragmentFunc_fromHtml_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromHtml(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // fromHtml(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextDocumentFragment cppResult = QTextDocumentFragment::fromHtml(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextDocumentFragment >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromHtml(QString,const QTextDocument*)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QTextDocument * cppArg1 = Shiboken::Converter<QTextDocument * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fromHtml(QString,const QTextDocument*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTextDocumentFragment cppResult = QTextDocumentFragment::fromHtml(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTextDocumentFragment >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFragmentFunc_fromHtml_TypeError:
        const char* overloads[] = {"QString", "QString, PySide.QtGui.QTextDocument", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocumentFragment.fromHtml", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFragmentFunc_fromPlainText(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromPlainText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // fromPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFragmentFunc_fromPlainText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromPlainText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextDocumentFragment cppResult = QTextDocumentFragment::fromPlainText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextDocumentFragment >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFragmentFunc_fromPlainText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextDocumentFragment.fromPlainText", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFragmentFunc_isEmpty(PyObject* self)
{
    QTextDocumentFragment* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocumentFragment* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextDocumentFragment*>(cppSelf)->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextDocumentFragmentFunc_toHtml(PyObject* self, PyObject* args)
{
    QTextDocumentFragment* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocumentFragment* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "toHtml", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toHtml()const
    // 1: toHtml(QByteArray)const
    if (numArgs == 0) {
        overloadId = 0; // toHtml()const
    } else if (numArgs == 1 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        overloadId = 1; // toHtml(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextDocumentFragmentFunc_toHtml_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toHtml()const
            {

                if(!PyErr_Occurred()) {
                    // toHtml()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QTextDocumentFragment*>(cppSelf)->toHtml();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // toHtml(QByteArray)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // toHtml(QByteArray)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = const_cast<const QTextDocumentFragment*>(cppSelf)->toHtml(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextDocumentFragmentFunc_toHtml_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextDocumentFragment.toHtml", overloads);
        return 0;
}

static PyObject* Sbk_QTextDocumentFragmentFunc_toPlainText(PyObject* self)
{
    QTextDocumentFragment* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextDocumentFragment* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toPlainText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QTextDocumentFragment*>(cppSelf)->toPlainText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFragment___copy__(PyObject *self)
{
        QTextDocumentFragment* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextDocumentFragment*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextDocumentFragment* copy = new QTextDocumentFragment(*cppSelf);
        pyResult = Shiboken::Converter<QTextDocumentFragment*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextDocumentFragment_methods[] = {
    {"fromHtml", (PyCFunction)Sbk_QTextDocumentFragmentFunc_fromHtml, METH_VARARGS|METH_STATIC},
    {"fromPlainText", (PyCFunction)Sbk_QTextDocumentFragmentFunc_fromPlainText, METH_O|METH_STATIC},
    {"isEmpty", (PyCFunction)Sbk_QTextDocumentFragmentFunc_isEmpty, METH_NOARGS},
    {"toHtml", (PyCFunction)Sbk_QTextDocumentFragmentFunc_toHtml, METH_VARARGS},
    {"toPlainText", (PyCFunction)Sbk_QTextDocumentFragmentFunc_toPlainText, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextDocumentFragment___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextDocumentFragment_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextDocumentFragment",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextDocumentFragment_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextDocumentFragment_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextDocumentFragment(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTDOCUMENTFRAGMENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextDocumentFragment_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextDocumentFragment_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextDocumentFragment_Type, &Shiboken::callCppDestructor<QTextDocumentFragment >);
    Py_INCREF((PyObject*)&Sbk_QTextDocumentFragment_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextDocumentFragment_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextDocumentFragment_Type, "QTextDocumentFragment");
    PyModule_AddObject(module, "QTextDocumentFragment",
        ((PyObject*)&Sbk_QTextDocumentFragment_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTextDocumentFragment >("QTextDocumentFragment");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextDocumentFragment >("QTextDocumentFragment*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextDocumentFragment >(typeid(QTextDocumentFragment).name());
    qRegisterMetaType< ::QTextDocumentFragment >("QTextDocumentFragment");
}

