/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextlistformat_wrapper.h"

// Extra includes
#include <QMap>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qpen.h>
#include <qtextformat.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextListFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextListFormat >()))
        return -1;

    QTextListFormat* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextListFormat", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QTextListFormat()
    // 1: QTextListFormat(QTextFormat)
    // 2: QTextListFormat(QTextListFormat)
    if (numArgs == 0) {
        overloadId = 0; // QTextListFormat()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextListFormat >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTextListFormat(QTextListFormat)
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextFormat >::isConvertible(pyargs[0])) {
        overloadId = 1; // QTextListFormat(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextListFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextListFormat()
            {

                if(!PyErr_Occurred()) {
                    // QTextListFormat()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextListFormat();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextListFormat(QTextFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextFormat cppArg0 = Shiboken::Converter<QTextFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextListFormat(QTextFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextListFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTextListFormat(QTextListFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextListFormat cppArg0 = Shiboken::Converter<QTextListFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextListFormat(QTextListFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextListFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextListFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextListFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextListFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextFormat", "PySide.QtGui.QTextListFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextListFormat", overloads);
        return -1;
}

static PyObject* Sbk_QTextListFormatFunc_indent(PyObject* self)
{
    QTextListFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextListFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // indent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QTextListFormat*>(cppSelf)->indent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextListFormatFunc_isValid(PyObject* self)
{
    QTextListFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextListFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextListFormat*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextListFormatFunc_setIndent(PyObject* self, PyObject* arg)
{
    QTextListFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextListFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIndent(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIndent(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextListFormatFunc_setIndent_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIndent(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIndent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextListFormatFunc_setIndent_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextListFormat.setIndent", overloads);
        return 0;
}

static PyObject* Sbk_QTextListFormatFunc_setStyle(PyObject* self, PyObject* arg)
{
    QTextListFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextListFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(QTextListFormat::Style)
    if (Shiboken::Converter< ::QTextListFormat::Style >::isConvertible(arg)) {
        overloadId = 0; // setStyle(QTextListFormat::Style)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextListFormatFunc_setStyle_TypeError;

    // Call function/method
    {
        {
            QTextListFormat::Style cppArg0 = Shiboken::Converter<QTextListFormat::Style >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStyle(QTextListFormat::Style)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStyle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextListFormatFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextListFormat.Style", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextListFormat.setStyle", overloads);
        return 0;
}

static PyObject* Sbk_QTextListFormatFunc_style(PyObject* self)
{
    QTextListFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextListFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // style()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextListFormat::Style cppResult = const_cast<const QTextListFormat*>(cppSelf)->style();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextListFormat::Style >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTextListFormat___copy__(PyObject *self)
{
        QTextListFormat* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextListFormat*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextListFormat* copy = new QTextListFormat(*cppSelf);
        pyResult = Shiboken::Converter<QTextListFormat*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextListFormat_methods[] = {
    {"indent", (PyCFunction)Sbk_QTextListFormatFunc_indent, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QTextListFormatFunc_isValid, METH_NOARGS},
    {"setIndent", (PyCFunction)Sbk_QTextListFormatFunc_setIndent, METH_O},
    {"setStyle", (PyCFunction)Sbk_QTextListFormatFunc_setStyle, METH_O},
    {"style", (PyCFunction)Sbk_QTextListFormatFunc_style, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextListFormat___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextListFormat_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextListFormat",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextListFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextListFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextListFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTLISTFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextListFormat_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextListFormat_Type);
    Sbk_QTextListFormat_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextListFormat_Type, &Shiboken::callCppDestructor<QTextListFormat >);
    Py_INCREF((PyObject*)&Sbk_QTextListFormat_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextListFormat_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextListFormat_Type, "QTextListFormat");
    PyModule_AddObject(module, "QTextListFormat",
        ((PyObject*)&Sbk_QTextListFormat_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Style
    PyTypeObject* SbkPySide_QtGui_QTextListFormat_Style = Shiboken::Enum::newType("PySide.QtGui.QTextListFormat.Style");
    SbkPySide_QtGuiTypes[SBK_QTEXTLISTFORMAT_STYLE_IDX] = SbkPySide_QtGui_QTextListFormat_Style;
    if (PyType_Ready(SbkPySide_QtGui_QTextListFormat_Style) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextListFormat_Type.super.ht_type.tp_dict,
            "Style",((PyObject*)SbkPySide_QtGui_QTextListFormat_Style));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextListFormat_Style,(long) QTextListFormat::ListDisc, "ListDisc");
    PyDict_SetItemString(Sbk_QTextListFormat_Type.super.ht_type.tp_dict,"ListDisc", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style->tp_dict,"ListDisc", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextListFormat_Style,(long) QTextListFormat::ListCircle, "ListCircle");
    PyDict_SetItemString(Sbk_QTextListFormat_Type.super.ht_type.tp_dict,"ListCircle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style->tp_dict,"ListCircle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextListFormat_Style,(long) QTextListFormat::ListSquare, "ListSquare");
    PyDict_SetItemString(Sbk_QTextListFormat_Type.super.ht_type.tp_dict,"ListSquare", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style->tp_dict,"ListSquare", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextListFormat_Style,(long) QTextListFormat::ListDecimal, "ListDecimal");
    PyDict_SetItemString(Sbk_QTextListFormat_Type.super.ht_type.tp_dict,"ListDecimal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style->tp_dict,"ListDecimal", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextListFormat_Style,(long) QTextListFormat::ListLowerAlpha, "ListLowerAlpha");
    PyDict_SetItemString(Sbk_QTextListFormat_Type.super.ht_type.tp_dict,"ListLowerAlpha", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style->tp_dict,"ListLowerAlpha", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextListFormat_Style,(long) QTextListFormat::ListUpperAlpha, "ListUpperAlpha");
    PyDict_SetItemString(Sbk_QTextListFormat_Type.super.ht_type.tp_dict,"ListUpperAlpha", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style->tp_dict,"ListUpperAlpha", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextListFormat_Style,(long) QTextListFormat::ListLowerRoman, "ListLowerRoman");
    PyDict_SetItemString(Sbk_QTextListFormat_Type.super.ht_type.tp_dict,"ListLowerRoman", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style->tp_dict,"ListLowerRoman", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextListFormat_Style,(long) QTextListFormat::ListUpperRoman, "ListUpperRoman");
    PyDict_SetItemString(Sbk_QTextListFormat_Type.super.ht_type.tp_dict,"ListUpperRoman", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style->tp_dict,"ListUpperRoman", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextListFormat_Style,(long) QTextListFormat::ListStyleUndefined, "ListStyleUndefined");
    PyDict_SetItemString(Sbk_QTextListFormat_Type.super.ht_type.tp_dict,"ListStyleUndefined", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextListFormat_Style->tp_dict,"ListStyleUndefined", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextListFormat::Style");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Style");
    // end of enum Style


    Shiboken::TypeResolver::createValueTypeResolver<QTextListFormat >("QTextListFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextListFormat >("QTextListFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextListFormat >(typeid(QTextListFormat).name());
    qRegisterMetaType< ::QTextListFormat >("QTextListFormat");
    qRegisterMetaType< ::QTextListFormat::Style >("QTextListFormat::Style");
}

