/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtexttablecellformat_wrapper.h"

// Extra includes
#include <QMap>
#include <QStringList>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qfont.h>
#include <qpen.h>
#include <qtextformat.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextTableCellFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextTableCellFormat >()))
        return -1;

    QTextTableCellFormat* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextTableCellFormat", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QTextTableCellFormat()
    // 1: QTextTableCellFormat(QTextFormat)
    // 2: QTextTableCellFormat(QTextTableCellFormat)
    if (numArgs == 0) {
        overloadId = 0; // QTextTableCellFormat()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextTableCellFormat >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTextTableCellFormat(QTextTableCellFormat)
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextFormat >::isConvertible(pyargs[0])) {
        overloadId = 1; // QTextTableCellFormat(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextTableCellFormat()
            {

                if(!PyErr_Occurred()) {
                    // QTextTableCellFormat()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextTableCellFormat();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextTableCellFormat(QTextFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextFormat cppArg0 = Shiboken::Converter<QTextFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextTableCellFormat(QTextFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextTableCellFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTextTableCellFormat(QTextTableCellFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextTableCellFormat cppArg0 = Shiboken::Converter<QTextTableCellFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextTableCellFormat(QTextTableCellFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextTableCellFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextTableCellFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextTableCellFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextTableCellFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextFormat", "PySide.QtGui.QTextTableCellFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextTableCellFormat", overloads);
        return -1;
}

static PyObject* Sbk_QTextTableCellFormatFunc_bottomPadding(PyObject* self)
{
    QTextTableCellFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextTableCellFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bottomPadding()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextTableCellFormat*>(cppSelf)->bottomPadding();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextTableCellFormatFunc_isValid(PyObject* self)
{
    QTextTableCellFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextTableCellFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QTextTableCellFormat*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextTableCellFormatFunc_leftPadding(PyObject* self)
{
    QTextTableCellFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextTableCellFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // leftPadding()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextTableCellFormat*>(cppSelf)->leftPadding();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextTableCellFormatFunc_rightPadding(PyObject* self)
{
    QTextTableCellFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextTableCellFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rightPadding()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextTableCellFormat*>(cppSelf)->rightPadding();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextTableCellFormatFunc_setBottomPadding(PyObject* self, PyObject* arg)
{
    QTextTableCellFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextTableCellFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBottomPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormatFunc_setBottomPadding_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBottomPadding(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBottomPadding(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextTableCellFormatFunc_setBottomPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableCellFormat.setBottomPadding", overloads);
        return 0;
}

static PyObject* Sbk_QTextTableCellFormatFunc_setLeftPadding(PyObject* self, PyObject* arg)
{
    QTextTableCellFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextTableCellFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeftPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLeftPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormatFunc_setLeftPadding_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLeftPadding(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLeftPadding(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextTableCellFormatFunc_setLeftPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableCellFormat.setLeftPadding", overloads);
        return 0;
}

static PyObject* Sbk_QTextTableCellFormatFunc_setPadding(PyObject* self, PyObject* arg)
{
    QTextTableCellFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextTableCellFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormatFunc_setPadding_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPadding(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPadding(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextTableCellFormatFunc_setPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableCellFormat.setPadding", overloads);
        return 0;
}

static PyObject* Sbk_QTextTableCellFormatFunc_setRightPadding(PyObject* self, PyObject* arg)
{
    QTextTableCellFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextTableCellFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRightPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRightPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormatFunc_setRightPadding_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRightPadding(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRightPadding(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextTableCellFormatFunc_setRightPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableCellFormat.setRightPadding", overloads);
        return 0;
}

static PyObject* Sbk_QTextTableCellFormatFunc_setTopPadding(PyObject* self, PyObject* arg)
{
    QTextTableCellFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextTableCellFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopPadding(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTopPadding(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextTableCellFormatFunc_setTopPadding_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTopPadding(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTopPadding(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextTableCellFormatFunc_setTopPadding_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextTableCellFormat.setTopPadding", overloads);
        return 0;
}

static PyObject* Sbk_QTextTableCellFormatFunc_topPadding(PyObject* self)
{
    QTextTableCellFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextTableCellFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // topPadding()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QTextTableCellFormat*>(cppSelf)->topPadding();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTextTableCellFormat___copy__(PyObject *self)
{
        QTextTableCellFormat* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextTableCellFormat*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextTableCellFormat* copy = new QTextTableCellFormat(*cppSelf);
        pyResult = Shiboken::Converter<QTextTableCellFormat*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextTableCellFormat_methods[] = {
    {"bottomPadding", (PyCFunction)Sbk_QTextTableCellFormatFunc_bottomPadding, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QTextTableCellFormatFunc_isValid, METH_NOARGS},
    {"leftPadding", (PyCFunction)Sbk_QTextTableCellFormatFunc_leftPadding, METH_NOARGS},
    {"rightPadding", (PyCFunction)Sbk_QTextTableCellFormatFunc_rightPadding, METH_NOARGS},
    {"setBottomPadding", (PyCFunction)Sbk_QTextTableCellFormatFunc_setBottomPadding, METH_O},
    {"setLeftPadding", (PyCFunction)Sbk_QTextTableCellFormatFunc_setLeftPadding, METH_O},
    {"setPadding", (PyCFunction)Sbk_QTextTableCellFormatFunc_setPadding, METH_O},
    {"setRightPadding", (PyCFunction)Sbk_QTextTableCellFormatFunc_setRightPadding, METH_O},
    {"setTopPadding", (PyCFunction)Sbk_QTextTableCellFormatFunc_setTopPadding, METH_O},
    {"topPadding", (PyCFunction)Sbk_QTextTableCellFormatFunc_topPadding, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextTableCellFormat___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextTableCellFormat_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextTableCellFormat",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextTableCellFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextTableCellFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextTableCellFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTTABLECELLFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextTableCellFormat_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextTableCellFormat_Type);
    Sbk_QTextTableCellFormat_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTEXTCHARFORMAT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextTableCellFormat_Type, &Shiboken::callCppDestructor<QTextTableCellFormat >);
    Py_INCREF((PyObject*)&Sbk_QTextTableCellFormat_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextTableCellFormat_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextTableCellFormat_Type, "QTextTableCellFormat");
    PyModule_AddObject(module, "QTextTableCellFormat",
        ((PyObject*)&Sbk_QTextTableCellFormat_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTextTableCellFormat >("QTextTableCellFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextTableCellFormat >("QTextTableCellFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextTableCellFormat >(typeid(QTextTableCellFormat).name());
    qRegisterMetaType< ::QTextTableCellFormat >("QTextTableCellFormat");
}

