/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_qtgui_python.h"

#include <qrgb.h>


// Extra includes

    // Begin code injection

    PyObject* moduleQtGui;

    // End of code injection

// Global functions ------------------------------------------------------------
static PyObject* SbkQtGuiModule_qAlpha(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qAlpha(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qAlpha(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtGuiModule_qAlpha_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // qAlpha(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = qAlpha(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtGuiModule_qAlpha_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qAlpha", overloads);
        return 0;
}

static PyObject* SbkQtGuiModule_qBlue(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qBlue(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qBlue(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtGuiModule_qBlue_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // qBlue(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = qBlue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtGuiModule_qBlue_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qBlue", overloads);
        return 0;
}

static PyObject* SbkQtGuiModule_qGray(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto SbkQtGuiModule_qGray_TypeError;

    if (!PyArg_UnpackTuple(args, "qGray", 1, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: qGray(uint)
    // 1: qGray(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // qGray(int,int,int)
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // qGray(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtGuiModule_qGray_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // qGray(uint)
            {
                unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // qGray(uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = qGray(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // qGray(int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // qGray(int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = qGray(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtGuiModule_qGray_TypeError:
        const char* overloads[] = {"unsigned int", "int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qGray", overloads);
        return 0;
}

static PyObject* SbkQtGuiModule_qGreen(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qGreen(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qGreen(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtGuiModule_qGreen_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // qGreen(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = qGreen(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtGuiModule_qGreen_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qGreen", overloads);
        return 0;
}

static PyObject* SbkQtGuiModule_qIsGray(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qIsGray(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qIsGray(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtGuiModule_qIsGray_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // qIsGray(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = qIsGray(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtGuiModule_qIsGray_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qIsGray", overloads);
        return 0;
}

static PyObject* SbkQtGuiModule_qRed(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: qRed(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // qRed(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtGuiModule_qRed_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // qRed(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = qRed(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtGuiModule_qRed_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "qRed", overloads);
        return 0;
}

static PyObject* SbkQtGuiModule_qRgb(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "qRgb", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: qRgb(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // qRgb(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtGuiModule_qRgb_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // qRgb(int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = qRgb(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtGuiModule_qRgb_TypeError:
        const char* overloads[] = {"int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qRgb", overloads);
        return 0;
}

static PyObject* SbkQtGuiModule_qRgba(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "qRgba", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: qRgba(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // qRgba(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto SbkQtGuiModule_qRgba_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // qRgba(int,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = qRgba(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    SbkQtGuiModule_qRgba_TypeError:
        const char* overloads[] = {"int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "qRgba", overloads);
        return 0;
}


static PyMethodDef QtGui_methods[] = {
    {"qAlpha", (PyCFunction)SbkQtGuiModule_qAlpha, METH_O},
    {"qBlue", (PyCFunction)SbkQtGuiModule_qBlue, METH_O},
    {"qGray", (PyCFunction)SbkQtGuiModule_qGray, METH_VARARGS},
    {"qGreen", (PyCFunction)SbkQtGuiModule_qGreen, METH_O},
    {"qIsGray", (PyCFunction)SbkQtGuiModule_qIsGray, METH_O},
    {"qRed", (PyCFunction)SbkQtGuiModule_qRed, METH_O},
    {"qRgb", (PyCFunction)SbkQtGuiModule_qRgb, METH_VARARGS},
    {"qRgba", (PyCFunction)SbkQtGuiModule_qRgba, METH_VARARGS},
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QMatrix2x4(PyObject* module);
void init_QMatrix2x3(PyObject* module);
void init_QMatrix2x2(PyObject* module);
void init_QMatrix3x4(PyObject* module);
void init_QMatrix3x3(PyObject* module);
void init_QMatrix3x2(PyObject* module);
void init_QMatrix4x3(PyObject* module);
void init_QMatrix4x2(PyObject* module);
void init_QX11Info(PyObject* module);
void init_QInputContextFactory(PyObject* module);
void init_QTreeWidgetItem(PyObject* module);
void init_QTreeWidgetItemIterator(PyObject* module);
void init_QTableWidgetItem(PyObject* module);
void init_QTableWidgetSelectionRange(PyObject* module);
void init_QStandardItem(PyObject* module);
void init_QListWidgetItem(PyObject* module);
void init_QItemEditorFactory(PyObject* module);
void init_QItemEditorCreatorBase(PyObject* module);
void init_QFileIconProvider(PyObject* module);
void init_QStyleFactory(PyObject* module);
void init_QItemSelection(PyObject* module);
void init_QItemSelectionRange(PyObject* module);
void init_QUndoCommand(PyObject* module);
void init_QDesktopServices(PyObject* module);
void init_QStyleOption(PyObject* module);
void init_QStyleOptionViewItem(PyObject* module);
void init_QStyleOptionViewItemV2(PyObject* module);
void init_QStyleOptionViewItemV3(PyObject* module);
void init_QStyleOptionViewItemV4(PyObject* module);
void init_QStyleOptionFrame(PyObject* module);
void init_QStyleOptionFrameV2(PyObject* module);
void init_QStyleOptionFrameV3(PyObject* module);
void init_QStyleHintReturn(PyObject* module);
void init_QStyleHintReturnVariant(PyObject* module);
void init_QStyleHintReturnMask(PyObject* module);
void init_QStyleOptionFocusRect(PyObject* module);
void init_QStyleOptionGraphicsItem(PyObject* module);
void init_QStyleOptionDockWidget(PyObject* module);
void init_QStyleOptionDockWidgetV2(PyObject* module);
void init_QStyleOptionMenuItem(PyObject* module);
void init_QStyleOptionProgressBar(PyObject* module);
void init_QStyleOptionProgressBarV2(PyObject* module);
void init_QStyleOptionToolBar(PyObject* module);
void init_QStyleOptionTab(PyObject* module);
void init_QStyleOptionTabV2(PyObject* module);
void init_QStyleOptionTabV3(PyObject* module);
void init_QStyleOptionComplex(PyObject* module);
void init_QStyleOptionSizeGrip(PyObject* module);
void init_QStyleOptionGroupBox(PyObject* module);
void init_QStyleOptionTitleBar(PyObject* module);
void init_QStyleOptionComboBox(PyObject* module);
void init_QStyleOptionToolButton(PyObject* module);
void init_QStyleOptionSpinBox(PyObject* module);
void init_QStyleOptionSlider(PyObject* module);
void init_QStyleOptionButton(PyObject* module);
void init_QStyleOptionRubberBand(PyObject* module);
void init_QStyleOptionHeader(PyObject* module);
void init_QStyleOptionToolBox(PyObject* module);
void init_QStyleOptionToolBoxV2(PyObject* module);
void init_QStyleOptionTabBarBase(PyObject* module);
void init_QStyleOptionTabBarBaseV2(PyObject* module);
void init_QStyleOptionTabWidgetFrame(PyObject* module);
void init_QVector2D(PyObject* module);
void init_QTextTableCell(PyObject* module);
void init_QTextDocumentFragment(PyObject* module);
void init_QTextFragment(PyObject* module);
void init_QTextBlock(PyObject* module);
void init_QTextBlock_iterator(PyObject* module);
void init_QTextBlockUserData(PyObject* module);
void init_QFontDatabase(PyObject* module);
void init_QTextObjectInterface(PyObject* module);
void init_QTextCursor(PyObject* module);
void init_QTextLine(PyObject* module);
void init_QTextInlineObject(PyObject* module);
void init_QTextFormat(PyObject* module);
void init_QTextFrameFormat(PyObject* module);
void init_QTextTableFormat(PyObject* module);
void init_QTextListFormat(PyObject* module);
void init_QTextBlockFormat(PyObject* module);
void init_QTextLength(PyObject* module);
void init_QPixmapCache(PyObject* module);
void init_QPictureIO(PyObject* module);
void init_QImageIOHandler(PyObject* module);
void init_QIconEngine(PyObject* module);
void init_QMatrix4x4(PyObject* module);
void init_QQuaternion(PyObject* module);
void init_QVector4D(PyObject* module);
void init_QVector3D(PyObject* module);
void init_QWhatsThis(PyObject* module);
void init_QToolTip(PyObject* module);
void init_QGestureRecognizer(PyObject* module);
void init_QLayoutItem(PyObject* module);
void init_QWidgetItem(PyObject* module);
void init_QKeySequence(PyObject* module);
void init_QCursor(PyObject* module);
void init_QSizePolicy(PyObject* module);
void init_QSpacerItem(PyObject* module);
void init_QPalette(PyObject* module);
void init_QPrinterInfo(PyObject* module);
void init_QPrintEngine(PyObject* module);
void init_QPaintEngineState(PyObject* module);
void init_QPaintEngine(PyObject* module);
void init_QTextItem(PyObject* module);
void init_QFontMetricsF(PyObject* module);
void init_QFontMetrics(PyObject* module);
void init_QFontInfo(PyObject* module);
void init_QFont(PyObject* module);
void init_QTextCharFormat(PyObject* module);
void init_QTextTableCellFormat(PyObject* module);
void init_QTextImageFormat(PyObject* module);
void init_QPen(PyObject* module);
void init_QTextOption(PyObject* module);
void init_QTextOption_Tab(PyObject* module);
void init_QTileRules(PyObject* module);
void init_QGradient(PyObject* module);
void init_QConicalGradient(PyObject* module);
void init_QRadialGradient(PyObject* module);
void init_QLinearGradient(PyObject* module);
void init_QBrush(PyObject* module);
void init_QPaintDevice(PyObject* module);
void init_QPicture(PyObject* module);
void init_QPrinter(PyObject* module);
void init_QTransform(PyObject* module);
void init_QPainterPathStroker(PyObject* module);
void init_QMatrix(PyObject* module);
void init_QPainterPath(PyObject* module);
void init_QPainterPath_Element(PyObject* module);
void init_QPolygonF(PyObject* module);
void init_QPolygon(PyObject* module);
void init_QColor(PyObject* module);
void init_QTextLayout(PyObject* module);
void init_QTextLayout_FormatRange(PyObject* module);
void init_QPixmap(PyObject* module);
void init_QImage(PyObject* module);
void init_QBitmap(PyObject* module);
void init_QGraphicsLayoutItem(PyObject* module);
void init_QGraphicsLayout(PyObject* module);
void init_QGraphicsLinearLayout(PyObject* module);
void init_QGraphicsGridLayout(PyObject* module);
void init_QGraphicsAnchorLayout(PyObject* module);
void init_QGraphicsItem(PyObject* module);
void init_QAbstractGraphicsShapeItem(PyObject* module);
void init_QGraphicsRectItem(PyObject* module);
void init_QGraphicsPathItem(PyObject* module);
void init_QIcon(PyObject* module);
void init_QIconEngineV2(PyObject* module);
void init_QGraphicsItemGroup(PyObject* module);
void init_QGraphicsSimpleTextItem(PyObject* module);
void init_QGraphicsPixmapItem(PyObject* module);
void init_QGraphicsLineItem(PyObject* module);
void init_QGraphicsPolygonItem(PyObject* module);
void init_QGraphicsEllipseItem(PyObject* module);
void init_QPainter(PyObject* module);
void init_QStylePainter(PyObject* module);
void init_QMouseEventTransition(PyObject* module);
void init_QKeyEventTransition(PyObject* module);
void init_QInputMethodEvent(PyObject* module);
void init_QInputMethodEvent_Attribute(PyObject* module);
void init_QHideEvent(PyObject* module);
void init_QShowEvent(PyObject* module);
void init_QIconDragEvent(PyObject* module);
void init_QCloseEvent(PyObject* module);
void init_QResizeEvent(PyObject* module);
void init_QAccessibleEvent(PyObject* module);
void init_QMoveEvent(PyObject* module);
void init_QPaintEvent(PyObject* module);
void init_QFocusEvent(PyObject* module);
void init_QHoverEvent(PyObject* module);
void init_QInputEvent(PyObject* module);
void init_QMouseEvent(PyObject* module);
void init_QTouchEvent(PyObject* module);
void init_QTouchEvent_TouchPoint(PyObject* module);
void init_QContextMenuEvent(PyObject* module);
void init_QKeyEvent(PyObject* module);
void init_QTabletEvent(PyObject* module);
void init_QWheelEvent(PyObject* module);
void init_QGraphicsSceneEvent(PyObject* module);
void init_QGraphicsSceneMoveEvent(PyObject* module);
void init_QGraphicsSceneResizeEvent(PyObject* module);
void init_QGraphicsSceneDragDropEvent(PyObject* module);
void init_QGraphicsSceneHelpEvent(PyObject* module);
void init_QGraphicsSceneHoverEvent(PyObject* module);
void init_QGraphicsSceneContextMenuEvent(PyObject* module);
void init_QGraphicsSceneWheelEvent(PyObject* module);
void init_QGraphicsSceneMouseEvent(PyObject* module);
void init_QGestureEvent(PyObject* module);
void init_QWindowStateChangeEvent(PyObject* module);
void init_QClipboardEvent(PyObject* module);
void init_QShortcutEvent(PyObject* module);
void init_QToolBarChangeEvent(PyObject* module);
void init_QFileOpenEvent(PyObject* module);
void init_QActionEvent(PyObject* module);
void init_QWhatsThisClickedEvent(PyObject* module);
void init_QStatusTipEvent(PyObject* module);
void init_QHelpEvent(PyObject* module);
void init_QDragLeaveEvent(PyObject* module);
void init_QDropEvent(PyObject* module);
void init_QDragMoveEvent(PyObject* module);
void init_QDragEnterEvent(PyObject* module);
void init_QFileSystemModel(PyObject* module);
void init_QAbstractProxyModel(PyObject* module);
void init_QStringListModel(PyObject* module);
void init_QStandardItemModel(PyObject* module);
void init_QSortFilterProxyModel(PyObject* module);
void init_QProxyModel(PyObject* module);
void init_QDirModel(PyObject* module);
void init_QApplication(PyObject* module);
void init_QRegion(PyObject* module);
void init_QItemSelectionModel(PyObject* module);
void init_QUndoStack(PyObject* module);
void init_QUndoGroup(PyObject* module);
void init_QTextObject(PyObject* module);
void init_QTextFrame(PyObject* module);
void init_QTextTable(PyObject* module);
void init_QTextFrame_iterator(PyObject* module);
void init_QTextBlockGroup(PyObject* module);
void init_QTextList(PyObject* module);
void init_QGraphicsObject(PyObject* module);
void init_QGraphicsWidget(PyObject* module);
void init_QGraphicsProxyWidget(PyObject* module);
void init_QGraphicsTextItem(PyObject* module);
void init_QSystemTrayIcon(PyObject* module);
void init_QCompleter(PyObject* module);
void init_QGraphicsTransform(PyObject* module);
void init_QGraphicsRotation(PyObject* module);
void init_QGraphicsScale(PyObject* module);
void init_QAbstractTextDocumentLayout(PyObject* module);
void init_QAbstractTextDocumentLayout_Selection(PyObject* module);
void init_QAbstractTextDocumentLayout_PaintContext(PyObject* module);
void init_QPlainTextDocumentLayout(PyObject* module);
void init_QSound(PyObject* module);
void init_QShortcut(PyObject* module);
void init_QSessionManager(PyObject* module);
void init_QPyTextObject(PyObject* module);
void init_QAbstractItemDelegate(PyObject* module);
void init_QStyledItemDelegate(PyObject* module);
void init_QItemDelegate(PyObject* module);
void init_QDrag(PyObject* module);
void init_QGesture(PyObject* module);
void init_QPanGesture(PyObject* module);
void init_QTapGesture(PyObject* module);
void init_QTapAndHoldGesture(PyObject* module);
void init_QSwipeGesture(PyObject* module);
void init_QPinchGesture(PyObject* module);
void init_QClipboard(PyObject* module);
void init_QDataWidgetMapper(PyObject* module);
void init_QButtonGroup(PyObject* module);
void init_QGraphicsScene(PyObject* module);
void init_QLayout(PyObject* module);
void init_QFormLayout(PyObject* module);
void init_QBoxLayout(PyObject* module);
void init_QVBoxLayout(PyObject* module);
void init_QHBoxLayout(PyObject* module);
void init_QStackedLayout(PyObject* module);
void init_QGridLayout(PyObject* module);
void init_QGraphicsItemAnimation(PyObject* module);
void init_QValidator(PyObject* module);
void init_QRegExpValidator(PyObject* module);
void init_QDoubleValidator(PyObject* module);
void init_QIntValidator(PyObject* module);
void init_QGraphicsAnchor(PyObject* module);
void init_QInputContext(PyObject* module);
void init_QActionGroup(PyObject* module);
void init_QAction(PyObject* module);
void init_QWidgetAction(PyObject* module);
void init_QWidget(PyObject* module);
void init_QStatusBar(PyObject* module);
void init_QSplitterHandle(PyObject* module);
void init_QSplashScreen(PyObject* module);
void init_QFrame(PyObject* module);
void init_QSplitter(PyObject* module);
void init_QStackedWidget(PyObject* module);
void init_QAbstractScrollArea(PyObject* module);
void init_QGraphicsView(PyObject* module);
void init_QScrollArea(PyObject* module);
void init_QSizeGrip(PyObject* module);
void init_QProgressBar(PyObject* module);
void init_QPrintPreviewWidget(PyObject* module);
void init_QPlainTextEdit(PyObject* module);
void init_QTextEdit(PyObject* module);
void init_QTextEdit_ExtraSelection(PyObject* module);
void init_QMenuBar(PyObject* module);
void init_QMenu(PyObject* module);
void init_QMdiSubWindow(PyObject* module);
void init_QMdiArea(PyObject* module);
void init_QMainWindow(PyObject* module);
void init_QLineEdit(PyObject* module);
void init_QLCDNumber(PyObject* module);
void init_QLabel(PyObject* module);
void init_QGroupBox(PyObject* module);
void init_QFocusFrame(PyObject* module);
void init_QDockWidget(PyObject* module);
void init_QDialogButtonBox(PyObject* module);
void init_QComboBox(PyObject* module);
void init_QFontComboBox(PyObject* module);
void init_QX11EmbedContainer(PyObject* module);
void init_QX11EmbedWidget(PyObject* module);
void init_QWizardPage(PyObject* module);
void init_QRubberBand(PyObject* module);
void init_QTabWidget(PyObject* module);
void init_QTabBar(PyObject* module);
void init_QCalendarWidget(PyObject* module);
void init_QAbstractSpinBox(PyObject* module);
void init_QDoubleSpinBox(PyObject* module);
void init_QSpinBox(PyObject* module);
void init_QDateTimeEdit(PyObject* module);
void init_QDateEdit(PyObject* module);
void init_QTimeEdit(PyObject* module);
void init_QAbstractSlider(PyObject* module);
void init_QScrollBar(PyObject* module);
void init_QSlider(PyObject* module);
void init_QDial(PyObject* module);
void init_QAbstractButton(PyObject* module);
void init_QRadioButton(PyObject* module);
void init_QCheckBox(PyObject* module);
void init_QPushButton(PyObject* module);
void init_QCommandLinkButton(PyObject* module);
void init_QDesktopWidget(PyObject* module);
void init_QDialog(PyObject* module);
void init_QFontDialog(PyObject* module);
void init_QErrorMessage(PyObject* module);
void init_QColorDialog(PyObject* module);
void init_QAbstractPrintDialog(PyObject* module);
void init_QPrintDialog(PyObject* module);
void init_QAbstractPageSetupDialog(PyObject* module);
void init_QPageSetupDialog(PyObject* module);
void init_QFileDialog(PyObject* module);
void init_QWizard(PyObject* module);
void init_QPrintPreviewDialog(PyObject* module);
void init_QProgressDialog(PyObject* module);
void init_QMessageBox(PyObject* module);
void init_QInputDialog(PyObject* module);
void init_QAbstractItemView(PyObject* module);
void init_QColumnView(PyObject* module);
void init_QTableView(PyObject* module);
void init_QTableWidget(PyObject* module);
void init_QHeaderView(PyObject* module);
void init_QListView(PyObject* module);
void init_QListWidget(PyObject* module);
void init_QUndoView(PyObject* module);
void init_QTreeView(PyObject* module);
void init_QTreeWidget(PyObject* module);
void init_QWorkspace(PyObject* module);
void init_QToolButton(PyObject* module);
void init_QToolBox(PyObject* module);
void init_QToolBar(PyObject* module);
void init_QTextBrowser(PyObject* module);
void init_QGraphicsEffect(PyObject* module);
void init_QGraphicsOpacityEffect(PyObject* module);
void init_QGraphicsDropShadowEffect(PyObject* module);
void init_QGraphicsBlurEffect(PyObject* module);
void init_QGraphicsColorizeEffect(PyObject* module);
void init_QSyntaxHighlighter(PyObject* module);
void init_QStyle(PyObject* module);
void init_QCommonStyle(PyObject* module);
void init_QWindowsStyle(PyObject* module);
void init_QPlastiqueStyle(PyObject* module);
void init_QCleanlooksStyle(PyObject* module);
void init_QGtkStyle(PyObject* module);
void init_QMotifStyle(PyObject* module);
void init_QCDEStyle(PyObject* module);
void init_QTextDocument(PyObject* module);
void init_QMovie(PyObject* module);
void init_QImageWriter(PyObject* module);
void init_QImageReader(PyObject* module);

PyTypeObject** SbkPySide_QtGuiTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------
// Extended Converters
static bool ExtendedIsConvertible_PySide_QtCore_QPointF(PyObject* pyobj)
{
    return Shiboken::Converter< ::QPainterPath::Element >::isConvertible(pyobj);
}
static void* ExtendedToCpp_PySide_QtCore_QPointF(PyObject* pyobj)
{
    void* cptr = 0;
    if (Shiboken::Converter< ::QPainterPath::Element >::isConvertible(pyobj))
        cptr = new QPointF(Shiboken::Converter< ::QPainterPath::Element >::toCpp(pyobj));
    return cptr;
}


#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initQtGui()
{

    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    Shiboken::init();
    PyObject* module = Py_InitModule("QtGui", QtGui_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_QtGui_IDX_COUNT];
    SbkPySide_QtGuiTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_QMatrix2x4(module);
    init_QMatrix2x3(module);
    init_QMatrix2x2(module);
    init_QMatrix3x4(module);
    init_QMatrix3x3(module);
    init_QMatrix3x2(module);
    init_QMatrix4x3(module);
    init_QMatrix4x2(module);
    init_QX11Info(module);
    init_QInputContextFactory(module);
    init_QTreeWidgetItem(module);
    init_QTreeWidgetItemIterator(module);
    init_QTableWidgetItem(module);
    init_QTableWidgetSelectionRange(module);
    init_QStandardItem(module);
    init_QListWidgetItem(module);
    init_QItemEditorFactory(module);
    init_QItemEditorCreatorBase(module);
    init_QFileIconProvider(module);
    init_QStyleFactory(module);
    init_QItemSelection(module);
    init_QItemSelectionRange(module);
    init_QUndoCommand(module);
    init_QDesktopServices(module);
    init_QStyleOption(module);
    init_QStyleOptionViewItem(module);
    init_QStyleOptionViewItemV2(module);
    init_QStyleOptionViewItemV3(module);
    init_QStyleOptionViewItemV4(module);
    init_QStyleOptionFrame(module);
    init_QStyleOptionFrameV2(module);
    init_QStyleOptionFrameV3(module);
    init_QStyleHintReturn(module);
    init_QStyleHintReturnVariant(module);
    init_QStyleHintReturnMask(module);
    init_QStyleOptionFocusRect(module);
    init_QStyleOptionGraphicsItem(module);
    init_QStyleOptionDockWidget(module);
    init_QStyleOptionDockWidgetV2(module);
    init_QStyleOptionMenuItem(module);
    init_QStyleOptionProgressBar(module);
    init_QStyleOptionProgressBarV2(module);
    init_QStyleOptionToolBar(module);
    init_QStyleOptionTab(module);
    init_QStyleOptionTabV2(module);
    init_QStyleOptionTabV3(module);
    init_QStyleOptionComplex(module);
    init_QStyleOptionSizeGrip(module);
    init_QStyleOptionGroupBox(module);
    init_QStyleOptionTitleBar(module);
    init_QStyleOptionComboBox(module);
    init_QStyleOptionToolButton(module);
    init_QStyleOptionSpinBox(module);
    init_QStyleOptionSlider(module);
    init_QStyleOptionButton(module);
    init_QStyleOptionRubberBand(module);
    init_QStyleOptionHeader(module);
    init_QStyleOptionToolBox(module);
    init_QStyleOptionToolBoxV2(module);
    init_QStyleOptionTabBarBase(module);
    init_QStyleOptionTabBarBaseV2(module);
    init_QStyleOptionTabWidgetFrame(module);
    init_QVector2D(module);
    init_QTextTableCell(module);
    init_QTextDocumentFragment(module);
    init_QTextFragment(module);
    init_QTextBlock(module);
    init_QTextBlock_iterator(SbkPySide_QtGuiTypes[SBK_QTEXTBLOCK_IDX]->tp_dict);
    init_QTextBlockUserData(module);
    init_QFontDatabase(module);
    init_QTextObjectInterface(module);
    init_QTextCursor(module);
    init_QTextLine(module);
    init_QTextInlineObject(module);
    init_QTextFormat(module);
    init_QTextFrameFormat(module);
    init_QTextTableFormat(module);
    init_QTextListFormat(module);
    init_QTextBlockFormat(module);
    init_QTextLength(module);
    init_QPixmapCache(module);
    init_QPictureIO(module);
    init_QImageIOHandler(module);
    init_QIconEngine(module);
    init_QMatrix4x4(module);
    init_QQuaternion(module);
    init_QVector4D(module);
    init_QVector3D(module);
    init_QWhatsThis(module);
    init_QToolTip(module);
    init_QGestureRecognizer(module);
    init_QLayoutItem(module);
    init_QWidgetItem(module);
    init_QKeySequence(module);
    init_QCursor(module);
    init_QSizePolicy(module);
    init_QSpacerItem(module);
    init_QPalette(module);
    init_QPrinterInfo(module);
    init_QPrintEngine(module);
    init_QPaintEngineState(module);
    init_QPaintEngine(module);
    init_QTextItem(module);
    init_QFontMetricsF(module);
    init_QFontMetrics(module);
    init_QFontInfo(module);
    init_QFont(module);
    init_QTextCharFormat(module);
    init_QTextTableCellFormat(module);
    init_QTextImageFormat(module);
    init_QPen(module);
    init_QTextOption(module);
    init_QTextOption_Tab(SbkPySide_QtGuiTypes[SBK_QTEXTOPTION_IDX]->tp_dict);
    init_QTileRules(module);
    init_QGradient(module);
    init_QConicalGradient(module);
    init_QRadialGradient(module);
    init_QLinearGradient(module);
    init_QBrush(module);
    init_QPaintDevice(module);
    init_QPicture(module);
    init_QPrinter(module);
    init_QTransform(module);
    init_QPainterPathStroker(module);
    init_QMatrix(module);
    init_QPainterPath(module);
    init_QPainterPath_Element(SbkPySide_QtGuiTypes[SBK_QPAINTERPATH_IDX]->tp_dict);
    init_QPolygonF(module);
    init_QPolygon(module);
    init_QColor(module);
    init_QTextLayout(module);
    init_QTextLayout_FormatRange(SbkPySide_QtGuiTypes[SBK_QTEXTLAYOUT_IDX]->tp_dict);
    init_QPixmap(module);
    init_QImage(module);
    init_QBitmap(module);
    init_QGraphicsLayoutItem(module);
    init_QGraphicsLayout(module);
    init_QGraphicsLinearLayout(module);
    init_QGraphicsGridLayout(module);
    init_QGraphicsAnchorLayout(module);
    init_QGraphicsItem(module);
    init_QAbstractGraphicsShapeItem(module);
    init_QGraphicsRectItem(module);
    init_QGraphicsPathItem(module);
    init_QIcon(module);
    init_QIconEngineV2(module);
    init_QGraphicsItemGroup(module);
    init_QGraphicsSimpleTextItem(module);
    init_QGraphicsPixmapItem(module);
    init_QGraphicsLineItem(module);
    init_QGraphicsPolygonItem(module);
    init_QGraphicsEllipseItem(module);
    init_QPainter(module);
    init_QStylePainter(module);
    init_QMouseEventTransition(module);
    init_QKeyEventTransition(module);
    init_QInputMethodEvent(module);
    init_QInputMethodEvent_Attribute(SbkPySide_QtGuiTypes[SBK_QINPUTMETHODEVENT_IDX]->tp_dict);
    init_QHideEvent(module);
    init_QShowEvent(module);
    init_QIconDragEvent(module);
    init_QCloseEvent(module);
    init_QResizeEvent(module);
    init_QAccessibleEvent(module);
    init_QMoveEvent(module);
    init_QPaintEvent(module);
    init_QFocusEvent(module);
    init_QHoverEvent(module);
    init_QInputEvent(module);
    init_QMouseEvent(module);
    init_QTouchEvent(module);
    init_QTouchEvent_TouchPoint(SbkPySide_QtGuiTypes[SBK_QTOUCHEVENT_IDX]->tp_dict);
    init_QContextMenuEvent(module);
    init_QKeyEvent(module);
    init_QTabletEvent(module);
    init_QWheelEvent(module);
    init_QGraphicsSceneEvent(module);
    init_QGraphicsSceneMoveEvent(module);
    init_QGraphicsSceneResizeEvent(module);
    init_QGraphicsSceneDragDropEvent(module);
    init_QGraphicsSceneHelpEvent(module);
    init_QGraphicsSceneHoverEvent(module);
    init_QGraphicsSceneContextMenuEvent(module);
    init_QGraphicsSceneWheelEvent(module);
    init_QGraphicsSceneMouseEvent(module);
    init_QGestureEvent(module);
    init_QWindowStateChangeEvent(module);
    init_QClipboardEvent(module);
    init_QShortcutEvent(module);
    init_QToolBarChangeEvent(module);
    init_QFileOpenEvent(module);
    init_QActionEvent(module);
    init_QWhatsThisClickedEvent(module);
    init_QStatusTipEvent(module);
    init_QHelpEvent(module);
    init_QDragLeaveEvent(module);
    init_QDropEvent(module);
    init_QDragMoveEvent(module);
    init_QDragEnterEvent(module);
    init_QFileSystemModel(module);
    init_QAbstractProxyModel(module);
    init_QStringListModel(module);
    init_QStandardItemModel(module);
    init_QSortFilterProxyModel(module);
    init_QProxyModel(module);
    init_QDirModel(module);
    init_QApplication(module);
    init_QRegion(module);
    init_QItemSelectionModel(module);
    init_QUndoStack(module);
    init_QUndoGroup(module);
    init_QTextObject(module);
    init_QTextFrame(module);
    init_QTextTable(module);
    init_QTextFrame_iterator(SbkPySide_QtGuiTypes[SBK_QTEXTFRAME_IDX]->tp_dict);
    init_QTextBlockGroup(module);
    init_QTextList(module);
    init_QGraphicsObject(module);
    init_QGraphicsWidget(module);
    init_QGraphicsProxyWidget(module);
    init_QGraphicsTextItem(module);
    init_QSystemTrayIcon(module);
    init_QCompleter(module);
    init_QGraphicsTransform(module);
    init_QGraphicsRotation(module);
    init_QGraphicsScale(module);
    init_QAbstractTextDocumentLayout(module);
    init_QAbstractTextDocumentLayout_Selection(SbkPySide_QtGuiTypes[SBK_QABSTRACTTEXTDOCUMENTLAYOUT_IDX]->tp_dict);
    init_QAbstractTextDocumentLayout_PaintContext(SbkPySide_QtGuiTypes[SBK_QABSTRACTTEXTDOCUMENTLAYOUT_IDX]->tp_dict);
    init_QPlainTextDocumentLayout(module);
    init_QSound(module);
    init_QShortcut(module);
    init_QSessionManager(module);
    init_QPyTextObject(module);
    init_QAbstractItemDelegate(module);
    init_QStyledItemDelegate(module);
    init_QItemDelegate(module);
    init_QDrag(module);
    init_QGesture(module);
    init_QPanGesture(module);
    init_QTapGesture(module);
    init_QTapAndHoldGesture(module);
    init_QSwipeGesture(module);
    init_QPinchGesture(module);
    init_QClipboard(module);
    init_QDataWidgetMapper(module);
    init_QButtonGroup(module);
    init_QGraphicsScene(module);
    init_QLayout(module);
    init_QFormLayout(module);
    init_QBoxLayout(module);
    init_QVBoxLayout(module);
    init_QHBoxLayout(module);
    init_QStackedLayout(module);
    init_QGridLayout(module);
    init_QGraphicsItemAnimation(module);
    init_QValidator(module);
    init_QRegExpValidator(module);
    init_QDoubleValidator(module);
    init_QIntValidator(module);
    init_QGraphicsAnchor(module);
    init_QInputContext(module);
    init_QActionGroup(module);
    init_QAction(module);
    init_QWidgetAction(module);
    init_QWidget(module);
    init_QStatusBar(module);
    init_QSplitterHandle(module);
    init_QSplashScreen(module);
    init_QFrame(module);
    init_QSplitter(module);
    init_QStackedWidget(module);
    init_QAbstractScrollArea(module);
    init_QGraphicsView(module);
    init_QScrollArea(module);
    init_QSizeGrip(module);
    init_QProgressBar(module);
    init_QPrintPreviewWidget(module);
    init_QPlainTextEdit(module);
    init_QTextEdit(module);
    init_QTextEdit_ExtraSelection(SbkPySide_QtGuiTypes[SBK_QTEXTEDIT_IDX]->tp_dict);
    init_QMenuBar(module);
    init_QMenu(module);
    init_QMdiSubWindow(module);
    init_QMdiArea(module);
    init_QMainWindow(module);
    init_QLineEdit(module);
    init_QLCDNumber(module);
    init_QLabel(module);
    init_QGroupBox(module);
    init_QFocusFrame(module);
    init_QDockWidget(module);
    init_QDialogButtonBox(module);
    init_QComboBox(module);
    init_QFontComboBox(module);
    init_QX11EmbedContainer(module);
    init_QX11EmbedWidget(module);
    init_QWizardPage(module);
    init_QRubberBand(module);
    init_QTabWidget(module);
    init_QTabBar(module);
    init_QCalendarWidget(module);
    init_QAbstractSpinBox(module);
    init_QDoubleSpinBox(module);
    init_QSpinBox(module);
    init_QDateTimeEdit(module);
    init_QDateEdit(module);
    init_QTimeEdit(module);
    init_QAbstractSlider(module);
    init_QScrollBar(module);
    init_QSlider(module);
    init_QDial(module);
    init_QAbstractButton(module);
    init_QRadioButton(module);
    init_QCheckBox(module);
    init_QPushButton(module);
    init_QCommandLinkButton(module);
    init_QDesktopWidget(module);
    init_QDialog(module);
    init_QFontDialog(module);
    init_QErrorMessage(module);
    init_QColorDialog(module);
    init_QAbstractPrintDialog(module);
    init_QPrintDialog(module);
    init_QAbstractPageSetupDialog(module);
    init_QPageSetupDialog(module);
    init_QFileDialog(module);
    init_QWizard(module);
    init_QPrintPreviewDialog(module);
    init_QProgressDialog(module);
    init_QMessageBox(module);
    init_QInputDialog(module);
    init_QAbstractItemView(module);
    init_QColumnView(module);
    init_QTableView(module);
    init_QTableWidget(module);
    init_QHeaderView(module);
    init_QListView(module);
    init_QListWidget(module);
    init_QUndoView(module);
    init_QTreeView(module);
    init_QTreeWidget(module);
    init_QWorkspace(module);
    init_QToolButton(module);
    init_QToolBox(module);
    init_QToolBar(module);
    init_QTextBrowser(module);
    init_QGraphicsEffect(module);
    init_QGraphicsOpacityEffect(module);
    init_QGraphicsDropShadowEffect(module);
    init_QGraphicsBlurEffect(module);
    init_QGraphicsColorizeEffect(module);
    init_QSyntaxHighlighter(module);
    init_QStyle(module);
    init_QCommonStyle(module);
    init_QWindowsStyle(module);
    init_QPlastiqueStyle(module);
    init_QCleanlooksStyle(module);
    init_QGtkStyle(module);
    init_QMotifStyle(module);
    init_QCDEStyle(module);
    init_QTextDocument(module);
    init_QMovie(module);
    init_QImageWriter(module);
    init_QImageReader(module);
    // Initialize extended Converters
    SbkObjectType* shiboType;

    // Extended implicit conversions for PySide.QtCore.QPointF
    shiboType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QPOINTF_IDX]);
    Shiboken::ObjectType::setExternalIsConvertibleFunction(shiboType, ExtendedIsConvertible_PySide_QtCore_QPointF);
    Shiboken::ObjectType::setExternalCppConversionFunction(shiboType, ExtendedToCpp_PySide_QtCore_QPointF);


    // Register primitive types on TypeResolver
    Shiboken::TypeResolver::createValueTypeResolver<QStringList >("QStringList");
    Shiboken::TypeResolver::createValueTypeResolver<QList<QRectF> >("QList<QRectF>");
    Shiboken::TypeResolver::createValueTypeResolver<QList<QModelIndex> >("QList<QModelIndex>");

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtGui");
    }
    // Begin code injection
    // ========================================================================
    // START of custom code block [file: glue/qtgui_qapp.cpp]
    // Init qApp macro to None.
    Py_INCREF(Py_None);
    PyModule_AddObject(module, "qApp", Py_None);
    moduleQtGui = module;

    // END of custom code block [file: glue/qtgui_qapp.cpp]
    // ========================================================================

    // End of code injection


}

