/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qundostack_wrapper.h"

// Extra includes
#include <QList>
#include <qaction.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qundostack.h>


// Native ---------------------------------------------------------

QUndoStackWrapper::QUndoStackWrapper(QObject * parent) : QUndoStack(parent) {
    // ... middle
}

void QUndoStackWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QUndoStackWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QUndoStackWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QUndoStackWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QUndoStackWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QUndoStack.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QUndoStackWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QUndoStack.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QUndoStackWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QUndoStackWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QUndoStackWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QUndoStack::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QUndoStackWrapper::~QUndoStackWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUndoStack_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QUndoStack >()))
        return -1;

    QUndoStackWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QUndoStack", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QUndoStack(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QUndoStack(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QUndoStack(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoStack_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QUndoStack_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QUndoStack(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QUndoStack(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QUndoStackWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QUndoStack >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QUndoStack_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QUndoStack_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QUndoStack", overloads);
        return -1;
}

static PyObject* Sbk_QUndoStackFunc_beginMacro(PyObject* self, PyObject* arg)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: beginMacro(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // beginMacro(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoStackFunc_beginMacro_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // beginMacro(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->beginMacro(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUndoStackFunc_beginMacro_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QUndoStack.beginMacro", overloads);
        return 0;
}

static PyObject* Sbk_QUndoStackFunc_canRedo(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // canRedo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUndoStack*>(cppSelf)->canRedo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoStackFunc_canUndo(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // canUndo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUndoStack*>(cppSelf)->canUndo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoStackFunc_cleanIndex(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cleanIndex()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QUndoStack*>(cppSelf)->cleanIndex();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoStackFunc_clear(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QUndoStackFunc_command(PyObject* self, PyObject* arg)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: command(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // command(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoStackFunc_command_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // command(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QUndoCommand * cppResult = const_cast<const QUndoStack*>(cppSelf)->command(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUndoCommand * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUndoStackFunc_command_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QUndoStack.command", overloads);
        return 0;
}

static PyObject* Sbk_QUndoStackFunc_count(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QUndoStack*>(cppSelf)->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoStackFunc_createRedoAction(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QUndoStack.createRedoAction(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QUndoStack.createRedoAction(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createRedoAction", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createRedoAction(QObject*,QString)const
    if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createRedoAction(QObject*,QString)const
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // createRedoAction(QObject*,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoStackFunc_createRedoAction_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "prefix");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "prefix";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QUndoStackFunc_createRedoAction_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QUndoStack.createRedoAction(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // createRedoAction(QObject*,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAction * cppResult = const_cast<const QUndoStack*>(cppSelf)->createRedoAction(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAction * >::toPython(cppResult);
                Shiboken::Object::setParent(pyargs[0], pyResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUndoStackFunc_createRedoAction_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QUndoStack.createRedoAction", overloads);
        return 0;
}

static PyObject* Sbk_QUndoStackFunc_createUndoAction(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QUndoStack.createUndoAction(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QUndoStack.createUndoAction(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:createUndoAction", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: createUndoAction(QObject*,QString)const
    if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // createUndoAction(QObject*,QString)const
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // createUndoAction(QObject*,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoStackFunc_createUndoAction_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "prefix");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "prefix";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QUndoStackFunc_createUndoAction_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QUndoStack.createUndoAction(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // createUndoAction(QObject*,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAction * cppResult = const_cast<const QUndoStack*>(cppSelf)->createUndoAction(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAction * >::toPython(cppResult);
                Shiboken::Object::setParent(pyargs[0], pyResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUndoStackFunc_createUndoAction_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QUndoStack.createUndoAction", overloads);
        return 0;
}

static PyObject* Sbk_QUndoStackFunc_endMacro(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endMacro()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->endMacro();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QUndoStackFunc_index(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // index()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QUndoStack*>(cppSelf)->index();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoStackFunc_isActive(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isActive()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUndoStack*>(cppSelf)->isActive();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoStackFunc_isClean(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isClean()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QUndoStack*>(cppSelf)->isClean();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoStackFunc_push(PyObject* self, PyObject* arg)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: push(QUndoCommand*)
    if (Shiboken::Converter< ::QUndoCommand * >::isConvertible(arg)) {
        overloadId = 0; // push(QUndoCommand*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoStackFunc_push_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUndoCommand * cppArg0 = Shiboken::Converter<QUndoCommand * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // push(QUndoCommand*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->push(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUndoStackFunc_push_TypeError:
        const char* overloads[] = {"PySide.QtGui.QUndoCommand", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QUndoStack.push", overloads);
        return 0;
}

static PyObject* Sbk_QUndoStackFunc_redo(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // redo()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->redo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QUndoStackFunc_redoText(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // redoText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QUndoStack*>(cppSelf)->redoText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoStackFunc_setActive(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QUndoStack.setActive(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:setActive", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: setActive(bool)
    if (numArgs == 0) {
        overloadId = 0; // setActive(bool)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // setActive(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoStackFunc_setActive_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "active");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "active";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QUndoStackFunc_setActive_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QUndoStack.setActive(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cppArg0 = pyargs[0] ? Shiboken::Converter<bool >::toCpp(pyargs[0]) : true;

            if(!PyErr_Occurred()) {
                // setActive(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setActive(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUndoStackFunc_setActive_TypeError:
        const char* overloads[] = {"bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QUndoStack.setActive", overloads);
        return 0;
}

static PyObject* Sbk_QUndoStackFunc_setClean(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // setClean()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setClean();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QUndoStackFunc_setIndex(PyObject* self, PyObject* arg)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIndex(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoStackFunc_setIndex_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIndex(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIndex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUndoStackFunc_setIndex_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QUndoStack.setIndex", overloads);
        return 0;
}

static PyObject* Sbk_QUndoStackFunc_setUndoLimit(PyObject* self, PyObject* arg)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUndoLimit(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setUndoLimit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoStackFunc_setUndoLimit_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUndoLimit(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUndoLimit(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUndoStackFunc_setUndoLimit_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QUndoStack.setUndoLimit", overloads);
        return 0;
}

static PyObject* Sbk_QUndoStackFunc_text(PyObject* self, PyObject* arg)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: text(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // text(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUndoStackFunc_text_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // text(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QUndoStack*>(cppSelf)->text(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUndoStackFunc_text_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QUndoStack.text", overloads);
        return 0;
}

static PyObject* Sbk_QUndoStackFunc_undo(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // undo()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->undo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QUndoStackFunc_undoLimit(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // undoLimit()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QUndoStack*>(cppSelf)->undoLimit();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUndoStackFunc_undoText(PyObject* self)
{
    QUndoStack* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUndoStack* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // undoText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QUndoStack*>(cppSelf)->undoText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QUndoStack_methods[] = {
    {"beginMacro", (PyCFunction)Sbk_QUndoStackFunc_beginMacro, METH_O},
    {"canRedo", (PyCFunction)Sbk_QUndoStackFunc_canRedo, METH_NOARGS},
    {"canUndo", (PyCFunction)Sbk_QUndoStackFunc_canUndo, METH_NOARGS},
    {"cleanIndex", (PyCFunction)Sbk_QUndoStackFunc_cleanIndex, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QUndoStackFunc_clear, METH_NOARGS},
    {"command", (PyCFunction)Sbk_QUndoStackFunc_command, METH_O},
    {"count", (PyCFunction)Sbk_QUndoStackFunc_count, METH_NOARGS},
    {"createRedoAction", (PyCFunction)Sbk_QUndoStackFunc_createRedoAction, METH_VARARGS|METH_KEYWORDS},
    {"createUndoAction", (PyCFunction)Sbk_QUndoStackFunc_createUndoAction, METH_VARARGS|METH_KEYWORDS},
    {"endMacro", (PyCFunction)Sbk_QUndoStackFunc_endMacro, METH_NOARGS},
    {"index", (PyCFunction)Sbk_QUndoStackFunc_index, METH_NOARGS},
    {"isActive", (PyCFunction)Sbk_QUndoStackFunc_isActive, METH_NOARGS},
    {"isClean", (PyCFunction)Sbk_QUndoStackFunc_isClean, METH_NOARGS},
    {"push", (PyCFunction)Sbk_QUndoStackFunc_push, METH_O},
    {"redo", (PyCFunction)Sbk_QUndoStackFunc_redo, METH_NOARGS},
    {"redoText", (PyCFunction)Sbk_QUndoStackFunc_redoText, METH_NOARGS},
    {"setActive", (PyCFunction)Sbk_QUndoStackFunc_setActive, METH_VARARGS|METH_KEYWORDS},
    {"setClean", (PyCFunction)Sbk_QUndoStackFunc_setClean, METH_NOARGS},
    {"setIndex", (PyCFunction)Sbk_QUndoStackFunc_setIndex, METH_O},
    {"setUndoLimit", (PyCFunction)Sbk_QUndoStackFunc_setUndoLimit, METH_O},
    {"text", (PyCFunction)Sbk_QUndoStackFunc_text, METH_O},
    {"undo", (PyCFunction)Sbk_QUndoStackFunc_undo, METH_NOARGS},
    {"undoLimit", (PyCFunction)Sbk_QUndoStackFunc_undoLimit, METH_NOARGS},
    {"undoText", (PyCFunction)Sbk_QUndoStackFunc_undoText, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QUndoStack_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QUndoStack",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QUndoStack_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QUndoStack_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QUndoStack_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QUndoStack*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QUndoStack_Type;
    return 0;
}


void init_QUndoStack(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QUNDOSTACK_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QUndoStack_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QUndoStack_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QUndoStack_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QUndoStack_Type, &QUndoStack::staticMetaObject);    Sbk_QUndoStack_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QUndoStack_Type, &Shiboken::callCppDestructor<QUndoStack >);
    Py_INCREF((PyObject*)&Sbk_QUndoStack_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QUndoStack_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QUndoStack_Type, &Sbk_QUndoStack_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QUndoStack_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QUndoStack_Type, "QUndoStack*");
    PyModule_AddObject(module, "QUndoStack",
        ((PyObject*)&Sbk_QUndoStack_Type));

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("canRedoChanged", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QUndoStack_Type, "canRedoChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("redoTextChanged", "QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QUndoStack_Type, "redoTextChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("undoTextChanged", "QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QUndoStack_Type, "undoTextChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("indexChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QUndoStack_Type, "indexChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("canUndoChanged", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QUndoStack_Type, "canUndoChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("cleanChanged", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QUndoStack_Type, "cleanChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QUndoStack >("QUndoStack*");
    Shiboken::TypeResolver::createObjectTypeResolver<QUndoStack >(typeid(QUndoStack).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QUndoStack >(typeid(QUndoStackWrapper).name());
    qRegisterMetaType< ::QUndoStack* >("QUndoStack*");
}

