/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qvector3d_wrapper.h"

// Extra includes
#include <QMatrix4x4>
#include <qdatastream.h>
#include <qpoint.h>
#include <qvector2d.h>
#include <qvector3d.h>
#include <qvector4d.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVector3D_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QVector3D >()))
        return -1;

    QVector3D* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QVector3D", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QVector3D()
    // 1: QVector3D(QPoint)
    // 2: QVector3D(QPointF)
    // 3: QVector3D(QVector2D)
    // 4: QVector3D(QVector2D,qreal)
    // 5: QVector3D(QVector3D)
    // 6: QVector3D(QVector4D)
    // 7: QVector3D(qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QVector3D()
    } else if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 7; // QVector3D(qreal,qreal,qreal)
    } else if (Shiboken::Converter< ::QVector2D >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QVector3D(QVector2D)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 4; // QVector3D(QVector2D,qreal)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[0])) {
        overloadId = 5; // QVector3D(QVector3D)
    } else if (numArgs == 1 && Shiboken::Converter< ::QVector4D >::isConvertible(pyargs[0])) {
        overloadId = 6; // QVector3D(QVector4D)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 1; // QVector3D(QPoint)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 2; // QVector3D(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3D_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QVector3D()
            {

                if(!PyErr_Occurred()) {
                    // QVector3D()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector3D();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QVector3D(QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVector3D(QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector3D(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QVector3D(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVector3D(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector3D(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QVector3D(QVector2D)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVector2D cppArg0 = Shiboken::Converter<QVector2D >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVector3D(QVector2D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector3D(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QVector3D(QVector2D,qreal)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVector2D cppArg0 = Shiboken::Converter<QVector2D >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QVector3D(QVector2D,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector3D(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QVector3D(QVector3D)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVector3D(QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector3D(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // QVector3D(QVector4D)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVector4D cppArg0 = Shiboken::Converter<QVector4D >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVector3D(QVector4D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector3D(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // QVector3D(qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // QVector3D(qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector3D(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QVector3D >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QVector3D_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QVector3D_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtGui.QVector2D", "PySide.QtGui.QVector2D, float", "PySide.QtGui.QVector3D", "PySide.QtGui.QVector4D", "float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QVector3D", overloads);
        return -1;
}

static PyObject* Sbk_QVector3DFunc___reduce__(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection

                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(ddd))", PyObject_Type(self), cppSelf->x(), cppSelf->y(), cppSelf->z());
                // TEMPLATE - reduce_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc___repr__(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __repr__()
                // Begin code injection

                // TEMPLATE - repr_code - START
                QString format = QString().sprintf("%s(%f, %f, %f)", ((PyObject*)self)->ob_type->tp_name, cppSelf->x(), cppSelf->y(), cppSelf->z());
                pyResult = PyString_FromString(qPrintable(format));
                // TEMPLATE - repr_code - END

                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_crossProduct(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "crossProduct", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: crossProduct(QVector3D,QVector3D)
    if (numArgs == 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[1])) {
        overloadId = 0; // crossProduct(QVector3D,QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc_crossProduct_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // crossProduct(QVector3D,QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector3D cppResult = QVector3D::crossProduct(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc_crossProduct_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D, PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QVector3D.crossProduct", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc_distanceToLine(PyObject* self, PyObject* args)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "distanceToLine", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: distanceToLine(QVector3D,QVector3D)const
    if (numArgs == 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[1])) {
        overloadId = 0; // distanceToLine(QVector3D,QVector3D)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc_distanceToLine_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // distanceToLine(QVector3D,QVector3D)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QVector3D*>(cppSelf)->distanceToLine(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc_distanceToLine_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D, PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QVector3D.distanceToLine", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc_distanceToPlane(PyObject* self, PyObject* args)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "distanceToPlane", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: distanceToPlane(QVector3D,QVector3D)const
    // 1: distanceToPlane(QVector3D,QVector3D,QVector3D)const
    if (numArgs >= 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // distanceToPlane(QVector3D,QVector3D)const
        } else if (numArgs == 3 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[2])) {
            overloadId = 1; // distanceToPlane(QVector3D,QVector3D,QVector3D)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc_distanceToPlane_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // distanceToPlane(QVector3D,QVector3D)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // distanceToPlane(QVector3D,QVector3D)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    qreal cppResult = const_cast<const QVector3D*>(cppSelf)->distanceToPlane(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< float >::toPython(cppResult);
                }
                break;
            }
            case 1: // distanceToPlane(QVector3D,QVector3D,QVector3D)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QVector3D cppArg2 = Shiboken::Converter<QVector3D >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // distanceToPlane(QVector3D,QVector3D,QVector3D)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    qreal cppResult = const_cast<const QVector3D*>(cppSelf)->distanceToPlane(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< float >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc_distanceToPlane_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D, PySide.QtGui.QVector3D", "PySide.QtGui.QVector3D, PySide.QtGui.QVector3D, PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QVector3D.distanceToPlane", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc_dotProduct(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "dotProduct", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: dotProduct(QVector3D,QVector3D)
    if (numArgs == 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[1])) {
        overloadId = 0; // dotProduct(QVector3D,QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc_dotProduct_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // dotProduct(QVector3D,QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = QVector3D::dotProduct(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc_dotProduct_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D, PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QVector3D.dotProduct", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc_isNull(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QVector3D*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_length(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // length()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QVector3D*>(cppSelf)->length();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_lengthSquared(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lengthSquared()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QVector3D*>(cppSelf)->lengthSquared();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_normal(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "normal", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: normal(QVector3D,QVector3D)
    // 1: normal(QVector3D,QVector3D,QVector3D)
    if (numArgs >= 2 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // normal(QVector3D,QVector3D)
        } else if (numArgs == 3 && Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[2])) {
            overloadId = 1; // normal(QVector3D,QVector3D,QVector3D)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc_normal_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // normal(QVector3D,QVector3D)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // normal(QVector3D,QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVector3D cppResult = QVector3D::normal(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
                }
                break;
            }
            case 1: // normal(QVector3D,QVector3D,QVector3D)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QVector3D cppArg1 = Shiboken::Converter<QVector3D >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QVector3D cppArg2 = Shiboken::Converter<QVector3D >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // normal(QVector3D,QVector3D,QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVector3D cppResult = QVector3D::normal(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc_normal_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D, PySide.QtGui.QVector3D", "PySide.QtGui.QVector3D, PySide.QtGui.QVector3D, PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QVector3D.normal", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc_normalize(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // normalize()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->normalize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QVector3DFunc_normalized(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // normalized()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector3D cppResult = const_cast<const QVector3D*>(cppSelf)->normalized();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_setX(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setX(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc_setX_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setX(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setX(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVector3DFunc_setX_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.setX", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc_setY(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setY(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc_setY_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setY(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setY(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVector3DFunc_setY_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.setY", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc_setZ(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setZ(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setZ(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc_setZ_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setZ(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setZ(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVector3DFunc_setZ_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.setZ", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc_toPoint(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toPoint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = const_cast<const QVector3D*>(cppSelf)->toPoint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_toPointF(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toPointF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = const_cast<const QVector3D*>(cppSelf)->toPointF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_toVector2D(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toVector2D()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector2D cppResult = const_cast<const QVector3D*>(cppSelf)->toVector2D();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector2D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_toVector4D(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toVector4D()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector4D cppResult = const_cast<const QVector3D*>(cppSelf)->toVector4D();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_x(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // x()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QVector3D*>(cppSelf)->x();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_y(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // y()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QVector3D*>(cppSelf)->y();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc_z(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // z()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QVector3D*>(cppSelf)->z();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QVector3D___copy__(PyObject *self)
{
        QVector3D* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QVector3D*>::toCpp(self);
        PyObject* pyResult = 0;
        QVector3D* copy = new QVector3D(*cppSelf);
        pyResult = Shiboken::Converter<QVector3D*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QVector3D_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QVector3DFunc___reduce__, METH_NOARGS},
    {"crossProduct", (PyCFunction)Sbk_QVector3DFunc_crossProduct, METH_VARARGS|METH_STATIC},
    {"distanceToLine", (PyCFunction)Sbk_QVector3DFunc_distanceToLine, METH_VARARGS},
    {"distanceToPlane", (PyCFunction)Sbk_QVector3DFunc_distanceToPlane, METH_VARARGS},
    {"dotProduct", (PyCFunction)Sbk_QVector3DFunc_dotProduct, METH_VARARGS|METH_STATIC},
    {"isNull", (PyCFunction)Sbk_QVector3DFunc_isNull, METH_NOARGS},
    {"length", (PyCFunction)Sbk_QVector3DFunc_length, METH_NOARGS},
    {"lengthSquared", (PyCFunction)Sbk_QVector3DFunc_lengthSquared, METH_NOARGS},
    {"normal", (PyCFunction)Sbk_QVector3DFunc_normal, METH_VARARGS|METH_STATIC},
    {"normalize", (PyCFunction)Sbk_QVector3DFunc_normalize, METH_NOARGS},
    {"normalized", (PyCFunction)Sbk_QVector3DFunc_normalized, METH_NOARGS},
    {"setX", (PyCFunction)Sbk_QVector3DFunc_setX, METH_O},
    {"setY", (PyCFunction)Sbk_QVector3DFunc_setY, METH_O},
    {"setZ", (PyCFunction)Sbk_QVector3DFunc_setZ, METH_O},
    {"toPoint", (PyCFunction)Sbk_QVector3DFunc_toPoint, METH_NOARGS},
    {"toPointF", (PyCFunction)Sbk_QVector3DFunc_toPointF, METH_NOARGS},
    {"toVector2D", (PyCFunction)Sbk_QVector3DFunc_toVector2D, METH_NOARGS},
    {"toVector4D", (PyCFunction)Sbk_QVector3DFunc_toVector4D, METH_NOARGS},
    {"x", (PyCFunction)Sbk_QVector3DFunc_x, METH_NOARGS},
    {"y", (PyCFunction)Sbk_QVector3DFunc_y, METH_NOARGS},
    {"z", (PyCFunction)Sbk_QVector3DFunc_z, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QVector3D___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QVector3D___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QVector3D* cppSelf = Shiboken::Converter< ::QVector3D*>::toCpp(pyObj);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

static PyObject* Sbk_QVector3DFunc___mul__(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector3D >::checkType(arg) && !Shiboken::Converter< ::QVector3D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QVector3D,QMatrix4x4)
    // 1: operator*(QMatrix4x4,QVector3D)
    // 2: operator*(QVector3D,QVector3D)
    // 3: operator*(QVector3D,qreal)
    // 4: operator*(qreal,QVector3D)
    if (isReverse && SbkNumber_Check(arg)) {
        overloadId = 4; // operator*(qreal,QVector3D)
    } else if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 3; // operator*(QVector3D,qreal)
    } else if (!isReverse && Shiboken::Converter< ::QVector3D >::isConvertible(arg)) {
        overloadId = 2; // operator*(QVector3D,QVector3D)
    } else if (isReverse && Shiboken::Converter< ::QMatrix4x4 >::isConvertible(arg)) {
        overloadId = 1; // operator*(QMatrix4x4,QVector3D)
    } else if (!isReverse && Shiboken::Converter< ::QMatrix4x4 >::isConvertible(arg)) {
        overloadId = 0; // operator*(QVector3D,QMatrix4x4)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QVector3D,QMatrix4x4)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QMatrix4x4 cppArg0 = Shiboken::Converter<QMatrix4x4 >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QVector3D,QMatrix4x4)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVector3D cppResult = (*cppSelf) * (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QMatrix4x4,QVector3D)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QMatrix4x4 cppArg0 = Shiboken::Converter<QMatrix4x4 >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QMatrix4x4,QVector3D) [reverse operator]
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVector3D cppResult = (cppArg0) * (*cppSelf);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
                }
                break;
            }
            case 2: // operator*(QVector3D,QVector3D)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QVector3D,QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QVector3D cppResult = (*cppSelf) * (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
                }
                break;
            }
            case 3: // operator*(QVector3D,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QVector3D,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QVector3D cppResult = (*cppSelf) * cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
                }
                break;
            }
            case 4: // operator*(qreal,QVector3D)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(qreal,QVector3D) [reverse operator]
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QVector3D cppResult = cppArg0 * (*cppSelf);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix4x4", "PySide.QtGui.QMatrix4x4", "PySide.QtGui.QVector3D", "float", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.__mul__", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc___imul__(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector3D >::checkType(arg) && !Shiboken::Converter< ::QVector3D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(QVector3D)
    // 1: operator*=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*=(qreal)
    } else if (!isReverse && Shiboken::Converter< ::QVector3D >::isConvertible(arg)) {
        overloadId = 0; // operator*=(QVector3D)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc___imul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*=(QVector3D)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*=(QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) *= (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // operator*=(qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*=(qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) *= cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QVector3DFunc___imul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.__imul__", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc___add__(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector3D >::checkType(arg) && !Shiboken::Converter< ::QVector3D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QVector3D,QVector3D)
    if (!isReverse && Shiboken::Converter< ::QVector3D >::isConvertible(arg)) {
        overloadId = 0; // operator+(QVector3D,QVector3D)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc___add___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+(QVector3D,QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QVector3D cppResult = (*cppSelf) + (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc___add___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.__add__", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc___iadd__(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector3D >::checkType(arg) && !Shiboken::Converter< ::QVector3D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QVector3D)
    if (!isReverse && Shiboken::Converter< ::QVector3D >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QVector3D)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc___iadd___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+=(QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) += (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QVector3DFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc___neg__(PyObject* self)
{
    QVector3D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // operator-(QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QVector3D cppResult = - (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector3DFunc___sub__(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector3D >::checkType(arg) && !Shiboken::Converter< ::QVector3D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QVector3D,QVector3D)
    if (!isReverse && Shiboken::Converter< ::QVector3D >::isConvertible(arg)) {
        overloadId = 0; // operator-(QVector3D,QVector3D)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc___sub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-(QVector3D,QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QVector3D cppResult = (*cppSelf) - (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc___sub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.__sub__", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc___isub__(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector3D >::checkType(arg) && !Shiboken::Converter< ::QVector3D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QVector3D)
    if (!isReverse && Shiboken::Converter< ::QVector3D >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QVector3D)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc___isub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-=(QVector3D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) -= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QVector3DFunc___isub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector3D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.__isub__", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc___div__(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector3D >::checkType(arg) && !Shiboken::Converter< ::QVector3D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rdiv__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rdiv__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator/(QVector3D,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/(QVector3D,qreal)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc___div___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator/(QVector3D,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QVector3D cppResult = (*cppSelf) / cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc___div___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.__div__", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc___idiv__(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector3D >::checkType(arg) && !Shiboken::Converter< ::QVector3D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/=(qreal)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc___idiv___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator/=(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) /= cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QVector3DFunc___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.__idiv__", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc___lshift__(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector3D >::checkType(arg) && !Shiboken::Converter< ::QVector3D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QVector3D)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QVector3D)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QVector3D) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QVector3DFunc___rshift__(PyObject* self, PyObject* arg)
{
    QVector3D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector3D >::checkType(arg) && !Shiboken::Converter< ::QVector3D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector3D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QVector3D&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QVector3D&)
    }

    if (isReverse && overloadId == -1) {
        PyErr_SetString(PyExc_NotImplementedError, "reverse operator not implemented.");
        return 0;
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector3DFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QVector3D&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector3DFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector3D.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QVector3D_as_number = {
    /*nb_add*/                  (binaryfunc)Sbk_QVector3DFunc___add__,
    /*nb_subtract*/             (binaryfunc)Sbk_QVector3DFunc___sub__,
    /*nb_multiply*/             (binaryfunc)Sbk_QVector3DFunc___mul__,
    /*nb_divide*/               (binaryfunc)Sbk_QVector3DFunc___div__,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)Sbk_QVector3DFunc___neg__,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QVector3D___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QVector3DFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QVector3DFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)Sbk_QVector3DFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)Sbk_QVector3DFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)Sbk_QVector3DFunc___imul__,
    /*nb_inplace_divide*/       (binaryfunc)Sbk_QVector3DFunc___idiv__,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)Sbk_QVector3DFunc___div__,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QVector3D_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QVector3D& cppSelf = *Shiboken::Converter< QVector3D* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QVector3D >::isConvertible(arg)) {
                // operator!=(const QVector3D & v2)
                QVector3D cppArg0 = Shiboken::Converter< ::QVector3D >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QVector3D >::isConvertible(arg)) {
                // operator==(const QVector3D & v2)
                QVector3D cppArg0 = Shiboken::Converter< ::QVector3D >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QVector3D_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QVector3D_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QVector3D_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QVector3D",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QVector3DFunc___repr__,
    /*tp_as_number*/        &Sbk_QVector3D_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QVector3D_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QVector3D_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QVector3D_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QVector3D(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QVECTOR3D_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QVector3D_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QVector3D_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QVector3D_Type, &Shiboken::callCppDestructor<QVector3D >);
    Py_INCREF((PyObject*)&Sbk_QVector3D_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QVector3D_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QVector3D_Type, "QVector3D");
    PyModule_AddObject(module, "QVector3D",
        ((PyObject*)&Sbk_QVector3D_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QVector3D >("QVector3D");
    Shiboken::TypeResolver::createObjectTypeResolver<QVector3D >("QVector3D*");
    Shiboken::TypeResolver::createValueTypeResolver<QVector3D >(typeid(QVector3D).name());
    qRegisterMetaType< ::QVector3D >("QVector3D");
}

