/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_qtmultimedia_python.h"



// Extra includes

// Global functions ------------------------------------------------------------

static PyMethodDef QtMultimedia_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QAudio(PyObject* module);
void init_QAudioDeviceInfo(PyObject* module);
void init_QAudioFormat(PyObject* module);
void init_QVideoFrame(PyObject* module);
void init_QAbstractVideoBuffer(PyObject* module);
void init_QVideoSurfaceFormat(PyObject* module);
void init_QAudioEngineFactoryInterface(PyObject* module);
void init_QAbstractVideoSurface(PyObject* module);
void init_QAudioOutput(PyObject* module);
void init_QAudioInput(PyObject* module);
void init_QAudioEnginePlugin(PyObject* module);
void init_QAbstractAudioInput(PyObject* module);
void init_QAbstractAudioOutput(PyObject* module);
void init_QAbstractAudioDeviceInfo(PyObject* module);

PyTypeObject** SbkPySide_QtMultimediaTypes;

PyTypeObject** SbkPySide_QtGuiTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initQtMultimedia()
{
    if (!Shiboken::importModule("PySide.QtGui", &SbkPySide_QtGuiTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtGui");
        return;
    }

    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    Shiboken::init();
    PyObject* module = Py_InitModule("QtMultimedia", QtMultimedia_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_QtMultimedia_IDX_COUNT];
    SbkPySide_QtMultimediaTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_QAudio(module);
    init_QAudioDeviceInfo(module);
    init_QAudioFormat(module);
    init_QVideoFrame(module);
    init_QAbstractVideoBuffer(module);
    init_QVideoSurfaceFormat(module);
    init_QAudioEngineFactoryInterface(module);
    init_QAbstractVideoSurface(module);
    init_QAudioOutput(module);
    init_QAudioInput(module);
    init_QAudioEnginePlugin(module);
    init_QAbstractAudioInput(module);
    init_QAbstractAudioOutput(module);
    init_QAbstractAudioDeviceInfo(module);

    // Register primitive types on TypeResolver

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtMultimedia");
    }
}

