/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtmultimedia_python.h"

#include "qvideosurfaceformat_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qrect.h>
#include <qsize.h>
#include <qvideosurfaceformat.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVideoSurfaceFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QVideoSurfaceFormat >()))
        return -1;

    QVideoSurfaceFormat* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QVideoSurfaceFormat(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QVideoSurfaceFormat", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QVideoSurfaceFormat()
    // 1: QVideoSurfaceFormat(QSize,QVideoFrame::PixelFormat,QAbstractVideoBuffer::HandleType)
    // 2: QVideoSurfaceFormat(QVideoSurfaceFormat)
    if (numArgs == 0) {
        overloadId = 0; // QVideoSurfaceFormat()
    } else if (numArgs == 1 && Shiboken::Converter< ::QVideoSurfaceFormat >::isConvertible(pyargs[0])) {
        overloadId = 2; // QVideoSurfaceFormat(QVideoSurfaceFormat)
    } else if (numArgs >= 2 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QVideoFrame::PixelFormat >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QVideoSurfaceFormat(QSize,QVideoFrame::PixelFormat,QAbstractVideoBuffer::HandleType)
        } else if (Shiboken::Converter< ::QAbstractVideoBuffer::HandleType >::isConvertible(pyargs[2])) {
            overloadId = 1; // QVideoSurfaceFormat(QSize,QVideoFrame::PixelFormat,QAbstractVideoBuffer::HandleType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoSurfaceFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QVideoSurfaceFormat()
            {

                if(!PyErr_Occurred()) {
                    // QVideoSurfaceFormat()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVideoSurfaceFormat();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QVideoSurfaceFormat(QSize,QVideoFrame::PixelFormat,QAbstractVideoBuffer::HandleType)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "handleType");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "handleType";
                        else if (Shiboken::Converter< ::QAbstractVideoBuffer::HandleType >::isConvertible(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QVideoSurfaceFormat_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QVideoSurfaceFormat(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);
                QVideoFrame::PixelFormat cppArg1 = Shiboken::Converter<QVideoFrame::PixelFormat >::toCpp(pyargs[1]);
                QAbstractVideoBuffer::HandleType cppArg2 = pyargs[2] ? Shiboken::Converter<QAbstractVideoBuffer::HandleType >::toCpp(pyargs[2]) : QAbstractVideoBuffer::NoHandle;

                if(!PyErr_Occurred()) {
                    // QVideoSurfaceFormat(QSize,QVideoFrame::PixelFormat,QAbstractVideoBuffer::HandleType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVideoSurfaceFormat(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QVideoSurfaceFormat(QVideoSurfaceFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVideoSurfaceFormat cppArg0 = Shiboken::Converter<QVideoSurfaceFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVideoSurfaceFormat(QVideoSurfaceFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVideoSurfaceFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QVideoSurfaceFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QVideoSurfaceFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QVideoSurfaceFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QSize, PySide.QtMultimedia.QVideoFrame.PixelFormat, PySide.QtMultimedia.QAbstractVideoBuffer.HandleType = QAbstractVideoBuffer.NoHandle", "PySide.QtMultimedia.QVideoSurfaceFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QVideoSurfaceFormat", overloads);
        return -1;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_frameHeight(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // frameHeight()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->frameHeight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_frameRate(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // frameRate()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->frameRate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_frameSize(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // frameSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->frameSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_frameWidth(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // frameWidth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->frameWidth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_handleType(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // handleType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractVideoBuffer::HandleType cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->handleType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractVideoBuffer::HandleType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_isValid(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_pixelAspectRatio(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pixelAspectRatio()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->pixelAspectRatio();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_pixelFormat(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pixelFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVideoFrame::PixelFormat cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->pixelFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVideoFrame::PixelFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_property(PyObject* self, PyObject* arg)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: property(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // property(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoSurfaceFormatFunc_property_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // property(const char*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->property(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVideoSurfaceFormatFunc_property_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoSurfaceFormat.property", overloads);
        return 0;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_propertyNames(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // propertyNames()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QByteArray > cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->propertyNames();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QByteArray > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_scanLineDirection(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scanLineDirection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVideoSurfaceFormat::Direction cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->scanLineDirection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVideoSurfaceFormat::Direction >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_setFrameRate(PyObject* self, PyObject* arg)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFrameRate(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setFrameRate(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoSurfaceFormatFunc_setFrameRate_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFrameRate(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFrameRate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVideoSurfaceFormatFunc_setFrameRate_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoSurfaceFormat.setFrameRate", overloads);
        return 0;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_setFrameSize(PyObject* self, PyObject* args)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFrameSize", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFrameSize(QSize)
    // 1: setFrameSize(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setFrameSize(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        overloadId = 0; // setFrameSize(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoSurfaceFormatFunc_setFrameSize_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setFrameSize(QSize)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setFrameSize(QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setFrameSize(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setFrameSize(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setFrameSize(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setFrameSize(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVideoSurfaceFormatFunc_setFrameSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QVideoSurfaceFormat.setFrameSize", overloads);
        return 0;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_setPixelAspectRatio(PyObject* self, PyObject* args)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setPixelAspectRatio", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPixelAspectRatio(QSize)
    // 1: setPixelAspectRatio(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // setPixelAspectRatio(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QSize >::isConvertible(pyargs[0])) {
        overloadId = 0; // setPixelAspectRatio(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoSurfaceFormatFunc_setPixelAspectRatio_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setPixelAspectRatio(QSize)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setPixelAspectRatio(QSize)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setPixelAspectRatio(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setPixelAspectRatio(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setPixelAspectRatio(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setPixelAspectRatio(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVideoSurfaceFormatFunc_setPixelAspectRatio_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QVideoSurfaceFormat.setPixelAspectRatio", overloads);
        return 0;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_setProperty(PyObject* self, PyObject* args)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setProperty(const char*,QVariant)
    if (numArgs == 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setProperty(const char*,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoSurfaceFormatFunc_setProperty_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            QVariant cppArg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setProperty(const char*,QVariant)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProperty(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVideoSurfaceFormatFunc_setProperty_TypeError:
        const char* overloads[] = {"str, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QVideoSurfaceFormat.setProperty", overloads);
        return 0;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_setScanLineDirection(PyObject* self, PyObject* arg)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScanLineDirection(QVideoSurfaceFormat::Direction)
    if (Shiboken::Converter< ::QVideoSurfaceFormat::Direction >::isConvertible(arg)) {
        overloadId = 0; // setScanLineDirection(QVideoSurfaceFormat::Direction)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoSurfaceFormatFunc_setScanLineDirection_TypeError;

    // Call function/method
    {
        {
            QVideoSurfaceFormat::Direction cppArg0 = Shiboken::Converter<QVideoSurfaceFormat::Direction >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScanLineDirection(QVideoSurfaceFormat::Direction)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScanLineDirection(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVideoSurfaceFormatFunc_setScanLineDirection_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QVideoSurfaceFormat.Direction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoSurfaceFormat.setScanLineDirection", overloads);
        return 0;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_setViewport(PyObject* self, PyObject* arg)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setViewport(QRect)
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // setViewport(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoSurfaceFormatFunc_setViewport_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setViewport(QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setViewport(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVideoSurfaceFormatFunc_setViewport_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoSurfaceFormat.setViewport", overloads);
        return 0;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_setYCbCrColorSpace(PyObject* self, PyObject* arg)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setYCbCrColorSpace(QVideoSurfaceFormat::YCbCrColorSpace)
    if (Shiboken::Converter< ::QVideoSurfaceFormat::YCbCrColorSpace >::isConvertible(arg)) {
        overloadId = 0; // setYCbCrColorSpace(QVideoSurfaceFormat::YCbCrColorSpace)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVideoSurfaceFormatFunc_setYCbCrColorSpace_TypeError;

    // Call function/method
    {
        {
            QVideoSurfaceFormat::YCbCrColorSpace cppArg0 = Shiboken::Converter<QVideoSurfaceFormat::YCbCrColorSpace >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setYCbCrColorSpace(QVideoSurfaceFormat::YCbCrColorSpace)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setYCbCrColorSpace(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVideoSurfaceFormatFunc_setYCbCrColorSpace_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QVideoSurfaceFormat.YCbCrColorSpace", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QVideoSurfaceFormat.setYCbCrColorSpace", overloads);
        return 0;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_sizeHint(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->sizeHint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_viewport(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // viewport()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->viewport();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVideoSurfaceFormatFunc_yCbCrColorSpace(PyObject* self)
{
    QVideoSurfaceFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // yCbCrColorSpace()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVideoSurfaceFormat::YCbCrColorSpace cppResult = const_cast<const QVideoSurfaceFormat*>(cppSelf)->yCbCrColorSpace();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVideoSurfaceFormat::YCbCrColorSpace >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QVideoSurfaceFormat___copy__(PyObject *self)
{
        QVideoSurfaceFormat* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QVideoSurfaceFormat*>::toCpp(self);
        PyObject* pyResult = 0;
        QVideoSurfaceFormat* copy = new QVideoSurfaceFormat(*cppSelf);
        pyResult = Shiboken::Converter<QVideoSurfaceFormat*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QVideoSurfaceFormat_methods[] = {
    {"frameHeight", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_frameHeight, METH_NOARGS},
    {"frameRate", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_frameRate, METH_NOARGS},
    {"frameSize", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_frameSize, METH_NOARGS},
    {"frameWidth", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_frameWidth, METH_NOARGS},
    {"handleType", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_handleType, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_isValid, METH_NOARGS},
    {"pixelAspectRatio", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_pixelAspectRatio, METH_NOARGS},
    {"pixelFormat", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_pixelFormat, METH_NOARGS},
    {"property", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_property, METH_O},
    {"propertyNames", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_propertyNames, METH_NOARGS},
    {"scanLineDirection", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_scanLineDirection, METH_NOARGS},
    {"setFrameRate", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_setFrameRate, METH_O},
    {"setFrameSize", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_setFrameSize, METH_VARARGS},
    {"setPixelAspectRatio", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_setPixelAspectRatio, METH_VARARGS},
    {"setProperty", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_setProperty, METH_VARARGS},
    {"setScanLineDirection", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_setScanLineDirection, METH_O},
    {"setViewport", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_setViewport, METH_O},
    {"setYCbCrColorSpace", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_setYCbCrColorSpace, METH_O},
    {"sizeHint", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_sizeHint, METH_NOARGS},
    {"viewport", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_viewport, METH_NOARGS},
    {"yCbCrColorSpace", (PyCFunction)Sbk_QVideoSurfaceFormatFunc_yCbCrColorSpace, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QVideoSurfaceFormat___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QVideoSurfaceFormat_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QVideoSurfaceFormat& cppSelf = *Shiboken::Converter< QVideoSurfaceFormat* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QVideoSurfaceFormat >::isConvertible(arg)) {
                // operator!=(const QVideoSurfaceFormat & format) const
                QVideoSurfaceFormat cppArg0 = Shiboken::Converter< ::QVideoSurfaceFormat >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QVideoSurfaceFormat >::isConvertible(arg)) {
                // operator==(const QVideoSurfaceFormat & format) const
                QVideoSurfaceFormat cppArg0 = Shiboken::Converter< ::QVideoSurfaceFormat >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QVideoSurfaceFormat_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QVideoSurfaceFormat_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QVideoSurfaceFormat__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QVideoSurfaceFormat >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtMultimedia.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QVideoSurfaceFormat_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtMultimedia.QVideoSurfaceFormat",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QVideoSurfaceFormat__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QVideoSurfaceFormat_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QVideoSurfaceFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QVideoSurfaceFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QVideoSurfaceFormat(PyObject* module)
{
    SbkPySide_QtMultimediaTypes[SBK_QVIDEOSURFACEFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QVideoSurfaceFormat_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QVideoSurfaceFormat_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QVideoSurfaceFormat_Type, &Shiboken::callCppDestructor<QVideoSurfaceFormat >);
    Py_INCREF((PyObject*)&Sbk_QVideoSurfaceFormat_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QVideoSurfaceFormat_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QVideoSurfaceFormat_Type, "QVideoSurfaceFormat");
    PyModule_AddObject(module, "QVideoSurfaceFormat",
        ((PyObject*)&Sbk_QVideoSurfaceFormat_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: YCbCrColorSpace
    PyTypeObject* SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace = Shiboken::Enum::newType("PySide.QtMultimedia.QVideoSurfaceFormat.YCbCrColorSpace");
    SbkPySide_QtMultimediaTypes[SBK_QVIDEOSURFACEFORMAT_YCBCRCOLORSPACE_IDX] = SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace;
    if (PyType_Ready(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace) < 0)
        return;
    PyDict_SetItemString(Sbk_QVideoSurfaceFormat_Type.super.ht_type.tp_dict,
            "YCbCrColorSpace",((PyObject*)SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace,(long) QVideoSurfaceFormat::YCbCr_Undefined, "YCbCr_Undefined");
    PyDict_SetItemString(Sbk_QVideoSurfaceFormat_Type.super.ht_type.tp_dict,"YCbCr_Undefined", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace->tp_dict,"YCbCr_Undefined", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace,(long) QVideoSurfaceFormat::YCbCr_BT601, "YCbCr_BT601");
    PyDict_SetItemString(Sbk_QVideoSurfaceFormat_Type.super.ht_type.tp_dict,"YCbCr_BT601", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace->tp_dict,"YCbCr_BT601", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace,(long) QVideoSurfaceFormat::YCbCr_BT709, "YCbCr_BT709");
    PyDict_SetItemString(Sbk_QVideoSurfaceFormat_Type.super.ht_type.tp_dict,"YCbCr_BT709", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace->tp_dict,"YCbCr_BT709", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace,(long) QVideoSurfaceFormat::YCbCr_xvYCC601, "YCbCr_xvYCC601");
    PyDict_SetItemString(Sbk_QVideoSurfaceFormat_Type.super.ht_type.tp_dict,"YCbCr_xvYCC601", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace->tp_dict,"YCbCr_xvYCC601", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace,(long) QVideoSurfaceFormat::YCbCr_xvYCC709, "YCbCr_xvYCC709");
    PyDict_SetItemString(Sbk_QVideoSurfaceFormat_Type.super.ht_type.tp_dict,"YCbCr_xvYCC709", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace->tp_dict,"YCbCr_xvYCC709", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace,(long) QVideoSurfaceFormat::YCbCr_JPEG, "YCbCr_JPEG");
    PyDict_SetItemString(Sbk_QVideoSurfaceFormat_Type.super.ht_type.tp_dict,"YCbCr_JPEG", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoSurfaceFormat_YCbCrColorSpace->tp_dict,"YCbCr_JPEG", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QVideoSurfaceFormat::YCbCrColorSpace");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::YCbCrColorSpace");
    // end of enum YCbCrColorSpace

    // init enum: Direction
    PyTypeObject* SbkPySide_QtMultimedia_QVideoSurfaceFormat_Direction = Shiboken::Enum::newType("PySide.QtMultimedia.QVideoSurfaceFormat.Direction");
    SbkPySide_QtMultimediaTypes[SBK_QVIDEOSURFACEFORMAT_DIRECTION_IDX] = SbkPySide_QtMultimedia_QVideoSurfaceFormat_Direction;
    if (PyType_Ready(SbkPySide_QtMultimedia_QVideoSurfaceFormat_Direction) < 0)
        return;
    PyDict_SetItemString(Sbk_QVideoSurfaceFormat_Type.super.ht_type.tp_dict,
            "Direction",((PyObject*)SbkPySide_QtMultimedia_QVideoSurfaceFormat_Direction));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoSurfaceFormat_Direction,(long) QVideoSurfaceFormat::TopToBottom, "TopToBottom");
    PyDict_SetItemString(Sbk_QVideoSurfaceFormat_Type.super.ht_type.tp_dict,"TopToBottom", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoSurfaceFormat_Direction->tp_dict,"TopToBottom", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QVideoSurfaceFormat_Direction,(long) QVideoSurfaceFormat::BottomToTop, "BottomToTop");
    PyDict_SetItemString(Sbk_QVideoSurfaceFormat_Type.super.ht_type.tp_dict,"BottomToTop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QVideoSurfaceFormat_Direction->tp_dict,"BottomToTop", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QVideoSurfaceFormat::Direction");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Direction");
    // end of enum Direction


    Shiboken::TypeResolver::createValueTypeResolver<QVideoSurfaceFormat >("QVideoSurfaceFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QVideoSurfaceFormat >("QVideoSurfaceFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QVideoSurfaceFormat >(typeid(QVideoSurfaceFormat).name());
    qRegisterMetaType< ::QVideoSurfaceFormat >("QVideoSurfaceFormat");
    qRegisterMetaType< ::QVideoSurfaceFormat::YCbCrColorSpace >("QVideoSurfaceFormat::YCbCrColorSpace");
    qRegisterMetaType< ::QVideoSurfaceFormat::Direction >("QVideoSurfaceFormat::Direction");
}

