/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qglcontext_wrapper.h"

// Extra includes
#include <qcolor.h>
#include <qgl.h>
#include <qimage.h>
#include <qpaintdevice.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>


// Native ---------------------------------------------------------

QGLContextWrapper::QGLContextWrapper(const QGLFormat & format) : QGLContext(format) {
    // ... middle
}

bool QGLContextWrapper::chooseContext(const QGLContext * shareContext)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "chooseContext"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLContext::chooseContext(shareContext);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGLContext * >::toPython(shareContext)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLContext.chooseContext", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

void * QGLContextWrapper::chooseVisual()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "chooseVisual"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLContext::chooseVisual();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< void * >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLContext.chooseVisual", Shiboken::SbkType<void >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    void * cppResult(Shiboken::Converter< void * >::toCpp(pyResult));
    return cppResult;
}

bool QGLContextWrapper::create(const QGLContext * shareContext)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "create"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLContext::create(shareContext);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGLContext * >::toPython(shareContext)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLContext.create", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

void QGLContextWrapper::doneCurrent()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "doneCurrent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLContext::doneCurrent();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGLContextWrapper::makeCurrent()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "makeCurrent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLContext::makeCurrent();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGLContextWrapper::swapBuffers() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "swapBuffers"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLContext::swapBuffers();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void * QGLContextWrapper::tryVisual(const QGLFormat & f, int bufDepth)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return 0;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tryVisual"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGLContext::tryVisual(f, bufDepth);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Ni)",
        Shiboken::Converter< ::QGLFormat >::toPython(f),
        bufDepth
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< void * >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGLContext.tryVisual", Shiboken::SbkType<void >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    void * cppResult(Shiboken::Converter< void * >::toCpp(pyResult));
    return cppResult;
}

QGLContextWrapper::~QGLContextWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGLContext_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLContext >()))
        return -1;

    QGLContextWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QGLContext", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QGLContext(QGLFormat)
    if (numArgs == 1 && Shiboken::Converter< ::QGLFormat >::isConvertible(pyargs[0])) {
        overloadId = 0; // QGLContext(QGLFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContext_Init_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QGLFormat cppArg0 = Shiboken::Converter<QGLFormat >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QGLContext(QGLFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QGLContextWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGLContext >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGLContext_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGLContext_Init_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext", overloads);
        return -1;
}

static PyObject* Sbk_QGLContextFunc_areSharing(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "areSharing", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: areSharing(const QGLContext*,const QGLContext*)
    if (numArgs == 2 && Shiboken::Converter< ::QGLContext * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QGLContext * >::isConvertible(pyargs[1])) {
        overloadId = 0; // areSharing(const QGLContext*,const QGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_areSharing_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGLContext * cppArg0 = Shiboken::Converter<QGLContext * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QGLContext * cppArg1 = Shiboken::Converter<QGLContext * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // areSharing(const QGLContext*,const QGLContext*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QGLContext::areSharing(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLContextFunc_areSharing_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLContext, PySide.QtOpenGL.QGLContext", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext.areSharing", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_bindTexture(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.bindTexture(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.bindTexture(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:bindTexture", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: bindTexture(QImage,uint,int)
    // 1: bindTexture(QImage,uint,int,QFlags<QGLContext::BindOption>)
    // 2: bindTexture(QPixmap,uint,int)
    // 3: bindTexture(QPixmap,uint,int,QFlags<QGLContext::BindOption>)
    // 4: bindTexture(QString)
    if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 4; // bindTexture(QString)
    } else if (Shiboken::Converter< ::QImage >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // bindTexture(QImage,uint,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // bindTexture(QImage,uint,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // bindTexture(QImage,uint,int)
                } else if (numArgs == 4 && Shiboken::Converter< ::QFlags<QGLContext::BindOption> >::isConvertible(pyargs[3])) {
                    overloadId = 1; // bindTexture(QImage,uint,int,QFlags<QGLContext::BindOption>)
                }
            }
        }
    } else if (Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // bindTexture(QPixmap,uint,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // bindTexture(QPixmap,uint,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 2; // bindTexture(QPixmap,uint,int)
                } else if (numArgs == 4 && Shiboken::Converter< ::QFlags<QGLContext::BindOption> >::isConvertible(pyargs[3])) {
                    overloadId = 3; // bindTexture(QPixmap,uint,int,QFlags<QGLContext::BindOption>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_bindTexture_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // bindTexture(QImage,uint,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "target";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGLContextFunc_bindTexture_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "format";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLContextFunc_bindTexture_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.bindTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(pyargs[0]);
                unsigned int cppArg1 = pyargs[1] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[1]) : 0x0DE1;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0x1908;

                if(!PyErr_Occurred()) {
                    // bindTexture(QImage,uint,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    unsigned int cppResult = cppSelf->bindTexture(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 1: // bindTexture(QImage,uint,int,QFlags<QGLContext::BindOption>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QImage cppArg0 = Shiboken::Converter<QImage >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                QFlags<QGLContext::BindOption> cppArg3 = Shiboken::Converter<QFlags<QGLContext::BindOption> >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // bindTexture(QImage,uint,int,QFlags<QGLContext::BindOption>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    unsigned int cppResult = cppSelf->bindTexture(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 2: // bindTexture(QPixmap,uint,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "target");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "target";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
                        else
                            goto Sbk_QGLContextFunc_bindTexture_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "format";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLContextFunc_bindTexture_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.bindTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPixmap cppArg0 = Shiboken::Converter<QPixmap >::toCpp(pyargs[0]);
                unsigned int cppArg1 = pyargs[1] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[1]) : 0x0DE1;
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0x1908;

                if(!PyErr_Occurred()) {
                    // bindTexture(QPixmap,uint,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    unsigned int cppResult = cppSelf->bindTexture(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 3: // bindTexture(QPixmap,uint,int,QFlags<QGLContext::BindOption>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPixmap cppArg0 = Shiboken::Converter<QPixmap >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                QFlags<QGLContext::BindOption> cppArg3 = Shiboken::Converter<QFlags<QGLContext::BindOption> >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // bindTexture(QPixmap,uint,int,QFlags<QGLContext::BindOption>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    unsigned int cppResult = cppSelf->bindTexture(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 4: // bindTexture(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // bindTexture(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    unsigned int cppResult = cppSelf->bindTexture(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLContextFunc_bindTexture_TypeError:
        const char* overloads[] = {"PySide.QtGui.QImage, unsigned int = 0x0DE1, int = 0x1908", "PySide.QtGui.QImage, unsigned int, int, PySide.QtOpenGL.QGLContext.BindOptions", "PySide.QtGui.QPixmap, unsigned int = 0x0DE1, int = 0x1908", "PySide.QtGui.QPixmap, unsigned int, int, PySide.QtOpenGL.QGLContext.BindOptions", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext.bindTexture", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_chooseContext(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.chooseContext(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:chooseContext", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: chooseContext(const QGLContext*)
    if (numArgs == 0) {
        overloadId = 0; // chooseContext(const QGLContext*)
    } else if (Shiboken::Converter< ::QGLContext * >::isConvertible(pyargs[0])) {
        overloadId = 0; // chooseContext(const QGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_chooseContext_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "shareContext");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "shareContext";
                    else if (Shiboken::Converter< ::QGLContext * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QGLContextFunc_chooseContext_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.chooseContext(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGLContext * cppArg0 = pyargs[0] ? Shiboken::Converter<QGLContext * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // chooseContext(const QGLContext*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGLContext::chooseContext(cppArg0) : cppSelf->chooseContext(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLContextFunc_chooseContext_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLContext = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext.chooseContext", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_chooseVisual(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // chooseVisual()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                void * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGLContext::chooseVisual() : cppSelf->chooseVisual());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< void * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_colorIndex(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: colorIndex(QColor)const
    if (Shiboken::Converter< ::QColor >::isConvertible(arg)) {
        overloadId = 0; // colorIndex(QColor)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_colorIndex_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QColor cppArg0 = Shiboken::Converter<QColor >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // colorIndex(QColor)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = const_cast<const QGLContext*>(cppSelf)->colorIndex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLContextFunc_colorIndex_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.colorIndex", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_create(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.create(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:create", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: create(const QGLContext*)
    if (numArgs == 0) {
        overloadId = 0; // create(const QGLContext*)
    } else if (Shiboken::Converter< ::QGLContext * >::isConvertible(pyargs[0])) {
        overloadId = 0; // create(const QGLContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_create_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "shareContext");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "shareContext";
                    else if (Shiboken::Converter< ::QGLContext * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QGLContextFunc_create_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.create(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGLContext * cppArg0 = pyargs[0] ? Shiboken::Converter<QGLContext * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // create(const QGLContext*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGLContext::create(cppArg0) : cppSelf->create(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLContextFunc_create_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLContext = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext.create", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_currentContext(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentContext()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QGLContext * cppResult = QGLContext::currentContext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLContext * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_deleteTexture(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: deleteTexture(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // deleteTexture(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_deleteTexture_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // deleteTexture(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->deleteTexture(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLContextFunc_deleteTexture_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.deleteTexture", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_device(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // device()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPaintDevice * cppResult = const_cast<const QGLContext*>(cppSelf)->device();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPaintDevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_deviceIsPixmap(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // deviceIsPixmap()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLContext*>(cppSelf)->deviceIsPixmap();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_doneCurrent(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doneCurrent()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGLContext::doneCurrent() : cppSelf->doneCurrent());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGLContextFunc_drawTexture(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.drawTexture(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.drawTexture(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:drawTexture", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: drawTexture(QPointF,uint,uint)
    // 1: drawTexture(QRectF,uint,uint)
    if (numArgs >= 2 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // drawTexture(QRectF,uint,uint)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // drawTexture(QRectF,uint,uint)
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // drawTexture(QPointF,uint,uint)
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 0; // drawTexture(QPointF,uint,uint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_drawTexture_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // drawTexture(QPointF,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "textureTarget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "textureTarget";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLContextFunc_drawTexture_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.drawTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                unsigned int cppArg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                    // drawTexture(QPointF,uint,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTexture(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // drawTexture(QRectF,uint,uint)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "textureTarget");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "textureTarget";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
                        else
                            goto Sbk_QGLContextFunc_drawTexture_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.drawTexture(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);
                unsigned int cppArg1 = Shiboken::Converter<unsigned int >::toCpp(pyargs[1]);
                unsigned int cppArg2 = pyargs[2] ? Shiboken::Converter<unsigned int >::toCpp(pyargs[2]) : 0x0DE1;

                if(!PyErr_Occurred()) {
                    // drawTexture(QRectF,uint,uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->drawTexture(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLContextFunc_drawTexture_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, unsigned int, unsigned int = 0x0DE1", "PySide.QtCore.QRectF, unsigned int, unsigned int = 0x0DE1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext.drawTexture", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_format(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // format()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFormat cppResult = const_cast<const QGLContext*>(cppSelf)->format();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_getProcAddress(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: getProcAddress(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // getProcAddress(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_getProcAddress_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // getProcAddress(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                void * cppResult = const_cast<const QGLContext*>(cppSelf)->getProcAddress(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< void * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLContextFunc_getProcAddress_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.getProcAddress", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_initialized(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // initialized()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLContext*>(cppSelf)->initialized();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_isSharing(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSharing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLContext*>(cppSelf)->isSharing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_isValid(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLContext*>(cppSelf)->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_makeCurrent(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // makeCurrent()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGLContext::makeCurrent() : cppSelf->makeCurrent());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGLContextFunc_overlayTransparentColor(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // overlayTransparentColor()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = const_cast<const QGLContext*>(cppSelf)->overlayTransparentColor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_requestedFormat(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // requestedFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFormat cppResult = const_cast<const QGLContext*>(cppSelf)->requestedFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_reset(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // reset()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->reset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGLContextFunc_setDevice(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDevice(QPaintDevice*)
    if (Shiboken::Converter< ::QPaintDevice * >::isConvertible(arg)) {
        overloadId = 0; // setDevice(QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_setDevice_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPaintDevice * cppArg0 = Shiboken::Converter<QPaintDevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDevice(QPaintDevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDevice(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLContextFunc_setDevice_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setDevice", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_setFormat(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFormat(QGLFormat)
    if (Shiboken::Converter< ::QGLFormat >::isConvertible(arg)) {
        overloadId = 0; // setFormat(QGLFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_setFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGLFormat cppArg0 = Shiboken::Converter<QGLFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFormat(QGLFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLContextFunc_setFormat_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setFormat", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_setInitialized(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInitialized(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setInitialized(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_setInitialized_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setInitialized(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setInitialized(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLContextFunc_setInitialized_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setInitialized", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_setTextureCacheLimit(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextureCacheLimit(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTextureCacheLimit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_setTextureCacheLimit_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTextureCacheLimit(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLContext::setTextureCacheLimit(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLContextFunc_setTextureCacheLimit_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setTextureCacheLimit", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_setValid(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setValid(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setValid(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_setValid_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setValid(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setValid(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLContextFunc_setValid_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setValid", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_setWindowCreated(PyObject* self, PyObject* arg)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowCreated(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWindowCreated(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_setWindowCreated_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowCreated(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setWindowCreated(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLContextFunc_setWindowCreated_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLContext.setWindowCreated", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_swapBuffers(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // swapBuffers()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? const_cast<const QGLContext*>(cppSelf)->::QGLContext::swapBuffers() : const_cast<const QGLContext*>(cppSelf)->swapBuffers());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGLContextFunc_textureCacheLimit(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textureCacheLimit()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QGLContext::textureCacheLimit();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLContextFunc_tryVisual(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.tryVisual(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.tryVisual(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:tryVisual", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: tryVisual(QGLFormat,int)
    if (Shiboken::Converter< ::QGLFormat >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // tryVisual(QGLFormat,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // tryVisual(QGLFormat,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLContextFunc_tryVisual_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "bufDepth");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "bufDepth";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QGLContextFunc_tryVisual_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtOpenGL.QGLContext.tryVisual(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGLFormat cppArg0 = Shiboken::Converter<QGLFormat >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 1;

            if(!PyErr_Occurred()) {
                // tryVisual(QGLFormat,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                void * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGLContext::tryVisual(cppArg0, cppArg1) : cppSelf->tryVisual(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< void * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGLContextFunc_tryVisual_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFormat, int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLContext.tryVisual", overloads);
        return 0;
}

static PyObject* Sbk_QGLContextFunc_windowCreated(PyObject* self)
{
    QGLContext* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLContext* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowCreated()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QGLContext*>(cppSelf)->windowCreated();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QGLContext_methods[] = {
    {"areSharing", (PyCFunction)Sbk_QGLContextFunc_areSharing, METH_VARARGS|METH_STATIC},
    {"bindTexture", (PyCFunction)Sbk_QGLContextFunc_bindTexture, METH_VARARGS|METH_KEYWORDS},
    {"chooseContext", (PyCFunction)Sbk_QGLContextFunc_chooseContext, METH_VARARGS|METH_KEYWORDS},
    {"chooseVisual", (PyCFunction)Sbk_QGLContextFunc_chooseVisual, METH_NOARGS},
    {"colorIndex", (PyCFunction)Sbk_QGLContextFunc_colorIndex, METH_O},
    {"create", (PyCFunction)Sbk_QGLContextFunc_create, METH_VARARGS|METH_KEYWORDS},
    {"currentContext", (PyCFunction)Sbk_QGLContextFunc_currentContext, METH_NOARGS|METH_STATIC},
    {"deleteTexture", (PyCFunction)Sbk_QGLContextFunc_deleteTexture, METH_O},
    {"device", (PyCFunction)Sbk_QGLContextFunc_device, METH_NOARGS},
    {"deviceIsPixmap", (PyCFunction)Sbk_QGLContextFunc_deviceIsPixmap, METH_NOARGS},
    {"doneCurrent", (PyCFunction)Sbk_QGLContextFunc_doneCurrent, METH_NOARGS},
    {"drawTexture", (PyCFunction)Sbk_QGLContextFunc_drawTexture, METH_VARARGS|METH_KEYWORDS},
    {"format", (PyCFunction)Sbk_QGLContextFunc_format, METH_NOARGS},
    {"getProcAddress", (PyCFunction)Sbk_QGLContextFunc_getProcAddress, METH_O},
    {"initialized", (PyCFunction)Sbk_QGLContextFunc_initialized, METH_NOARGS},
    {"isSharing", (PyCFunction)Sbk_QGLContextFunc_isSharing, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QGLContextFunc_isValid, METH_NOARGS},
    {"makeCurrent", (PyCFunction)Sbk_QGLContextFunc_makeCurrent, METH_NOARGS},
    {"overlayTransparentColor", (PyCFunction)Sbk_QGLContextFunc_overlayTransparentColor, METH_NOARGS},
    {"requestedFormat", (PyCFunction)Sbk_QGLContextFunc_requestedFormat, METH_NOARGS},
    {"reset", (PyCFunction)Sbk_QGLContextFunc_reset, METH_NOARGS},
    {"setDevice", (PyCFunction)Sbk_QGLContextFunc_setDevice, METH_O},
    {"setFormat", (PyCFunction)Sbk_QGLContextFunc_setFormat, METH_O},
    {"setInitialized", (PyCFunction)Sbk_QGLContextFunc_setInitialized, METH_O},
    {"setTextureCacheLimit", (PyCFunction)Sbk_QGLContextFunc_setTextureCacheLimit, METH_O|METH_STATIC},
    {"setValid", (PyCFunction)Sbk_QGLContextFunc_setValid, METH_O},
    {"setWindowCreated", (PyCFunction)Sbk_QGLContextFunc_setWindowCreated, METH_O},
    {"swapBuffers", (PyCFunction)Sbk_QGLContextFunc_swapBuffers, METH_NOARGS},
    {"textureCacheLimit", (PyCFunction)Sbk_QGLContextFunc_textureCacheLimit, METH_NOARGS|METH_STATIC},
    {"tryVisual", (PyCFunction)Sbk_QGLContextFunc_tryVisual, METH_VARARGS|METH_KEYWORDS},
    {"windowCreated", (PyCFunction)Sbk_QGLContextFunc_windowCreated, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGLContext_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLContext",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGLContext_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGLContext_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtOpenGL_QGLContext_BindOption___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLContext::BindOptions >::toPython(
        Shiboken::Converter<QGLContext::BindOptions>::toCpp(self)
        & Shiboken::Converter< QGLContext::BindOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLContext_BindOption___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLContext::BindOptions >::toPython(
        Shiboken::Converter<QGLContext::BindOptions>::toCpp(self)
        | Shiboken::Converter< QGLContext::BindOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLContext_BindOption___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLContext::BindOptions >::toPython(
        Shiboken::Converter<QGLContext::BindOptions>::toCpp(self)
        ^ Shiboken::Converter< QGLContext::BindOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtOpenGL_QGLContext_BindOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGLContext::BindOptions >::toPython(
        ~Shiboken::Converter<QGLContext::BindOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtOpenGL_QGLContext_BindOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtOpenGL_QGLContext_BindOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtOpenGL_QGLContext_BindOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtOpenGL_QGLContext_BindOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtOpenGL_QGLContext_BindOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtOpenGL_QGLContext_BindOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "BindOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtOpenGL_QGLContext_BindOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QGLContext(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLCONTEXT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGLContext_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGLContext_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGLContext_Type, &Shiboken::callCppDestructor<QGLContext >);
    Py_INCREF((PyObject*)&Sbk_QGLContext_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QGLContext_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QGLContext_Type, "QGLContext*");
    PyModule_AddObject(module, "QGLContext",
        ((PyObject*)&Sbk_QGLContext_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: BindOption
    PyTypeObject* SbkPySide_QtOpenGL_QGLContext_BindOption = Shiboken::Enum::newType("PySide.QtOpenGL.QGLContext.BindOption");
    SbkPySide_QtOpenGL_QGLContext_BindOption->tp_as_number = &SbkPySide_QtOpenGL_QGLContext_BindOption_as_number;
    SbkPySide_QtOpenGLTypes[SBK_QGLCONTEXT_BINDOPTION_IDX] = SbkPySide_QtOpenGL_QGLContext_BindOption;
    if (PyType_Ready(SbkPySide_QtOpenGL_QGLContext_BindOption) < 0)
        return;
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,
            "BindOption",((PyObject*)SbkPySide_QtOpenGL_QGLContext_BindOption));

    // init flags class: QFlags<QGLContext::BindOption>
    SbkPySide_QtOpenGLTypes[SBK_QFLAGS_QGLCONTEXT_BINDOPTION__IDX] = &SbkPySide_QtOpenGL_QGLContext_BindOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtOpenGL_QGLContext_BindOptions_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,
            "BindOptions",((PyObject*)&SbkPySide_QtOpenGL_QGLContext_BindOptions_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLContext_BindOption,(long) QGLContext::NoBindOption, "NoBindOption");
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,"NoBindOption", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption->tp_dict,"NoBindOption", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLContext_BindOption,(long) QGLContext::InvertedYBindOption, "InvertedYBindOption");
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,"InvertedYBindOption", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption->tp_dict,"InvertedYBindOption", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLContext_BindOption,(long) QGLContext::MipmapBindOption, "MipmapBindOption");
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,"MipmapBindOption", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption->tp_dict,"MipmapBindOption", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLContext_BindOption,(long) QGLContext::PremultipliedAlphaBindOption, "PremultipliedAlphaBindOption");
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,"PremultipliedAlphaBindOption", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption->tp_dict,"PremultipliedAlphaBindOption", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLContext_BindOption,(long) QGLContext::LinearFilteringBindOption, "LinearFilteringBindOption");
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,"LinearFilteringBindOption", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption->tp_dict,"LinearFilteringBindOption", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLContext_BindOption,(long) QGLContext::MemoryManagedBindOption, "MemoryManagedBindOption");
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,"MemoryManagedBindOption", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption->tp_dict,"MemoryManagedBindOption", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLContext_BindOption,(long) QGLContext::CanFlipNativePixmapBindOption, "CanFlipNativePixmapBindOption");
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,"CanFlipNativePixmapBindOption", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption->tp_dict,"CanFlipNativePixmapBindOption", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLContext_BindOption,(long) QGLContext::DefaultBindOption, "DefaultBindOption");
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,"DefaultBindOption", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption->tp_dict,"DefaultBindOption", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtOpenGL_QGLContext_BindOption,(long) QGLContext::InternalBindOption, "InternalBindOption");
    PyDict_SetItemString(Sbk_QGLContext_Type.super.ht_type.tp_dict,"InternalBindOption", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtOpenGL_QGLContext_BindOption->tp_dict,"InternalBindOption", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGLContext::BindOption");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::BindOption");
    // end of enum BindOption


    Shiboken::TypeResolver::createObjectTypeResolver<QGLContext >("QGLContext*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLContext >(typeid(QGLContext).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGLContext >(typeid(QGLContextWrapper).name());
    qRegisterMetaType< ::QGLContext* >("QGLContext*");
    qRegisterMetaType< ::QGLContext::BindOption >("QGLContext::BindOption");
    qRegisterMetaType< ::QGLContext::BindOptions >("QGLContext::BindOptions");
}

