/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtscript_python.h"

#include "qscriptvalueiterator_wrapper.h"

// Extra includes
#include <qscriptstring.h>
#include <qscriptvalue.h>
#include <qscriptvalueiterator.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScriptValueIterator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptValueIterator >()))
        return -1;

    QScriptValueIterator* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptValueIterator", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QScriptValueIterator(QScriptValue)
    if (numArgs == 1 && Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[0])) {
        overloadId = 0; // QScriptValueIterator(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueIterator_Init_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QScriptValue cppArg0 = Shiboken::Converter<QScriptValue >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QScriptValueIterator(QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QScriptValueIterator(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptValueIterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QScriptValueIterator_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QScriptValueIterator_Init_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptValueIterator", overloads);
        return -1;
}

static PyObject* Sbk_QScriptValueIteratorFunc_flags(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // flags()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QScriptValue::PropertyFlag> cppResult = const_cast<const QScriptValueIterator*>(cppSelf)->flags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QScriptValue::PropertyFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueIteratorFunc_hasNext(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasNext()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QScriptValueIterator*>(cppSelf)->hasNext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueIteratorFunc_hasPrevious(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasPrevious()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QScriptValueIterator*>(cppSelf)->hasPrevious();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueIteratorFunc_name(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QScriptValueIterator*>(cppSelf)->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueIteratorFunc_next(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // next()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->next();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptValueIteratorFunc_previous(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // previous()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->previous();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptValueIteratorFunc_remove(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // remove()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->remove();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptValueIteratorFunc_scriptName(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scriptName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptString cppResult = const_cast<const QScriptValueIterator*>(cppSelf)->scriptName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptValueIteratorFunc_setValue(PyObject* self, PyObject* arg)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setValue(QScriptValue)
    if (Shiboken::Converter< ::QScriptValue >::isConvertible(arg)) {
        overloadId = 0; // setValue(QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptValueIteratorFunc_setValue_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QScriptValue cppArg0 = Shiboken::Converter<QScriptValue >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setValue(QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptValueIteratorFunc_setValue_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptValueIterator.setValue", overloads);
        return 0;
}

static PyObject* Sbk_QScriptValueIteratorFunc_toBack(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toBack()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->toBack();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptValueIteratorFunc_toFront(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toFront()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->toFront();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptValueIteratorFunc_value(PyObject* self)
{
    QScriptValueIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptValueIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // value()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptValue cppResult = const_cast<const QScriptValueIterator*>(cppSelf)->value();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptValue >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QScriptValueIterator_methods[] = {
    {"flags", (PyCFunction)Sbk_QScriptValueIteratorFunc_flags, METH_NOARGS},
    {"hasNext", (PyCFunction)Sbk_QScriptValueIteratorFunc_hasNext, METH_NOARGS},
    {"hasPrevious", (PyCFunction)Sbk_QScriptValueIteratorFunc_hasPrevious, METH_NOARGS},
    {"name", (PyCFunction)Sbk_QScriptValueIteratorFunc_name, METH_NOARGS},
    {"next", (PyCFunction)Sbk_QScriptValueIteratorFunc_next, METH_NOARGS},
    {"previous", (PyCFunction)Sbk_QScriptValueIteratorFunc_previous, METH_NOARGS},
    {"remove", (PyCFunction)Sbk_QScriptValueIteratorFunc_remove, METH_NOARGS},
    {"scriptName", (PyCFunction)Sbk_QScriptValueIteratorFunc_scriptName, METH_NOARGS},
    {"setValue", (PyCFunction)Sbk_QScriptValueIteratorFunc_setValue, METH_O},
    {"toBack", (PyCFunction)Sbk_QScriptValueIteratorFunc_toBack, METH_NOARGS},
    {"toFront", (PyCFunction)Sbk_QScriptValueIteratorFunc_toFront, METH_NOARGS},
    {"value", (PyCFunction)Sbk_QScriptValueIteratorFunc_value, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QScriptValueIterator_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptValueIterator",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QScriptValueIterator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QScriptValueIterator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QScriptValueIterator(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTVALUEITERATOR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QScriptValueIterator_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QScriptValueIterator_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QScriptValueIterator_Type, &Shiboken::callCppDestructor<QScriptValueIterator >);
    Py_INCREF((PyObject*)&Sbk_QScriptValueIterator_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QScriptValueIterator_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QScriptValueIterator_Type, "QScriptValueIterator*");
    PyModule_AddObject(module, "QScriptValueIterator",
        ((PyObject*)&Sbk_QScriptValueIterator_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptValueIterator >("QScriptValueIterator*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptValueIterator >(typeid(QScriptValueIterator).name());
    qRegisterMetaType< ::QScriptValueIterator* >("QScriptValueIterator*");
}

