/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


#include <Python.h>
#include <shiboken.h>
#include <algorithm>
#include "pyside_qtscript_python.h"



// Extra includes

// Global functions ------------------------------------------------------------

static PyMethodDef QtScript_methods[] = {
    {0} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
void init_QScriptValueIterator(PyObject* module);
void init_QScriptEngineAgent(PyObject* module);
void init_QScriptString(PyObject* module);
void init_QScriptContextInfo(PyObject* module);
void init_QScriptContext(PyObject* module);
void init_QScriptProgram(PyObject* module);
void init_QScriptClassPropertyIterator(PyObject* module);
void init_QScriptClass(PyObject* module);
void init_QScriptValue(PyObject* module);
void init_QScriptable(PyObject* module);
void init_QScriptExtensionInterface(PyObject* module);
void init_QScriptExtensionPlugin(PyObject* module);
void init_QScriptEngine(PyObject* module);

PyTypeObject** SbkPySide_QtScriptTypes;

PyTypeObject** SbkPySide_QtCoreTypes;

// Module initialization ------------------------------------------------------------

#if defined _WIN32 || defined __CYGWIN__
    #define SBK_EXPORT_MODULE __declspec(dllexport)
#elif __GNUC__ >= 4
    #define SBK_EXPORT_MODULE __attribute__ ((visibility("default")))
#else
    #define SBK_EXPORT_MODULE
#endif

extern "C" SBK_EXPORT_MODULE void initQtScript()
{
    if (!Shiboken::importModule("PySide.QtCore", &SbkPySide_QtCoreTypes)) {
        PyErr_SetString(PyExc_ImportError,"could not import PySide.QtCore");
        return;
    }

    Shiboken::init();
    PyObject* module = Py_InitModule("QtScript", QtScript_methods);

    // Create a CObject containing the API pointer array's address
    static PyTypeObject* cppApi[SBK_QtScript_IDX_COUNT];
    SbkPySide_QtScriptTypes = cppApi;
    PyObject* cppApiObject = PyCObject_FromVoidPtr(reinterpret_cast<void*>(cppApi), 0);
    PyModule_AddObject(module, "_Cpp_Api", cppApiObject);

    // Initialize classes in the type system
    init_QScriptValueIterator(module);
    init_QScriptEngineAgent(module);
    init_QScriptString(module);
    init_QScriptContextInfo(module);
    init_QScriptContext(module);
    init_QScriptProgram(module);
    init_QScriptClassPropertyIterator(module);
    init_QScriptClass(module);
    init_QScriptValue(module);
    init_QScriptable(module);
    init_QScriptExtensionInterface(module);
    init_QScriptExtensionPlugin(module);
    init_QScriptEngine(module);

    // Register primitive types on TypeResolver

    if (PyErr_Occurred()) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtScript");
    }
}

