/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebelement_wrapper.h"

// Extra includes
#include <QStringList>
#include <qpainter.h>
#include <qrect.h>
#include <qwebelement.h>
#include <qwebframe.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebElement_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QWebElement >()))
        return -1;

    QWebElement* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QWebElement", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QWebElement()
    // 1: QWebElement(QWebElement)
    if (numArgs == 0) {
        overloadId = 0; // QWebElement()
    } else if (numArgs == 1 && Shiboken::Converter< ::QWebElement >::isConvertible(pyargs[0])) {
        overloadId = 1; // QWebElement(QWebElement)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElement_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QWebElement()
            {

                if(!PyErr_Occurred()) {
                    // QWebElement()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QWebElement();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QWebElement(QWebElement)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QWebElement cppArg0 = Shiboken::Converter<QWebElement >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QWebElement(QWebElement)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QWebElement(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QWebElement >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWebElement_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QWebElement_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement", overloads);
        return -1;
}

static PyObject* Sbk_QWebElementFunc_addClass(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addClass(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // addClass(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_addClass_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addClass(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addClass(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_addClass_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.addClass", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_appendInside(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: appendInside(QString)
    // 1: appendInside(QWebElement)
    if (Shiboken::Converter< ::QWebElement >::isConvertible(arg)) {
        overloadId = 1; // appendInside(QWebElement)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // appendInside(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_appendInside_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // appendInside(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // appendInside(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->appendInside(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // appendInside(QWebElement)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWebElement cppArg0 = Shiboken::Converter<QWebElement >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // appendInside(QWebElement)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->appendInside(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_appendInside_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.appendInside", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_appendOutside(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: appendOutside(QString)
    // 1: appendOutside(QWebElement)
    if (Shiboken::Converter< ::QWebElement >::isConvertible(arg)) {
        overloadId = 1; // appendOutside(QWebElement)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // appendOutside(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_appendOutside_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // appendOutside(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // appendOutside(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->appendOutside(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // appendOutside(QWebElement)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWebElement cppArg0 = Shiboken::Converter<QWebElement >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // appendOutside(QWebElement)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->appendOutside(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_appendOutside_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.appendOutside", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_attribute(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attribute(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attribute(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:attribute", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: attribute(QString,QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // attribute(QString,QString)const
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // attribute(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_attribute_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defaultValue");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "defaultValue";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QWebElementFunc_attribute_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attribute(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // attribute(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebElement*>(cppSelf)->attribute(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebElementFunc_attribute_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.attribute", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_attributeNS(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNS(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNS(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:attributeNS", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: attributeNS(QString,QString,QString)const
    if (numArgs >= 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // attributeNS(QString,QString,QString)const
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
            overloadId = 0; // attributeNS(QString,QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_attributeNS_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "defaultValue");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "defaultValue";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[2] = value;
                    else
                        goto Sbk_QWebElementFunc_attributeNS_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNS(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = pyargs[2] ? Shiboken::Converter<QString >::toCpp(pyargs[2]) : QString();

            if(!PyErr_Occurred()) {
                // attributeNS(QString,QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebElement*>(cppSelf)->attributeNS(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebElementFunc_attributeNS_TypeError:
        const char* overloads[] = {"QString, QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.attributeNS", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_attributeNames(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNames(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:attributeNames", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: attributeNames(QString)const
    if (numArgs == 0) {
        overloadId = 0; // attributeNames(QString)const
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // attributeNames(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_attributeNames_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "namespaceUri");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "namespaceUri";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_QWebElementFunc_attributeNames_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebElement.attributeNames(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();

            if(!PyErr_Occurred()) {
                // attributeNames(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QWebElement*>(cppSelf)->attributeNames(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebElementFunc_attributeNames_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.attributeNames", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_classes(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // classes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = const_cast<const QWebElement*>(cppSelf)->classes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_clone(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clone()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebElement cppResult = const_cast<const QWebElement*>(cppSelf)->clone();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_document(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // document()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebElement cppResult = const_cast<const QWebElement*>(cppSelf)->document();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_encloseContentsWith(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: encloseContentsWith(QString)
    // 1: encloseContentsWith(QWebElement)
    if (Shiboken::Converter< ::QWebElement >::isConvertible(arg)) {
        overloadId = 1; // encloseContentsWith(QWebElement)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // encloseContentsWith(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_encloseContentsWith_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // encloseContentsWith(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // encloseContentsWith(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->encloseContentsWith(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // encloseContentsWith(QWebElement)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWebElement cppArg0 = Shiboken::Converter<QWebElement >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // encloseContentsWith(QWebElement)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->encloseContentsWith(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_encloseContentsWith_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.encloseContentsWith", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_encloseWith(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: encloseWith(QString)
    // 1: encloseWith(QWebElement)
    if (Shiboken::Converter< ::QWebElement >::isConvertible(arg)) {
        overloadId = 1; // encloseWith(QWebElement)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // encloseWith(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_encloseWith_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // encloseWith(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // encloseWith(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->encloseWith(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // encloseWith(QWebElement)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWebElement cppArg0 = Shiboken::Converter<QWebElement >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // encloseWith(QWebElement)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->encloseWith(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_encloseWith_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.encloseWith", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_evaluateJavaScript(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: evaluateJavaScript(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // evaluateJavaScript(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_evaluateJavaScript_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // evaluateJavaScript(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = cppSelf->evaluateJavaScript(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebElementFunc_evaluateJavaScript_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.evaluateJavaScript", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_findAll(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findAll(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // findAll(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_findAll_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // findAll(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebElementCollection cppResult = const_cast<const QWebElement*>(cppSelf)->findAll(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebElementCollection >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebElementFunc_findAll_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.findAll", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_findFirst(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: findFirst(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // findFirst(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_findFirst_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // findFirst(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebElement cppResult = const_cast<const QWebElement*>(cppSelf)->findFirst(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebElementFunc_findFirst_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.findFirst", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_firstChild(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // firstChild()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebElement cppResult = const_cast<const QWebElement*>(cppSelf)->firstChild();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_geometry(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // geometry()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = const_cast<const QWebElement*>(cppSelf)->geometry();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_hasAttribute(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasAttribute(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // hasAttribute(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_hasAttribute_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasAttribute(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWebElement*>(cppSelf)->hasAttribute(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebElementFunc_hasAttribute_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.hasAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_hasAttributeNS(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "hasAttributeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: hasAttributeNS(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // hasAttributeNS(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_hasAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // hasAttributeNS(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWebElement*>(cppSelf)->hasAttributeNS(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebElementFunc_hasAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.hasAttributeNS", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_hasAttributes(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasAttributes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWebElement*>(cppSelf)->hasAttributes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_hasClass(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasClass(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // hasClass(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_hasClass_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasClass(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWebElement*>(cppSelf)->hasClass(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebElementFunc_hasClass_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.hasClass", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_hasFocus(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasFocus()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWebElement*>(cppSelf)->hasFocus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_isNull(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = const_cast<const QWebElement*>(cppSelf)->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_lastChild(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lastChild()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebElement cppResult = const_cast<const QWebElement*>(cppSelf)->lastChild();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_localName(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // localName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebElement*>(cppSelf)->localName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_namespaceUri(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // namespaceUri()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebElement*>(cppSelf)->namespaceUri();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_nextSibling(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nextSibling()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebElement cppResult = const_cast<const QWebElement*>(cppSelf)->nextSibling();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_parent(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // parent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebElement cppResult = const_cast<const QWebElement*>(cppSelf)->parent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_prefix(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // prefix()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebElement*>(cppSelf)->prefix();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_prependInside(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: prependInside(QString)
    // 1: prependInside(QWebElement)
    if (Shiboken::Converter< ::QWebElement >::isConvertible(arg)) {
        overloadId = 1; // prependInside(QWebElement)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // prependInside(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_prependInside_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // prependInside(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // prependInside(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->prependInside(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // prependInside(QWebElement)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWebElement cppArg0 = Shiboken::Converter<QWebElement >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // prependInside(QWebElement)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->prependInside(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_prependInside_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.prependInside", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_prependOutside(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: prependOutside(QString)
    // 1: prependOutside(QWebElement)
    if (Shiboken::Converter< ::QWebElement >::isConvertible(arg)) {
        overloadId = 1; // prependOutside(QWebElement)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // prependOutside(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_prependOutside_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // prependOutside(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // prependOutside(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->prependOutside(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // prependOutside(QWebElement)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWebElement cppArg0 = Shiboken::Converter<QWebElement >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // prependOutside(QWebElement)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->prependOutside(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_prependOutside_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.prependOutside", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_previousSibling(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // previousSibling()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebElement cppResult = const_cast<const QWebElement*>(cppSelf)->previousSibling();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebElement >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_removeAllChildren(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // removeAllChildren()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeAllChildren();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWebElementFunc_removeAttribute(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAttribute(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // removeAttribute(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_removeAttribute_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeAttribute(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeAttribute(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_removeAttribute_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.removeAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_removeAttributeNS(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "removeAttributeNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeAttributeNS(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // removeAttributeNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_removeAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // removeAttributeNS(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeAttributeNS(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_removeAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.removeAttributeNS", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_removeClass(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeClass(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // removeClass(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_removeClass_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeClass(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeClass(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_removeClass_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.removeClass", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_removeFromDocument(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // removeFromDocument()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeFromDocument();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWebElementFunc_render(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: render(QPainter*)
    if (Shiboken::Converter< ::QPainter * >::isConvertible(arg)) {
        overloadId = 0; // render(QPainter*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_render_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // render(QPainter*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->render(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_render_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.render", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_replace(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: replace(QString)
    // 1: replace(QWebElement)
    if (Shiboken::Converter< ::QWebElement >::isConvertible(arg)) {
        overloadId = 1; // replace(QWebElement)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // replace(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_replace_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // replace(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // replace(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->replace(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // replace(QWebElement)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWebElement cppArg0 = Shiboken::Converter<QWebElement >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // replace(QWebElement)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->replace(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_replace_TypeError:
        const char* overloads[] = {"QString", "PySide.QtWebKit.QWebElement", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.replace", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_setAttribute(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttribute", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAttribute(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setAttribute(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_setAttribute_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setAttribute(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttribute(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_setAttribute_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.setAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_setAttributeNS(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttributeNS", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setAttributeNS(QString,QString,QString)
    if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // setAttributeNS(QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_setAttributeNS_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setAttributeNS(QString,QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttributeNS(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_setAttributeNS_TypeError:
        const char* overloads[] = {"QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.setAttributeNS", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_setFocus(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // setFocus()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFocus();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWebElementFunc_setInnerXml(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInnerXml(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setInnerXml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_setInnerXml_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setInnerXml(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setInnerXml(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_setInnerXml_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.setInnerXml", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_setOuterXml(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOuterXml(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setOuterXml(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_setOuterXml_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOuterXml(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOuterXml(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_setOuterXml_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.setOuterXml", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_setPlainText(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPlainText(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_setPlainText_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPlainText(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPlainText(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_setPlainText_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.setPlainText", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_setStyleProperty(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setStyleProperty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setStyleProperty(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setStyleProperty(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_setStyleProperty_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setStyleProperty(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStyleProperty(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_setStyleProperty_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.setStyleProperty", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_styleProperty(PyObject* self, PyObject* args)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "styleProperty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: styleProperty(QString,QWebElement::StyleResolveStrategy)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QWebElement::StyleResolveStrategy >::isConvertible(pyargs[1])) {
        overloadId = 0; // styleProperty(QString,QWebElement::StyleResolveStrategy)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_styleProperty_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QWebElement::StyleResolveStrategy cppArg1 = Shiboken::Converter<QWebElement::StyleResolveStrategy >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // styleProperty(QString,QWebElement::StyleResolveStrategy)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebElement*>(cppSelf)->styleProperty(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebElementFunc_styleProperty_TypeError:
        const char* overloads[] = {"QString, PySide.QtWebKit.QWebElement.StyleResolveStrategy", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebElement.styleProperty", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_tagName(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // tagName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebElement*>(cppSelf)->tagName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_takeFromDocument(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // takeFromDocument()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebElement & cppResult = cppSelf->takeFromDocument();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebElement & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_toInnerXml(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toInnerXml()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebElement*>(cppSelf)->toInnerXml();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_toOuterXml(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toOuterXml()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebElement*>(cppSelf)->toOuterXml();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_toPlainText(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toPlainText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = const_cast<const QWebElement*>(cppSelf)->toPlainText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebElementFunc_toggleClass(PyObject* self, PyObject* arg)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: toggleClass(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // toggleClass(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebElementFunc_toggleClass_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toggleClass(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->toggleClass(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebElementFunc_toggleClass_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebElement.toggleClass", overloads);
        return 0;
}

static PyObject* Sbk_QWebElementFunc_webFrame(PyObject* self)
{
    QWebElement* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebElement* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // webFrame()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebFrame * cppResult = const_cast<const QWebElement*>(cppSelf)->webFrame();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebFrame * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QWebElement___copy__(PyObject *self)
{
        QWebElement* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QWebElement*>::toCpp(self);
        PyObject* pyResult = 0;
        QWebElement* copy = new QWebElement(*cppSelf);
        pyResult = Shiboken::Converter<QWebElement*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QWebElement_methods[] = {
    {"addClass", (PyCFunction)Sbk_QWebElementFunc_addClass, METH_O},
    {"appendInside", (PyCFunction)Sbk_QWebElementFunc_appendInside, METH_O},
    {"appendOutside", (PyCFunction)Sbk_QWebElementFunc_appendOutside, METH_O},
    {"attribute", (PyCFunction)Sbk_QWebElementFunc_attribute, METH_VARARGS|METH_KEYWORDS},
    {"attributeNS", (PyCFunction)Sbk_QWebElementFunc_attributeNS, METH_VARARGS|METH_KEYWORDS},
    {"attributeNames", (PyCFunction)Sbk_QWebElementFunc_attributeNames, METH_VARARGS|METH_KEYWORDS},
    {"classes", (PyCFunction)Sbk_QWebElementFunc_classes, METH_NOARGS},
    {"clone", (PyCFunction)Sbk_QWebElementFunc_clone, METH_NOARGS},
    {"document", (PyCFunction)Sbk_QWebElementFunc_document, METH_NOARGS},
    {"encloseContentsWith", (PyCFunction)Sbk_QWebElementFunc_encloseContentsWith, METH_O},
    {"encloseWith", (PyCFunction)Sbk_QWebElementFunc_encloseWith, METH_O},
    {"evaluateJavaScript", (PyCFunction)Sbk_QWebElementFunc_evaluateJavaScript, METH_O},
    {"findAll", (PyCFunction)Sbk_QWebElementFunc_findAll, METH_O},
    {"findFirst", (PyCFunction)Sbk_QWebElementFunc_findFirst, METH_O},
    {"firstChild", (PyCFunction)Sbk_QWebElementFunc_firstChild, METH_NOARGS},
    {"geometry", (PyCFunction)Sbk_QWebElementFunc_geometry, METH_NOARGS},
    {"hasAttribute", (PyCFunction)Sbk_QWebElementFunc_hasAttribute, METH_O},
    {"hasAttributeNS", (PyCFunction)Sbk_QWebElementFunc_hasAttributeNS, METH_VARARGS},
    {"hasAttributes", (PyCFunction)Sbk_QWebElementFunc_hasAttributes, METH_NOARGS},
    {"hasClass", (PyCFunction)Sbk_QWebElementFunc_hasClass, METH_O},
    {"hasFocus", (PyCFunction)Sbk_QWebElementFunc_hasFocus, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QWebElementFunc_isNull, METH_NOARGS},
    {"lastChild", (PyCFunction)Sbk_QWebElementFunc_lastChild, METH_NOARGS},
    {"localName", (PyCFunction)Sbk_QWebElementFunc_localName, METH_NOARGS},
    {"namespaceUri", (PyCFunction)Sbk_QWebElementFunc_namespaceUri, METH_NOARGS},
    {"nextSibling", (PyCFunction)Sbk_QWebElementFunc_nextSibling, METH_NOARGS},
    {"parent", (PyCFunction)Sbk_QWebElementFunc_parent, METH_NOARGS},
    {"prefix", (PyCFunction)Sbk_QWebElementFunc_prefix, METH_NOARGS},
    {"prependInside", (PyCFunction)Sbk_QWebElementFunc_prependInside, METH_O},
    {"prependOutside", (PyCFunction)Sbk_QWebElementFunc_prependOutside, METH_O},
    {"previousSibling", (PyCFunction)Sbk_QWebElementFunc_previousSibling, METH_NOARGS},
    {"removeAllChildren", (PyCFunction)Sbk_QWebElementFunc_removeAllChildren, METH_NOARGS},
    {"removeAttribute", (PyCFunction)Sbk_QWebElementFunc_removeAttribute, METH_O},
    {"removeAttributeNS", (PyCFunction)Sbk_QWebElementFunc_removeAttributeNS, METH_VARARGS},
    {"removeClass", (PyCFunction)Sbk_QWebElementFunc_removeClass, METH_O},
    {"removeFromDocument", (PyCFunction)Sbk_QWebElementFunc_removeFromDocument, METH_NOARGS},
    {"render", (PyCFunction)Sbk_QWebElementFunc_render, METH_O},
    {"replace", (PyCFunction)Sbk_QWebElementFunc_replace, METH_O},
    {"setAttribute", (PyCFunction)Sbk_QWebElementFunc_setAttribute, METH_VARARGS},
    {"setAttributeNS", (PyCFunction)Sbk_QWebElementFunc_setAttributeNS, METH_VARARGS},
    {"setFocus", (PyCFunction)Sbk_QWebElementFunc_setFocus, METH_NOARGS},
    {"setInnerXml", (PyCFunction)Sbk_QWebElementFunc_setInnerXml, METH_O},
    {"setOuterXml", (PyCFunction)Sbk_QWebElementFunc_setOuterXml, METH_O},
    {"setPlainText", (PyCFunction)Sbk_QWebElementFunc_setPlainText, METH_O},
    {"setStyleProperty", (PyCFunction)Sbk_QWebElementFunc_setStyleProperty, METH_VARARGS},
    {"styleProperty", (PyCFunction)Sbk_QWebElementFunc_styleProperty, METH_VARARGS},
    {"tagName", (PyCFunction)Sbk_QWebElementFunc_tagName, METH_NOARGS},
    {"takeFromDocument", (PyCFunction)Sbk_QWebElementFunc_takeFromDocument, METH_NOARGS},
    {"toInnerXml", (PyCFunction)Sbk_QWebElementFunc_toInnerXml, METH_NOARGS},
    {"toOuterXml", (PyCFunction)Sbk_QWebElementFunc_toOuterXml, METH_NOARGS},
    {"toPlainText", (PyCFunction)Sbk_QWebElementFunc_toPlainText, METH_NOARGS},
    {"toggleClass", (PyCFunction)Sbk_QWebElementFunc_toggleClass, METH_O},
    {"webFrame", (PyCFunction)Sbk_QWebElementFunc_webFrame, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QWebElement___copy__, METH_NOARGS},
    {0} // Sentinel
};

static int Sbk_QWebElement___nb_bool(PyObject* pyObj)
{
    if (!Shiboken::Object::isValid(pyObj))
        return -1;
    const ::QWebElement* cppSelf = Shiboken::Converter< ::QWebElement*>::toCpp(pyObj);
    int result;
    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
    result = !cppSelf->isNull();
    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    return result;
}

// type has number operators
static PyNumberMethods Sbk_QWebElement_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              Sbk_QWebElement___nb_bool,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QWebElement_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QWebElement& cppSelf = *Shiboken::Converter< QWebElement* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QWebElement >::isConvertible(arg)) {
                // operator!=(const QWebElement & o) const
                QWebElement cppArg0 = Shiboken::Converter< ::QWebElement >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QWebElement >::isConvertible(arg)) {
                // operator==(const QWebElement & o) const
                QWebElement cppArg0 = Shiboken::Converter< ::QWebElement >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            goto Sbk_QWebElement_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QWebElement_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWebElement_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebElement",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QWebElement_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QWebElement_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWebElement_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QWebElement_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QWebElement(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBELEMENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWebElement_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QWebElement_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QWebElement_Type, &Shiboken::callCppDestructor<QWebElement >);
    Py_INCREF((PyObject*)&Sbk_QWebElement_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QWebElement_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QWebElement_Type, "QWebElement");
    PyModule_AddObject(module, "QWebElement",
        ((PyObject*)&Sbk_QWebElement_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleResolveStrategy
    PyTypeObject* SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy = Shiboken::Enum::newType("PySide.QtWebKit.QWebElement.StyleResolveStrategy");
    SbkPySide_QtWebKitTypes[SBK_QWEBELEMENT_STYLERESOLVESTRATEGY_IDX] = SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebElement_Type.super.ht_type.tp_dict,
            "StyleResolveStrategy",((PyObject*)SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy,(long) QWebElement::InlineStyle, "InlineStyle");
    PyDict_SetItemString(Sbk_QWebElement_Type.super.ht_type.tp_dict,"InlineStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy->tp_dict,"InlineStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy,(long) QWebElement::CascadedStyle, "CascadedStyle");
    PyDict_SetItemString(Sbk_QWebElement_Type.super.ht_type.tp_dict,"CascadedStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy->tp_dict,"CascadedStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy,(long) QWebElement::ComputedStyle, "ComputedStyle");
    PyDict_SetItemString(Sbk_QWebElement_Type.super.ht_type.tp_dict,"ComputedStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebElement_StyleResolveStrategy->tp_dict,"ComputedStyle", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebElement::StyleResolveStrategy");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleResolveStrategy");
    // end of enum StyleResolveStrategy


    Shiboken::TypeResolver::createValueTypeResolver<QWebElement >("QWebElement");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebElement >("QWebElement*");
    Shiboken::TypeResolver::createValueTypeResolver<QWebElement >(typeid(QWebElement).name());
    qRegisterMetaType< ::QWebElement >("QWebElement");
    qRegisterMetaType< ::QWebElement::StyleResolveStrategy >("QWebElement::StyleResolveStrategy");
}

