/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_effectinterface_wrapper.h"

// Extra includes
#include <QList>
#include <effectparameter.h>

using namespace Phonon;

// Native ---------------------------------------------------------

EffectInterfaceWrapper::EffectInterfaceWrapper() : Phonon::EffectInterface() {
    // ... middle
}

QVariant EffectInterfaceWrapper::parameterValue(const Phonon::EffectParameter & arg__1) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "parameterValue"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'EffectInterface.parameterValue()' not implemented.");
        return QVariant(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Phonon::EffectParameter >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "EffectInterface.parameterValue", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

QList<Phonon::EffectParameter > EffectInterfaceWrapper::parameters() const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QList<Phonon::EffectParameter >();
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "parameters"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'EffectInterface.parameters()' not implemented.");
        return QList<Phonon::EffectParameter >();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<Phonon::EffectParameter >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<Phonon::EffectParameter > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "EffectInterface.parameters", "list", pyResult->ob_type->tp_name);
        return QList<Phonon::EffectParameter >();
    }
    QList<Phonon::EffectParameter > cppResult(Shiboken::Converter< ::QList<Phonon::EffectParameter > >::toCpp(pyResult));
    return cppResult;
}

void EffectInterfaceWrapper::setParameterValue(const Phonon::EffectParameter & arg__1, const QVariant & newValue)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setParameterValue"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'EffectInterface.setParameterValue()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::Phonon::EffectParameter >::toPython(arg__1),
        Shiboken::Converter< QVariant >::toPython(newValue)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

EffectInterfaceWrapper::~EffectInterfaceWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Phonon_EffectInterface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::EffectInterface >()))
        return -1;

    EffectInterfaceWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_phononTypes[SBK_PHONON_EFFECTINTERFACE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'Phonon::EffectInterface' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // EffectInterface()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new EffectInterfaceWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::EffectInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_Phonon_EffectInterfaceFunc_parameterValue(PyObject* self, PyObject* arg)
{
    Phonon::EffectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::EffectInterface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: parameterValue(Phonon::EffectParameter)const
    if (Shiboken::Converter< ::Phonon::EffectParameter >::isConvertible(arg)) {
        overloadId = 0; // parameterValue(Phonon::EffectParameter)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_EffectInterfaceFunc_parameterValue_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            Phonon::EffectParameter cppArg0 = Shiboken::Converter<Phonon::EffectParameter >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // parameterValue(Phonon::EffectParameter)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'EffectInterface.parameterValue()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = const_cast<const Phonon::EffectInterface*>(cppSelf)->parameterValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_Phonon_EffectInterfaceFunc_parameterValue_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::EffectParameter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.EffectInterface.parameterValue", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_EffectInterfaceFunc_parameters(PyObject* self)
{
    Phonon::EffectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::EffectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // parameters()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'EffectInterface.parameters()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<Phonon::EffectParameter > cppResult = const_cast<const Phonon::EffectInterface*>(cppSelf)->parameters();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<Phonon::EffectParameter > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_EffectInterfaceFunc_setParameterValue(PyObject* self, PyObject* args)
{
    Phonon::EffectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::EffectInterface* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setParameterValue", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setParameterValue(Phonon::EffectParameter,QVariant)
    if (numArgs == 2 && Shiboken::Converter< ::Phonon::EffectParameter >::isConvertible(pyargs[0]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setParameterValue(Phonon::EffectParameter,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_EffectInterfaceFunc_setParameterValue_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            Phonon::EffectParameter cppArg0 = Shiboken::Converter<Phonon::EffectParameter >::toCpp(pyargs[0]);
            QVariant cppArg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setParameterValue(Phonon::EffectParameter,QVariant)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'EffectInterface.setParameterValue()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setParameterValue(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_EffectInterfaceFunc_setParameterValue_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::EffectParameter, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.EffectInterface.setParameterValue", overloads);
        return 0;
}

static PyMethodDef Sbk_Phonon_EffectInterface_methods[] = {
    {"parameterValue", (PyCFunction)Sbk_Phonon_EffectInterfaceFunc_parameterValue, METH_O},
    {"parameters", (PyCFunction)Sbk_Phonon_EffectInterfaceFunc_parameters, METH_NOARGS},
    {"setParameterValue", (PyCFunction)Sbk_Phonon_EffectInterfaceFunc_setParameterValue, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_EffectInterface_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.Phonon.EffectInterface",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_EffectInterface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_Phonon_EffectInterface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_Phonon_EffectInterface(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_EFFECTINTERFACE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_EffectInterface_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_Phonon_EffectInterface_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_Phonon_EffectInterface_Type, &Shiboken::callCppDestructor<Phonon::EffectInterface >);
    Py_INCREF((PyObject*)&Sbk_Phonon_EffectInterface_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_Phonon_EffectInterface_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_Phonon_EffectInterface_Type, "Phonon::EffectInterface*");
    PyDict_SetItemString(module,"EffectInterface", (PyObject*)&Sbk_Phonon_EffectInterface_Type);

    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::EffectInterface >("Phonon::EffectInterface*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::EffectInterface >("Phonon::EffectInterface$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::EffectInterface >(typeid(Phonon::EffectInterface).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::EffectInterface >(typeid(EffectInterfaceWrapper).name());
}

