/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_phonon_python.h"

#include "phonon_volumefadereffect_wrapper.h"

// Extra includes
#include <QList>
#include <effectparameter.h>
#include <objectdescription.h>
#include <path.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>

using namespace Phonon;

// Native ---------------------------------------------------------

VolumeFaderEffectWrapper::VolumeFaderEffectWrapper(QObject * parent) : Phonon::VolumeFaderEffect(parent) {
    // ... middle
}

void VolumeFaderEffectWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void VolumeFaderEffectWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void VolumeFaderEffectWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void VolumeFaderEffectWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool VolumeFaderEffectWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "VolumeFaderEffect.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool VolumeFaderEffectWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "VolumeFaderEffect.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void VolumeFaderEffectWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

const QMetaObject* VolumeFaderEffectWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int VolumeFaderEffectWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = Phonon::VolumeFaderEffect::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

VolumeFaderEffectWrapper::~VolumeFaderEffectWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Phonon_VolumeFaderEffect_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::VolumeFaderEffect >()))
        return -1;

    VolumeFaderEffectWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:VolumeFaderEffect", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: VolumeFaderEffect(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // VolumeFaderEffect(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // VolumeFaderEffect(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_VolumeFaderEffect_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
                    else
                        goto Sbk_Phonon_VolumeFaderEffect_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.phonon.VolumeFaderEffect(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // VolumeFaderEffect(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new VolumeFaderEffectWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::VolumeFaderEffect >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_Phonon_VolumeFaderEffect_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_Phonon_VolumeFaderEffect_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.VolumeFaderEffect", overloads);
        return -1;
}

static PyObject* Sbk_Phonon_VolumeFaderEffectFunc_fadeCurve(PyObject* self)
{
    Phonon::VolumeFaderEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::VolumeFaderEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fadeCurve()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Phonon::VolumeFaderEffect::FadeCurve cppResult = const_cast<const Phonon::VolumeFaderEffect*>(cppSelf)->fadeCurve();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Phonon::VolumeFaderEffect::FadeCurve >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_VolumeFaderEffectFunc_fadeIn(PyObject* self, PyObject* arg)
{
    Phonon::VolumeFaderEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::VolumeFaderEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: fadeIn(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fadeIn(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_VolumeFaderEffectFunc_fadeIn_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fadeIn(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->fadeIn(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_VolumeFaderEffectFunc_fadeIn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.VolumeFaderEffect.fadeIn", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_VolumeFaderEffectFunc_fadeOut(PyObject* self, PyObject* arg)
{
    Phonon::VolumeFaderEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::VolumeFaderEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: fadeOut(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fadeOut(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_VolumeFaderEffectFunc_fadeOut_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fadeOut(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->fadeOut(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_VolumeFaderEffectFunc_fadeOut_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.VolumeFaderEffect.fadeOut", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_VolumeFaderEffectFunc_fadeTo(PyObject* self, PyObject* args)
{
    Phonon::VolumeFaderEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::VolumeFaderEffect* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fadeTo", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fadeTo(float,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // fadeTo(float,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_VolumeFaderEffectFunc_fadeTo_TypeError;

    // Call function/method
    {
        {
            float cppArg0 = Shiboken::Converter<float >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // fadeTo(float,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->fadeTo(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_VolumeFaderEffectFunc_fadeTo_TypeError:
        const char* overloads[] = {"float, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.VolumeFaderEffect.fadeTo", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_VolumeFaderEffectFunc_setFadeCurve(PyObject* self, PyObject* arg)
{
    Phonon::VolumeFaderEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::VolumeFaderEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFadeCurve(Phonon::VolumeFaderEffect::FadeCurve)
    if (Shiboken::Converter< ::Phonon::VolumeFaderEffect::FadeCurve >::isConvertible(arg)) {
        overloadId = 0; // setFadeCurve(Phonon::VolumeFaderEffect::FadeCurve)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_VolumeFaderEffectFunc_setFadeCurve_TypeError;

    // Call function/method
    {
        {
            Phonon::VolumeFaderEffect::FadeCurve cppArg0 = Shiboken::Converter<Phonon::VolumeFaderEffect::FadeCurve >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFadeCurve(Phonon::VolumeFaderEffect::FadeCurve)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFadeCurve(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_VolumeFaderEffectFunc_setFadeCurve_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::VolumeFaderEffect.FadeCurve", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.VolumeFaderEffect.setFadeCurve", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_VolumeFaderEffectFunc_setVolume(PyObject* self, PyObject* arg)
{
    Phonon::VolumeFaderEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::VolumeFaderEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVolume(float)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVolume(float)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_VolumeFaderEffectFunc_setVolume_TypeError;

    // Call function/method
    {
        {
            float cppArg0 = Shiboken::Converter<float >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVolume(float)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVolume(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_VolumeFaderEffectFunc_setVolume_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.VolumeFaderEffect.setVolume", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_VolumeFaderEffectFunc_setVolumeDecibel(PyObject* self, PyObject* arg)
{
    Phonon::VolumeFaderEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::VolumeFaderEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVolumeDecibel(double)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setVolumeDecibel(double)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_VolumeFaderEffectFunc_setVolumeDecibel_TypeError;

    // Call function/method
    {
        {
            double cppArg0 = Shiboken::Converter<double >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVolumeDecibel(double)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVolumeDecibel(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_VolumeFaderEffectFunc_setVolumeDecibel_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.VolumeFaderEffect.setVolumeDecibel", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_VolumeFaderEffectFunc_volume(PyObject* self)
{
    Phonon::VolumeFaderEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::VolumeFaderEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // volume()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                float cppResult = const_cast<const Phonon::VolumeFaderEffect*>(cppSelf)->volume();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< float >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_VolumeFaderEffectFunc_volumeDecibel(PyObject* self)
{
    Phonon::VolumeFaderEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::VolumeFaderEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // volumeDecibel()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                double cppResult = const_cast<const Phonon::VolumeFaderEffect*>(cppSelf)->volumeDecibel();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_Phonon_VolumeFaderEffect_methods[] = {
    {"fadeCurve", (PyCFunction)Sbk_Phonon_VolumeFaderEffectFunc_fadeCurve, METH_NOARGS},
    {"fadeIn", (PyCFunction)Sbk_Phonon_VolumeFaderEffectFunc_fadeIn, METH_O},
    {"fadeOut", (PyCFunction)Sbk_Phonon_VolumeFaderEffectFunc_fadeOut, METH_O},
    {"fadeTo", (PyCFunction)Sbk_Phonon_VolumeFaderEffectFunc_fadeTo, METH_VARARGS},
    {"setFadeCurve", (PyCFunction)Sbk_Phonon_VolumeFaderEffectFunc_setFadeCurve, METH_O},
    {"setVolume", (PyCFunction)Sbk_Phonon_VolumeFaderEffectFunc_setVolume, METH_O},
    {"setVolumeDecibel", (PyCFunction)Sbk_Phonon_VolumeFaderEffectFunc_setVolumeDecibel, METH_O},
    {"volume", (PyCFunction)Sbk_Phonon_VolumeFaderEffectFunc_volume, METH_NOARGS},
    {"volumeDecibel", (PyCFunction)Sbk_Phonon_VolumeFaderEffectFunc_volumeDecibel, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_Phonon_VolumeFaderEffectSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    Phonon::VolumeFaderEffect* me = reinterpret_cast<Phonon::VolumeFaderEffect*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_phononTypes[SBK_PHONON_EFFECT_IDX]))
        return static_cast<Phonon::Effect*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_phononTypes[SBK_PHONON_MEDIANODE_IDX]))
        return static_cast<Phonon::MediaNode*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_VolumeFaderEffect_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.Phonon.VolumeFaderEffect",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_VolumeFaderEffect_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_Phonon_VolumeFaderEffect_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_Phonon_VolumeFaderEffect_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<Phonon::VolumeFaderEffect*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_Phonon_VolumeFaderEffect_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<Phonon::MediaNode >()) && dynamic_cast<Phonon::VolumeFaderEffect*>(reinterpret_cast<Phonon::MediaNode*>(cptr)))
        return &Sbk_Phonon_VolumeFaderEffect_Type;
    return 0;
}


void init_Phonon_VolumeFaderEffect(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_VOLUMEFADEREFFECT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_VolumeFaderEffect_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_Phonon_VolumeFaderEffect_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_Phonon_VolumeFaderEffect_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_Phonon_VolumeFaderEffect_Type, &Phonon::VolumeFaderEffect::staticMetaObject);    Sbk_Phonon_VolumeFaderEffect_Type.super.ht_type.tp_base = SbkPySide_phononTypes[SBK_PHONON_EFFECT_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_phononTypes[SBK_PHONON_EFFECT_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_Phonon_VolumeFaderEffect_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_Phonon_VolumeFaderEffect_Type, &Sbk_Phonon_VolumeFaderEffectSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_Phonon_VolumeFaderEffect_Type, &Shiboken::callCppDestructor<Phonon::VolumeFaderEffect >);
    Py_INCREF((PyObject*)&Sbk_Phonon_VolumeFaderEffect_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_Phonon_VolumeFaderEffect_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_Phonon_VolumeFaderEffect_Type, &Sbk_Phonon_VolumeFaderEffect_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_phononTypes[SBK_PHONON_EFFECT_IDX]), &Sbk_Phonon_VolumeFaderEffect_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_Phonon_VolumeFaderEffect_Type, "Phonon::VolumeFaderEffect*");
    PyDict_SetItemString(module,"VolumeFaderEffect", (PyObject*)&Sbk_Phonon_VolumeFaderEffect_Type);
    // Initialize enums
    PyObject* enumItem;

    // init enum: FadeCurve
    PyTypeObject* SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve = Shiboken::Enum::newType("PySide.phonon.Phonon.VolumeFaderEffect.FadeCurve");
    SbkPySide_phononTypes[SBK_PHONON_VOLUMEFADEREFFECT_FADECURVE_IDX] = SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve;
    if (PyType_Ready(SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_VolumeFaderEffect_Type.super.ht_type.tp_dict,
            "FadeCurve",((PyObject*)SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve,(long) Phonon::VolumeFaderEffect::Fade3Decibel, "Fade3Decibel");
    PyDict_SetItemString(Sbk_Phonon_VolumeFaderEffect_Type.super.ht_type.tp_dict,"Fade3Decibel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve->tp_dict,"Fade3Decibel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve,(long) Phonon::VolumeFaderEffect::Fade6Decibel, "Fade6Decibel");
    PyDict_SetItemString(Sbk_Phonon_VolumeFaderEffect_Type.super.ht_type.tp_dict,"Fade6Decibel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve->tp_dict,"Fade6Decibel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve,(long) Phonon::VolumeFaderEffect::Fade9Decibel, "Fade9Decibel");
    PyDict_SetItemString(Sbk_Phonon_VolumeFaderEffect_Type.super.ht_type.tp_dict,"Fade9Decibel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve->tp_dict,"Fade9Decibel", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve,(long) Phonon::VolumeFaderEffect::Fade12Decibel, "Fade12Decibel");
    PyDict_SetItemString(Sbk_Phonon_VolumeFaderEffect_Type.super.ht_type.tp_dict,"Fade12Decibel", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_VolumeFaderEffect_FadeCurve->tp_dict,"Fade12Decibel", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::VolumeFaderEffect::FadeCurve");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FadeCurve");
    // end of enum FadeCurve


    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::VolumeFaderEffect >("Phonon::VolumeFaderEffect*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::VolumeFaderEffect >(typeid(Phonon::VolumeFaderEffect).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::VolumeFaderEffect >(typeid(VolumeFaderEffectWrapper).name());
    qRegisterMetaType< ::Phonon::VolumeFaderEffect* >("VolumeFaderEffect*");
    qRegisterMetaType< ::Phonon::VolumeFaderEffect* >("Phonon::VolumeFaderEffect*");
    qRegisterMetaType< ::Phonon::VolumeFaderEffect::FadeCurve >("VolumeFaderEffect::FadeCurve");
    qRegisterMetaType< ::Phonon::VolumeFaderEffect::FadeCurve >("Phonon::VolumeFaderEffect::FadeCurve");
}

